/* @copyright Itential, LLC 2019 (pre-modifications) */

// Set globals
/* global describe it log pronghornProps */
/* eslint global-require: warn */
/* eslint no-unused-vars: warn */
/* eslint import/no-dynamic-require:warn */

// include required items for testing & logging
const assert = require('assert');
const path = require('path');
const util = require('util');
const execute = require('child_process').execSync;
const fs = require('fs-extra');
const mocha = require('mocha');
const winston = require('winston');
const { expect } = require('chai');
const { use } = require('chai');
const td = require('testdouble');
const Ajv = require('ajv');

const ajv = new Ajv({ strictSchema: false, allErrors: true, allowUnionTypes: true });
const anything = td.matchers.anything();
let logLevel = 'none';
const isRapidFail = false;

// read in the properties from the sampleProperties files
let adaptdir = __dirname;
if (adaptdir.endsWith('/test/integration')) {
  adaptdir = adaptdir.substring(0, adaptdir.length - 17);
} else if (adaptdir.endsWith('/test/unit')) {
  adaptdir = adaptdir.substring(0, adaptdir.length - 10);
}
const samProps = require(`${adaptdir}/sampleProperties.json`).properties;

// these variables can be changed to run in integrated mode so easier to set them here
// always check these in with bogus data!!!
samProps.stub = true;

// uncomment if connecting
// samProps.host = 'replace.hostorip.here';
// samProps.authentication.username = 'username';
// samProps.authentication.password = 'password';
// samProps.authentication.token = 'password';
// samProps.protocol = 'http';
// samProps.port = 80;
// samProps.ssl.enabled = false;
// samProps.ssl.accept_invalid_cert = false;

samProps.request.attempt_timeout = 1200000;
const attemptTimeout = samProps.request.attempt_timeout;
const { stub } = samProps;

// these are the adapter properties. You generally should not need to alter
// any of these after they are initially set up
global.pronghornProps = {
  pathProps: {
    encrypted: false
  },
  adapterProps: {
    adapters: [{
      id: 'Test-github',
      type: 'GitHub',
      properties: samProps
    }]
  }
};

global.$HOME = `${__dirname}/../..`;

// set the log levels that Pronghorn uses, spam and trace are not defaulted in so without
// this you may error on log.trace calls.
const myCustomLevels = {
  levels: {
    spam: 6,
    trace: 5,
    debug: 4,
    info: 3,
    warn: 2,
    error: 1,
    none: 0
  }
};

// need to see if there is a log level passed in
process.argv.forEach((val) => {
  // is there a log level defined to be passed in?
  if (val.indexOf('--LOG') === 0) {
    // get the desired log level
    const inputVal = val.split('=')[1];

    // validate the log level is supported, if so set it
    if (Object.hasOwnProperty.call(myCustomLevels.levels, inputVal)) {
      logLevel = inputVal;
    }
  }
});

// need to set global logging
global.log = winston.createLogger({
  level: logLevel,
  levels: myCustomLevels.levels,
  transports: [
    new winston.transports.Console()
  ]
});

/**
 * Runs the error asserts for the test
 */
function runErrorAsserts(data, error, code, origin, displayStr) {
  assert.equal(null, data);
  assert.notEqual(undefined, error);
  assert.notEqual(null, error);
  assert.notEqual(undefined, error.IAPerror);
  assert.notEqual(null, error.IAPerror);
  assert.notEqual(undefined, error.IAPerror.displayString);
  assert.notEqual(null, error.IAPerror.displayString);
  assert.equal(code, error.icode);
  assert.equal(origin, error.IAPerror.origin);
  assert.equal(displayStr, error.IAPerror.displayString);
}

// require the adapter that we are going to be using
const GitHub = require('../../adapter');

// delete the .DS_Store directory in entities -- otherwise this will cause errors
const dirPath = path.join(__dirname, '../../entities/.DS_Store');
if (fs.existsSync(dirPath)) {
  try {
    fs.removeSync(dirPath);
    console.log('.DS_Store deleted');
  } catch (e) {
    console.log('Error when deleting .DS_Store:', e);
  }
}

// begin the testing - these should be pretty well defined between the describe and the it!
describe('[unit] GitHub Adapter Test', () => {
  describe('GitHub Class Tests', () => {
    const a = new GitHub(
      pronghornProps.adapterProps.adapters[0].id,
      pronghornProps.adapterProps.adapters[0].properties
    );

    if (isRapidFail) {
      const state = {};
      state.passed = true;

      mocha.afterEach(function x() {
        state.passed = state.passed
        && (this.currentTest.state === 'passed');
      });
      mocha.beforeEach(function x() {
        if (!state.passed) {
          return this.currentTest.skip();
        }
        return true;
      });
    }

    describe('#class instance created', () => {
      it('should be a class with properties', (done) => {
        try {
          assert.notEqual(null, a);
          assert.notEqual(undefined, a);
          const checkId = global.pronghornProps.adapterProps.adapters[0].id;
          assert.equal(checkId, a.id);
          assert.notEqual(null, a.allProps);
          const check = global.pronghornProps.adapterProps.adapters[0].properties.healthcheck.type;
          assert.equal(check, a.healthcheckType);
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('adapterBase.js', () => {
      it('should have an adapterBase.js', (done) => {
        try {
          fs.exists('adapterBase.js', (val) => {
            assert.equal(true, val);
            done();
          });
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      });
    });

    let wffunctions = [];
    describe('#iapGetAdapterWorkflowFunctions', () => {
      it('should retrieve workflow functions', (done) => {
        try {
          wffunctions = a.iapGetAdapterWorkflowFunctions([]);

          try {
            assert.notEqual(0, wffunctions.length);
            done();
          } catch (err) {
            log.error(`Test Failure: ${err}`);
            done(err);
          }
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('package.json', () => {
      it('should have a package.json', (done) => {
        try {
          fs.exists('package.json', (val) => {
            assert.equal(true, val);
            done();
          });
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      });
      it('package.json should be validated', (done) => {
        try {
          const packageDotJson = require('../../package.json');
          // Define the JSON schema for package.json
          const packageJsonSchema = {
            type: 'object',
            properties: {
              name: { type: 'string' },
              version: { type: 'string' }
              // May need to add more properties as needed
            },
            required: ['name', 'version']
          };
          const validate = ajv.compile(packageJsonSchema);
          const isValid = validate(packageDotJson);

          if (isValid === false) {
            log.error('The package.json contains errors');
            assert.equal(true, isValid);
          } else {
            assert.equal(true, isValid);
          }

          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      });
      it('package.json standard fields should be customized', (done) => {
        try {
          const packageDotJson = require('../../package.json');
          assert.notEqual(-1, packageDotJson.name.indexOf('github'));
          assert.notEqual(undefined, packageDotJson.version);
          assert.notEqual(null, packageDotJson.version);
          assert.notEqual('', packageDotJson.version);
          assert.notEqual(undefined, packageDotJson.description);
          assert.notEqual(null, packageDotJson.description);
          assert.notEqual('', packageDotJson.description);
          assert.equal('adapter.js', packageDotJson.main);
          assert.notEqual(undefined, packageDotJson.wizardVersion);
          assert.notEqual(null, packageDotJson.wizardVersion);
          assert.notEqual('', packageDotJson.wizardVersion);
          assert.notEqual(undefined, packageDotJson.engineVersion);
          assert.notEqual(null, packageDotJson.engineVersion);
          assert.notEqual('', packageDotJson.engineVersion);
          assert.equal('http', packageDotJson.adapterType);
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      });
      it('package.json proper scripts should be provided', (done) => {
        try {
          const packageDotJson = require('../../package.json');
          assert.notEqual(undefined, packageDotJson.scripts);
          assert.notEqual(null, packageDotJson.scripts);
          assert.notEqual('', packageDotJson.scripts);
          assert.equal('node utils/setup.js', packageDotJson.scripts.preinstall);
          assert.equal('node --max_old_space_size=4096 ./node_modules/eslint/bin/eslint.js . --ext .json --ext .js', packageDotJson.scripts.lint);
          assert.equal('node --max_old_space_size=4096 ./node_modules/eslint/bin/eslint.js . --ext .json --ext .js --quiet', packageDotJson.scripts['lint:errors']);
          assert.equal('mocha test/unit/adapterBaseTestUnit.js --LOG=error', packageDotJson.scripts['test:baseunit']);
          assert.equal('mocha test/unit/adapterTestUnit.js --LOG=error', packageDotJson.scripts['test:unit']);
          assert.equal('mocha test/integration/adapterTestIntegration.js --LOG=error', packageDotJson.scripts['test:integration']);
          assert.equal('npm run test:baseunit && npm run test:unit && npm run test:integration', packageDotJson.scripts.test);
          assert.equal('npm publish --registry=https://registry.npmjs.org --access=public', packageDotJson.scripts.deploy);
          assert.equal('npm run deploy', packageDotJson.scripts.build);
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      });
      it('package.json proper directories should be provided', (done) => {
        try {
          const packageDotJson = require('../../package.json');
          assert.notEqual(undefined, packageDotJson.repository);
          assert.notEqual(null, packageDotJson.repository);
          assert.notEqual('', packageDotJson.repository);
          assert.equal('git', packageDotJson.repository.type);
          assert.equal('git@gitlab.com:itentialopensource/adapters/', packageDotJson.repository.url.substring(0, 43));
          assert.equal('https://gitlab.com/itentialopensource/adapters/', packageDotJson.homepage.substring(0, 47));
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      });
      it('package.json proper dependencies should be provided', (done) => {
        try {
          const packageDotJson = require('../../package.json');
          assert.notEqual(undefined, packageDotJson.dependencies);
          assert.notEqual(null, packageDotJson.dependencies);
          assert.notEqual('', packageDotJson.dependencies);
          assert.equal('^8.17.1', packageDotJson.dependencies.ajv);
          assert.equal('^1.7.4', packageDotJson.dependencies.axios);
          assert.equal('^11.0.0', packageDotJson.dependencies.commander);
          assert.equal('^11.2.0', packageDotJson.dependencies['fs-extra']);
          assert.equal('^10.7.3', packageDotJson.dependencies.mocha);
          assert.equal('^2.0.1', packageDotJson.dependencies['mocha-param']);
          assert.equal('^0.4.4', packageDotJson.dependencies.ping);
          assert.equal('^1.4.10', packageDotJson.dependencies['readline-sync']);
          assert.equal('^7.6.3', packageDotJson.dependencies.semver);
          assert.equal('^3.14.2', packageDotJson.dependencies.winston);
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      });
      it('package.json proper dev dependencies should be provided', (done) => {
        try {
          const packageDotJson = require('../../package.json');
          assert.notEqual(undefined, packageDotJson.devDependencies);
          assert.notEqual(null, packageDotJson.devDependencies);
          assert.notEqual('', packageDotJson.devDependencies);
          assert.equal('^4.3.7', packageDotJson.devDependencies.chai);
          assert.equal('^8.44.0', packageDotJson.devDependencies.eslint);
          assert.equal('^15.0.0', packageDotJson.devDependencies['eslint-config-airbnb-base']);
          assert.equal('^2.27.5', packageDotJson.devDependencies['eslint-plugin-import']);
          assert.equal('^3.1.0', packageDotJson.devDependencies['eslint-plugin-json']);
          assert.equal('^3.18.0', packageDotJson.devDependencies.testdouble);
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      });
    });

    describe('pronghorn.json', () => {
      it('should have a pronghorn.json', (done) => {
        try {
          fs.exists('pronghorn.json', (val) => {
            assert.equal(true, val);
            done();
          });
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      });
      it('pronghorn.json should be customized', (done) => {
        try {
          const pronghornDotJson = require('../../pronghorn.json');
          assert.notEqual(-1, pronghornDotJson.id.indexOf('github'));
          assert.equal('Adapter', pronghornDotJson.type);
          assert.equal('GitHub', pronghornDotJson.export);
          assert.equal('GitHub', pronghornDotJson.title);
          assert.equal('adapter.js', pronghornDotJson.src);
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      });
      it('pronghorn.json should contain generic adapter methods', (done) => {
        try {
          const pronghornDotJson = require('../../pronghorn.json');
          assert.notEqual(undefined, pronghornDotJson.methods);
          assert.notEqual(null, pronghornDotJson.methods);
          assert.notEqual('', pronghornDotJson.methods);
          assert.equal(true, Array.isArray(pronghornDotJson.methods));
          assert.notEqual(0, pronghornDotJson.methods.length);
          assert.notEqual(undefined, pronghornDotJson.methods.find((e) => e.name === 'iapUpdateAdapterConfiguration'));
          assert.notEqual(undefined, pronghornDotJson.methods.find((e) => e.name === 'iapSuspendAdapter'));
          assert.notEqual(undefined, pronghornDotJson.methods.find((e) => e.name === 'iapUnsuspendAdapter'));
          assert.notEqual(undefined, pronghornDotJson.methods.find((e) => e.name === 'iapGetAdapterQueue'));
          assert.notEqual(undefined, pronghornDotJson.methods.find((e) => e.name === 'iapFindAdapterPath'));
          assert.notEqual(undefined, pronghornDotJson.methods.find((e) => e.name === 'iapTroubleshootAdapter'));
          assert.notEqual(undefined, pronghornDotJson.methods.find((e) => e.name === 'iapRunAdapterHealthcheck'));
          assert.notEqual(undefined, pronghornDotJson.methods.find((e) => e.name === 'iapRunAdapterConnectivity'));
          assert.notEqual(undefined, pronghornDotJson.methods.find((e) => e.name === 'iapRunAdapterBasicGet'));
          assert.notEqual(undefined, pronghornDotJson.methods.find((e) => e.name === 'iapMoveAdapterEntitiesToDB'));
          assert.notEqual(undefined, pronghornDotJson.methods.find((e) => e.name === 'iapDeactivateTasks'));
          assert.notEqual(undefined, pronghornDotJson.methods.find((e) => e.name === 'iapActivateTasks'));
          assert.notEqual(undefined, pronghornDotJson.methods.find((e) => e.name === 'iapPopulateEntityCache'));
          assert.notEqual(undefined, pronghornDotJson.methods.find((e) => e.name === 'iapRetrieveEntitiesCache'));
          assert.notEqual(undefined, pronghornDotJson.methods.find((e) => e.name === 'getDevice'));
          assert.notEqual(undefined, pronghornDotJson.methods.find((e) => e.name === 'getDevicesFiltered'));
          assert.notEqual(undefined, pronghornDotJson.methods.find((e) => e.name === 'isAlive'));
          assert.notEqual(undefined, pronghornDotJson.methods.find((e) => e.name === 'getConfig'));
          assert.notEqual(undefined, pronghornDotJson.methods.find((e) => e.name === 'iapGetDeviceCount'));
          assert.notEqual(undefined, pronghornDotJson.methods.find((e) => e.name === 'iapExpandedGenericAdapterRequest'));
          assert.notEqual(undefined, pronghornDotJson.methods.find((e) => e.name === 'genericAdapterRequest'));
          assert.notEqual(undefined, pronghornDotJson.methods.find((e) => e.name === 'genericAdapterRequestNoBasePath'));
          assert.notEqual(undefined, pronghornDotJson.methods.find((e) => e.name === 'iapRunAdapterLint'));
          assert.notEqual(undefined, pronghornDotJson.methods.find((e) => e.name === 'iapRunAdapterTests'));
          assert.notEqual(undefined, pronghornDotJson.methods.find((e) => e.name === 'iapGetAdapterInventory'));
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      });
      it('pronghorn.json should only expose workflow functions', (done) => {
        try {
          const pronghornDotJson = require('../../pronghorn.json');

          for (let m = 0; m < pronghornDotJson.methods.length; m += 1) {
            let found = false;
            let paramissue = false;

            for (let w = 0; w < wffunctions.length; w += 1) {
              if (pronghornDotJson.methods[m].name === wffunctions[w]) {
                found = true;
                const methLine = execute(`grep "  ${wffunctions[w]}(" adapter.js | grep "callback) {"`).toString();
                let wfparams = [];

                if (methLine && methLine.indexOf('(') >= 0 && methLine.indexOf(')') >= 0) {
                  const temp = methLine.substring(methLine.indexOf('(') + 1, methLine.lastIndexOf(')'));
                  wfparams = temp.split(',');

                  for (let t = 0; t < wfparams.length; t += 1) {
                    // remove default value from the parameter name
                    wfparams[t] = wfparams[t].substring(0, wfparams[t].search(/=/) > 0 ? wfparams[t].search(/#|\?|=/) : wfparams[t].length);
                    // remove spaces
                    wfparams[t] = wfparams[t].trim();

                    if (wfparams[t] === 'callback') {
                      wfparams.splice(t, 1);
                    }
                  }
                }

                // if there are inputs defined but not on the method line
                if (wfparams.length === 0 && (pronghornDotJson.methods[m].input
                    && pronghornDotJson.methods[m].input.length > 0)) {
                  paramissue = true;
                } else if (wfparams.length > 0 && (!pronghornDotJson.methods[m].input
                    || pronghornDotJson.methods[m].input.length === 0)) {
                  // if there are no inputs defined but there are on the method line
                  paramissue = true;
                } else {
                  for (let p = 0; p < pronghornDotJson.methods[m].input.length; p += 1) {
                    let pfound = false;
                    for (let wfp = 0; wfp < wfparams.length; wfp += 1) {
                      if (pronghornDotJson.methods[m].input[p].name.toUpperCase() === wfparams[wfp].toUpperCase()) {
                        pfound = true;
                      }
                    }

                    if (!pfound) {
                      paramissue = true;
                    }
                  }
                  for (let wfp = 0; wfp < wfparams.length; wfp += 1) {
                    let pfound = false;
                    for (let p = 0; p < pronghornDotJson.methods[m].input.length; p += 1) {
                      if (pronghornDotJson.methods[m].input[p].name.toUpperCase() === wfparams[wfp].toUpperCase()) {
                        pfound = true;
                      }
                    }

                    if (!pfound) {
                      paramissue = true;
                    }
                  }
                }

                break;
              }
            }

            if (!found) {
              // this is the reason to go through both loops - log which ones are not found so
              // they can be worked
              log.error(`${pronghornDotJson.methods[m].name} not found in workflow functions`);
            }
            if (paramissue) {
              // this is the reason to go through both loops - log which ones are not found so
              // they can be worked
              log.error(`${pronghornDotJson.methods[m].name} has a parameter mismatch`);
            }
            assert.equal(true, found);
            assert.equal(false, paramissue);
          }
          done();
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('pronghorn.json should expose all workflow functions', (done) => {
        try {
          const pronghornDotJson = require('../../pronghorn.json');
          for (let w = 0; w < wffunctions.length; w += 1) {
            let found = false;

            for (let m = 0; m < pronghornDotJson.methods.length; m += 1) {
              if (pronghornDotJson.methods[m].name === wffunctions[w]) {
                found = true;
                break;
              }
            }

            if (!found) {
              // this is the reason to go through both loops - log which ones are not found so
              // they can be worked
              log.error(`${wffunctions[w]} not found in pronghorn.json`);
            }
            assert.equal(true, found);
          }
          done();
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      });
      it('pronghorn.json verify input/output schema objects', (done) => {
        const verifySchema = (methodName, schema) => {
          try {
            ajv.compile(schema);
          } catch (error) {
            const errorMessage = `Invalid schema found in '${methodName}' method.
          Schema => ${JSON.stringify(schema)}.
          Details => ${error.message}`;
            throw new Error(errorMessage);
          }
        };

        try {
          const pronghornDotJson = require('../../pronghorn.json');
          const { methods } = pronghornDotJson;
          for (let i = 0; i < methods.length; i += 1) {
            for (let j = 0; j < methods[i].input.length; j += 1) {
              const inputSchema = methods[i].input[j].schema;
              if (inputSchema) {
                verifySchema(methods[i].name, inputSchema);
              }
            }
            const outputSchema = methods[i].output.schema;
            if (outputSchema) {
              verifySchema(methods[i].name, outputSchema);
            }
          }
          done();
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('propertiesSchema.json', () => {
      it('should have a propertiesSchema.json', (done) => {
        try {
          fs.exists('propertiesSchema.json', (val) => {
            assert.equal(true, val);
            done();
          });
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      });
      it('propertiesSchema.json should be customized', (done) => {
        try {
          const propertiesDotJson = require('../../propertiesSchema.json');
          assert.equal('adapter-github', propertiesDotJson.$id);
          assert.equal('object', propertiesDotJson.type);
          assert.equal('http://json-schema.org/draft-07/schema#', propertiesDotJson.$schema);
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      });
      it('propertiesSchema.json should contain generic adapter properties', (done) => {
        try {
          const propertiesDotJson = require('../../propertiesSchema.json');
          assert.notEqual(undefined, propertiesDotJson.properties);
          assert.notEqual(null, propertiesDotJson.properties);
          assert.notEqual('', propertiesDotJson.properties);
          assert.equal('string', propertiesDotJson.properties.host.type);
          assert.equal('integer', propertiesDotJson.properties.port.type);
          assert.equal('boolean', propertiesDotJson.properties.stub.type);
          assert.equal('string', propertiesDotJson.properties.protocol.type);
          assert.notEqual(undefined, propertiesDotJson.definitions.authentication);
          assert.notEqual(null, propertiesDotJson.definitions.authentication);
          assert.notEqual('', propertiesDotJson.definitions.authentication);
          assert.equal('string', propertiesDotJson.definitions.authentication.properties.auth_method.type);
          assert.equal('string', propertiesDotJson.definitions.authentication.properties.username.type);
          assert.equal('string', propertiesDotJson.definitions.authentication.properties.password.type);
          assert.equal('string', propertiesDotJson.definitions.authentication.properties.token.type);
          assert.equal('integer', propertiesDotJson.definitions.authentication.properties.invalid_token_error.type);
          assert.equal('integer', propertiesDotJson.definitions.authentication.properties.token_timeout.type);
          assert.equal('string', propertiesDotJson.definitions.authentication.properties.token_cache.type);
          assert.equal(true, Array.isArray(propertiesDotJson.definitions.authentication.properties.auth_field.type));
          assert.equal(true, Array.isArray(propertiesDotJson.definitions.authentication.properties.auth_field_format.type));
          assert.equal('boolean', propertiesDotJson.definitions.authentication.properties.auth_logging.type);
          assert.equal('string', propertiesDotJson.definitions.authentication.properties.client_id.type);
          assert.equal('string', propertiesDotJson.definitions.authentication.properties.client_secret.type);
          assert.equal('string', propertiesDotJson.definitions.authentication.properties.grant_type.type);
          assert.notEqual(undefined, propertiesDotJson.definitions.ssl);
          assert.notEqual(null, propertiesDotJson.definitions.ssl);
          assert.notEqual('', propertiesDotJson.definitions.ssl);
          assert.equal('string', propertiesDotJson.definitions.ssl.properties.ecdhCurve.type);
          assert.equal('boolean', propertiesDotJson.definitions.ssl.properties.enabled.type);
          assert.equal('boolean', propertiesDotJson.definitions.ssl.properties.accept_invalid_cert.type);
          assert.equal('string', propertiesDotJson.definitions.ssl.properties.ca_file.type);
          assert.equal('string', propertiesDotJson.definitions.ssl.properties.key_file.type);
          assert.equal('string', propertiesDotJson.definitions.ssl.properties.cert_file.type);
          assert.equal('string', propertiesDotJson.definitions.ssl.properties.secure_protocol.type);
          assert.equal('string', propertiesDotJson.definitions.ssl.properties.ciphers.type);
          assert.equal('string', propertiesDotJson.properties.base_path.type);
          assert.equal('string', propertiesDotJson.properties.version.type);
          assert.equal('string', propertiesDotJson.properties.cache_location.type);
          assert.equal('boolean', propertiesDotJson.properties.encode_pathvars.type);
          assert.equal('boolean', propertiesDotJson.properties.encode_queryvars.type);
          assert.equal(true, Array.isArray(propertiesDotJson.properties.save_metric.type));
          assert.notEqual(undefined, propertiesDotJson.definitions);
          assert.notEqual(null, propertiesDotJson.definitions);
          assert.notEqual('', propertiesDotJson.definitions);
          assert.notEqual(undefined, propertiesDotJson.definitions.healthcheck);
          assert.notEqual(null, propertiesDotJson.definitions.healthcheck);
          assert.notEqual('', propertiesDotJson.definitions.healthcheck);
          assert.equal('string', propertiesDotJson.definitions.healthcheck.properties.type.type);
          assert.equal('integer', propertiesDotJson.definitions.healthcheck.properties.frequency.type);
          assert.equal('object', propertiesDotJson.definitions.healthcheck.properties.query_object.type);
          assert.notEqual(undefined, propertiesDotJson.definitions.throttle);
          assert.notEqual(null, propertiesDotJson.definitions.throttle);
          assert.notEqual('', propertiesDotJson.definitions.throttle);
          assert.equal('boolean', propertiesDotJson.definitions.throttle.properties.throttle_enabled.type);
          assert.equal('integer', propertiesDotJson.definitions.throttle.properties.number_pronghorns.type);
          assert.equal('string', propertiesDotJson.definitions.throttle.properties.sync_async.type);
          assert.equal('integer', propertiesDotJson.definitions.throttle.properties.max_in_queue.type);
          assert.equal('integer', propertiesDotJson.definitions.throttle.properties.concurrent_max.type);
          assert.equal('integer', propertiesDotJson.definitions.throttle.properties.expire_timeout.type);
          assert.equal('integer', propertiesDotJson.definitions.throttle.properties.avg_runtime.type);
          assert.equal('array', propertiesDotJson.definitions.throttle.properties.priorities.type);
          assert.notEqual(undefined, propertiesDotJson.definitions.request);
          assert.notEqual(null, propertiesDotJson.definitions.request);
          assert.notEqual('', propertiesDotJson.definitions.request);
          assert.equal('integer', propertiesDotJson.definitions.request.properties.number_redirects.type);
          assert.equal('integer', propertiesDotJson.definitions.request.properties.number_retries.type);
          assert.equal(true, Array.isArray(propertiesDotJson.definitions.request.properties.limit_retry_error.type));
          assert.equal('array', propertiesDotJson.definitions.request.properties.failover_codes.type);
          assert.equal('integer', propertiesDotJson.definitions.request.properties.attempt_timeout.type);
          assert.equal('object', propertiesDotJson.definitions.request.properties.global_request.type);
          assert.equal('object', propertiesDotJson.definitions.request.properties.global_request.properties.payload.type);
          assert.equal('object', propertiesDotJson.definitions.request.properties.global_request.properties.uriOptions.type);
          assert.equal('object', propertiesDotJson.definitions.request.properties.global_request.properties.addlHeaders.type);
          assert.equal('object', propertiesDotJson.definitions.request.properties.global_request.properties.authData.type);
          assert.equal('boolean', propertiesDotJson.definitions.request.properties.healthcheck_on_timeout.type);
          assert.equal('boolean', propertiesDotJson.definitions.request.properties.return_raw.type);
          assert.equal('boolean', propertiesDotJson.definitions.request.properties.archiving.type);
          assert.equal('boolean', propertiesDotJson.definitions.request.properties.return_request.type);
          assert.notEqual(undefined, propertiesDotJson.definitions.proxy);
          assert.notEqual(null, propertiesDotJson.definitions.proxy);
          assert.notEqual('', propertiesDotJson.definitions.proxy);
          assert.equal('boolean', propertiesDotJson.definitions.proxy.properties.enabled.type);
          assert.equal('string', propertiesDotJson.definitions.proxy.properties.host.type);
          assert.equal('integer', propertiesDotJson.definitions.proxy.properties.port.type);
          assert.equal('string', propertiesDotJson.definitions.proxy.properties.protocol.type);
          assert.equal('string', propertiesDotJson.definitions.proxy.properties.username.type);
          assert.equal('string', propertiesDotJson.definitions.proxy.properties.password.type);
          assert.notEqual(undefined, propertiesDotJson.definitions.mongo);
          assert.notEqual(null, propertiesDotJson.definitions.mongo);
          assert.notEqual('', propertiesDotJson.definitions.mongo);
          assert.equal('string', propertiesDotJson.definitions.mongo.properties.host.type);
          assert.equal('integer', propertiesDotJson.definitions.mongo.properties.port.type);
          assert.equal('string', propertiesDotJson.definitions.mongo.properties.database.type);
          assert.equal('string', propertiesDotJson.definitions.mongo.properties.username.type);
          assert.equal('string', propertiesDotJson.definitions.mongo.properties.password.type);
          assert.equal('string', propertiesDotJson.definitions.mongo.properties.replSet.type);
          assert.equal('object', propertiesDotJson.definitions.mongo.properties.db_ssl.type);
          assert.equal('boolean', propertiesDotJson.definitions.mongo.properties.db_ssl.properties.enabled.type);
          assert.equal('boolean', propertiesDotJson.definitions.mongo.properties.db_ssl.properties.accept_invalid_cert.type);
          assert.equal('string', propertiesDotJson.definitions.mongo.properties.db_ssl.properties.ca_file.type);
          assert.equal('string', propertiesDotJson.definitions.mongo.properties.db_ssl.properties.key_file.type);
          assert.equal('string', propertiesDotJson.definitions.mongo.properties.db_ssl.properties.cert_file.type);
          assert.notEqual('', propertiesDotJson.definitions.devicebroker);
          assert.equal('array', propertiesDotJson.definitions.devicebroker.properties.getDevice.type);
          assert.equal('array', propertiesDotJson.definitions.devicebroker.properties.getDevicesFiltered.type);
          assert.equal('array', propertiesDotJson.definitions.devicebroker.properties.isAlive.type);
          assert.equal('array', propertiesDotJson.definitions.devicebroker.properties.getConfig.type);
          assert.equal('array', propertiesDotJson.definitions.devicebroker.properties.getCount.type);
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      });
    });

    describe('error.json', () => {
      it('should have an error.json', (done) => {
        try {
          fs.exists('error.json', (val) => {
            assert.equal(true, val);
            done();
          });
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      });
      it('error.json should have standard adapter errors', (done) => {
        try {
          const errorDotJson = require('../../error.json');
          assert.notEqual(undefined, errorDotJson.errors);
          assert.notEqual(null, errorDotJson.errors);
          assert.notEqual('', errorDotJson.errors);
          assert.equal(true, Array.isArray(errorDotJson.errors));
          assert.notEqual(0, errorDotJson.errors.length);
          assert.notEqual(undefined, errorDotJson.errors.find((e) => e.icode === 'AD.100'));
          assert.notEqual(undefined, errorDotJson.errors.find((e) => e.icode === 'AD.101'));
          assert.notEqual(undefined, errorDotJson.errors.find((e) => e.icode === 'AD.102'));
          assert.notEqual(undefined, errorDotJson.errors.find((e) => e.icode === 'AD.110'));
          assert.notEqual(undefined, errorDotJson.errors.find((e) => e.icode === 'AD.111'));
          assert.notEqual(undefined, errorDotJson.errors.find((e) => e.icode === 'AD.112'));
          assert.notEqual(undefined, errorDotJson.errors.find((e) => e.icode === 'AD.113'));
          assert.notEqual(undefined, errorDotJson.errors.find((e) => e.icode === 'AD.114'));
          assert.notEqual(undefined, errorDotJson.errors.find((e) => e.icode === 'AD.115'));
          assert.notEqual(undefined, errorDotJson.errors.find((e) => e.icode === 'AD.116'));
          assert.notEqual(undefined, errorDotJson.errors.find((e) => e.icode === 'AD.300'));
          assert.notEqual(undefined, errorDotJson.errors.find((e) => e.icode === 'AD.301'));
          assert.notEqual(undefined, errorDotJson.errors.find((e) => e.icode === 'AD.302'));
          assert.notEqual(undefined, errorDotJson.errors.find((e) => e.icode === 'AD.303'));
          assert.notEqual(undefined, errorDotJson.errors.find((e) => e.icode === 'AD.304'));
          assert.notEqual(undefined, errorDotJson.errors.find((e) => e.icode === 'AD.305'));
          assert.notEqual(undefined, errorDotJson.errors.find((e) => e.icode === 'AD.310'));
          assert.notEqual(undefined, errorDotJson.errors.find((e) => e.icode === 'AD.311'));
          assert.notEqual(undefined, errorDotJson.errors.find((e) => e.icode === 'AD.312'));
          assert.notEqual(undefined, errorDotJson.errors.find((e) => e.icode === 'AD.320'));
          assert.notEqual(undefined, errorDotJson.errors.find((e) => e.icode === 'AD.321'));
          assert.notEqual(undefined, errorDotJson.errors.find((e) => e.icode === 'AD.400'));
          assert.notEqual(undefined, errorDotJson.errors.find((e) => e.icode === 'AD.401'));
          assert.notEqual(undefined, errorDotJson.errors.find((e) => e.icode === 'AD.402'));
          assert.notEqual(undefined, errorDotJson.errors.find((e) => e.icode === 'AD.500'));
          assert.notEqual(undefined, errorDotJson.errors.find((e) => e.icode === 'AD.501'));
          assert.notEqual(undefined, errorDotJson.errors.find((e) => e.icode === 'AD.502'));
          assert.notEqual(undefined, errorDotJson.errors.find((e) => e.icode === 'AD.503'));
          assert.notEqual(undefined, errorDotJson.errors.find((e) => e.icode === 'AD.600'));
          assert.notEqual(undefined, errorDotJson.errors.find((e) => e.icode === 'AD.900'));
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      });
    });

    describe('sampleProperties.json', () => {
      it('should have a sampleProperties.json', (done) => {
        try {
          fs.exists('sampleProperties.json', (val) => {
            assert.equal(true, val);
            done();
          });
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      });
      it('sampleProperties.json should contain generic adapter properties', (done) => {
        try {
          const sampleDotJson = require('../../sampleProperties.json');
          assert.notEqual(-1, sampleDotJson.id.indexOf('github'));
          assert.equal('GitHub', sampleDotJson.type);
          assert.notEqual(undefined, sampleDotJson.properties);
          assert.notEqual(null, sampleDotJson.properties);
          assert.notEqual('', sampleDotJson.properties);
          assert.notEqual(undefined, sampleDotJson.properties.host);
          assert.notEqual(undefined, sampleDotJson.properties.port);
          assert.notEqual(undefined, sampleDotJson.properties.stub);
          assert.notEqual(undefined, sampleDotJson.properties.protocol);
          assert.notEqual(undefined, sampleDotJson.properties.authentication);
          assert.notEqual(null, sampleDotJson.properties.authentication);
          assert.notEqual('', sampleDotJson.properties.authentication);
          assert.notEqual(undefined, sampleDotJson.properties.authentication.auth_method);
          assert.notEqual(undefined, sampleDotJson.properties.authentication.username);
          assert.notEqual(undefined, sampleDotJson.properties.authentication.password);
          assert.notEqual(undefined, sampleDotJson.properties.authentication.token);
          assert.notEqual(undefined, sampleDotJson.properties.authentication.invalid_token_error);
          assert.notEqual(undefined, sampleDotJson.properties.authentication.token_timeout);
          assert.notEqual(undefined, sampleDotJson.properties.authentication.token_cache);
          assert.notEqual(undefined, sampleDotJson.properties.authentication.auth_field);
          assert.notEqual(undefined, sampleDotJson.properties.authentication.auth_field_format);
          assert.notEqual(undefined, sampleDotJson.properties.authentication.auth_logging);
          assert.notEqual(undefined, sampleDotJson.properties.authentication.client_id);
          assert.notEqual(undefined, sampleDotJson.properties.authentication.client_secret);
          assert.notEqual(undefined, sampleDotJson.properties.authentication.grant_type);
          assert.notEqual(undefined, sampleDotJson.properties.ssl);
          assert.notEqual(null, sampleDotJson.properties.ssl);
          assert.notEqual('', sampleDotJson.properties.ssl);
          assert.notEqual(undefined, sampleDotJson.properties.ssl.ecdhCurve);
          assert.notEqual(undefined, sampleDotJson.properties.ssl.enabled);
          assert.notEqual(undefined, sampleDotJson.properties.ssl.accept_invalid_cert);
          assert.notEqual(undefined, sampleDotJson.properties.ssl.ca_file);
          assert.notEqual(undefined, sampleDotJson.properties.ssl.key_file);
          assert.notEqual(undefined, sampleDotJson.properties.ssl.cert_file);
          assert.notEqual(undefined, sampleDotJson.properties.ssl.secure_protocol);
          assert.notEqual(undefined, sampleDotJson.properties.ssl.ciphers);
          assert.notEqual(undefined, sampleDotJson.properties.base_path);
          assert.notEqual(undefined, sampleDotJson.properties.version);
          assert.notEqual(undefined, sampleDotJson.properties.cache_location);
          assert.notEqual(undefined, sampleDotJson.properties.encode_pathvars);
          assert.notEqual(undefined, sampleDotJson.properties.encode_queryvars);
          assert.notEqual(undefined, sampleDotJson.properties.save_metric);
          assert.notEqual(undefined, sampleDotJson.properties.healthcheck);
          assert.notEqual(null, sampleDotJson.properties.healthcheck);
          assert.notEqual('', sampleDotJson.properties.healthcheck);
          assert.notEqual(undefined, sampleDotJson.properties.healthcheck.type);
          assert.notEqual(undefined, sampleDotJson.properties.healthcheck.frequency);
          assert.notEqual(undefined, sampleDotJson.properties.healthcheck.query_object);
          assert.notEqual(undefined, sampleDotJson.properties.throttle);
          assert.notEqual(null, sampleDotJson.properties.throttle);
          assert.notEqual('', sampleDotJson.properties.throttle);
          assert.notEqual(undefined, sampleDotJson.properties.throttle.throttle_enabled);
          assert.notEqual(undefined, sampleDotJson.properties.throttle.number_pronghorns);
          assert.notEqual(undefined, sampleDotJson.properties.throttle.sync_async);
          assert.notEqual(undefined, sampleDotJson.properties.throttle.max_in_queue);
          assert.notEqual(undefined, sampleDotJson.properties.throttle.concurrent_max);
          assert.notEqual(undefined, sampleDotJson.properties.throttle.expire_timeout);
          assert.notEqual(undefined, sampleDotJson.properties.throttle.avg_runtime);
          assert.notEqual(undefined, sampleDotJson.properties.throttle.priorities);
          assert.notEqual(undefined, sampleDotJson.properties.request);
          assert.notEqual(null, sampleDotJson.properties.request);
          assert.notEqual('', sampleDotJson.properties.request);
          assert.notEqual(undefined, sampleDotJson.properties.request.number_redirects);
          assert.notEqual(undefined, sampleDotJson.properties.request.number_retries);
          assert.notEqual(undefined, sampleDotJson.properties.request.limit_retry_error);
          assert.notEqual(undefined, sampleDotJson.properties.request.failover_codes);
          assert.notEqual(undefined, sampleDotJson.properties.request.attempt_timeout);
          assert.notEqual(undefined, sampleDotJson.properties.request.global_request);
          assert.notEqual(undefined, sampleDotJson.properties.request.global_request.payload);
          assert.notEqual(undefined, sampleDotJson.properties.request.global_request.uriOptions);
          assert.notEqual(undefined, sampleDotJson.properties.request.global_request.addlHeaders);
          assert.notEqual(undefined, sampleDotJson.properties.request.global_request.authData);
          assert.notEqual(undefined, sampleDotJson.properties.request.healthcheck_on_timeout);
          assert.notEqual(undefined, sampleDotJson.properties.request.return_raw);
          assert.notEqual(undefined, sampleDotJson.properties.request.archiving);
          assert.notEqual(undefined, sampleDotJson.properties.request.return_request);
          assert.notEqual(undefined, sampleDotJson.properties.proxy);
          assert.notEqual(null, sampleDotJson.properties.proxy);
          assert.notEqual('', sampleDotJson.properties.proxy);
          assert.notEqual(undefined, sampleDotJson.properties.proxy.enabled);
          assert.notEqual(undefined, sampleDotJson.properties.proxy.host);
          assert.notEqual(undefined, sampleDotJson.properties.proxy.port);
          assert.notEqual(undefined, sampleDotJson.properties.proxy.protocol);
          assert.notEqual(undefined, sampleDotJson.properties.proxy.username);
          assert.notEqual(undefined, sampleDotJson.properties.proxy.password);
          assert.notEqual(undefined, sampleDotJson.properties.mongo);
          assert.notEqual(null, sampleDotJson.properties.mongo);
          assert.notEqual('', sampleDotJson.properties.mongo);
          assert.notEqual(undefined, sampleDotJson.properties.mongo.host);
          assert.notEqual(undefined, sampleDotJson.properties.mongo.port);
          assert.notEqual(undefined, sampleDotJson.properties.mongo.database);
          assert.notEqual(undefined, sampleDotJson.properties.mongo.username);
          assert.notEqual(undefined, sampleDotJson.properties.mongo.password);
          assert.notEqual(undefined, sampleDotJson.properties.mongo.replSet);
          assert.notEqual(undefined, sampleDotJson.properties.mongo.db_ssl);
          assert.notEqual(undefined, sampleDotJson.properties.mongo.db_ssl.enabled);
          assert.notEqual(undefined, sampleDotJson.properties.mongo.db_ssl.accept_invalid_cert);
          assert.notEqual(undefined, sampleDotJson.properties.mongo.db_ssl.ca_file);
          assert.notEqual(undefined, sampleDotJson.properties.mongo.db_ssl.key_file);
          assert.notEqual(undefined, sampleDotJson.properties.mongo.db_ssl.cert_file);
          assert.notEqual(undefined, sampleDotJson.properties.devicebroker);
          assert.notEqual(undefined, sampleDotJson.properties.devicebroker.getDevice);
          assert.notEqual(undefined, sampleDotJson.properties.devicebroker.getDevicesFiltered);
          assert.notEqual(undefined, sampleDotJson.properties.devicebroker.isAlive);
          assert.notEqual(undefined, sampleDotJson.properties.devicebroker.getConfig);
          assert.notEqual(undefined, sampleDotJson.properties.devicebroker.getCount);
          assert.notEqual(undefined, sampleDotJson.properties.cache);
          assert.notEqual(undefined, sampleDotJson.properties.cache.entities);
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      });
    });

    describe('#checkProperties', () => {
      it('should have a checkProperties function', (done) => {
        try {
          assert.equal(true, typeof a.checkProperties === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      });
      it('the sample properties should be good - if failure change the log level', (done) => {
        try {
          const samplePropsJson = require('../../sampleProperties.json');
          const clean = a.checkProperties(samplePropsJson.properties);

          try {
            assert.notEqual(0, Object.keys(clean));
            assert.equal(undefined, clean.exception);
            assert.notEqual(undefined, clean.host);
            assert.notEqual(null, clean.host);
            assert.notEqual('', clean.host);
            done();
          } catch (err) {
            log.error(`Test Failure: ${err}`);
            done(err);
          }
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('README.md', () => {
      it('should have a README', (done) => {
        try {
          fs.exists('README.md', (val) => {
            assert.equal(true, val);
            done();
          });
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      });
      it('README.md should be customized', (done) => {
        try {
          fs.readFile('README.md', 'utf8', (err, data) => {
            assert.equal(-1, data.indexOf('[System]'));
            assert.equal(-1, data.indexOf('[system]'));
            assert.equal(-1, data.indexOf('[version]'));
            assert.equal(-1, data.indexOf('[namespace]'));
            done();
          });
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      });
    });

    describe('#connect', () => {
      it('should have a connect function', (done) => {
        try {
          assert.equal(true, typeof a.connect === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      });
    });

    describe('#healthCheck', () => {
      it('should have a healthCheck function', (done) => {
        try {
          assert.equal(true, typeof a.healthCheck === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      });
    });

    describe('#iapUpdateAdapterConfiguration', () => {
      it('should have a iapUpdateAdapterConfiguration function', (done) => {
        try {
          assert.equal(true, typeof a.iapUpdateAdapterConfiguration === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      });
    });

    describe('#iapSuspendAdapter', () => {
      it('should have a iapSuspendAdapter function', (done) => {
        try {
          assert.equal(true, typeof a.iapSuspendAdapter === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      });
    });

    describe('#iapUnsuspendAdapter', () => {
      it('should have a iapUnsuspendAdapter function', (done) => {
        try {
          assert.equal(true, typeof a.iapUnsuspendAdapter === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      });
    });

    describe('#iapGetAdapterQueue', () => {
      it('should have a iapGetAdapterQueue function', (done) => {
        try {
          assert.equal(true, typeof a.iapGetAdapterQueue === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      });
    });

    describe('#iapFindAdapterPath', () => {
      it('should have a iapFindAdapterPath function', (done) => {
        try {
          assert.equal(true, typeof a.iapFindAdapterPath === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      });
      it('iapFindAdapterPath should find atleast one path that matches', (done) => {
        try {
          a.iapFindAdapterPath('{base_path}/{version}', (data, error) => {
            try {
              assert.equal(undefined, error);
              assert.notEqual(undefined, data);
              assert.notEqual(null, data);
              assert.equal(true, data.found);
              assert.notEqual(undefined, data.foundIn);
              assert.notEqual(null, data.foundIn);
              assert.notEqual(0, data.foundIn.length);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#iapTroubleshootAdapter', () => {
      it('should have a iapTroubleshootAdapter function', (done) => {
        try {
          assert.equal(true, typeof a.iapTroubleshootAdapter === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      });
    });

    describe('#iapRunAdapterHealthcheck', () => {
      it('should have a iapRunAdapterHealthcheck function', (done) => {
        try {
          assert.equal(true, typeof a.iapRunAdapterHealthcheck === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      });
    });

    describe('#iapRunAdapterConnectivity', () => {
      it('should have a iapRunAdapterConnectivity function', (done) => {
        try {
          assert.equal(true, typeof a.iapRunAdapterConnectivity === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      });
    });

    describe('#iapRunAdapterBasicGet', () => {
      it('should have a iapRunAdapterBasicGet function', (done) => {
        try {
          assert.equal(true, typeof a.iapRunAdapterBasicGet === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      });
    });

    describe('#iapMoveAdapterEntitiesToDB', () => {
      it('should have a iapMoveAdapterEntitiesToDB function', (done) => {
        try {
          assert.equal(true, typeof a.iapMoveAdapterEntitiesToDB === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      });
    });

    describe('#checkActionFiles', () => {
      it('should have a checkActionFiles function', (done) => {
        try {
          assert.equal(true, typeof a.checkActionFiles === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      });
      it('the action files should be good - if failure change the log level as most issues are warnings', (done) => {
        try {
          const clean = a.checkActionFiles();

          try {
            for (let c = 0; c < clean.length; c += 1) {
              log.error(clean[c]);
            }
            assert.equal(0, clean.length);
            done();
          } catch (err) {
            log.error(`Test Failure: ${err}`);
            done(err);
          }
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#encryptProperty', () => {
      it('should have a encryptProperty function', (done) => {
        try {
          assert.equal(true, typeof a.encryptProperty === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      });
      it('should get base64 encoded property', (done) => {
        try {
          a.encryptProperty('testing', 'base64', (data, error) => {
            try {
              assert.equal(undefined, error);
              assert.notEqual(undefined, data);
              assert.notEqual(null, data);
              assert.notEqual(undefined, data.response);
              assert.notEqual(null, data.response);
              assert.equal(0, data.response.indexOf('{code}'));
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should get encrypted property', (done) => {
        try {
          a.encryptProperty('testing', 'encrypt', (data, error) => {
            try {
              assert.equal(undefined, error);
              assert.notEqual(undefined, data);
              assert.notEqual(null, data);
              assert.notEqual(undefined, data.response);
              assert.notEqual(null, data.response);
              assert.equal(0, data.response.indexOf('{crypt}'));
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#iapDeactivateTasks', () => {
      it('should have a iapDeactivateTasks function', (done) => {
        try {
          assert.equal(true, typeof a.iapDeactivateTasks === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      });
    });

    describe('#iapActivateTasks', () => {
      it('should have a iapActivateTasks function', (done) => {
        try {
          assert.equal(true, typeof a.iapActivateTasks === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      });
    });

    describe('#iapPopulateEntityCache', () => {
      it('should have a iapPopulateEntityCache function', (done) => {
        try {
          assert.equal(true, typeof a.iapPopulateEntityCache === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      });
    });

    describe('#iapRetrieveEntitiesCache', () => {
      it('should have a iapRetrieveEntitiesCache function', (done) => {
        try {
          assert.equal(true, typeof a.iapRetrieveEntitiesCache === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      });
    });

    describe('#hasEntities', () => {
      it('should have a hasEntities function', (done) => {
        try {
          assert.equal(true, typeof a.hasEntities === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      });
    });

    describe('#getDevice', () => {
      it('should have a getDevice function', (done) => {
        try {
          assert.equal(true, typeof a.getDevice === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      });
    });

    describe('#getDevicesFiltered', () => {
      it('should have a getDevicesFiltered function', (done) => {
        try {
          assert.equal(true, typeof a.getDevicesFiltered === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      });
    });

    describe('#isAlive', () => {
      it('should have a isAlive function', (done) => {
        try {
          assert.equal(true, typeof a.isAlive === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      });
    });

    describe('#getConfig', () => {
      it('should have a getConfig function', (done) => {
        try {
          assert.equal(true, typeof a.getConfig === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      });
    });

    describe('#iapGetDeviceCount', () => {
      it('should have a iapGetDeviceCount function', (done) => {
        try {
          assert.equal(true, typeof a.iapGetDeviceCount === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      });
    });

    describe('#iapExpandedGenericAdapterRequest', () => {
      it('should have a iapExpandedGenericAdapterRequest function', (done) => {
        try {
          assert.equal(true, typeof a.iapExpandedGenericAdapterRequest === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      });
    });

    describe('#genericAdapterRequest', () => {
      it('should have a genericAdapterRequest function', (done) => {
        try {
          assert.equal(true, typeof a.genericAdapterRequest === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      });
    });

    describe('#genericAdapterRequestNoBasePath', () => {
      it('should have a genericAdapterRequestNoBasePath function', (done) => {
        try {
          assert.equal(true, typeof a.genericAdapterRequestNoBasePath === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      });
    });

    describe('#iapRunAdapterLint', () => {
      it('should have a iapRunAdapterLint function', (done) => {
        try {
          assert.equal(true, typeof a.iapRunAdapterLint === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      });
      it('retrieve the lint results', (done) => {
        try {
          a.iapRunAdapterLint((data, error) => {
            try {
              assert.equal(undefined, error);
              assert.notEqual(undefined, data);
              assert.notEqual(null, data);
              assert.notEqual(undefined, data.status);
              assert.notEqual(null, data.status);
              assert.equal('SUCCESS', data.status);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#iapRunAdapterTests', () => {
      it('should have a iapRunAdapterTests function', (done) => {
        try {
          assert.equal(true, typeof a.iapRunAdapterTests === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      });
    });

    describe('#iapGetAdapterInventory', () => {
      it('should have a iapGetAdapterInventory function', (done) => {
        try {
          assert.equal(true, typeof a.iapGetAdapterInventory === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      });
      it('retrieve the inventory', (done) => {
        try {
          a.iapGetAdapterInventory((data, error) => {
            try {
              assert.equal(undefined, error);
              assert.notEqual(undefined, data);
              assert.notEqual(null, data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });
    describe('metadata.json', () => {
      it('should have a metadata.json', (done) => {
        try {
          fs.exists('metadata.json', (val) => {
            assert.equal(true, val);
            done();
          });
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      });
      it('metadata.json is customized', (done) => {
        try {
          const metadataDotJson = require('../../metadata.json');
          assert.equal('adapter-github', metadataDotJson.name);
          assert.notEqual(undefined, metadataDotJson.webName);
          assert.notEqual(null, metadataDotJson.webName);
          assert.notEqual('', metadataDotJson.webName);
          assert.equal('Adapter', metadataDotJson.type);
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      });
      it('metadata.json contains accurate documentation', (done) => {
        try {
          const metadataDotJson = require('../../metadata.json');
          assert.notEqual(undefined, metadataDotJson.documentation);
          assert.equal('https://www.npmjs.com/package/@itentialopensource/adapter-github', metadataDotJson.documentation.npmLink);
          assert.equal('https://docs.itential.com/opensource/docs/troubleshooting-an-adapter', metadataDotJson.documentation.faqLink);
          assert.equal('https://gitlab.com/itentialopensource/adapters/contributing-guide', metadataDotJson.documentation.contributeLink);
          assert.equal('https://itential.atlassian.net/servicedesk/customer/portals', metadataDotJson.documentation.issueLink);
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      });
      it('metadata.json has related items', (done) => {
        try {
          const metadataDotJson = require('../../metadata.json');
          assert.notEqual(undefined, metadataDotJson.relatedItems);
          assert.notEqual(undefined, metadataDotJson.relatedItems.adapters);
          assert.notEqual(undefined, metadataDotJson.relatedItems.integrations);
          assert.notEqual(undefined, metadataDotJson.relatedItems.ecosystemApplications);
          assert.notEqual(undefined, metadataDotJson.relatedItems.workflowProjects);
          assert.notEqual(undefined, metadataDotJson.relatedItems.transformationProjects);
          assert.notEqual(undefined, metadataDotJson.relatedItems.exampleProjects);
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      });
    });
    /*
    -----------------------------------------------------------------------
    -----------------------------------------------------------------------
    *** All code above this comment will be replaced during a migration ***
    ******************* DO NOT REMOVE THIS COMMENT BLOCK ******************
    -----------------------------------------------------------------------
    -----------------------------------------------------------------------
    */

    describe('#getEmojis - errors', () => {
      it('should have a getEmojis function', (done) => {
        try {
          assert.equal(true, typeof a.getEmojis === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getEvents - errors', () => {
      it('should have a getEvents function', (done) => {
        try {
          assert.equal(true, typeof a.getEvents === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getFeeds - errors', () => {
      it('should have a getFeeds function', (done) => {
        try {
          assert.equal(true, typeof a.getFeeds === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getGists - errors', () => {
      it('should have a getGists function', (done) => {
        try {
          assert.equal(true, typeof a.getGists === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#postGists - errors', () => {
      it('should have a postGists function', (done) => {
        try {
          assert.equal(true, typeof a.postGists === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        try {
          a.postGists(null, (data, error) => {
            try {
              const displayE = 'body is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-postGists', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getGistsPublic - errors', () => {
      it('should have a getGistsPublic function', (done) => {
        try {
          assert.equal(true, typeof a.getGistsPublic === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getGistsStarred - errors', () => {
      it('should have a getGistsStarred function', (done) => {
        try {
          assert.equal(true, typeof a.getGistsStarred === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#deleteGistsId - errors', () => {
      it('should have a deleteGistsId function', (done) => {
        try {
          assert.equal(true, typeof a.deleteGistsId === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        try {
          a.deleteGistsId(null, (data, error) => {
            try {
              const displayE = 'id is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-deleteGistsId', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getGistsId - errors', () => {
      it('should have a getGistsId function', (done) => {
        try {
          assert.equal(true, typeof a.getGistsId === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        try {
          a.getGistsId(null, (data, error) => {
            try {
              const displayE = 'id is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getGistsId', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#patchGistsId - errors', () => {
      it('should have a patchGistsId function', (done) => {
        try {
          assert.equal(true, typeof a.patchGistsId === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        try {
          a.patchGistsId(null, null, (data, error) => {
            try {
              const displayE = 'id is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-patchGistsId', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        try {
          a.patchGistsId('fakeparam', null, (data, error) => {
            try {
              const displayE = 'body is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-patchGistsId', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getGistsIdComments - errors', () => {
      it('should have a getGistsIdComments function', (done) => {
        try {
          assert.equal(true, typeof a.getGistsIdComments === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        try {
          a.getGistsIdComments(null, (data, error) => {
            try {
              const displayE = 'gistId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getGistsIdCommentsQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#postGistsIdComments - errors', () => {
      it('should have a postGistsIdComments function', (done) => {
        try {
          assert.equal(true, typeof a.postGistsIdComments === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        try {
          a.postGistsIdComments(null, null, (data, error) => {
            try {
              const displayE = 'id is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-postGistsIdComments', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        try {
          a.postGistsIdComments('fakeparam', null, (data, error) => {
            try {
              const displayE = 'body is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-postGistsIdComments', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#deleteGistsIdCommentsCommentId - errors', () => {
      it('should have a deleteGistsIdCommentsCommentId function', (done) => {
        try {
          assert.equal(true, typeof a.deleteGistsIdCommentsCommentId === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        try {
          a.deleteGistsIdCommentsCommentId(null, null, (data, error) => {
            try {
              const displayE = 'id is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-deleteGistsIdCommentsCommentId', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing commentId', (done) => {
        try {
          a.deleteGistsIdCommentsCommentId('fakeparam', null, (data, error) => {
            try {
              const displayE = 'commentId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-deleteGistsIdCommentsCommentId', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getGistsIdCommentsCommentId - errors', () => {
      it('should have a getGistsIdCommentsCommentId function', (done) => {
        try {
          assert.equal(true, typeof a.getGistsIdCommentsCommentId === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        try {
          a.getGistsIdCommentsCommentId(null, null, (data, error) => {
            try {
              const displayE = 'id is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getGistsIdCommentsCommentId', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing commentId', (done) => {
        try {
          a.getGistsIdCommentsCommentId('fakeparam', null, (data, error) => {
            try {
              const displayE = 'commentId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getGistsIdCommentsCommentId', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#patchGistsIdCommentsCommentId - errors', () => {
      it('should have a patchGistsIdCommentsCommentId function', (done) => {
        try {
          assert.equal(true, typeof a.patchGistsIdCommentsCommentId === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        try {
          a.patchGistsIdCommentsCommentId(null, null, null, (data, error) => {
            try {
              const displayE = 'id is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-patchGistsIdCommentsCommentId', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing commentId', (done) => {
        try {
          a.patchGistsIdCommentsCommentId('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'commentId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-patchGistsIdCommentsCommentId', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        try {
          a.patchGistsIdCommentsCommentId('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'body is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-patchGistsIdCommentsCommentId', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#postGistsIdForks - errors', () => {
      it('should have a postGistsIdForks function', (done) => {
        try {
          assert.equal(true, typeof a.postGistsIdForks === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        try {
          a.postGistsIdForks(null, (data, error) => {
            try {
              const displayE = 'id is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-postGistsIdForks', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#deleteGistsIdStar - errors', () => {
      it('should have a deleteGistsIdStar function', (done) => {
        try {
          assert.equal(true, typeof a.deleteGistsIdStar === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        try {
          a.deleteGistsIdStar(null, (data, error) => {
            try {
              const displayE = 'id is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-deleteGistsIdStar', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getGistsIdStar - errors', () => {
      it('should have a getGistsIdStar function', (done) => {
        try {
          assert.equal(true, typeof a.getGistsIdStar === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        try {
          a.getGistsIdStar(null, (data, error) => {
            try {
              const displayE = 'id is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getGistsIdStar', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#putGistsIdStar - errors', () => {
      it('should have a putGistsIdStar function', (done) => {
        try {
          assert.equal(true, typeof a.putGistsIdStar === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        try {
          a.putGistsIdStar(null, (data, error) => {
            try {
              const displayE = 'id is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-putGistsIdStar', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getGitignoreTemplates - errors', () => {
      it('should have a getGitignoreTemplates function', (done) => {
        try {
          assert.equal(true, typeof a.getGitignoreTemplates === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getGitignoreTemplatesLanguage - errors', () => {
      it('should have a getGitignoreTemplatesLanguage function', (done) => {
        try {
          assert.equal(true, typeof a.getGitignoreTemplatesLanguage === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing language', (done) => {
        try {
          a.getGitignoreTemplatesLanguage(null, (data, error) => {
            try {
              const displayE = 'language is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getGitignoreTemplatesLanguage', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getIssues - errors', () => {
      it('should have a getIssues function', (done) => {
        try {
          assert.equal(true, typeof a.getIssues === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getLegacyIssuesSearchOwnerRepositoryStateKeyword - errors', () => {
      it('should have a getLegacyIssuesSearchOwnerRepositoryStateKeyword function', (done) => {
        try {
          assert.equal(true, typeof a.getLegacyIssuesSearchOwnerRepositoryStateKeyword === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing keyword', (done) => {
        try {
          a.getLegacyIssuesSearchOwnerRepositoryStateKeyword(null, null, null, null, (data, error) => {
            try {
              const displayE = 'keyword is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getLegacyIssuesSearchOwnerRepositoryStateKeyword', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing state', (done) => {
        try {
          a.getLegacyIssuesSearchOwnerRepositoryStateKeyword('fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'state is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getLegacyIssuesSearchOwnerRepositoryStateKeyword', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.getLegacyIssuesSearchOwnerRepositoryStateKeyword('fakeparam', 'fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getLegacyIssuesSearchOwnerRepositoryStateKeyword', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repository', (done) => {
        try {
          a.getLegacyIssuesSearchOwnerRepositoryStateKeyword('fakeparam', 'fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'repository is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getLegacyIssuesSearchOwnerRepositoryStateKeyword', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getLegacyReposSearchKeyword - errors', () => {
      it('should have a getLegacyReposSearchKeyword function', (done) => {
        try {
          assert.equal(true, typeof a.getLegacyReposSearchKeyword === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing keyword', (done) => {
        try {
          a.getLegacyReposSearchKeyword(null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'keyword is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getLegacyReposSearchKeyword', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getLegacyUserEmailEmail - errors', () => {
      it('should have a getLegacyUserEmailEmail function', (done) => {
        try {
          assert.equal(true, typeof a.getLegacyUserEmailEmail === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing email', (done) => {
        try {
          a.getLegacyUserEmailEmail(null, (data, error) => {
            try {
              const displayE = 'email is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getLegacyUserEmailEmail', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getLegacyUserSearchKeyword - errors', () => {
      it('should have a getLegacyUserSearchKeyword function', (done) => {
        try {
          assert.equal(true, typeof a.getLegacyUserSearchKeyword === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing keyword', (done) => {
        try {
          a.getLegacyUserSearchKeyword(null, null, null, null, (data, error) => {
            try {
              const displayE = 'keyword is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getLegacyUserSearchKeyword', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#postMarkdown - errors', () => {
      it('should have a postMarkdown function', (done) => {
        try {
          assert.equal(true, typeof a.postMarkdown === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        try {
          a.postMarkdown(null, (data, error) => {
            try {
              const displayE = 'body is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-postMarkdown', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#postMarkdownRaw - errors', () => {
      it('should have a postMarkdownRaw function', (done) => {
        try {
          assert.equal(true, typeof a.postMarkdownRaw === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getMeta - errors', () => {
      it('should have a getMeta function', (done) => {
        try {
          assert.equal(true, typeof a.getMeta === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getNetworksOwnerRepoEvents - errors', () => {
      it('should have a getNetworksOwnerRepoEvents function', (done) => {
        try {
          assert.equal(true, typeof a.getNetworksOwnerRepoEvents === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.getNetworksOwnerRepoEvents(null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getNetworksOwnerRepoEventsQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.getNetworksOwnerRepoEvents('fakeparam', null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getNetworksOwnerRepoEventsQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getNotifications - errors', () => {
      it('should have a getNotifications function', (done) => {
        try {
          assert.equal(true, typeof a.getNotifications === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#putNotifications - errors', () => {
      it('should have a putNotifications function', (done) => {
        try {
          assert.equal(true, typeof a.putNotifications === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        try {
          a.putNotifications(null, (data, error) => {
            try {
              const displayE = 'body is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-putNotifications', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getNotificationsThreadsId - errors', () => {
      it('should have a getNotificationsThreadsId function', (done) => {
        try {
          assert.equal(true, typeof a.getNotificationsThreadsId === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        try {
          a.getNotificationsThreadsId(null, (data, error) => {
            try {
              const displayE = 'id is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getNotificationsThreadsId', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#patchNotificationsThreadsId - errors', () => {
      it('should have a patchNotificationsThreadsId function', (done) => {
        try {
          assert.equal(true, typeof a.patchNotificationsThreadsId === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        try {
          a.patchNotificationsThreadsId(null, (data, error) => {
            try {
              const displayE = 'id is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-patchNotificationsThreadsId', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#deleteNotificationsThreadsIdSubscription - errors', () => {
      it('should have a deleteNotificationsThreadsIdSubscription function', (done) => {
        try {
          assert.equal(true, typeof a.deleteNotificationsThreadsIdSubscription === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        try {
          a.deleteNotificationsThreadsIdSubscription(null, (data, error) => {
            try {
              const displayE = 'id is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-deleteNotificationsThreadsIdSubscription', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getNotificationsThreadsIdSubscription - errors', () => {
      it('should have a getNotificationsThreadsIdSubscription function', (done) => {
        try {
          assert.equal(true, typeof a.getNotificationsThreadsIdSubscription === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        try {
          a.getNotificationsThreadsIdSubscription(null, (data, error) => {
            try {
              const displayE = 'id is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getNotificationsThreadsIdSubscription', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#putNotificationsThreadsIdSubscription - errors', () => {
      it('should have a putNotificationsThreadsIdSubscription function', (done) => {
        try {
          assert.equal(true, typeof a.putNotificationsThreadsIdSubscription === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        try {
          a.putNotificationsThreadsIdSubscription(null, null, (data, error) => {
            try {
              const displayE = 'id is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-putNotificationsThreadsIdSubscription', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        try {
          a.putNotificationsThreadsIdSubscription('fakeparam', null, (data, error) => {
            try {
              const displayE = 'body is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-putNotificationsThreadsIdSubscription', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getOrgsOrg - errors', () => {
      it('should have a getOrgsOrg function', (done) => {
        try {
          assert.equal(true, typeof a.getOrgsOrg === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.getOrgsOrg(null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getOrgsOrg', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#patchOrgsOrg - errors', () => {
      it('should have a patchOrgsOrg function', (done) => {
        try {
          assert.equal(true, typeof a.patchOrgsOrg === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.patchOrgsOrg(null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-patchOrgsOrg', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        try {
          a.patchOrgsOrg('fakeparam', null, (data, error) => {
            try {
              const displayE = 'body is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-patchOrgsOrg', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getOrgsOrgEvents - errors', () => {
      it('should have a getOrgsOrgEvents function', (done) => {
        try {
          assert.equal(true, typeof a.getOrgsOrgEvents === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.getOrgsOrgEvents(null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getOrgsOrgEventsQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getOrgsOrgIssues - errors', () => {
      it('should have a getOrgsOrgIssues function', (done) => {
        try {
          assert.equal(true, typeof a.getOrgsOrgIssues === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.getOrgsOrgIssues(null, null, null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getOrgsOrgIssuesQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getOrgsOrgMembers - errors', () => {
      it('should have a getOrgsOrgMembers function', (done) => {
        try {
          assert.equal(true, typeof a.getOrgsOrgMembers === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.getOrgsOrgMembers(null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getOrgsOrgMembersQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#deleteOrgsOrgMembersUsername - errors', () => {
      it('should have a deleteOrgsOrgMembersUsername function', (done) => {
        try {
          assert.equal(true, typeof a.deleteOrgsOrgMembersUsername === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.deleteOrgsOrgMembersUsername(null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-deleteOrgsOrgMembersUsername', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing username', (done) => {
        try {
          a.deleteOrgsOrgMembersUsername('fakeparam', null, (data, error) => {
            try {
              const displayE = 'username is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-deleteOrgsOrgMembersUsername', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getOrgsOrgMembersUsername - errors', () => {
      it('should have a getOrgsOrgMembersUsername function', (done) => {
        try {
          assert.equal(true, typeof a.getOrgsOrgMembersUsername === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.getOrgsOrgMembersUsername(null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getOrgsOrgMembersUsername', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing username', (done) => {
        try {
          a.getOrgsOrgMembersUsername('fakeparam', null, (data, error) => {
            try {
              const displayE = 'username is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getOrgsOrgMembersUsername', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getOrgsOrgPublicMembers - errors', () => {
      it('should have a getOrgsOrgPublicMembers function', (done) => {
        try {
          assert.equal(true, typeof a.getOrgsOrgPublicMembers === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.getOrgsOrgPublicMembers(null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getOrgsOrgPublicMembersQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#deleteOrgsOrgPublicMembersUsername - errors', () => {
      it('should have a deleteOrgsOrgPublicMembersUsername function', (done) => {
        try {
          assert.equal(true, typeof a.deleteOrgsOrgPublicMembersUsername === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.deleteOrgsOrgPublicMembersUsername(null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-deleteOrgsOrgPublicMembersUsername', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing username', (done) => {
        try {
          a.deleteOrgsOrgPublicMembersUsername('fakeparam', null, (data, error) => {
            try {
              const displayE = 'username is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-deleteOrgsOrgPublicMembersUsername', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getOrgsOrgPublicMembersUsername - errors', () => {
      it('should have a getOrgsOrgPublicMembersUsername function', (done) => {
        try {
          assert.equal(true, typeof a.getOrgsOrgPublicMembersUsername === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.getOrgsOrgPublicMembersUsername(null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getOrgsOrgPublicMembersUsername', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing username', (done) => {
        try {
          a.getOrgsOrgPublicMembersUsername('fakeparam', null, (data, error) => {
            try {
              const displayE = 'username is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getOrgsOrgPublicMembersUsername', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#putOrgsOrgPublicMembersUsername - errors', () => {
      it('should have a putOrgsOrgPublicMembersUsername function', (done) => {
        try {
          assert.equal(true, typeof a.putOrgsOrgPublicMembersUsername === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.putOrgsOrgPublicMembersUsername(null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-putOrgsOrgPublicMembersUsername', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing username', (done) => {
        try {
          a.putOrgsOrgPublicMembersUsername('fakeparam', null, (data, error) => {
            try {
              const displayE = 'username is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-putOrgsOrgPublicMembersUsername', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getOrgsOrgRepos - errors', () => {
      it('should have a getOrgsOrgRepos function', (done) => {
        try {
          assert.equal(true, typeof a.getOrgsOrgRepos === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.getOrgsOrgRepos(null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getOrgsOrgReposQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#postOrgsOrgRepos - errors', () => {
      it('should have a postOrgsOrgRepos function', (done) => {
        try {
          assert.equal(true, typeof a.postOrgsOrgRepos === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.postOrgsOrgRepos(null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-postOrgsOrgRepos', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        try {
          a.postOrgsOrgRepos('fakeparam', null, (data, error) => {
            try {
              const displayE = 'body is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-postOrgsOrgRepos', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getOrgsOrgTeams - errors', () => {
      it('should have a getOrgsOrgTeams function', (done) => {
        try {
          assert.equal(true, typeof a.getOrgsOrgTeams === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.getOrgsOrgTeams(null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getOrgsOrgTeamsQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#postOrgsOrgTeams - errors', () => {
      it('should have a postOrgsOrgTeams function', (done) => {
        try {
          assert.equal(true, typeof a.postOrgsOrgTeams === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.postOrgsOrgTeams(null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-postOrgsOrgTeams', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        try {
          a.postOrgsOrgTeams('fakeparam', null, (data, error) => {
            try {
              const displayE = 'body is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-postOrgsOrgTeams', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getRateLimit - errors', () => {
      it('should have a getRateLimit function', (done) => {
        try {
          assert.equal(true, typeof a.getRateLimit === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#deleteReposOwnerRepo - errors', () => {
      it('should have a deleteReposOwnerRepo function', (done) => {
        try {
          assert.equal(true, typeof a.deleteReposOwnerRepo === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.deleteReposOwnerRepo(null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-deleteReposOwnerRepo', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.deleteReposOwnerRepo('fakeparam', null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-deleteReposOwnerRepo', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepo - errors', () => {
      it('should have a getReposOwnerRepo function', (done) => {
        try {
          assert.equal(true, typeof a.getReposOwnerRepo === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.getReposOwnerRepo(null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepo', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.getReposOwnerRepo('fakeparam', null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepo', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#patchReposOwnerRepo - errors', () => {
      it('should have a patchReposOwnerRepo function', (done) => {
        try {
          assert.equal(true, typeof a.patchReposOwnerRepo === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.patchReposOwnerRepo(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-patchReposOwnerRepo', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.patchReposOwnerRepo('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-patchReposOwnerRepo', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        try {
          a.patchReposOwnerRepo('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'body is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-patchReposOwnerRepo', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoAssignees - errors', () => {
      it('should have a getReposOwnerRepoAssignees function', (done) => {
        try {
          assert.equal(true, typeof a.getReposOwnerRepoAssignees === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.getReposOwnerRepoAssignees(null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoAssigneesQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.getReposOwnerRepoAssignees('fakeparam', null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoAssigneesQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoAssigneesAssignee - errors', () => {
      it('should have a getReposOwnerRepoAssigneesAssignee function', (done) => {
        try {
          assert.equal(true, typeof a.getReposOwnerRepoAssigneesAssignee === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.getReposOwnerRepoAssigneesAssignee(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoAssigneesAssignee', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.getReposOwnerRepoAssigneesAssignee('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoAssigneesAssignee', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing assignee', (done) => {
        try {
          a.getReposOwnerRepoAssigneesAssignee('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'assignee is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoAssigneesAssignee', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoBranches - errors', () => {
      it('should have a getReposOwnerRepoBranches function', (done) => {
        try {
          assert.equal(true, typeof a.getReposOwnerRepoBranches === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.getReposOwnerRepoBranches(null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoBranchesQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.getReposOwnerRepoBranches('fakeparam', null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoBranchesQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoBranchesBranch - errors', () => {
      it('should have a getReposOwnerRepoBranchesBranch function', (done) => {
        try {
          assert.equal(true, typeof a.getReposOwnerRepoBranchesBranch === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.getReposOwnerRepoBranchesBranch(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoBranchesBranch', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.getReposOwnerRepoBranchesBranch('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoBranchesBranch', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing branch', (done) => {
        try {
          a.getReposOwnerRepoBranchesBranch('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'branch is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoBranchesBranch', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoCollaborators - errors', () => {
      it('should have a getReposOwnerRepoCollaborators function', (done) => {
        try {
          assert.equal(true, typeof a.getReposOwnerRepoCollaborators === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.getReposOwnerRepoCollaborators(null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoCollaboratorsQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.getReposOwnerRepoCollaborators('fakeparam', null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoCollaboratorsQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#deleteReposOwnerRepoCollaboratorsUser - errors', () => {
      it('should have a deleteReposOwnerRepoCollaboratorsUser function', (done) => {
        try {
          assert.equal(true, typeof a.deleteReposOwnerRepoCollaboratorsUser === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.deleteReposOwnerRepoCollaboratorsUser(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-deleteReposOwnerRepoCollaboratorsUser', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.deleteReposOwnerRepoCollaboratorsUser('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-deleteReposOwnerRepoCollaboratorsUser', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing user', (done) => {
        try {
          a.deleteReposOwnerRepoCollaboratorsUser('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'user is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-deleteReposOwnerRepoCollaboratorsUser', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoCollaboratorsUser - errors', () => {
      it('should have a getReposOwnerRepoCollaboratorsUser function', (done) => {
        try {
          assert.equal(true, typeof a.getReposOwnerRepoCollaboratorsUser === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.getReposOwnerRepoCollaboratorsUser(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoCollaboratorsUser', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.getReposOwnerRepoCollaboratorsUser('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoCollaboratorsUser', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing user', (done) => {
        try {
          a.getReposOwnerRepoCollaboratorsUser('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'user is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoCollaboratorsUser', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#putReposOwnerRepoCollaboratorsUser - errors', () => {
      it('should have a putReposOwnerRepoCollaboratorsUser function', (done) => {
        try {
          assert.equal(true, typeof a.putReposOwnerRepoCollaboratorsUser === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.putReposOwnerRepoCollaboratorsUser(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-putReposOwnerRepoCollaboratorsUser', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.putReposOwnerRepoCollaboratorsUser('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-putReposOwnerRepoCollaboratorsUser', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing user', (done) => {
        try {
          a.putReposOwnerRepoCollaboratorsUser('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'user is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-putReposOwnerRepoCollaboratorsUser', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoComments - errors', () => {
      it('should have a getReposOwnerRepoComments function', (done) => {
        try {
          assert.equal(true, typeof a.getReposOwnerRepoComments === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.getReposOwnerRepoComments(null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoCommentsQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.getReposOwnerRepoComments('fakeparam', null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoCommentsQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#deleteReposOwnerRepoCommentsCommentId - errors', () => {
      it('should have a deleteReposOwnerRepoCommentsCommentId function', (done) => {
        try {
          assert.equal(true, typeof a.deleteReposOwnerRepoCommentsCommentId === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.deleteReposOwnerRepoCommentsCommentId(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-deleteReposOwnerRepoCommentsCommentId', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.deleteReposOwnerRepoCommentsCommentId('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-deleteReposOwnerRepoCommentsCommentId', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing commentId', (done) => {
        try {
          a.deleteReposOwnerRepoCommentsCommentId('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'commentId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-deleteReposOwnerRepoCommentsCommentId', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoCommentsCommentId - errors', () => {
      it('should have a getReposOwnerRepoCommentsCommentId function', (done) => {
        try {
          assert.equal(true, typeof a.getReposOwnerRepoCommentsCommentId === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.getReposOwnerRepoCommentsCommentId(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoCommentsCommentId', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.getReposOwnerRepoCommentsCommentId('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoCommentsCommentId', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing commentId', (done) => {
        try {
          a.getReposOwnerRepoCommentsCommentId('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'commentId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoCommentsCommentId', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#patchReposOwnerRepoCommentsCommentId - errors', () => {
      it('should have a patchReposOwnerRepoCommentsCommentId function', (done) => {
        try {
          assert.equal(true, typeof a.patchReposOwnerRepoCommentsCommentId === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.patchReposOwnerRepoCommentsCommentId(null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-patchReposOwnerRepoCommentsCommentId', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.patchReposOwnerRepoCommentsCommentId('fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-patchReposOwnerRepoCommentsCommentId', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing commentId', (done) => {
        try {
          a.patchReposOwnerRepoCommentsCommentId('fakeparam', 'fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'commentId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-patchReposOwnerRepoCommentsCommentId', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        try {
          a.patchReposOwnerRepoCommentsCommentId('fakeparam', 'fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'body is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-patchReposOwnerRepoCommentsCommentId', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoCommits - errors', () => {
      it('should have a getReposOwnerRepoCommits function', (done) => {
        try {
          assert.equal(true, typeof a.getReposOwnerRepoCommits === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.getReposOwnerRepoCommits(null, null, null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoCommitsQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.getReposOwnerRepoCommits('fakeparam', null, null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoCommitsQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoCommitsRefStatus - errors', () => {
      it('should have a getReposOwnerRepoCommitsRefStatus function', (done) => {
        try {
          assert.equal(true, typeof a.getReposOwnerRepoCommitsRefStatus === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.getReposOwnerRepoCommitsRefStatus(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoCommitsRefStatusQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.getReposOwnerRepoCommitsRefStatus('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoCommitsRefStatusQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing ref', (done) => {
        try {
          a.getReposOwnerRepoCommitsRefStatus('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'ref is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoCommitsRefStatusQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoCommitsShaCode - errors', () => {
      it('should have a getReposOwnerRepoCommitsShaCode function', (done) => {
        try {
          assert.equal(true, typeof a.getReposOwnerRepoCommitsShaCode === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.getReposOwnerRepoCommitsShaCode(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoCommitsShaCode', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.getReposOwnerRepoCommitsShaCode('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoCommitsShaCode', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing shaCode', (done) => {
        try {
          a.getReposOwnerRepoCommitsShaCode('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'shaCode is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoCommitsShaCode', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoCommitsShaCodeComments - errors', () => {
      it('should have a getReposOwnerRepoCommitsShaCodeComments function', (done) => {
        try {
          assert.equal(true, typeof a.getReposOwnerRepoCommitsShaCodeComments === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.getReposOwnerRepoCommitsShaCodeComments(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoCommitsShaCodeCommentsQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.getReposOwnerRepoCommitsShaCodeComments('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoCommitsShaCodeCommentsQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing shaCode', (done) => {
        try {
          a.getReposOwnerRepoCommitsShaCodeComments('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'shaCode is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoCommitsShaCodeCommentsQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#postReposOwnerRepoCommitsShaCodeComments - errors', () => {
      it('should have a postReposOwnerRepoCommitsShaCodeComments function', (done) => {
        try {
          assert.equal(true, typeof a.postReposOwnerRepoCommitsShaCodeComments === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.postReposOwnerRepoCommitsShaCodeComments(null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-postReposOwnerRepoCommitsShaCodeComments', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.postReposOwnerRepoCommitsShaCodeComments('fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-postReposOwnerRepoCommitsShaCodeComments', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing shaCode', (done) => {
        try {
          a.postReposOwnerRepoCommitsShaCodeComments('fakeparam', 'fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'shaCode is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-postReposOwnerRepoCommitsShaCodeComments', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        try {
          a.postReposOwnerRepoCommitsShaCodeComments('fakeparam', 'fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'body is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-postReposOwnerRepoCommitsShaCodeComments', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoCompareBaseIdHeadId - errors', () => {
      it('should have a getReposOwnerRepoCompareBaseIdHeadId function', (done) => {
        try {
          assert.equal(true, typeof a.getReposOwnerRepoCompareBaseIdHeadId === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.getReposOwnerRepoCompareBaseIdHeadId(null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoCompareBaseIdHeadIdQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.getReposOwnerRepoCompareBaseIdHeadId('fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoCompareBaseIdHeadIdQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing baseId', (done) => {
        try {
          a.getReposOwnerRepoCompareBaseIdHeadId('fakeparam', 'fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'baseId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoCompareBaseIdHeadIdQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing headId', (done) => {
        try {
          a.getReposOwnerRepoCompareBaseIdHeadId('fakeparam', 'fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'headId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoCompareBaseIdHeadIdQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#deleteReposOwnerRepoContentsPath - errors', () => {
      it('should have a deleteReposOwnerRepoContentsPath function', (done) => {
        try {
          assert.equal(true, typeof a.deleteReposOwnerRepoContentsPath === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.deleteReposOwnerRepoContentsPath(null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-deleteReposOwnerRepoContentsPath', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.deleteReposOwnerRepoContentsPath('fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-deleteReposOwnerRepoContentsPath', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing pathParam', (done) => {
        try {
          a.deleteReposOwnerRepoContentsPath('fakeparam', 'fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'pathParam is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-deleteReposOwnerRepoContentsPath', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        try {
          a.deleteReposOwnerRepoContentsPath('fakeparam', 'fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'body is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-deleteReposOwnerRepoContentsPath', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoContentsPath - errors', () => {
      it('should have a getReposOwnerRepoContentsPath function', (done) => {
        try {
          assert.equal(true, typeof a.getReposOwnerRepoContentsPath === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.getReposOwnerRepoContentsPath(null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoContentsPath', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.getReposOwnerRepoContentsPath('fakeparam', null, null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoContentsPath', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing pathParam', (done) => {
        try {
          a.getReposOwnerRepoContentsPath('fakeparam', 'fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'pathParam is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoContentsPath', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#putReposOwnerRepoContentsPath - errors', () => {
      it('should have a putReposOwnerRepoContentsPath function', (done) => {
        try {
          assert.equal(true, typeof a.putReposOwnerRepoContentsPath === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.putReposOwnerRepoContentsPath(null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-putReposOwnerRepoContentsPath', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.putReposOwnerRepoContentsPath('fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-putReposOwnerRepoContentsPath', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing pathParam', (done) => {
        try {
          a.putReposOwnerRepoContentsPath('fakeparam', 'fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'pathParam is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-putReposOwnerRepoContentsPath', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        try {
          a.putReposOwnerRepoContentsPath('fakeparam', 'fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'body is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-putReposOwnerRepoContentsPath', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoContributors - errors', () => {
      it('should have a getReposOwnerRepoContributors function', (done) => {
        try {
          assert.equal(true, typeof a.getReposOwnerRepoContributors === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.getReposOwnerRepoContributors(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoContributorsQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.getReposOwnerRepoContributors('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoContributorsQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoDeployments - errors', () => {
      it('should have a getReposOwnerRepoDeployments function', (done) => {
        try {
          assert.equal(true, typeof a.getReposOwnerRepoDeployments === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.getReposOwnerRepoDeployments(null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoDeploymentsQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.getReposOwnerRepoDeployments('fakeparam', null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoDeploymentsQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#postReposOwnerRepoDeployments - errors', () => {
      it('should have a postReposOwnerRepoDeployments function', (done) => {
        try {
          assert.equal(true, typeof a.postReposOwnerRepoDeployments === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.postReposOwnerRepoDeployments(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-postReposOwnerRepoDeployments', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.postReposOwnerRepoDeployments('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-postReposOwnerRepoDeployments', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        try {
          a.postReposOwnerRepoDeployments('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'body is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-postReposOwnerRepoDeployments', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoDeploymentsIdStatuses - errors', () => {
      it('should have a getReposOwnerRepoDeploymentsIdStatuses function', (done) => {
        try {
          assert.equal(true, typeof a.getReposOwnerRepoDeploymentsIdStatuses === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.getReposOwnerRepoDeploymentsIdStatuses(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoDeploymentsIdStatusesQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.getReposOwnerRepoDeploymentsIdStatuses('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoDeploymentsIdStatusesQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        try {
          a.getReposOwnerRepoDeploymentsIdStatuses('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'deploymentId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoDeploymentsIdStatusesQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#postReposOwnerRepoDeploymentsIdStatuses - errors', () => {
      it('should have a postReposOwnerRepoDeploymentsIdStatuses function', (done) => {
        try {
          assert.equal(true, typeof a.postReposOwnerRepoDeploymentsIdStatuses === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.postReposOwnerRepoDeploymentsIdStatuses(null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-postReposOwnerRepoDeploymentsIdStatuses', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.postReposOwnerRepoDeploymentsIdStatuses('fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-postReposOwnerRepoDeploymentsIdStatuses', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        try {
          a.postReposOwnerRepoDeploymentsIdStatuses('fakeparam', 'fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'id is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-postReposOwnerRepoDeploymentsIdStatuses', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        try {
          a.postReposOwnerRepoDeploymentsIdStatuses('fakeparam', 'fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'body is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-postReposOwnerRepoDeploymentsIdStatuses', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoDownloads - errors', () => {
      it('should have a getReposOwnerRepoDownloads function', (done) => {
        try {
          assert.equal(true, typeof a.getReposOwnerRepoDownloads === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.getReposOwnerRepoDownloads(null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoDownloads', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.getReposOwnerRepoDownloads('fakeparam', null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoDownloads', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#deleteReposOwnerRepoDownloadsDownloadId - errors', () => {
      it('should have a deleteReposOwnerRepoDownloadsDownloadId function', (done) => {
        try {
          assert.equal(true, typeof a.deleteReposOwnerRepoDownloadsDownloadId === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.deleteReposOwnerRepoDownloadsDownloadId(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-deleteReposOwnerRepoDownloadsDownloadId', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.deleteReposOwnerRepoDownloadsDownloadId('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-deleteReposOwnerRepoDownloadsDownloadId', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing downloadId', (done) => {
        try {
          a.deleteReposOwnerRepoDownloadsDownloadId('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'downloadId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-deleteReposOwnerRepoDownloadsDownloadId', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoDownloadsDownloadId - errors', () => {
      it('should have a getReposOwnerRepoDownloadsDownloadId function', (done) => {
        try {
          assert.equal(true, typeof a.getReposOwnerRepoDownloadsDownloadId === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.getReposOwnerRepoDownloadsDownloadId(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoDownloadsDownloadId', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.getReposOwnerRepoDownloadsDownloadId('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoDownloadsDownloadId', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing downloadId', (done) => {
        try {
          a.getReposOwnerRepoDownloadsDownloadId('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'downloadId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoDownloadsDownloadId', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoEvents - errors', () => {
      it('should have a getReposOwnerRepoEvents function', (done) => {
        try {
          assert.equal(true, typeof a.getReposOwnerRepoEvents === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.getReposOwnerRepoEvents(null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoEventsQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.getReposOwnerRepoEvents('fakeparam', null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoEventsQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoForks - errors', () => {
      it('should have a getReposOwnerRepoForks function', (done) => {
        try {
          assert.equal(true, typeof a.getReposOwnerRepoForks === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.getReposOwnerRepoForks(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoForksQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.getReposOwnerRepoForks('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoForksQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#postReposOwnerRepoForks - errors', () => {
      it('should have a postReposOwnerRepoForks function', (done) => {
        try {
          assert.equal(true, typeof a.postReposOwnerRepoForks === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.postReposOwnerRepoForks(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-postReposOwnerRepoForks', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.postReposOwnerRepoForks('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-postReposOwnerRepoForks', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        try {
          a.postReposOwnerRepoForks('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'body is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-postReposOwnerRepoForks', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#postReposOwnerRepoGitBlobs - errors', () => {
      it('should have a postReposOwnerRepoGitBlobs function', (done) => {
        try {
          assert.equal(true, typeof a.postReposOwnerRepoGitBlobs === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.postReposOwnerRepoGitBlobs(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-postReposOwnerRepoGitBlobs', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.postReposOwnerRepoGitBlobs('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-postReposOwnerRepoGitBlobs', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        try {
          a.postReposOwnerRepoGitBlobs('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'body is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-postReposOwnerRepoGitBlobs', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoGitBlobsShaCode - errors', () => {
      it('should have a getReposOwnerRepoGitBlobsShaCode function', (done) => {
        try {
          assert.equal(true, typeof a.getReposOwnerRepoGitBlobsShaCode === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.getReposOwnerRepoGitBlobsShaCode(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoGitBlobsShaCode', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.getReposOwnerRepoGitBlobsShaCode('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoGitBlobsShaCode', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing shaCode', (done) => {
        try {
          a.getReposOwnerRepoGitBlobsShaCode('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'shaCode is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoGitBlobsShaCode', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#postReposOwnerRepoGitCommits - errors', () => {
      it('should have a postReposOwnerRepoGitCommits function', (done) => {
        try {
          assert.equal(true, typeof a.postReposOwnerRepoGitCommits === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.postReposOwnerRepoGitCommits(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-postReposOwnerRepoGitCommits', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.postReposOwnerRepoGitCommits('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-postReposOwnerRepoGitCommits', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        try {
          a.postReposOwnerRepoGitCommits('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'body is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-postReposOwnerRepoGitCommits', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoGitCommitsShaCode - errors', () => {
      it('should have a getReposOwnerRepoGitCommitsShaCode function', (done) => {
        try {
          assert.equal(true, typeof a.getReposOwnerRepoGitCommitsShaCode === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.getReposOwnerRepoGitCommitsShaCode(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoGitCommitsShaCode', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.getReposOwnerRepoGitCommitsShaCode('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoGitCommitsShaCode', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing shaCode', (done) => {
        try {
          a.getReposOwnerRepoGitCommitsShaCode('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'shaCode is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoGitCommitsShaCode', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoGitRefs - errors', () => {
      it('should have a getReposOwnerRepoGitRefs function', (done) => {
        try {
          assert.equal(true, typeof a.getReposOwnerRepoGitRefs === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.getReposOwnerRepoGitRefs(null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoGitRefs', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.getReposOwnerRepoGitRefs('fakeparam', null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoGitRefs', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#postReposOwnerRepoGitRefs - errors', () => {
      it('should have a postReposOwnerRepoGitRefs function', (done) => {
        try {
          assert.equal(true, typeof a.postReposOwnerRepoGitRefs === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.postReposOwnerRepoGitRefs(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-postReposOwnerRepoGitRefs', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.postReposOwnerRepoGitRefs('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-postReposOwnerRepoGitRefs', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        try {
          a.postReposOwnerRepoGitRefs('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'body is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-postReposOwnerRepoGitRefs', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#deleteReposOwnerRepoGitRefsRef - errors', () => {
      it('should have a deleteReposOwnerRepoGitRefsRef function', (done) => {
        try {
          assert.equal(true, typeof a.deleteReposOwnerRepoGitRefsRef === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.deleteReposOwnerRepoGitRefsRef(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-deleteReposOwnerRepoGitRefsRef', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.deleteReposOwnerRepoGitRefsRef('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-deleteReposOwnerRepoGitRefsRef', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing ref', (done) => {
        try {
          a.deleteReposOwnerRepoGitRefsRef('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'ref is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-deleteReposOwnerRepoGitRefsRef', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoGitMatchingRefs - errors', () => {
      it('should have a getReposOwnerRepoGitMatchingRefs function', (done) => {
        try {
          assert.equal(true, typeof a.getReposOwnerRepoGitMatchingRefs === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.getReposOwnerRepoGitMatchingRefs(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoGitMatchingRefs', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.getReposOwnerRepoGitMatchingRefs('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoGitMatchingRefs', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing ref', (done) => {
        try {
          a.getReposOwnerRepoGitMatchingRefs('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'ref is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoGitMatchingRefs', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoGitRefsRef - errors', () => {
      it('should have a getReposOwnerRepoGitRefsRef function', (done) => {
        try {
          assert.equal(true, typeof a.getReposOwnerRepoGitRefsRef === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.getReposOwnerRepoGitRefsRef(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoGitRefsRef', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.getReposOwnerRepoGitRefsRef('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoGitRefsRef', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing ref', (done) => {
        try {
          a.getReposOwnerRepoGitRefsRef('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'ref is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoGitRefsRef', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#patchReposOwnerRepoGitRefsRef - errors', () => {
      it('should have a patchReposOwnerRepoGitRefsRef function', (done) => {
        try {
          assert.equal(true, typeof a.patchReposOwnerRepoGitRefsRef === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.patchReposOwnerRepoGitRefsRef(null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-patchReposOwnerRepoGitRefsRef', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.patchReposOwnerRepoGitRefsRef('fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-patchReposOwnerRepoGitRefsRef', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing ref', (done) => {
        try {
          a.patchReposOwnerRepoGitRefsRef('fakeparam', 'fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'ref is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-patchReposOwnerRepoGitRefsRef', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        try {
          a.patchReposOwnerRepoGitRefsRef('fakeparam', 'fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'body is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-patchReposOwnerRepoGitRefsRef', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#postReposOwnerRepoGitTags - errors', () => {
      it('should have a postReposOwnerRepoGitTags function', (done) => {
        try {
          assert.equal(true, typeof a.postReposOwnerRepoGitTags === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.postReposOwnerRepoGitTags(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-postReposOwnerRepoGitTags', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.postReposOwnerRepoGitTags('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-postReposOwnerRepoGitTags', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        try {
          a.postReposOwnerRepoGitTags('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'body is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-postReposOwnerRepoGitTags', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoGitTagsShaCode - errors', () => {
      it('should have a getReposOwnerRepoGitTagsShaCode function', (done) => {
        try {
          assert.equal(true, typeof a.getReposOwnerRepoGitTagsShaCode === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.getReposOwnerRepoGitTagsShaCode(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoGitTagsShaCode', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.getReposOwnerRepoGitTagsShaCode('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoGitTagsShaCode', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing shaCode', (done) => {
        try {
          a.getReposOwnerRepoGitTagsShaCode('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'shaCode is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoGitTagsShaCode', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#postReposOwnerRepoGitTrees - errors', () => {
      it('should have a postReposOwnerRepoGitTrees function', (done) => {
        try {
          assert.equal(true, typeof a.postReposOwnerRepoGitTrees === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.postReposOwnerRepoGitTrees(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-postReposOwnerRepoGitTrees', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.postReposOwnerRepoGitTrees('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-postReposOwnerRepoGitTrees', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        try {
          a.postReposOwnerRepoGitTrees('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'body is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-postReposOwnerRepoGitTrees', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoGitTreesShaCode - errors', () => {
      it('should have a getReposOwnerRepoGitTreesShaCode function', (done) => {
        try {
          assert.equal(true, typeof a.getReposOwnerRepoGitTreesShaCode === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.getReposOwnerRepoGitTreesShaCode(null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoGitTreesShaCode', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.getReposOwnerRepoGitTreesShaCode('fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoGitTreesShaCode', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing shaCode', (done) => {
        try {
          a.getReposOwnerRepoGitTreesShaCode('fakeparam', 'fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'shaCode is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoGitTreesShaCode', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoHooks - errors', () => {
      it('should have a getReposOwnerRepoHooks function', (done) => {
        try {
          assert.equal(true, typeof a.getReposOwnerRepoHooks === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.getReposOwnerRepoHooks(null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoHooksQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.getReposOwnerRepoHooks('fakeparam', null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoHooksQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#postReposOwnerRepoHooks - errors', () => {
      it('should have a postReposOwnerRepoHooks function', (done) => {
        try {
          assert.equal(true, typeof a.postReposOwnerRepoHooks === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.postReposOwnerRepoHooks(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-postReposOwnerRepoHooks', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.postReposOwnerRepoHooks('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-postReposOwnerRepoHooks', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        try {
          a.postReposOwnerRepoHooks('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'body is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-postReposOwnerRepoHooks', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#deleteReposOwnerRepoHooksHookId - errors', () => {
      it('should have a deleteReposOwnerRepoHooksHookId function', (done) => {
        try {
          assert.equal(true, typeof a.deleteReposOwnerRepoHooksHookId === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.deleteReposOwnerRepoHooksHookId(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-deleteReposOwnerRepoHooksHookId', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.deleteReposOwnerRepoHooksHookId('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-deleteReposOwnerRepoHooksHookId', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing hookId', (done) => {
        try {
          a.deleteReposOwnerRepoHooksHookId('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'hookId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-deleteReposOwnerRepoHooksHookId', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoHooksHookId - errors', () => {
      it('should have a getReposOwnerRepoHooksHookId function', (done) => {
        try {
          assert.equal(true, typeof a.getReposOwnerRepoHooksHookId === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.getReposOwnerRepoHooksHookId(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoHooksHookId', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.getReposOwnerRepoHooksHookId('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoHooksHookId', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing hookId', (done) => {
        try {
          a.getReposOwnerRepoHooksHookId('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'hookId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoHooksHookId', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#patchReposOwnerRepoHooksHookId - errors', () => {
      it('should have a patchReposOwnerRepoHooksHookId function', (done) => {
        try {
          assert.equal(true, typeof a.patchReposOwnerRepoHooksHookId === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.patchReposOwnerRepoHooksHookId(null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-patchReposOwnerRepoHooksHookId', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.patchReposOwnerRepoHooksHookId('fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-patchReposOwnerRepoHooksHookId', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing hookId', (done) => {
        try {
          a.patchReposOwnerRepoHooksHookId('fakeparam', 'fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'hookId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-patchReposOwnerRepoHooksHookId', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        try {
          a.patchReposOwnerRepoHooksHookId('fakeparam', 'fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'body is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-patchReposOwnerRepoHooksHookId', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#postReposOwnerRepoHooksHookIdTests - errors', () => {
      it('should have a postReposOwnerRepoHooksHookIdTests function', (done) => {
        try {
          assert.equal(true, typeof a.postReposOwnerRepoHooksHookIdTests === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.postReposOwnerRepoHooksHookIdTests(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-postReposOwnerRepoHooksHookIdTests', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.postReposOwnerRepoHooksHookIdTests('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-postReposOwnerRepoHooksHookIdTests', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing hookId', (done) => {
        try {
          a.postReposOwnerRepoHooksHookIdTests('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'hookId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-postReposOwnerRepoHooksHookIdTests', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoIssues - errors', () => {
      it('should have a getReposOwnerRepoIssues function', (done) => {
        try {
          assert.equal(true, typeof a.getReposOwnerRepoIssues === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.getReposOwnerRepoIssues(null, null, null, null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoIssues', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.getReposOwnerRepoIssues('fakeparam', null, null, null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoIssues', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing filter', (done) => {
        try {
          a.getReposOwnerRepoIssues('fakeparam', 'fakeparam', null, null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'filter is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoIssues', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing state', (done) => {
        try {
          a.getReposOwnerRepoIssues('fakeparam', 'fakeparam', 'fakeparam', null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'state is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoIssues', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing labels', (done) => {
        try {
          a.getReposOwnerRepoIssues('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, null, (data, error) => {
            try {
              const displayE = 'labels is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoIssues', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing sort', (done) => {
        try {
          a.getReposOwnerRepoIssues('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'sort is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoIssues', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing direction', (done) => {
        try {
          a.getReposOwnerRepoIssues('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'direction is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoIssues', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#postReposOwnerRepoIssues - errors', () => {
      it('should have a postReposOwnerRepoIssues function', (done) => {
        try {
          assert.equal(true, typeof a.postReposOwnerRepoIssues === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.postReposOwnerRepoIssues(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-postReposOwnerRepoIssues', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.postReposOwnerRepoIssues('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-postReposOwnerRepoIssues', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        try {
          a.postReposOwnerRepoIssues('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'body is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-postReposOwnerRepoIssues', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoIssuesComments - errors', () => {
      it('should have a getReposOwnerRepoIssuesComments function', (done) => {
        try {
          assert.equal(true, typeof a.getReposOwnerRepoIssuesComments === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.getReposOwnerRepoIssuesComments(null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoIssuesCommentsQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.getReposOwnerRepoIssuesComments('fakeparam', null, null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoIssuesCommentsQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#deleteReposOwnerRepoIssuesCommentsCommentId - errors', () => {
      it('should have a deleteReposOwnerRepoIssuesCommentsCommentId function', (done) => {
        try {
          assert.equal(true, typeof a.deleteReposOwnerRepoIssuesCommentsCommentId === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.deleteReposOwnerRepoIssuesCommentsCommentId(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-deleteReposOwnerRepoIssuesCommentsCommentId', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.deleteReposOwnerRepoIssuesCommentsCommentId('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-deleteReposOwnerRepoIssuesCommentsCommentId', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing commentId', (done) => {
        try {
          a.deleteReposOwnerRepoIssuesCommentsCommentId('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'commentId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-deleteReposOwnerRepoIssuesCommentsCommentId', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoIssuesCommentsCommentId - errors', () => {
      it('should have a getReposOwnerRepoIssuesCommentsCommentId function', (done) => {
        try {
          assert.equal(true, typeof a.getReposOwnerRepoIssuesCommentsCommentId === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.getReposOwnerRepoIssuesCommentsCommentId(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoIssuesCommentsCommentId', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.getReposOwnerRepoIssuesCommentsCommentId('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoIssuesCommentsCommentId', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing commentId', (done) => {
        try {
          a.getReposOwnerRepoIssuesCommentsCommentId('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'commentId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoIssuesCommentsCommentId', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#patchReposOwnerRepoIssuesCommentsCommentId - errors', () => {
      it('should have a patchReposOwnerRepoIssuesCommentsCommentId function', (done) => {
        try {
          assert.equal(true, typeof a.patchReposOwnerRepoIssuesCommentsCommentId === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.patchReposOwnerRepoIssuesCommentsCommentId(null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-patchReposOwnerRepoIssuesCommentsCommentId', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.patchReposOwnerRepoIssuesCommentsCommentId('fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-patchReposOwnerRepoIssuesCommentsCommentId', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing commentId', (done) => {
        try {
          a.patchReposOwnerRepoIssuesCommentsCommentId('fakeparam', 'fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'commentId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-patchReposOwnerRepoIssuesCommentsCommentId', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        try {
          a.patchReposOwnerRepoIssuesCommentsCommentId('fakeparam', 'fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'body is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-patchReposOwnerRepoIssuesCommentsCommentId', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoIssuesEvents - errors', () => {
      it('should have a getReposOwnerRepoIssuesEvents function', (done) => {
        try {
          assert.equal(true, typeof a.getReposOwnerRepoIssuesEvents === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.getReposOwnerRepoIssuesEvents(null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoIssuesEventsQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.getReposOwnerRepoIssuesEvents('fakeparam', null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoIssuesEventsQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoIssuesEventsEventId - errors', () => {
      it('should have a getReposOwnerRepoIssuesEventsEventId function', (done) => {
        try {
          assert.equal(true, typeof a.getReposOwnerRepoIssuesEventsEventId === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.getReposOwnerRepoIssuesEventsEventId(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoIssuesEventsEventId', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.getReposOwnerRepoIssuesEventsEventId('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoIssuesEventsEventId', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing eventId', (done) => {
        try {
          a.getReposOwnerRepoIssuesEventsEventId('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'eventId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoIssuesEventsEventId', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoIssuesNumber - errors', () => {
      it('should have a getReposOwnerRepoIssuesNumber function', (done) => {
        try {
          assert.equal(true, typeof a.getReposOwnerRepoIssuesNumber === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.getReposOwnerRepoIssuesNumber(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoIssuesNumber', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.getReposOwnerRepoIssuesNumber('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoIssuesNumber', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing number', (done) => {
        try {
          a.getReposOwnerRepoIssuesNumber('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'number is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoIssuesNumber', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#patchReposOwnerRepoIssuesNumber - errors', () => {
      it('should have a patchReposOwnerRepoIssuesNumber function', (done) => {
        try {
          assert.equal(true, typeof a.patchReposOwnerRepoIssuesNumber === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.patchReposOwnerRepoIssuesNumber(null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-patchReposOwnerRepoIssuesNumber', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.patchReposOwnerRepoIssuesNumber('fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-patchReposOwnerRepoIssuesNumber', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing number', (done) => {
        try {
          a.patchReposOwnerRepoIssuesNumber('fakeparam', 'fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'number is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-patchReposOwnerRepoIssuesNumber', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        try {
          a.patchReposOwnerRepoIssuesNumber('fakeparam', 'fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'body is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-patchReposOwnerRepoIssuesNumber', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoIssuesNumberComments - errors', () => {
      it('should have a getReposOwnerRepoIssuesNumberComments function', (done) => {
        try {
          assert.equal(true, typeof a.getReposOwnerRepoIssuesNumberComments === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.getReposOwnerRepoIssuesNumberComments(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoIssuesNumberCommentsQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.getReposOwnerRepoIssuesNumberComments('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoIssuesNumberCommentsQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing number', (done) => {
        try {
          a.getReposOwnerRepoIssuesNumberComments('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'issueNumber is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoIssuesNumberCommentsQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#postReposOwnerRepoIssuesNumberComments - errors', () => {
      it('should have a postReposOwnerRepoIssuesNumberComments function', (done) => {
        try {
          assert.equal(true, typeof a.postReposOwnerRepoIssuesNumberComments === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.postReposOwnerRepoIssuesNumberComments(null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-postReposOwnerRepoIssuesNumberComments', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.postReposOwnerRepoIssuesNumberComments('fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-postReposOwnerRepoIssuesNumberComments', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing number', (done) => {
        try {
          a.postReposOwnerRepoIssuesNumberComments('fakeparam', 'fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'number is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-postReposOwnerRepoIssuesNumberComments', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        try {
          a.postReposOwnerRepoIssuesNumberComments('fakeparam', 'fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'body is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-postReposOwnerRepoIssuesNumberComments', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoIssuesNumberEvents - errors', () => {
      it('should have a getReposOwnerRepoIssuesNumberEvents function', (done) => {
        try {
          assert.equal(true, typeof a.getReposOwnerRepoIssuesNumberEvents === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.getReposOwnerRepoIssuesNumberEvents(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoIssuesNumberEventsQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.getReposOwnerRepoIssuesNumberEvents('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoIssuesNumberEventsQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing number', (done) => {
        try {
          a.getReposOwnerRepoIssuesNumberEvents('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'issueNumber is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoIssuesNumberEventsQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#deleteReposOwnerRepoIssuesNumberLabels - errors', () => {
      it('should have a deleteReposOwnerRepoIssuesNumberLabels function', (done) => {
        try {
          assert.equal(true, typeof a.deleteReposOwnerRepoIssuesNumberLabels === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.deleteReposOwnerRepoIssuesNumberLabels(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-deleteReposOwnerRepoIssuesNumberLabels', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.deleteReposOwnerRepoIssuesNumberLabels('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-deleteReposOwnerRepoIssuesNumberLabels', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing number', (done) => {
        try {
          a.deleteReposOwnerRepoIssuesNumberLabels('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'number is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-deleteReposOwnerRepoIssuesNumberLabels', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoIssuesNumberLabels - errors', () => {
      it('should have a getReposOwnerRepoIssuesNumberLabels function', (done) => {
        try {
          assert.equal(true, typeof a.getReposOwnerRepoIssuesNumberLabels === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.getReposOwnerRepoIssuesNumberLabels(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoIssuesNumberLabelsQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.getReposOwnerRepoIssuesNumberLabels('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoIssuesNumberLabelsQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing number', (done) => {
        try {
          a.getReposOwnerRepoIssuesNumberLabels('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'issueNumber is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoIssuesNumberLabelsQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#postReposOwnerRepoIssuesNumberLabels - errors', () => {
      it('should have a postReposOwnerRepoIssuesNumberLabels function', (done) => {
        try {
          assert.equal(true, typeof a.postReposOwnerRepoIssuesNumberLabels === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.postReposOwnerRepoIssuesNumberLabels(null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-postReposOwnerRepoIssuesNumberLabels', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.postReposOwnerRepoIssuesNumberLabels('fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-postReposOwnerRepoIssuesNumberLabels', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing number', (done) => {
        try {
          a.postReposOwnerRepoIssuesNumberLabels('fakeparam', 'fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'number is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-postReposOwnerRepoIssuesNumberLabels', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        try {
          a.postReposOwnerRepoIssuesNumberLabels('fakeparam', 'fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'body is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-postReposOwnerRepoIssuesNumberLabels', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#putReposOwnerRepoIssuesNumberLabels - errors', () => {
      it('should have a putReposOwnerRepoIssuesNumberLabels function', (done) => {
        try {
          assert.equal(true, typeof a.putReposOwnerRepoIssuesNumberLabels === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.putReposOwnerRepoIssuesNumberLabels(null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-putReposOwnerRepoIssuesNumberLabels', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.putReposOwnerRepoIssuesNumberLabels('fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-putReposOwnerRepoIssuesNumberLabels', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing number', (done) => {
        try {
          a.putReposOwnerRepoIssuesNumberLabels('fakeparam', 'fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'number is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-putReposOwnerRepoIssuesNumberLabels', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        try {
          a.putReposOwnerRepoIssuesNumberLabels('fakeparam', 'fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'body is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-putReposOwnerRepoIssuesNumberLabels', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#deleteReposOwnerRepoIssuesNumberLabelsName - errors', () => {
      it('should have a deleteReposOwnerRepoIssuesNumberLabelsName function', (done) => {
        try {
          assert.equal(true, typeof a.deleteReposOwnerRepoIssuesNumberLabelsName === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.deleteReposOwnerRepoIssuesNumberLabelsName(null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-deleteReposOwnerRepoIssuesNumberLabelsName', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.deleteReposOwnerRepoIssuesNumberLabelsName('fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-deleteReposOwnerRepoIssuesNumberLabelsName', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing number', (done) => {
        try {
          a.deleteReposOwnerRepoIssuesNumberLabelsName('fakeparam', 'fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'number is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-deleteReposOwnerRepoIssuesNumberLabelsName', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing name', (done) => {
        try {
          a.deleteReposOwnerRepoIssuesNumberLabelsName('fakeparam', 'fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'name is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-deleteReposOwnerRepoIssuesNumberLabelsName', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoKeys - errors', () => {
      it('should have a getReposOwnerRepoKeys function', (done) => {
        try {
          assert.equal(true, typeof a.getReposOwnerRepoKeys === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.getReposOwnerRepoKeys(null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoKeysQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.getReposOwnerRepoKeys('fakeparam', null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoKeysQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#postReposOwnerRepoKeys - errors', () => {
      it('should have a postReposOwnerRepoKeys function', (done) => {
        try {
          assert.equal(true, typeof a.postReposOwnerRepoKeys === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.postReposOwnerRepoKeys(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-postReposOwnerRepoKeys', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.postReposOwnerRepoKeys('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-postReposOwnerRepoKeys', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        try {
          a.postReposOwnerRepoKeys('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'body is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-postReposOwnerRepoKeys', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#deleteReposOwnerRepoKeysKeyId - errors', () => {
      it('should have a deleteReposOwnerRepoKeysKeyId function', (done) => {
        try {
          assert.equal(true, typeof a.deleteReposOwnerRepoKeysKeyId === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.deleteReposOwnerRepoKeysKeyId(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-deleteReposOwnerRepoKeysKeyId', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.deleteReposOwnerRepoKeysKeyId('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-deleteReposOwnerRepoKeysKeyId', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing keyId', (done) => {
        try {
          a.deleteReposOwnerRepoKeysKeyId('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'keyId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-deleteReposOwnerRepoKeysKeyId', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoKeysKeyId - errors', () => {
      it('should have a getReposOwnerRepoKeysKeyId function', (done) => {
        try {
          assert.equal(true, typeof a.getReposOwnerRepoKeysKeyId === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.getReposOwnerRepoKeysKeyId(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoKeysKeyId', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.getReposOwnerRepoKeysKeyId('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoKeysKeyId', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing keyId', (done) => {
        try {
          a.getReposOwnerRepoKeysKeyId('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'keyId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoKeysKeyId', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoLabels - errors', () => {
      it('should have a getReposOwnerRepoLabels function', (done) => {
        try {
          assert.equal(true, typeof a.getReposOwnerRepoLabels === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.getReposOwnerRepoLabels(null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoLabelsQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.getReposOwnerRepoLabels('fakeparam', null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoLabelsQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#postReposOwnerRepoLabels - errors', () => {
      it('should have a postReposOwnerRepoLabels function', (done) => {
        try {
          assert.equal(true, typeof a.postReposOwnerRepoLabels === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.postReposOwnerRepoLabels(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-postReposOwnerRepoLabels', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.postReposOwnerRepoLabels('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-postReposOwnerRepoLabels', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        try {
          a.postReposOwnerRepoLabels('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'body is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-postReposOwnerRepoLabels', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#deleteReposOwnerRepoLabelsName - errors', () => {
      it('should have a deleteReposOwnerRepoLabelsName function', (done) => {
        try {
          assert.equal(true, typeof a.deleteReposOwnerRepoLabelsName === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.deleteReposOwnerRepoLabelsName(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-deleteReposOwnerRepoLabelsName', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.deleteReposOwnerRepoLabelsName('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-deleteReposOwnerRepoLabelsName', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing name', (done) => {
        try {
          a.deleteReposOwnerRepoLabelsName('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'name is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-deleteReposOwnerRepoLabelsName', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoLabelsName - errors', () => {
      it('should have a getReposOwnerRepoLabelsName function', (done) => {
        try {
          assert.equal(true, typeof a.getReposOwnerRepoLabelsName === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.getReposOwnerRepoLabelsName(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoLabelsName', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.getReposOwnerRepoLabelsName('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoLabelsName', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing name', (done) => {
        try {
          a.getReposOwnerRepoLabelsName('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'name is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoLabelsName', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#patchReposOwnerRepoLabelsName - errors', () => {
      it('should have a patchReposOwnerRepoLabelsName function', (done) => {
        try {
          assert.equal(true, typeof a.patchReposOwnerRepoLabelsName === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.patchReposOwnerRepoLabelsName(null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-patchReposOwnerRepoLabelsName', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.patchReposOwnerRepoLabelsName('fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-patchReposOwnerRepoLabelsName', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing name', (done) => {
        try {
          a.patchReposOwnerRepoLabelsName('fakeparam', 'fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'name is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-patchReposOwnerRepoLabelsName', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        try {
          a.patchReposOwnerRepoLabelsName('fakeparam', 'fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'body is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-patchReposOwnerRepoLabelsName', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoLanguages - errors', () => {
      it('should have a getReposOwnerRepoLanguages function', (done) => {
        try {
          assert.equal(true, typeof a.getReposOwnerRepoLanguages === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.getReposOwnerRepoLanguages(null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoLanguages', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.getReposOwnerRepoLanguages('fakeparam', null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoLanguages', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#postReposOwnerRepoMerges - errors', () => {
      it('should have a postReposOwnerRepoMerges function', (done) => {
        try {
          assert.equal(true, typeof a.postReposOwnerRepoMerges === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.postReposOwnerRepoMerges(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-postReposOwnerRepoMerges', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.postReposOwnerRepoMerges('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-postReposOwnerRepoMerges', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        try {
          a.postReposOwnerRepoMerges('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'body is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-postReposOwnerRepoMerges', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoMilestones - errors', () => {
      it('should have a getReposOwnerRepoMilestones function', (done) => {
        try {
          assert.equal(true, typeof a.getReposOwnerRepoMilestones === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.getReposOwnerRepoMilestones(null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoMilestonesQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.getReposOwnerRepoMilestones('fakeparam', null, null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoMilestonesQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#postReposOwnerRepoMilestones - errors', () => {
      it('should have a postReposOwnerRepoMilestones function', (done) => {
        try {
          assert.equal(true, typeof a.postReposOwnerRepoMilestones === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.postReposOwnerRepoMilestones(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-postReposOwnerRepoMilestones', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.postReposOwnerRepoMilestones('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-postReposOwnerRepoMilestones', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        try {
          a.postReposOwnerRepoMilestones('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'body is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-postReposOwnerRepoMilestones', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#deleteReposOwnerRepoMilestonesNumber - errors', () => {
      it('should have a deleteReposOwnerRepoMilestonesNumber function', (done) => {
        try {
          assert.equal(true, typeof a.deleteReposOwnerRepoMilestonesNumber === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.deleteReposOwnerRepoMilestonesNumber(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-deleteReposOwnerRepoMilestonesNumber', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.deleteReposOwnerRepoMilestonesNumber('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-deleteReposOwnerRepoMilestonesNumber', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing number', (done) => {
        try {
          a.deleteReposOwnerRepoMilestonesNumber('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'number is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-deleteReposOwnerRepoMilestonesNumber', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoMilestonesNumber - errors', () => {
      it('should have a getReposOwnerRepoMilestonesNumber function', (done) => {
        try {
          assert.equal(true, typeof a.getReposOwnerRepoMilestonesNumber === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.getReposOwnerRepoMilestonesNumber(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoMilestonesNumber', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.getReposOwnerRepoMilestonesNumber('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoMilestonesNumber', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing number', (done) => {
        try {
          a.getReposOwnerRepoMilestonesNumber('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'number is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoMilestonesNumber', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#patchReposOwnerRepoMilestonesNumber - errors', () => {
      it('should have a patchReposOwnerRepoMilestonesNumber function', (done) => {
        try {
          assert.equal(true, typeof a.patchReposOwnerRepoMilestonesNumber === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.patchReposOwnerRepoMilestonesNumber(null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-patchReposOwnerRepoMilestonesNumber', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.patchReposOwnerRepoMilestonesNumber('fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-patchReposOwnerRepoMilestonesNumber', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing number', (done) => {
        try {
          a.patchReposOwnerRepoMilestonesNumber('fakeparam', 'fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'number is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-patchReposOwnerRepoMilestonesNumber', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        try {
          a.patchReposOwnerRepoMilestonesNumber('fakeparam', 'fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'body is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-patchReposOwnerRepoMilestonesNumber', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoMilestonesNumberLabels - errors', () => {
      it('should have a getReposOwnerRepoMilestonesNumberLabels function', (done) => {
        try {
          assert.equal(true, typeof a.getReposOwnerRepoMilestonesNumberLabels === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.getReposOwnerRepoMilestonesNumberLabels(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoMilestonesNumberLabelsQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.getReposOwnerRepoMilestonesNumberLabels('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoMilestonesNumberLabelsQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing number', (done) => {
        try {
          a.getReposOwnerRepoMilestonesNumberLabels('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'milestoneNumber is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoMilestonesNumberLabelsQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoNotifications - errors', () => {
      it('should have a getReposOwnerRepoNotifications function', (done) => {
        try {
          assert.equal(true, typeof a.getReposOwnerRepoNotifications === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.getReposOwnerRepoNotifications(null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoNotificationsQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.getReposOwnerRepoNotifications('fakeparam', null, null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoNotificationsQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#putReposOwnerRepoNotifications - errors', () => {
      it('should have a putReposOwnerRepoNotifications function', (done) => {
        try {
          assert.equal(true, typeof a.putReposOwnerRepoNotifications === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.putReposOwnerRepoNotifications(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-putReposOwnerRepoNotifications', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.putReposOwnerRepoNotifications('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-putReposOwnerRepoNotifications', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        try {
          a.putReposOwnerRepoNotifications('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'body is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-putReposOwnerRepoNotifications', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoPulls - errors', () => {
      it('should have a getReposOwnerRepoPulls function', (done) => {
        try {
          assert.equal(true, typeof a.getReposOwnerRepoPulls === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.getReposOwnerRepoPulls(null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoPullsQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.getReposOwnerRepoPulls('fakeparam', null, null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoPullsQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#postReposOwnerRepoPulls - errors', () => {
      it('should have a postReposOwnerRepoPulls function', (done) => {
        try {
          assert.equal(true, typeof a.postReposOwnerRepoPulls === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.postReposOwnerRepoPulls(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-postReposOwnerRepoPulls', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.postReposOwnerRepoPulls('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-postReposOwnerRepoPulls', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        try {
          a.postReposOwnerRepoPulls('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'body is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-postReposOwnerRepoPulls', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoPullsComments - errors', () => {
      it('should have a getReposOwnerRepoPullsComments function', (done) => {
        try {
          assert.equal(true, typeof a.getReposOwnerRepoPullsComments === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.getReposOwnerRepoPullsComments(null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoPullsCommentsQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.getReposOwnerRepoPullsComments('fakeparam', null, null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoPullsCommentsQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#deleteReposOwnerRepoPullsCommentsCommentId - errors', () => {
      it('should have a deleteReposOwnerRepoPullsCommentsCommentId function', (done) => {
        try {
          assert.equal(true, typeof a.deleteReposOwnerRepoPullsCommentsCommentId === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.deleteReposOwnerRepoPullsCommentsCommentId(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-deleteReposOwnerRepoPullsCommentsCommentId', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.deleteReposOwnerRepoPullsCommentsCommentId('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-deleteReposOwnerRepoPullsCommentsCommentId', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing commentId', (done) => {
        try {
          a.deleteReposOwnerRepoPullsCommentsCommentId('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'commentId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-deleteReposOwnerRepoPullsCommentsCommentId', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoPullsCommentsCommentId - errors', () => {
      it('should have a getReposOwnerRepoPullsCommentsCommentId function', (done) => {
        try {
          assert.equal(true, typeof a.getReposOwnerRepoPullsCommentsCommentId === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.getReposOwnerRepoPullsCommentsCommentId(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoPullsCommentsCommentId', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.getReposOwnerRepoPullsCommentsCommentId('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoPullsCommentsCommentId', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing commentId', (done) => {
        try {
          a.getReposOwnerRepoPullsCommentsCommentId('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'commentId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoPullsCommentsCommentId', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#patchReposOwnerRepoPullsCommentsCommentId - errors', () => {
      it('should have a patchReposOwnerRepoPullsCommentsCommentId function', (done) => {
        try {
          assert.equal(true, typeof a.patchReposOwnerRepoPullsCommentsCommentId === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.patchReposOwnerRepoPullsCommentsCommentId(null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-patchReposOwnerRepoPullsCommentsCommentId', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.patchReposOwnerRepoPullsCommentsCommentId('fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-patchReposOwnerRepoPullsCommentsCommentId', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing commentId', (done) => {
        try {
          a.patchReposOwnerRepoPullsCommentsCommentId('fakeparam', 'fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'commentId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-patchReposOwnerRepoPullsCommentsCommentId', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        try {
          a.patchReposOwnerRepoPullsCommentsCommentId('fakeparam', 'fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'body is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-patchReposOwnerRepoPullsCommentsCommentId', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoPullsNumber - errors', () => {
      it('should have a getReposOwnerRepoPullsNumber function', (done) => {
        try {
          assert.equal(true, typeof a.getReposOwnerRepoPullsNumber === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.getReposOwnerRepoPullsNumber(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoPullsNumber', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.getReposOwnerRepoPullsNumber('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoPullsNumber', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing number', (done) => {
        try {
          a.getReposOwnerRepoPullsNumber('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'number is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoPullsNumber', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#patchReposOwnerRepoPullsNumber - errors', () => {
      it('should have a patchReposOwnerRepoPullsNumber function', (done) => {
        try {
          assert.equal(true, typeof a.patchReposOwnerRepoPullsNumber === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.patchReposOwnerRepoPullsNumber(null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-patchReposOwnerRepoPullsNumber', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.patchReposOwnerRepoPullsNumber('fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-patchReposOwnerRepoPullsNumber', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing number', (done) => {
        try {
          a.patchReposOwnerRepoPullsNumber('fakeparam', 'fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'number is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-patchReposOwnerRepoPullsNumber', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        try {
          a.patchReposOwnerRepoPullsNumber('fakeparam', 'fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'body is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-patchReposOwnerRepoPullsNumber', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoPullsNumberComments - errors', () => {
      it('should have a getReposOwnerRepoPullsNumberComments function', (done) => {
        try {
          assert.equal(true, typeof a.getReposOwnerRepoPullsNumberComments === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.getReposOwnerRepoPullsNumberComments(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoPullsNumberCommentsQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.getReposOwnerRepoPullsNumberComments('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoPullsNumberCommentsQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing number', (done) => {
        try {
          a.getReposOwnerRepoPullsNumberComments('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'pullNumber is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoPullsNumberCommentsQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#postReposOwnerRepoPullsNumberComments - errors', () => {
      it('should have a postReposOwnerRepoPullsNumberComments function', (done) => {
        try {
          assert.equal(true, typeof a.postReposOwnerRepoPullsNumberComments === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.postReposOwnerRepoPullsNumberComments(null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-postReposOwnerRepoPullsNumberComments', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.postReposOwnerRepoPullsNumberComments('fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-postReposOwnerRepoPullsNumberComments', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing number', (done) => {
        try {
          a.postReposOwnerRepoPullsNumberComments('fakeparam', 'fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'number is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-postReposOwnerRepoPullsNumberComments', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        try {
          a.postReposOwnerRepoPullsNumberComments('fakeparam', 'fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'body is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-postReposOwnerRepoPullsNumberComments', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoPullsNumberCommits - errors', () => {
      it('should have a getReposOwnerRepoPullsNumberCommits function', (done) => {
        try {
          assert.equal(true, typeof a.getReposOwnerRepoPullsNumberCommits === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.getReposOwnerRepoPullsNumberCommits(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoPullsNumberCommitsQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.getReposOwnerRepoPullsNumberCommits('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoPullsNumberCommitsQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing number', (done) => {
        try {
          a.getReposOwnerRepoPullsNumberCommits('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'pullNumber is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoPullsNumberCommitsQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoPullsNumberFiles - errors', () => {
      it('should have a getReposOwnerRepoPullsNumberFiles function', (done) => {
        try {
          assert.equal(true, typeof a.getReposOwnerRepoPullsNumberFiles === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.getReposOwnerRepoPullsNumberFiles(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoPullsNumberFilesQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.getReposOwnerRepoPullsNumberFiles('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoPullsNumberFilesQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing number', (done) => {
        try {
          a.getReposOwnerRepoPullsNumberFiles('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'pullNumber is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoPullsNumberFilesQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoPullsNumberMerge - errors', () => {
      it('should have a getReposOwnerRepoPullsNumberMerge function', (done) => {
        try {
          assert.equal(true, typeof a.getReposOwnerRepoPullsNumberMerge === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.getReposOwnerRepoPullsNumberMerge(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoPullsNumberMerge', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.getReposOwnerRepoPullsNumberMerge('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoPullsNumberMerge', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing number', (done) => {
        try {
          a.getReposOwnerRepoPullsNumberMerge('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'number is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoPullsNumberMerge', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#putReposOwnerRepoPullsNumberMerge - errors', () => {
      it('should have a putReposOwnerRepoPullsNumberMerge function', (done) => {
        try {
          assert.equal(true, typeof a.putReposOwnerRepoPullsNumberMerge === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.putReposOwnerRepoPullsNumberMerge(null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-putReposOwnerRepoPullsNumberMerge', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.putReposOwnerRepoPullsNumberMerge('fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-putReposOwnerRepoPullsNumberMerge', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing number', (done) => {
        try {
          a.putReposOwnerRepoPullsNumberMerge('fakeparam', 'fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'number is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-putReposOwnerRepoPullsNumberMerge', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        try {
          a.putReposOwnerRepoPullsNumberMerge('fakeparam', 'fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'body is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-putReposOwnerRepoPullsNumberMerge', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoReadme - errors', () => {
      it('should have a getReposOwnerRepoReadme function', (done) => {
        try {
          assert.equal(true, typeof a.getReposOwnerRepoReadme === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.getReposOwnerRepoReadme(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoReadme', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.getReposOwnerRepoReadme('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoReadme', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoReleases - errors', () => {
      it('should have a getReposOwnerRepoReleases function', (done) => {
        try {
          assert.equal(true, typeof a.getReposOwnerRepoReleases === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.getReposOwnerRepoReleases(null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoReleasesQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.getReposOwnerRepoReleases('fakeparam', null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoReleasesQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#postReposOwnerRepoReleases - errors', () => {
      it('should have a postReposOwnerRepoReleases function', (done) => {
        try {
          assert.equal(true, typeof a.postReposOwnerRepoReleases === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.postReposOwnerRepoReleases(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-postReposOwnerRepoReleases', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.postReposOwnerRepoReleases('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-postReposOwnerRepoReleases', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        try {
          a.postReposOwnerRepoReleases('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'body is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-postReposOwnerRepoReleases', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#deleteReposOwnerRepoReleasesAssetsId - errors', () => {
      it('should have a deleteReposOwnerRepoReleasesAssetsId function', (done) => {
        try {
          assert.equal(true, typeof a.deleteReposOwnerRepoReleasesAssetsId === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.deleteReposOwnerRepoReleasesAssetsId(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-deleteReposOwnerRepoReleasesAssetsId', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.deleteReposOwnerRepoReleasesAssetsId('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-deleteReposOwnerRepoReleasesAssetsId', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        try {
          a.deleteReposOwnerRepoReleasesAssetsId('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'id is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-deleteReposOwnerRepoReleasesAssetsId', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoReleasesAssetsId - errors', () => {
      it('should have a getReposOwnerRepoReleasesAssetsId function', (done) => {
        try {
          assert.equal(true, typeof a.getReposOwnerRepoReleasesAssetsId === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.getReposOwnerRepoReleasesAssetsId(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoReleasesAssetsId', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.getReposOwnerRepoReleasesAssetsId('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoReleasesAssetsId', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        try {
          a.getReposOwnerRepoReleasesAssetsId('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'id is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoReleasesAssetsId', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#patchReposOwnerRepoReleasesAssetsId - errors', () => {
      it('should have a patchReposOwnerRepoReleasesAssetsId function', (done) => {
        try {
          assert.equal(true, typeof a.patchReposOwnerRepoReleasesAssetsId === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.patchReposOwnerRepoReleasesAssetsId(null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-patchReposOwnerRepoReleasesAssetsId', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.patchReposOwnerRepoReleasesAssetsId('fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-patchReposOwnerRepoReleasesAssetsId', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        try {
          a.patchReposOwnerRepoReleasesAssetsId('fakeparam', 'fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'id is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-patchReposOwnerRepoReleasesAssetsId', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        try {
          a.patchReposOwnerRepoReleasesAssetsId('fakeparam', 'fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'body is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-patchReposOwnerRepoReleasesAssetsId', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#deleteReposOwnerRepoReleasesId - errors', () => {
      it('should have a deleteReposOwnerRepoReleasesId function', (done) => {
        try {
          assert.equal(true, typeof a.deleteReposOwnerRepoReleasesId === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.deleteReposOwnerRepoReleasesId(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-deleteReposOwnerRepoReleasesId', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.deleteReposOwnerRepoReleasesId('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-deleteReposOwnerRepoReleasesId', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        try {
          a.deleteReposOwnerRepoReleasesId('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'id is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-deleteReposOwnerRepoReleasesId', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoReleasesId - errors', () => {
      it('should have a getReposOwnerRepoReleasesId function', (done) => {
        try {
          assert.equal(true, typeof a.getReposOwnerRepoReleasesId === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.getReposOwnerRepoReleasesId(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoReleasesId', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.getReposOwnerRepoReleasesId('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoReleasesId', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        try {
          a.getReposOwnerRepoReleasesId('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'id is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoReleasesId', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#patchReposOwnerRepoReleasesId - errors', () => {
      it('should have a patchReposOwnerRepoReleasesId function', (done) => {
        try {
          assert.equal(true, typeof a.patchReposOwnerRepoReleasesId === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.patchReposOwnerRepoReleasesId(null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-patchReposOwnerRepoReleasesId', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.patchReposOwnerRepoReleasesId('fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-patchReposOwnerRepoReleasesId', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        try {
          a.patchReposOwnerRepoReleasesId('fakeparam', 'fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'id is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-patchReposOwnerRepoReleasesId', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        try {
          a.patchReposOwnerRepoReleasesId('fakeparam', 'fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'body is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-patchReposOwnerRepoReleasesId', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoReleasesIdAssets - errors', () => {
      it('should have a getReposOwnerRepoReleasesIdAssets function', (done) => {
        try {
          assert.equal(true, typeof a.getReposOwnerRepoReleasesIdAssets === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.getReposOwnerRepoReleasesIdAssets(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposListReleaseAssetsQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.getReposOwnerRepoReleasesIdAssets('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposListReleaseAssetsQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        try {
          a.getReposOwnerRepoReleasesIdAssets('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'releaseId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposListReleaseAssetsQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoStargazers - errors', () => {
      it('should have a getReposOwnerRepoStargazers function', (done) => {
        try {
          assert.equal(true, typeof a.getReposOwnerRepoStargazers === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.getReposOwnerRepoStargazers(null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoStargazersQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.getReposOwnerRepoStargazers('fakeparam', null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoStargazersQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoStatsCodeFrequency - errors', () => {
      it('should have a getReposOwnerRepoStatsCodeFrequency function', (done) => {
        try {
          assert.equal(true, typeof a.getReposOwnerRepoStatsCodeFrequency === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.getReposOwnerRepoStatsCodeFrequency(null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoStatsCodeFrequency', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.getReposOwnerRepoStatsCodeFrequency('fakeparam', null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoStatsCodeFrequency', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoStatsCommitActivity - errors', () => {
      it('should have a getReposOwnerRepoStatsCommitActivity function', (done) => {
        try {
          assert.equal(true, typeof a.getReposOwnerRepoStatsCommitActivity === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.getReposOwnerRepoStatsCommitActivity(null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoStatsCommitActivity', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.getReposOwnerRepoStatsCommitActivity('fakeparam', null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoStatsCommitActivity', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoStatsContributors - errors', () => {
      it('should have a getReposOwnerRepoStatsContributors function', (done) => {
        try {
          assert.equal(true, typeof a.getReposOwnerRepoStatsContributors === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.getReposOwnerRepoStatsContributors(null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoStatsContributors', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.getReposOwnerRepoStatsContributors('fakeparam', null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoStatsContributors', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoStatsParticipation - errors', () => {
      it('should have a getReposOwnerRepoStatsParticipation function', (done) => {
        try {
          assert.equal(true, typeof a.getReposOwnerRepoStatsParticipation === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.getReposOwnerRepoStatsParticipation(null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoStatsParticipation', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.getReposOwnerRepoStatsParticipation('fakeparam', null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoStatsParticipation', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoStatsPunchCard - errors', () => {
      it('should have a getReposOwnerRepoStatsPunchCard function', (done) => {
        try {
          assert.equal(true, typeof a.getReposOwnerRepoStatsPunchCard === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.getReposOwnerRepoStatsPunchCard(null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoStatsPunchCard', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.getReposOwnerRepoStatsPunchCard('fakeparam', null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoStatsPunchCard', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoStatusesRef - errors', () => {
      it('should have a getReposOwnerRepoStatusesRef function', (done) => {
        try {
          assert.equal(true, typeof a.getReposOwnerRepoStatusesRef === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.getReposOwnerRepoStatusesRef(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoStatusesRef', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.getReposOwnerRepoStatusesRef('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoStatusesRef', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing ref', (done) => {
        try {
          a.getReposOwnerRepoStatusesRef('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'ref is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoStatusesRef', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#postReposOwnerRepoStatusesRef - errors', () => {
      it('should have a postReposOwnerRepoStatusesRef function', (done) => {
        try {
          assert.equal(true, typeof a.postReposOwnerRepoStatusesRef === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.postReposOwnerRepoStatusesRef(null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-postReposOwnerRepoStatusesRef', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.postReposOwnerRepoStatusesRef('fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-postReposOwnerRepoStatusesRef', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing ref', (done) => {
        try {
          a.postReposOwnerRepoStatusesRef('fakeparam', 'fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'ref is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-postReposOwnerRepoStatusesRef', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        try {
          a.postReposOwnerRepoStatusesRef('fakeparam', 'fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'body is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-postReposOwnerRepoStatusesRef', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoSubscribers - errors', () => {
      it('should have a getReposOwnerRepoSubscribers function', (done) => {
        try {
          assert.equal(true, typeof a.getReposOwnerRepoSubscribers === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.getReposOwnerRepoSubscribers(null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoSubscribersQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.getReposOwnerRepoSubscribers('fakeparam', null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoSubscribersQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#deleteReposOwnerRepoSubscription - errors', () => {
      it('should have a deleteReposOwnerRepoSubscription function', (done) => {
        try {
          assert.equal(true, typeof a.deleteReposOwnerRepoSubscription === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.deleteReposOwnerRepoSubscription(null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-deleteReposOwnerRepoSubscription', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.deleteReposOwnerRepoSubscription('fakeparam', null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-deleteReposOwnerRepoSubscription', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoSubscription - errors', () => {
      it('should have a getReposOwnerRepoSubscription function', (done) => {
        try {
          assert.equal(true, typeof a.getReposOwnerRepoSubscription === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.getReposOwnerRepoSubscription(null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoSubscription', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.getReposOwnerRepoSubscription('fakeparam', null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoSubscription', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#putReposOwnerRepoSubscription - errors', () => {
      it('should have a putReposOwnerRepoSubscription function', (done) => {
        try {
          assert.equal(true, typeof a.putReposOwnerRepoSubscription === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.putReposOwnerRepoSubscription(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-putReposOwnerRepoSubscription', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.putReposOwnerRepoSubscription('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-putReposOwnerRepoSubscription', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        try {
          a.putReposOwnerRepoSubscription('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'body is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-putReposOwnerRepoSubscription', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoTags - errors', () => {
      it('should have a getReposOwnerRepoTags function', (done) => {
        try {
          assert.equal(true, typeof a.getReposOwnerRepoTags === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.getReposOwnerRepoTags(null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoTagsQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.getReposOwnerRepoTags('fakeparam', null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoTagsQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoTeams - errors', () => {
      it('should have a getReposOwnerRepoTeams function', (done) => {
        try {
          assert.equal(true, typeof a.getReposOwnerRepoTeams === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.getReposOwnerRepoTeams(null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoTeamsQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.getReposOwnerRepoTeams('fakeparam', null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoTeamsQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoWatchers - errors', () => {
      it('should have a getReposOwnerRepoWatchers function', (done) => {
        try {
          assert.equal(true, typeof a.getReposOwnerRepoWatchers === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.getReposOwnerRepoWatchers(null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoWatchers', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.getReposOwnerRepoWatchers('fakeparam', null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoWatchers', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoArchiveFormatPath - errors', () => {
      it('should have a getReposOwnerRepoArchiveFormatPath function', (done) => {
        try {
          assert.equal(true, typeof a.getReposOwnerRepoArchiveFormatPath === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.getReposOwnerRepoArchiveFormatPath(null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoArchiveFormatPath', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.getReposOwnerRepoArchiveFormatPath('fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoArchiveFormatPath', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing archiveFormat', (done) => {
        try {
          a.getReposOwnerRepoArchiveFormatPath('fakeparam', 'fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'archiveFormat is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoArchiveFormatPath', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing pathParam', (done) => {
        try {
          a.getReposOwnerRepoArchiveFormatPath('fakeparam', 'fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'pathParam is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoArchiveFormatPath', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getRepositories - errors', () => {
      it('should have a getRepositories function', (done) => {
        try {
          assert.equal(true, typeof a.getRepositories === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getSearchCode - errors', () => {
      it('should have a getSearchCode function', (done) => {
        try {
          assert.equal(true, typeof a.getSearchCode === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing q', (done) => {
        try {
          a.getSearchCode('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'q is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getSearchCodeWithOptions', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const fakeData = {
      order: 'desc'
    };
    describe('#getSearchCodeWithOptions - errors', () => {
      it('should have a getSearchCodeWithOptions function', (done) => {
        try {
          assert.equal(true, typeof a.getSearchCodeWithOptions === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing q', (done) => {
        try {
          a.getSearchCodeWithOptions(fakeData, (data, error) => {
            try {
              const displayE = 'q is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getSearchCodeWithOptions', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getSearchIssues - errors', () => {
      it('should have a getSearchIssues function', (done) => {
        try {
          assert.equal(true, typeof a.getSearchIssues === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing q', (done) => {
        try {
          a.getSearchIssues('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'q is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getSearchIssuesWithOptions', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getSearchIssuesWithOptions - errors', () => {
      it('should have a getSearchIssuesWithOptions function', (done) => {
        try {
          assert.equal(true, typeof a.getSearchIssuesWithOptions === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing q', (done) => {
        try {
          a.getSearchIssuesWithOptions(fakeData, (data, error) => {
            try {
              const displayE = 'q is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getSearchIssuesWithOptions', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getSearchRepositories - errors', () => {
      it('should have a getSearchRepositories function', (done) => {
        try {
          assert.equal(true, typeof a.getSearchRepositories === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing q', (done) => {
        try {
          a.getSearchRepositories('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'q is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getSearchRepositoriesQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getSearchUsers - errors', () => {
      it('should have a getSearchUsers function', (done) => {
        try {
          assert.equal(true, typeof a.getSearchUsers === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing q', (done) => {
        try {
          a.getSearchUsers('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'q is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getSearchUsersQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#deleteTeamsTeamId - errors', () => {
      it('should have a deleteTeamsTeamId function', (done) => {
        try {
          assert.equal(true, typeof a.deleteTeamsTeamId === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing teamId', (done) => {
        try {
          a.deleteTeamsTeamId(null, (data, error) => {
            try {
              const displayE = 'teamId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-deleteTeamsTeamId', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getTeamsTeamId - errors', () => {
      it('should have a getTeamsTeamId function', (done) => {
        try {
          assert.equal(true, typeof a.getTeamsTeamId === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing teamId', (done) => {
        try {
          a.getTeamsTeamId(null, (data, error) => {
            try {
              const displayE = 'teamId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getTeamsTeamId', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#patchTeamsTeamId - errors', () => {
      it('should have a patchTeamsTeamId function', (done) => {
        try {
          assert.equal(true, typeof a.patchTeamsTeamId === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing teamId', (done) => {
        try {
          a.patchTeamsTeamId(null, null, (data, error) => {
            try {
              const displayE = 'teamId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-patchTeamsTeamId', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        try {
          a.patchTeamsTeamId('fakeparam', null, (data, error) => {
            try {
              const displayE = 'body is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-patchTeamsTeamId', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getTeamsTeamIdMembers - errors', () => {
      it('should have a getTeamsTeamIdMembers function', (done) => {
        try {
          assert.equal(true, typeof a.getTeamsTeamIdMembers === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing teamId', (done) => {
        try {
          a.getTeamsTeamIdMembers(null, (data, error) => {
            try {
              const displayE = 'teamId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getTeamsTeamIdMembersQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#deleteTeamsTeamIdMembersUsername - errors', () => {
      it('should have a deleteTeamsTeamIdMembersUsername function', (done) => {
        try {
          assert.equal(true, typeof a.deleteTeamsTeamIdMembersUsername === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing teamId', (done) => {
        try {
          a.deleteTeamsTeamIdMembersUsername(null, null, (data, error) => {
            try {
              const displayE = 'teamId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-deleteTeamsTeamIdMembersUsername', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing username', (done) => {
        try {
          a.deleteTeamsTeamIdMembersUsername('fakeparam', null, (data, error) => {
            try {
              const displayE = 'username is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-deleteTeamsTeamIdMembersUsername', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getTeamsTeamIdMembersUsername - errors', () => {
      it('should have a getTeamsTeamIdMembersUsername function', (done) => {
        try {
          assert.equal(true, typeof a.getTeamsTeamIdMembersUsername === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing teamId', (done) => {
        try {
          a.getTeamsTeamIdMembersUsername(null, null, (data, error) => {
            try {
              const displayE = 'teamId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getTeamsTeamIdMembersUsername', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing username', (done) => {
        try {
          a.getTeamsTeamIdMembersUsername('fakeparam', null, (data, error) => {
            try {
              const displayE = 'username is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getTeamsTeamIdMembersUsername', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#putTeamsTeamIdMembersUsername - errors', () => {
      it('should have a putTeamsTeamIdMembersUsername function', (done) => {
        try {
          assert.equal(true, typeof a.putTeamsTeamIdMembersUsername === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing teamId', (done) => {
        try {
          a.putTeamsTeamIdMembersUsername(null, null, (data, error) => {
            try {
              const displayE = 'teamId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-putTeamsTeamIdMembersUsername', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing username', (done) => {
        try {
          a.putTeamsTeamIdMembersUsername('fakeparam', null, (data, error) => {
            try {
              const displayE = 'username is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-putTeamsTeamIdMembersUsername', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#deleteTeamsTeamIdMembershipsUsername - errors', () => {
      it('should have a deleteTeamsTeamIdMembershipsUsername function', (done) => {
        try {
          assert.equal(true, typeof a.deleteTeamsTeamIdMembershipsUsername === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing teamId', (done) => {
        try {
          a.deleteTeamsTeamIdMembershipsUsername(null, null, (data, error) => {
            try {
              const displayE = 'teamId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-deleteTeamsTeamIdMembershipsUsername', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing username', (done) => {
        try {
          a.deleteTeamsTeamIdMembershipsUsername('fakeparam', null, (data, error) => {
            try {
              const displayE = 'username is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-deleteTeamsTeamIdMembershipsUsername', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getTeamsTeamIdMembershipsUsername - errors', () => {
      it('should have a getTeamsTeamIdMembershipsUsername function', (done) => {
        try {
          assert.equal(true, typeof a.getTeamsTeamIdMembershipsUsername === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing teamId', (done) => {
        try {
          a.getTeamsTeamIdMembershipsUsername(null, null, (data, error) => {
            try {
              const displayE = 'teamId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getTeamsTeamIdMembershipsUsername', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing username', (done) => {
        try {
          a.getTeamsTeamIdMembershipsUsername('fakeparam', null, (data, error) => {
            try {
              const displayE = 'username is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getTeamsTeamIdMembershipsUsername', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#putTeamsTeamIdMembershipsUsername - errors', () => {
      it('should have a putTeamsTeamIdMembershipsUsername function', (done) => {
        try {
          assert.equal(true, typeof a.putTeamsTeamIdMembershipsUsername === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing teamId', (done) => {
        try {
          a.putTeamsTeamIdMembershipsUsername(null, null, (data, error) => {
            try {
              const displayE = 'teamId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-putTeamsTeamIdMembershipsUsername', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing username', (done) => {
        try {
          a.putTeamsTeamIdMembershipsUsername('fakeparam', null, (data, error) => {
            try {
              const displayE = 'username is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-putTeamsTeamIdMembershipsUsername', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getTeamsTeamIdRepos - errors', () => {
      it('should have a getTeamsTeamIdRepos function', (done) => {
        try {
          assert.equal(true, typeof a.getTeamsTeamIdRepos === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing teamId', (done) => {
        try {
          a.getTeamsTeamIdRepos(null, (data, error) => {
            try {
              const displayE = 'teamId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getTeamsTeamIdReposQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#deleteTeamsTeamIdReposOwnerRepo - errors', () => {
      it('should have a deleteTeamsTeamIdReposOwnerRepo function', (done) => {
        try {
          assert.equal(true, typeof a.deleteTeamsTeamIdReposOwnerRepo === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing teamId', (done) => {
        try {
          a.deleteTeamsTeamIdReposOwnerRepo(null, null, null, (data, error) => {
            try {
              const displayE = 'teamId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-deleteTeamsTeamIdReposOwnerRepo', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.deleteTeamsTeamIdReposOwnerRepo('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-deleteTeamsTeamIdReposOwnerRepo', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.deleteTeamsTeamIdReposOwnerRepo('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-deleteTeamsTeamIdReposOwnerRepo', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getTeamsTeamIdReposOwnerRepo - errors', () => {
      it('should have a getTeamsTeamIdReposOwnerRepo function', (done) => {
        try {
          assert.equal(true, typeof a.getTeamsTeamIdReposOwnerRepo === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing teamId', (done) => {
        try {
          a.getTeamsTeamIdReposOwnerRepo(null, null, null, (data, error) => {
            try {
              const displayE = 'teamId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getTeamsTeamIdReposOwnerRepo', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.getTeamsTeamIdReposOwnerRepo('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getTeamsTeamIdReposOwnerRepo', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.getTeamsTeamIdReposOwnerRepo('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getTeamsTeamIdReposOwnerRepo', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#putTeamsTeamIdReposOwnerRepo - errors', () => {
      it('should have a putTeamsTeamIdReposOwnerRepo function', (done) => {
        try {
          assert.equal(true, typeof a.putTeamsTeamIdReposOwnerRepo === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing teamId', (done) => {
        try {
          a.putTeamsTeamIdReposOwnerRepo(null, null, null, (data, error) => {
            try {
              const displayE = 'teamId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-putTeamsTeamIdReposOwnerRepo', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.putTeamsTeamIdReposOwnerRepo('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-putTeamsTeamIdReposOwnerRepo', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.putTeamsTeamIdReposOwnerRepo('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-putTeamsTeamIdReposOwnerRepo', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getUser - errors', () => {
      it('should have a getUser function', (done) => {
        try {
          assert.equal(true, typeof a.getUser === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#patchUser - errors', () => {
      it('should have a patchUser function', (done) => {
        try {
          assert.equal(true, typeof a.patchUser === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        try {
          a.patchUser(null, (data, error) => {
            try {
              const displayE = 'body is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-patchUser', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#deleteUserEmails - errors', () => {
      it('should have a deleteUserEmails function', (done) => {
        try {
          assert.equal(true, typeof a.deleteUserEmails === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        try {
          a.deleteUserEmails(null, (data, error) => {
            try {
              const displayE = 'body is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-deleteUserEmails', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getUserEmails - errors', () => {
      it('should have a getUserEmails function', (done) => {
        try {
          assert.equal(true, typeof a.getUserEmails === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#postUserEmails - errors', () => {
      it('should have a postUserEmails function', (done) => {
        try {
          assert.equal(true, typeof a.postUserEmails === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        try {
          a.postUserEmails(null, (data, error) => {
            try {
              const displayE = 'body is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-postUserEmails', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getUserFollowers - errors', () => {
      it('should have a getUserFollowers function', (done) => {
        try {
          assert.equal(true, typeof a.getUserFollowers === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getUserFollowing - errors', () => {
      it('should have a getUserFollowing function', (done) => {
        try {
          assert.equal(true, typeof a.getUserFollowing === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#deleteUserFollowingUsername - errors', () => {
      it('should have a deleteUserFollowingUsername function', (done) => {
        try {
          assert.equal(true, typeof a.deleteUserFollowingUsername === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing username', (done) => {
        try {
          a.deleteUserFollowingUsername(null, (data, error) => {
            try {
              const displayE = 'username is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-deleteUserFollowingUsername', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getUserFollowingUsername - errors', () => {
      it('should have a getUserFollowingUsername function', (done) => {
        try {
          assert.equal(true, typeof a.getUserFollowingUsername === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing username', (done) => {
        try {
          a.getUserFollowingUsername(null, (data, error) => {
            try {
              const displayE = 'username is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getUserFollowingUsername', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#putUserFollowingUsername - errors', () => {
      it('should have a putUserFollowingUsername function', (done) => {
        try {
          assert.equal(true, typeof a.putUserFollowingUsername === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing username', (done) => {
        try {
          a.putUserFollowingUsername(null, (data, error) => {
            try {
              const displayE = 'username is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-putUserFollowingUsername', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getUserIssues - errors', () => {
      it('should have a getUserIssues function', (done) => {
        try {
          assert.equal(true, typeof a.getUserIssues === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getUserKeys - errors', () => {
      it('should have a getUserKeys function', (done) => {
        try {
          assert.equal(true, typeof a.getUserKeys === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#postUserKeys - errors', () => {
      it('should have a postUserKeys function', (done) => {
        try {
          assert.equal(true, typeof a.postUserKeys === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        try {
          a.postUserKeys(null, (data, error) => {
            try {
              const displayE = 'body is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-postUserKeys', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#deleteUserKeysKeyId - errors', () => {
      it('should have a deleteUserKeysKeyId function', (done) => {
        try {
          assert.equal(true, typeof a.deleteUserKeysKeyId === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing keyId', (done) => {
        try {
          a.deleteUserKeysKeyId(null, (data, error) => {
            try {
              const displayE = 'keyId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-deleteUserKeysKeyId', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getUserKeysKeyId - errors', () => {
      it('should have a getUserKeysKeyId function', (done) => {
        try {
          assert.equal(true, typeof a.getUserKeysKeyId === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing keyId', (done) => {
        try {
          a.getUserKeysKeyId(null, (data, error) => {
            try {
              const displayE = 'keyId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getUserKeysKeyId', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getUserOrgs - errors', () => {
      it('should have a getUserOrgs function', (done) => {
        try {
          assert.equal(true, typeof a.getUserOrgs === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getUserRepos - errors', () => {
      it('should have a getUserRepos function', (done) => {
        try {
          assert.equal(true, typeof a.getUserRepos === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#postUserRepos - errors', () => {
      it('should have a postUserRepos function', (done) => {
        try {
          assert.equal(true, typeof a.postUserRepos === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        try {
          a.postUserRepos(null, (data, error) => {
            try {
              const displayE = 'body is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-postUserRepos', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getUserStarred - errors', () => {
      it('should have a getUserStarred function', (done) => {
        try {
          assert.equal(true, typeof a.getUserStarred === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#deleteUserStarredOwnerRepo - errors', () => {
      it('should have a deleteUserStarredOwnerRepo function', (done) => {
        try {
          assert.equal(true, typeof a.deleteUserStarredOwnerRepo === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.deleteUserStarredOwnerRepo(null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-deleteUserStarredOwnerRepo', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.deleteUserStarredOwnerRepo('fakeparam', null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-deleteUserStarredOwnerRepo', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getUserStarredOwnerRepo - errors', () => {
      it('should have a getUserStarredOwnerRepo function', (done) => {
        try {
          assert.equal(true, typeof a.getUserStarredOwnerRepo === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.getUserStarredOwnerRepo(null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getUserStarredOwnerRepo', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.getUserStarredOwnerRepo('fakeparam', null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getUserStarredOwnerRepo', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#putUserStarredOwnerRepo - errors', () => {
      it('should have a putUserStarredOwnerRepo function', (done) => {
        try {
          assert.equal(true, typeof a.putUserStarredOwnerRepo === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.putUserStarredOwnerRepo(null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-putUserStarredOwnerRepo', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.putUserStarredOwnerRepo('fakeparam', null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-putUserStarredOwnerRepo', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getUserSubscriptions - errors', () => {
      it('should have a getUserSubscriptions function', (done) => {
        try {
          assert.equal(true, typeof a.getUserSubscriptions === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#deleteUserSubscriptionsOwnerRepo - errors', () => {
      it('should have a deleteUserSubscriptionsOwnerRepo function', (done) => {
        try {
          assert.equal(true, typeof a.deleteUserSubscriptionsOwnerRepo === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.deleteUserSubscriptionsOwnerRepo(null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-deleteUserSubscriptionsOwnerRepo', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.deleteUserSubscriptionsOwnerRepo('fakeparam', null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-deleteUserSubscriptionsOwnerRepo', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getUserSubscriptionsOwnerRepo - errors', () => {
      it('should have a getUserSubscriptionsOwnerRepo function', (done) => {
        try {
          assert.equal(true, typeof a.getUserSubscriptionsOwnerRepo === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.getUserSubscriptionsOwnerRepo(null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getUserSubscriptionsOwnerRepo', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.getUserSubscriptionsOwnerRepo('fakeparam', null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getUserSubscriptionsOwnerRepo', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#putUserSubscriptionsOwnerRepo - errors', () => {
      it('should have a putUserSubscriptionsOwnerRepo function', (done) => {
        try {
          assert.equal(true, typeof a.putUserSubscriptionsOwnerRepo === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.putUserSubscriptionsOwnerRepo(null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-putUserSubscriptionsOwnerRepo', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.putUserSubscriptionsOwnerRepo('fakeparam', null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-putUserSubscriptionsOwnerRepo', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getUserTeams - errors', () => {
      it('should have a getUserTeams function', (done) => {
        try {
          assert.equal(true, typeof a.getUserTeams === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getUsers - errors', () => {
      it('should have a getUsers function', (done) => {
        try {
          assert.equal(true, typeof a.getUsers === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getUsersUsername - errors', () => {
      it('should have a getUsersUsername function', (done) => {
        try {
          assert.equal(true, typeof a.getUsersUsername === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing username', (done) => {
        try {
          a.getUsersUsername(null, (data, error) => {
            try {
              const displayE = 'username is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getUsersUsername', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getUsersUsernameEvents - errors', () => {
      it('should have a getUsersUsernameEvents function', (done) => {
        try {
          assert.equal(true, typeof a.getUsersUsernameEvents === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing username', (done) => {
        try {
          a.getUsersUsernameEvents(null, (data, error) => {
            try {
              const displayE = 'username is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getUsersUsernameEventsQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getUsersUsernameEventsOrgsOrg - errors', () => {
      it('should have a getUsersUsernameEventsOrgsOrg function', (done) => {
        try {
          assert.equal(true, typeof a.getUsersUsernameEventsOrgsOrg === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing username', (done) => {
        try {
          a.getUsersUsernameEventsOrgsOrg(null, null, (data, error) => {
            try {
              const displayE = 'username is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getUsersUsernameEventsOrgsOrgQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.getUsersUsernameEventsOrgsOrg('fakeparam', null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getUsersUsernameEventsOrgsOrgQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getUsersUsernameFollowers - errors', () => {
      it('should have a getUsersUsernameFollowers function', (done) => {
        try {
          assert.equal(true, typeof a.getUsersUsernameFollowers === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing username', (done) => {
        try {
          a.getUsersUsernameFollowers(null, (data, error) => {
            try {
              const displayE = 'username is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getUsersUsernameFollowersQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getUsersUsernameFollowingTargetUser - errors', () => {
      it('should have a getUsersUsernameFollowingTargetUser function', (done) => {
        try {
          assert.equal(true, typeof a.getUsersUsernameFollowingTargetUser === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing username', (done) => {
        try {
          a.getUsersUsernameFollowingTargetUser(null, null, (data, error) => {
            try {
              const displayE = 'username is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getUsersUsernameFollowingTargetUser', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing targetUser', (done) => {
        try {
          a.getUsersUsernameFollowingTargetUser('fakeparam', null, (data, error) => {
            try {
              const displayE = 'targetUser is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getUsersUsernameFollowingTargetUser', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getUsersUsernameGists - errors', () => {
      it('should have a getUsersUsernameGists function', (done) => {
        try {
          assert.equal(true, typeof a.getUsersUsernameGists === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing username', (done) => {
        try {
          a.getUsersUsernameGists(null, null, (data, error) => {
            try {
              const displayE = 'username is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getUsersUsernameGistsQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getUsersUsernameKeys - errors', () => {
      it('should have a getUsersUsernameKeys function', (done) => {
        try {
          assert.equal(true, typeof a.getUsersUsernameKeys === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing username', (done) => {
        try {
          a.getUsersUsernameKeys(null, (data, error) => {
            try {
              const displayE = 'username is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getUsersUsernameKeysQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getUsersUsernameOrgs - errors', () => {
      it('should have a getUsersUsernameOrgs function', (done) => {
        try {
          assert.equal(true, typeof a.getUsersUsernameOrgs === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing username', (done) => {
        try {
          a.getUsersUsernameOrgs(null, (data, error) => {
            try {
              const displayE = 'username is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getUsersUsernameOrgsQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getUsersUsernameReceivedEvents - errors', () => {
      it('should have a getUsersUsernameReceivedEvents function', (done) => {
        try {
          assert.equal(true, typeof a.getUsersUsernameReceivedEvents === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing username', (done) => {
        try {
          a.getUsersUsernameReceivedEvents(null, (data, error) => {
            try {
              const displayE = 'username is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getUsersUsernameReceivedEventsQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getUsersUsernameReceivedEventsPublic - errors', () => {
      it('should have a getUsersUsernameReceivedEventsPublic function', (done) => {
        try {
          assert.equal(true, typeof a.getUsersUsernameReceivedEventsPublic === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing username', (done) => {
        try {
          a.getUsersUsernameReceivedEventsPublic(null, (data, error) => {
            try {
              const displayE = 'username is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getUsersUsernameReceivedEventsPublicQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getUsersUsernameRepos - errors', () => {
      it('should have a getUsersUsernameRepos function', (done) => {
        try {
          assert.equal(true, typeof a.getUsersUsernameRepos === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing username', (done) => {
        try {
          a.getUsersUsernameRepos(null, null, (data, error) => {
            try {
              const displayE = 'username is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getUsersUsernameReposQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getUsersUsernameStarred - errors', () => {
      it('should have a getUsersUsernameStarred function', (done) => {
        try {
          assert.equal(true, typeof a.getUsersUsernameStarred === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing username', (done) => {
        try {
          a.getUsersUsernameStarred(null, (data, error) => {
            try {
              const displayE = 'username is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getUsersUsernameStarredQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getUsersUsernameSubscriptions - errors', () => {
      it('should have a getUsersUsernameSubscriptions function', (done) => {
        try {
          assert.equal(true, typeof a.getUsersUsernameSubscriptions === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing username', (done) => {
        try {
          a.getUsersUsernameSubscriptions(null, (data, error) => {
            try {
              const displayE = 'username is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getUsersUsernameSubscriptionsQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#actionsGetActionsCacheUsageForOrg - errors', () => {
      it('should have a actionsGetActionsCacheUsageForOrg function', (done) => {
        try {
          assert.equal(true, typeof a.actionsGetActionsCacheUsageForOrg === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.actionsGetActionsCacheUsageForOrg(null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsGetActionsCacheUsageForOrg', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#actionsGetActionsCacheUsageByRepoForOrg - errors', () => {
      it('should have a actionsGetActionsCacheUsageByRepoForOrg function', (done) => {
        try {
          assert.equal(true, typeof a.actionsGetActionsCacheUsageByRepoForOrg === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.actionsGetActionsCacheUsageByRepoForOrg(null, null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsGetActionsCacheUsageByRepoForOrg', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#actionsGetGithubActionsPermissionsOrganization - errors', () => {
      it('should have a actionsGetGithubActionsPermissionsOrganization function', (done) => {
        try {
          assert.equal(true, typeof a.actionsGetGithubActionsPermissionsOrganization === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.actionsGetGithubActionsPermissionsOrganization(null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsGetGithubActionsPermissionsOrganization', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#actionsSetGithubActionsPermissionsOrganization - errors', () => {
      it('should have a actionsSetGithubActionsPermissionsOrganization function', (done) => {
        try {
          assert.equal(true, typeof a.actionsSetGithubActionsPermissionsOrganization === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.actionsSetGithubActionsPermissionsOrganization(null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsSetGithubActionsPermissionsOrganization', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#actionsListSelectedRepositoriesEnabledGithubActionsOrganization - errors', () => {
      it('should have a actionsListSelectedRepositoriesEnabledGithubActionsOrganization function', (done) => {
        try {
          assert.equal(true, typeof a.actionsListSelectedRepositoriesEnabledGithubActionsOrganization === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.actionsListSelectedRepositoriesEnabledGithubActionsOrganization(null, null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsListSelectedRepositoriesEnabledGithubActionsOrganization', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#actionsSetSelectedRepositoriesEnabledGithubActionsOrganization - errors', () => {
      it('should have a actionsSetSelectedRepositoriesEnabledGithubActionsOrganization function', (done) => {
        try {
          assert.equal(true, typeof a.actionsSetSelectedRepositoriesEnabledGithubActionsOrganization === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.actionsSetSelectedRepositoriesEnabledGithubActionsOrganization(null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsSetSelectedRepositoriesEnabledGithubActionsOrganization', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#actionsEnableSelectedRepositoryGithubActionsOrganization - errors', () => {
      it('should have a actionsEnableSelectedRepositoryGithubActionsOrganization function', (done) => {
        try {
          assert.equal(true, typeof a.actionsEnableSelectedRepositoryGithubActionsOrganization === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.actionsEnableSelectedRepositoryGithubActionsOrganization(null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsEnableSelectedRepositoryGithubActionsOrganization', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repositoryId', (done) => {
        try {
          a.actionsEnableSelectedRepositoryGithubActionsOrganization('fakeparam', null, (data, error) => {
            try {
              const displayE = 'repositoryId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsEnableSelectedRepositoryGithubActionsOrganization', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#actionsDisableSelectedRepositoryGithubActionsOrganization - errors', () => {
      it('should have a actionsDisableSelectedRepositoryGithubActionsOrganization function', (done) => {
        try {
          assert.equal(true, typeof a.actionsDisableSelectedRepositoryGithubActionsOrganization === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.actionsDisableSelectedRepositoryGithubActionsOrganization(null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsDisableSelectedRepositoryGithubActionsOrganization', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repositoryId', (done) => {
        try {
          a.actionsDisableSelectedRepositoryGithubActionsOrganization('fakeparam', null, (data, error) => {
            try {
              const displayE = 'repositoryId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsDisableSelectedRepositoryGithubActionsOrganization', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#actionsGetAllowedActionsOrganization - errors', () => {
      it('should have a actionsGetAllowedActionsOrganization function', (done) => {
        try {
          assert.equal(true, typeof a.actionsGetAllowedActionsOrganization === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.actionsGetAllowedActionsOrganization(null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsGetAllowedActionsOrganization', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#actionsSetAllowedActionsOrganization - errors', () => {
      it('should have a actionsSetAllowedActionsOrganization function', (done) => {
        try {
          assert.equal(true, typeof a.actionsSetAllowedActionsOrganization === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.actionsSetAllowedActionsOrganization(null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsSetAllowedActionsOrganization', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#actionsGetGithubActionsDefaultWorkflowPermissionsOrganization - errors', () => {
      it('should have a actionsGetGithubActionsDefaultWorkflowPermissionsOrganization function', (done) => {
        try {
          assert.equal(true, typeof a.actionsGetGithubActionsDefaultWorkflowPermissionsOrganization === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.actionsGetGithubActionsDefaultWorkflowPermissionsOrganization(null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsGetGithubActionsDefaultWorkflowPermissionsOrganization', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#actionsSetGithubActionsDefaultWorkflowPermissionsOrganization - errors', () => {
      it('should have a actionsSetGithubActionsDefaultWorkflowPermissionsOrganization function', (done) => {
        try {
          assert.equal(true, typeof a.actionsSetGithubActionsDefaultWorkflowPermissionsOrganization === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.actionsSetGithubActionsDefaultWorkflowPermissionsOrganization(null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsSetGithubActionsDefaultWorkflowPermissionsOrganization', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#actionsListSelfHostedRunnersForOrg - errors', () => {
      it('should have a actionsListSelfHostedRunnersForOrg function', (done) => {
        try {
          assert.equal(true, typeof a.actionsListSelfHostedRunnersForOrg === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.actionsListSelfHostedRunnersForOrg('fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsListSelfHostedRunnersForOrg', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#actionsListRunnerApplicationsForOrg - errors', () => {
      it('should have a actionsListRunnerApplicationsForOrg function', (done) => {
        try {
          assert.equal(true, typeof a.actionsListRunnerApplicationsForOrg === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.actionsListRunnerApplicationsForOrg(null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsListRunnerApplicationsForOrg', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#actionsGenerateRunnerJitconfigForOrg - errors', () => {
      it('should have a actionsGenerateRunnerJitconfigForOrg function', (done) => {
        try {
          assert.equal(true, typeof a.actionsGenerateRunnerJitconfigForOrg === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.actionsGenerateRunnerJitconfigForOrg(null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsGenerateRunnerJitconfigForOrg', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#actionsCreateRegistrationTokenForOrg - errors', () => {
      it('should have a actionsCreateRegistrationTokenForOrg function', (done) => {
        try {
          assert.equal(true, typeof a.actionsCreateRegistrationTokenForOrg === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.actionsCreateRegistrationTokenForOrg(null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsCreateRegistrationTokenForOrg', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#actionsCreateRemoveTokenForOrg - errors', () => {
      it('should have a actionsCreateRemoveTokenForOrg function', (done) => {
        try {
          assert.equal(true, typeof a.actionsCreateRemoveTokenForOrg === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.actionsCreateRemoveTokenForOrg(null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsCreateRemoveTokenForOrg', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#actionsGetSelfHostedRunnerForOrg - errors', () => {
      it('should have a actionsGetSelfHostedRunnerForOrg function', (done) => {
        try {
          assert.equal(true, typeof a.actionsGetSelfHostedRunnerForOrg === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.actionsGetSelfHostedRunnerForOrg(null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsGetSelfHostedRunnerForOrg', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing runnerId', (done) => {
        try {
          a.actionsGetSelfHostedRunnerForOrg('fakeparam', null, (data, error) => {
            try {
              const displayE = 'runnerId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsGetSelfHostedRunnerForOrg', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#actionsDeleteSelfHostedRunnerFromOrg - errors', () => {
      it('should have a actionsDeleteSelfHostedRunnerFromOrg function', (done) => {
        try {
          assert.equal(true, typeof a.actionsDeleteSelfHostedRunnerFromOrg === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.actionsDeleteSelfHostedRunnerFromOrg(null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsDeleteSelfHostedRunnerFromOrg', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing runnerId', (done) => {
        try {
          a.actionsDeleteSelfHostedRunnerFromOrg('fakeparam', null, (data, error) => {
            try {
              const displayE = 'runnerId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsDeleteSelfHostedRunnerFromOrg', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#actionsListLabelsForSelfHostedRunnerForOrg - errors', () => {
      it('should have a actionsListLabelsForSelfHostedRunnerForOrg function', (done) => {
        try {
          assert.equal(true, typeof a.actionsListLabelsForSelfHostedRunnerForOrg === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.actionsListLabelsForSelfHostedRunnerForOrg(null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsListLabelsForSelfHostedRunnerForOrg', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing runnerId', (done) => {
        try {
          a.actionsListLabelsForSelfHostedRunnerForOrg('fakeparam', null, (data, error) => {
            try {
              const displayE = 'runnerId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsListLabelsForSelfHostedRunnerForOrg', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#actionsAddCustomLabelsToSelfHostedRunnerForOrg - errors', () => {
      it('should have a actionsAddCustomLabelsToSelfHostedRunnerForOrg function', (done) => {
        try {
          assert.equal(true, typeof a.actionsAddCustomLabelsToSelfHostedRunnerForOrg === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.actionsAddCustomLabelsToSelfHostedRunnerForOrg(null, null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsAddCustomLabelsToSelfHostedRunnerForOrg', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing runnerId', (done) => {
        try {
          a.actionsAddCustomLabelsToSelfHostedRunnerForOrg('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'runnerId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsAddCustomLabelsToSelfHostedRunnerForOrg', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#actionsSetCustomLabelsForSelfHostedRunnerForOrg - errors', () => {
      it('should have a actionsSetCustomLabelsForSelfHostedRunnerForOrg function', (done) => {
        try {
          assert.equal(true, typeof a.actionsSetCustomLabelsForSelfHostedRunnerForOrg === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.actionsSetCustomLabelsForSelfHostedRunnerForOrg(null, null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsSetCustomLabelsForSelfHostedRunnerForOrg', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing runnerId', (done) => {
        try {
          a.actionsSetCustomLabelsForSelfHostedRunnerForOrg('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'runnerId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsSetCustomLabelsForSelfHostedRunnerForOrg', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#actionsRemoveAllCustomLabelsFromSelfHostedRunnerForOrg - errors', () => {
      it('should have a actionsRemoveAllCustomLabelsFromSelfHostedRunnerForOrg function', (done) => {
        try {
          assert.equal(true, typeof a.actionsRemoveAllCustomLabelsFromSelfHostedRunnerForOrg === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.actionsRemoveAllCustomLabelsFromSelfHostedRunnerForOrg(null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsRemoveAllCustomLabelsFromSelfHostedRunnerForOrg', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing runnerId', (done) => {
        try {
          a.actionsRemoveAllCustomLabelsFromSelfHostedRunnerForOrg('fakeparam', null, (data, error) => {
            try {
              const displayE = 'runnerId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsRemoveAllCustomLabelsFromSelfHostedRunnerForOrg', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#actionsRemoveCustomLabelFromSelfHostedRunnerForOrg - errors', () => {
      it('should have a actionsRemoveCustomLabelFromSelfHostedRunnerForOrg function', (done) => {
        try {
          assert.equal(true, typeof a.actionsRemoveCustomLabelFromSelfHostedRunnerForOrg === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.actionsRemoveCustomLabelFromSelfHostedRunnerForOrg(null, null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsRemoveCustomLabelFromSelfHostedRunnerForOrg', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing runnerId', (done) => {
        try {
          a.actionsRemoveCustomLabelFromSelfHostedRunnerForOrg('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'runnerId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsRemoveCustomLabelFromSelfHostedRunnerForOrg', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing name', (done) => {
        try {
          a.actionsRemoveCustomLabelFromSelfHostedRunnerForOrg('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'name is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsRemoveCustomLabelFromSelfHostedRunnerForOrg', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#actionsListOrgSecrets - errors', () => {
      it('should have a actionsListOrgSecrets function', (done) => {
        try {
          assert.equal(true, typeof a.actionsListOrgSecrets === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.actionsListOrgSecrets(null, null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsListOrgSecrets', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#actionsGetOrgPublicKey - errors', () => {
      it('should have a actionsGetOrgPublicKey function', (done) => {
        try {
          assert.equal(true, typeof a.actionsGetOrgPublicKey === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.actionsGetOrgPublicKey(null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsGetOrgPublicKey', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#actionsGetOrgSecret - errors', () => {
      it('should have a actionsGetOrgSecret function', (done) => {
        try {
          assert.equal(true, typeof a.actionsGetOrgSecret === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.actionsGetOrgSecret(null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsGetOrgSecret', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing secretName', (done) => {
        try {
          a.actionsGetOrgSecret('fakeparam', null, (data, error) => {
            try {
              const displayE = 'secretName is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsGetOrgSecret', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#actionsCreateOrUpdateOrgSecret - errors', () => {
      it('should have a actionsCreateOrUpdateOrgSecret function', (done) => {
        try {
          assert.equal(true, typeof a.actionsCreateOrUpdateOrgSecret === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.actionsCreateOrUpdateOrgSecret(null, null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsCreateOrUpdateOrgSecret', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing secretName', (done) => {
        try {
          a.actionsCreateOrUpdateOrgSecret('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'secretName is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsCreateOrUpdateOrgSecret', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#actionsDeleteOrgSecret - errors', () => {
      it('should have a actionsDeleteOrgSecret function', (done) => {
        try {
          assert.equal(true, typeof a.actionsDeleteOrgSecret === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.actionsDeleteOrgSecret(null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsDeleteOrgSecret', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing secretName', (done) => {
        try {
          a.actionsDeleteOrgSecret('fakeparam', null, (data, error) => {
            try {
              const displayE = 'secretName is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsDeleteOrgSecret', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#actionsListSelectedReposForOrgSecret - errors', () => {
      it('should have a actionsListSelectedReposForOrgSecret function', (done) => {
        try {
          assert.equal(true, typeof a.actionsListSelectedReposForOrgSecret === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.actionsListSelectedReposForOrgSecret(null, null, null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsListSelectedReposForOrgSecret', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing secretName', (done) => {
        try {
          a.actionsListSelectedReposForOrgSecret('fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'secretName is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsListSelectedReposForOrgSecret', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#actionsSetSelectedReposForOrgSecret - errors', () => {
      it('should have a actionsSetSelectedReposForOrgSecret function', (done) => {
        try {
          assert.equal(true, typeof a.actionsSetSelectedReposForOrgSecret === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.actionsSetSelectedReposForOrgSecret(null, null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsSetSelectedReposForOrgSecret', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing secretName', (done) => {
        try {
          a.actionsSetSelectedReposForOrgSecret('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'secretName is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsSetSelectedReposForOrgSecret', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#actionsAddSelectedRepoToOrgSecret - errors', () => {
      it('should have a actionsAddSelectedRepoToOrgSecret function', (done) => {
        try {
          assert.equal(true, typeof a.actionsAddSelectedRepoToOrgSecret === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.actionsAddSelectedRepoToOrgSecret(null, null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsAddSelectedRepoToOrgSecret', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing secretName', (done) => {
        try {
          a.actionsAddSelectedRepoToOrgSecret('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'secretName is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsAddSelectedRepoToOrgSecret', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repositoryId', (done) => {
        try {
          a.actionsAddSelectedRepoToOrgSecret('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'repositoryId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsAddSelectedRepoToOrgSecret', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#actionsRemoveSelectedRepoFromOrgSecret - errors', () => {
      it('should have a actionsRemoveSelectedRepoFromOrgSecret function', (done) => {
        try {
          assert.equal(true, typeof a.actionsRemoveSelectedRepoFromOrgSecret === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.actionsRemoveSelectedRepoFromOrgSecret(null, null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsRemoveSelectedRepoFromOrgSecret', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing secretName', (done) => {
        try {
          a.actionsRemoveSelectedRepoFromOrgSecret('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'secretName is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsRemoveSelectedRepoFromOrgSecret', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repositoryId', (done) => {
        try {
          a.actionsRemoveSelectedRepoFromOrgSecret('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'repositoryId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsRemoveSelectedRepoFromOrgSecret', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#actionsListOrgVariables - errors', () => {
      it('should have a actionsListOrgVariables function', (done) => {
        try {
          assert.equal(true, typeof a.actionsListOrgVariables === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.actionsListOrgVariables(null, null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsListOrgVariables', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#actionsCreateOrgVariable - errors', () => {
      it('should have a actionsCreateOrgVariable function', (done) => {
        try {
          assert.equal(true, typeof a.actionsCreateOrgVariable === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.actionsCreateOrgVariable(null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsCreateOrgVariable', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#actionsGetOrgVariable - errors', () => {
      it('should have a actionsGetOrgVariable function', (done) => {
        try {
          assert.equal(true, typeof a.actionsGetOrgVariable === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.actionsGetOrgVariable(null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsGetOrgVariable', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing name', (done) => {
        try {
          a.actionsGetOrgVariable('fakeparam', null, (data, error) => {
            try {
              const displayE = 'name is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsGetOrgVariable', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#actionsUpdateOrgVariable - errors', () => {
      it('should have a actionsUpdateOrgVariable function', (done) => {
        try {
          assert.equal(true, typeof a.actionsUpdateOrgVariable === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.actionsUpdateOrgVariable(null, null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsUpdateOrgVariable', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing name', (done) => {
        try {
          a.actionsUpdateOrgVariable('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'name is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsUpdateOrgVariable', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#actionsDeleteOrgVariable - errors', () => {
      it('should have a actionsDeleteOrgVariable function', (done) => {
        try {
          assert.equal(true, typeof a.actionsDeleteOrgVariable === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.actionsDeleteOrgVariable(null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsDeleteOrgVariable', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing name', (done) => {
        try {
          a.actionsDeleteOrgVariable('fakeparam', null, (data, error) => {
            try {
              const displayE = 'name is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsDeleteOrgVariable', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#actionsListSelectedReposForOrgVariable - errors', () => {
      it('should have a actionsListSelectedReposForOrgVariable function', (done) => {
        try {
          assert.equal(true, typeof a.actionsListSelectedReposForOrgVariable === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.actionsListSelectedReposForOrgVariable(null, null, null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsListSelectedReposForOrgVariable', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing name', (done) => {
        try {
          a.actionsListSelectedReposForOrgVariable('fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'name is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsListSelectedReposForOrgVariable', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#actionsSetSelectedReposForOrgVariable - errors', () => {
      it('should have a actionsSetSelectedReposForOrgVariable function', (done) => {
        try {
          assert.equal(true, typeof a.actionsSetSelectedReposForOrgVariable === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.actionsSetSelectedReposForOrgVariable(null, null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsSetSelectedReposForOrgVariable', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing name', (done) => {
        try {
          a.actionsSetSelectedReposForOrgVariable('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'name is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsSetSelectedReposForOrgVariable', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#actionsAddSelectedRepoToOrgVariable - errors', () => {
      it('should have a actionsAddSelectedRepoToOrgVariable function', (done) => {
        try {
          assert.equal(true, typeof a.actionsAddSelectedRepoToOrgVariable === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.actionsAddSelectedRepoToOrgVariable(null, null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsAddSelectedRepoToOrgVariable', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing name', (done) => {
        try {
          a.actionsAddSelectedRepoToOrgVariable('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'name is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsAddSelectedRepoToOrgVariable', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repositoryId', (done) => {
        try {
          a.actionsAddSelectedRepoToOrgVariable('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'repositoryId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsAddSelectedRepoToOrgVariable', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#actionsRemoveSelectedRepoFromOrgVariable - errors', () => {
      it('should have a actionsRemoveSelectedRepoFromOrgVariable function', (done) => {
        try {
          assert.equal(true, typeof a.actionsRemoveSelectedRepoFromOrgVariable === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.actionsRemoveSelectedRepoFromOrgVariable(null, null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsRemoveSelectedRepoFromOrgVariable', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing name', (done) => {
        try {
          a.actionsRemoveSelectedRepoFromOrgVariable('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'name is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsRemoveSelectedRepoFromOrgVariable', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repositoryId', (done) => {
        try {
          a.actionsRemoveSelectedRepoFromOrgVariable('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'repositoryId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsRemoveSelectedRepoFromOrgVariable', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#actionsListArtifactsForRepo - errors', () => {
      it('should have a actionsListArtifactsForRepo function', (done) => {
        try {
          assert.equal(true, typeof a.actionsListArtifactsForRepo === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.actionsListArtifactsForRepo(null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsListArtifactsForRepo', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.actionsListArtifactsForRepo('fakeparam', null, null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsListArtifactsForRepo', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#actionsGetArtifact - errors', () => {
      it('should have a actionsGetArtifact function', (done) => {
        try {
          assert.equal(true, typeof a.actionsGetArtifact === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.actionsGetArtifact(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsGetArtifact', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.actionsGetArtifact('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsGetArtifact', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing artifactId', (done) => {
        try {
          a.actionsGetArtifact('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'artifactId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsGetArtifact', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#actionsDeleteArtifact - errors', () => {
      it('should have a actionsDeleteArtifact function', (done) => {
        try {
          assert.equal(true, typeof a.actionsDeleteArtifact === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.actionsDeleteArtifact(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsDeleteArtifact', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.actionsDeleteArtifact('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsDeleteArtifact', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing artifactId', (done) => {
        try {
          a.actionsDeleteArtifact('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'artifactId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsDeleteArtifact', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#actionsDownloadArtifact - errors', () => {
      it('should have a actionsDownloadArtifact function', (done) => {
        try {
          assert.equal(true, typeof a.actionsDownloadArtifact === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.actionsDownloadArtifact(null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsDownloadArtifact', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.actionsDownloadArtifact('fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsDownloadArtifact', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing artifactId', (done) => {
        try {
          a.actionsDownloadArtifact('fakeparam', 'fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'artifactId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsDownloadArtifact', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing archiveFormat', (done) => {
        try {
          a.actionsDownloadArtifact('fakeparam', 'fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'archiveFormat is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsDownloadArtifact', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#actionsGetActionsCacheUsage - errors', () => {
      it('should have a actionsGetActionsCacheUsage function', (done) => {
        try {
          assert.equal(true, typeof a.actionsGetActionsCacheUsage === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.actionsGetActionsCacheUsage(null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsGetActionsCacheUsage', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.actionsGetActionsCacheUsage('fakeparam', null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsGetActionsCacheUsage', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#actionsGetActionsCacheList - errors', () => {
      it('should have a actionsGetActionsCacheList function', (done) => {
        try {
          assert.equal(true, typeof a.actionsGetActionsCacheList === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.actionsGetActionsCacheList(null, null, null, null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsGetActionsCacheList', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.actionsGetActionsCacheList('fakeparam', null, null, null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsGetActionsCacheList', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#actionsDeleteActionsCacheByKey - errors', () => {
      it('should have a actionsDeleteActionsCacheByKey function', (done) => {
        try {
          assert.equal(true, typeof a.actionsDeleteActionsCacheByKey === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.actionsDeleteActionsCacheByKey(null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsDeleteActionsCacheByKey', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.actionsDeleteActionsCacheByKey('fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsDeleteActionsCacheByKey', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing key', (done) => {
        try {
          a.actionsDeleteActionsCacheByKey('fakeparam', 'fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'key is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsDeleteActionsCacheByKey', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#actionsDeleteActionsCacheById - errors', () => {
      it('should have a actionsDeleteActionsCacheById function', (done) => {
        try {
          assert.equal(true, typeof a.actionsDeleteActionsCacheById === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.actionsDeleteActionsCacheById(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsDeleteActionsCacheById', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.actionsDeleteActionsCacheById('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsDeleteActionsCacheById', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing cacheId', (done) => {
        try {
          a.actionsDeleteActionsCacheById('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'cacheId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsDeleteActionsCacheById', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#actionsGetJobForWorkflowRun - errors', () => {
      it('should have a actionsGetJobForWorkflowRun function', (done) => {
        try {
          assert.equal(true, typeof a.actionsGetJobForWorkflowRun === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.actionsGetJobForWorkflowRun(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsGetJobForWorkflowRun', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.actionsGetJobForWorkflowRun('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsGetJobForWorkflowRun', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing jobId', (done) => {
        try {
          a.actionsGetJobForWorkflowRun('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'jobId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsGetJobForWorkflowRun', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#actionsDownloadJobLogsForWorkflowRun - errors', () => {
      it('should have a actionsDownloadJobLogsForWorkflowRun function', (done) => {
        try {
          assert.equal(true, typeof a.actionsDownloadJobLogsForWorkflowRun === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.actionsDownloadJobLogsForWorkflowRun(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsDownloadJobLogsForWorkflowRun', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.actionsDownloadJobLogsForWorkflowRun('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsDownloadJobLogsForWorkflowRun', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing jobId', (done) => {
        try {
          a.actionsDownloadJobLogsForWorkflowRun('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'jobId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsDownloadJobLogsForWorkflowRun', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#actionsReRunJobForWorkflowRun - errors', () => {
      it('should have a actionsReRunJobForWorkflowRun function', (done) => {
        try {
          assert.equal(true, typeof a.actionsReRunJobForWorkflowRun === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.actionsReRunJobForWorkflowRun(null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsReRunJobForWorkflowRun', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.actionsReRunJobForWorkflowRun('fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsReRunJobForWorkflowRun', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing jobId', (done) => {
        try {
          a.actionsReRunJobForWorkflowRun('fakeparam', 'fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'jobId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsReRunJobForWorkflowRun', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#actionsGetCustomOidcSubClaimForRepo - errors', () => {
      it('should have a actionsGetCustomOidcSubClaimForRepo function', (done) => {
        try {
          assert.equal(true, typeof a.actionsGetCustomOidcSubClaimForRepo === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.actionsGetCustomOidcSubClaimForRepo(null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsGetCustomOidcSubClaimForRepo', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.actionsGetCustomOidcSubClaimForRepo('fakeparam', null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsGetCustomOidcSubClaimForRepo', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#actionsSetCustomOidcSubClaimForRepo - errors', () => {
      it('should have a actionsSetCustomOidcSubClaimForRepo function', (done) => {
        try {
          assert.equal(true, typeof a.actionsSetCustomOidcSubClaimForRepo === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.actionsSetCustomOidcSubClaimForRepo(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsSetCustomOidcSubClaimForRepo', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.actionsSetCustomOidcSubClaimForRepo('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsSetCustomOidcSubClaimForRepo', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#actionsListRepoOrganizationSecrets - errors', () => {
      it('should have a actionsListRepoOrganizationSecrets function', (done) => {
        try {
          assert.equal(true, typeof a.actionsListRepoOrganizationSecrets === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.actionsListRepoOrganizationSecrets(null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsListRepoOrganizationSecrets', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.actionsListRepoOrganizationSecrets('fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsListRepoOrganizationSecrets', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#actionsListRepoOrganizationVariables - errors', () => {
      it('should have a actionsListRepoOrganizationVariables function', (done) => {
        try {
          assert.equal(true, typeof a.actionsListRepoOrganizationVariables === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.actionsListRepoOrganizationVariables(null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsListRepoOrganizationVariables', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.actionsListRepoOrganizationVariables('fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsListRepoOrganizationVariables', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#actionsGetGithubActionsPermissionsRepository - errors', () => {
      it('should have a actionsGetGithubActionsPermissionsRepository function', (done) => {
        try {
          assert.equal(true, typeof a.actionsGetGithubActionsPermissionsRepository === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.actionsGetGithubActionsPermissionsRepository(null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsGetGithubActionsPermissionsRepository', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.actionsGetGithubActionsPermissionsRepository('fakeparam', null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsGetGithubActionsPermissionsRepository', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#actionsSetGithubActionsPermissionsRepository - errors', () => {
      it('should have a actionsSetGithubActionsPermissionsRepository function', (done) => {
        try {
          assert.equal(true, typeof a.actionsSetGithubActionsPermissionsRepository === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.actionsSetGithubActionsPermissionsRepository(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsSetGithubActionsPermissionsRepository', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.actionsSetGithubActionsPermissionsRepository('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsSetGithubActionsPermissionsRepository', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#actionsGetWorkflowAccessToRepository - errors', () => {
      it('should have a actionsGetWorkflowAccessToRepository function', (done) => {
        try {
          assert.equal(true, typeof a.actionsGetWorkflowAccessToRepository === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.actionsGetWorkflowAccessToRepository(null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsGetWorkflowAccessToRepository', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.actionsGetWorkflowAccessToRepository('fakeparam', null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsGetWorkflowAccessToRepository', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#actionsSetWorkflowAccessToRepository - errors', () => {
      it('should have a actionsSetWorkflowAccessToRepository function', (done) => {
        try {
          assert.equal(true, typeof a.actionsSetWorkflowAccessToRepository === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.actionsSetWorkflowAccessToRepository(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsSetWorkflowAccessToRepository', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.actionsSetWorkflowAccessToRepository('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsSetWorkflowAccessToRepository', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#actionsGetAllowedActionsRepository - errors', () => {
      it('should have a actionsGetAllowedActionsRepository function', (done) => {
        try {
          assert.equal(true, typeof a.actionsGetAllowedActionsRepository === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.actionsGetAllowedActionsRepository(null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsGetAllowedActionsRepository', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.actionsGetAllowedActionsRepository('fakeparam', null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsGetAllowedActionsRepository', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#actionsSetAllowedActionsRepository - errors', () => {
      it('should have a actionsSetAllowedActionsRepository function', (done) => {
        try {
          assert.equal(true, typeof a.actionsSetAllowedActionsRepository === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.actionsSetAllowedActionsRepository(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsSetAllowedActionsRepository', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.actionsSetAllowedActionsRepository('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsSetAllowedActionsRepository', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#actionsGetGithubActionsDefaultWorkflowPermissionsRepository - errors', () => {
      it('should have a actionsGetGithubActionsDefaultWorkflowPermissionsRepository function', (done) => {
        try {
          assert.equal(true, typeof a.actionsGetGithubActionsDefaultWorkflowPermissionsRepository === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.actionsGetGithubActionsDefaultWorkflowPermissionsRepository(null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsGetGithubActionsDefaultWorkflowPermissionsRepository', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.actionsGetGithubActionsDefaultWorkflowPermissionsRepository('fakeparam', null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsGetGithubActionsDefaultWorkflowPermissionsRepository', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#actionsSetGithubActionsDefaultWorkflowPermissionsRepository - errors', () => {
      it('should have a actionsSetGithubActionsDefaultWorkflowPermissionsRepository function', (done) => {
        try {
          assert.equal(true, typeof a.actionsSetGithubActionsDefaultWorkflowPermissionsRepository === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.actionsSetGithubActionsDefaultWorkflowPermissionsRepository(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsSetGithubActionsDefaultWorkflowPermissionsRepository', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.actionsSetGithubActionsDefaultWorkflowPermissionsRepository('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsSetGithubActionsDefaultWorkflowPermissionsRepository', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#actionsListSelfHostedRunnersForRepo - errors', () => {
      it('should have a actionsListSelfHostedRunnersForRepo function', (done) => {
        try {
          assert.equal(true, typeof a.actionsListSelfHostedRunnersForRepo === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.actionsListSelfHostedRunnersForRepo('fakeparam', null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsListSelfHostedRunnersForRepo', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.actionsListSelfHostedRunnersForRepo('fakeparam', 'fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsListSelfHostedRunnersForRepo', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#actionsListRunnerApplicationsForRepo - errors', () => {
      it('should have a actionsListRunnerApplicationsForRepo function', (done) => {
        try {
          assert.equal(true, typeof a.actionsListRunnerApplicationsForRepo === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.actionsListRunnerApplicationsForRepo(null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsListRunnerApplicationsForRepo', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.actionsListRunnerApplicationsForRepo('fakeparam', null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsListRunnerApplicationsForRepo', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#actionsGenerateRunnerJitconfigForRepo - errors', () => {
      it('should have a actionsGenerateRunnerJitconfigForRepo function', (done) => {
        try {
          assert.equal(true, typeof a.actionsGenerateRunnerJitconfigForRepo === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.actionsGenerateRunnerJitconfigForRepo(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsGenerateRunnerJitconfigForRepo', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.actionsGenerateRunnerJitconfigForRepo('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsGenerateRunnerJitconfigForRepo', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#actionsCreateRegistrationTokenForRepo - errors', () => {
      it('should have a actionsCreateRegistrationTokenForRepo function', (done) => {
        try {
          assert.equal(true, typeof a.actionsCreateRegistrationTokenForRepo === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.actionsCreateRegistrationTokenForRepo(null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsCreateRegistrationTokenForRepo', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.actionsCreateRegistrationTokenForRepo('fakeparam', null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsCreateRegistrationTokenForRepo', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#actionsCreateRemoveTokenForRepo - errors', () => {
      it('should have a actionsCreateRemoveTokenForRepo function', (done) => {
        try {
          assert.equal(true, typeof a.actionsCreateRemoveTokenForRepo === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.actionsCreateRemoveTokenForRepo(null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsCreateRemoveTokenForRepo', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.actionsCreateRemoveTokenForRepo('fakeparam', null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsCreateRemoveTokenForRepo', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#actionsGetSelfHostedRunnerForRepo - errors', () => {
      it('should have a actionsGetSelfHostedRunnerForRepo function', (done) => {
        try {
          assert.equal(true, typeof a.actionsGetSelfHostedRunnerForRepo === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.actionsGetSelfHostedRunnerForRepo(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsGetSelfHostedRunnerForRepo', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.actionsGetSelfHostedRunnerForRepo('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsGetSelfHostedRunnerForRepo', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing runnerId', (done) => {
        try {
          a.actionsGetSelfHostedRunnerForRepo('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'runnerId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsGetSelfHostedRunnerForRepo', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#actionsDeleteSelfHostedRunnerFromRepo - errors', () => {
      it('should have a actionsDeleteSelfHostedRunnerFromRepo function', (done) => {
        try {
          assert.equal(true, typeof a.actionsDeleteSelfHostedRunnerFromRepo === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.actionsDeleteSelfHostedRunnerFromRepo(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsDeleteSelfHostedRunnerFromRepo', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.actionsDeleteSelfHostedRunnerFromRepo('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsDeleteSelfHostedRunnerFromRepo', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing runnerId', (done) => {
        try {
          a.actionsDeleteSelfHostedRunnerFromRepo('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'runnerId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsDeleteSelfHostedRunnerFromRepo', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#actionsListLabelsForSelfHostedRunnerForRepo - errors', () => {
      it('should have a actionsListLabelsForSelfHostedRunnerForRepo function', (done) => {
        try {
          assert.equal(true, typeof a.actionsListLabelsForSelfHostedRunnerForRepo === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.actionsListLabelsForSelfHostedRunnerForRepo(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsListLabelsForSelfHostedRunnerForRepo', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.actionsListLabelsForSelfHostedRunnerForRepo('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsListLabelsForSelfHostedRunnerForRepo', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing runnerId', (done) => {
        try {
          a.actionsListLabelsForSelfHostedRunnerForRepo('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'runnerId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsListLabelsForSelfHostedRunnerForRepo', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#actionsAddCustomLabelsToSelfHostedRunnerForRepo - errors', () => {
      it('should have a actionsAddCustomLabelsToSelfHostedRunnerForRepo function', (done) => {
        try {
          assert.equal(true, typeof a.actionsAddCustomLabelsToSelfHostedRunnerForRepo === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.actionsAddCustomLabelsToSelfHostedRunnerForRepo(null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsAddCustomLabelsToSelfHostedRunnerForRepo', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.actionsAddCustomLabelsToSelfHostedRunnerForRepo('fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsAddCustomLabelsToSelfHostedRunnerForRepo', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing runnerId', (done) => {
        try {
          a.actionsAddCustomLabelsToSelfHostedRunnerForRepo('fakeparam', 'fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'runnerId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsAddCustomLabelsToSelfHostedRunnerForRepo', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#actionsSetCustomLabelsForSelfHostedRunnerForRepo - errors', () => {
      it('should have a actionsSetCustomLabelsForSelfHostedRunnerForRepo function', (done) => {
        try {
          assert.equal(true, typeof a.actionsSetCustomLabelsForSelfHostedRunnerForRepo === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.actionsSetCustomLabelsForSelfHostedRunnerForRepo(null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsSetCustomLabelsForSelfHostedRunnerForRepo', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.actionsSetCustomLabelsForSelfHostedRunnerForRepo('fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsSetCustomLabelsForSelfHostedRunnerForRepo', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing runnerId', (done) => {
        try {
          a.actionsSetCustomLabelsForSelfHostedRunnerForRepo('fakeparam', 'fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'runnerId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsSetCustomLabelsForSelfHostedRunnerForRepo', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#actionsRemoveAllCustomLabelsFromSelfHostedRunnerForRepo - errors', () => {
      it('should have a actionsRemoveAllCustomLabelsFromSelfHostedRunnerForRepo function', (done) => {
        try {
          assert.equal(true, typeof a.actionsRemoveAllCustomLabelsFromSelfHostedRunnerForRepo === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.actionsRemoveAllCustomLabelsFromSelfHostedRunnerForRepo(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsRemoveAllCustomLabelsFromSelfHostedRunnerForRepo', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.actionsRemoveAllCustomLabelsFromSelfHostedRunnerForRepo('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsRemoveAllCustomLabelsFromSelfHostedRunnerForRepo', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing runnerId', (done) => {
        try {
          a.actionsRemoveAllCustomLabelsFromSelfHostedRunnerForRepo('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'runnerId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsRemoveAllCustomLabelsFromSelfHostedRunnerForRepo', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#actionsRemoveCustomLabelFromSelfHostedRunnerForRepo - errors', () => {
      it('should have a actionsRemoveCustomLabelFromSelfHostedRunnerForRepo function', (done) => {
        try {
          assert.equal(true, typeof a.actionsRemoveCustomLabelFromSelfHostedRunnerForRepo === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.actionsRemoveCustomLabelFromSelfHostedRunnerForRepo(null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsRemoveCustomLabelFromSelfHostedRunnerForRepo', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.actionsRemoveCustomLabelFromSelfHostedRunnerForRepo('fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsRemoveCustomLabelFromSelfHostedRunnerForRepo', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing runnerId', (done) => {
        try {
          a.actionsRemoveCustomLabelFromSelfHostedRunnerForRepo('fakeparam', 'fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'runnerId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsRemoveCustomLabelFromSelfHostedRunnerForRepo', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing name', (done) => {
        try {
          a.actionsRemoveCustomLabelFromSelfHostedRunnerForRepo('fakeparam', 'fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'name is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsRemoveCustomLabelFromSelfHostedRunnerForRepo', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#actionsListWorkflowRunsForRepo - errors', () => {
      it('should have a actionsListWorkflowRunsForRepo function', (done) => {
        try {
          assert.equal(true, typeof a.actionsListWorkflowRunsForRepo === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.actionsListWorkflowRunsForRepo(null, null, null, null, null, null, null, null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsListWorkflowRunsForRepo', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.actionsListWorkflowRunsForRepo('fakeparam', null, null, null, null, null, null, null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsListWorkflowRunsForRepo', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#actionsGetWorkflowRun - errors', () => {
      it('should have a actionsGetWorkflowRun function', (done) => {
        try {
          assert.equal(true, typeof a.actionsGetWorkflowRun === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.actionsGetWorkflowRun(null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsGetWorkflowRun', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.actionsGetWorkflowRun('fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsGetWorkflowRun', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing runId', (done) => {
        try {
          a.actionsGetWorkflowRun('fakeparam', 'fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'runId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsGetWorkflowRun', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#actionsDeleteWorkflowRun - errors', () => {
      it('should have a actionsDeleteWorkflowRun function', (done) => {
        try {
          assert.equal(true, typeof a.actionsDeleteWorkflowRun === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.actionsDeleteWorkflowRun(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsDeleteWorkflowRun', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.actionsDeleteWorkflowRun('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsDeleteWorkflowRun', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing runId', (done) => {
        try {
          a.actionsDeleteWorkflowRun('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'runId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsDeleteWorkflowRun', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#actionsGetReviewsForRun - errors', () => {
      it('should have a actionsGetReviewsForRun function', (done) => {
        try {
          assert.equal(true, typeof a.actionsGetReviewsForRun === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.actionsGetReviewsForRun(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsGetReviewsForRun', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.actionsGetReviewsForRun('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsGetReviewsForRun', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing runId', (done) => {
        try {
          a.actionsGetReviewsForRun('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'runId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsGetReviewsForRun', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#actionsApproveWorkflowRun - errors', () => {
      it('should have a actionsApproveWorkflowRun function', (done) => {
        try {
          assert.equal(true, typeof a.actionsApproveWorkflowRun === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.actionsApproveWorkflowRun(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsApproveWorkflowRun', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.actionsApproveWorkflowRun('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsApproveWorkflowRun', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing runId', (done) => {
        try {
          a.actionsApproveWorkflowRun('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'runId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsApproveWorkflowRun', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#actionsListWorkflowRunArtifacts - errors', () => {
      it('should have a actionsListWorkflowRunArtifacts function', (done) => {
        try {
          assert.equal(true, typeof a.actionsListWorkflowRunArtifacts === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.actionsListWorkflowRunArtifacts(null, null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsListWorkflowRunArtifacts', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.actionsListWorkflowRunArtifacts('fakeparam', null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsListWorkflowRunArtifacts', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing runId', (done) => {
        try {
          a.actionsListWorkflowRunArtifacts('fakeparam', 'fakeparam', null, null, null, null, (data, error) => {
            try {
              const displayE = 'runId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsListWorkflowRunArtifacts', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#actionsGetWorkflowRunAttempt - errors', () => {
      it('should have a actionsGetWorkflowRunAttempt function', (done) => {
        try {
          assert.equal(true, typeof a.actionsGetWorkflowRunAttempt === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.actionsGetWorkflowRunAttempt(null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsGetWorkflowRunAttempt', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.actionsGetWorkflowRunAttempt('fakeparam', null, null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsGetWorkflowRunAttempt', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing runId', (done) => {
        try {
          a.actionsGetWorkflowRunAttempt('fakeparam', 'fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'runId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsGetWorkflowRunAttempt', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing attemptNumber', (done) => {
        try {
          a.actionsGetWorkflowRunAttempt('fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'attemptNumber is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsGetWorkflowRunAttempt', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#actionsListJobsForWorkflowRunAttempt - errors', () => {
      it('should have a actionsListJobsForWorkflowRunAttempt function', (done) => {
        try {
          assert.equal(true, typeof a.actionsListJobsForWorkflowRunAttempt === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.actionsListJobsForWorkflowRunAttempt(null, null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsListJobsForWorkflowRunAttempt', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.actionsListJobsForWorkflowRunAttempt('fakeparam', null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsListJobsForWorkflowRunAttempt', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing runId', (done) => {
        try {
          a.actionsListJobsForWorkflowRunAttempt('fakeparam', 'fakeparam', null, null, null, null, (data, error) => {
            try {
              const displayE = 'runId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsListJobsForWorkflowRunAttempt', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing attemptNumber', (done) => {
        try {
          a.actionsListJobsForWorkflowRunAttempt('fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'attemptNumber is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsListJobsForWorkflowRunAttempt', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#actionsDownloadWorkflowRunAttemptLogs - errors', () => {
      it('should have a actionsDownloadWorkflowRunAttemptLogs function', (done) => {
        try {
          assert.equal(true, typeof a.actionsDownloadWorkflowRunAttemptLogs === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.actionsDownloadWorkflowRunAttemptLogs(null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsDownloadWorkflowRunAttemptLogs', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.actionsDownloadWorkflowRunAttemptLogs('fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsDownloadWorkflowRunAttemptLogs', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing runId', (done) => {
        try {
          a.actionsDownloadWorkflowRunAttemptLogs('fakeparam', 'fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'runId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsDownloadWorkflowRunAttemptLogs', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing attemptNumber', (done) => {
        try {
          a.actionsDownloadWorkflowRunAttemptLogs('fakeparam', 'fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'attemptNumber is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsDownloadWorkflowRunAttemptLogs', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#actionsCancelWorkflowRun - errors', () => {
      it('should have a actionsCancelWorkflowRun function', (done) => {
        try {
          assert.equal(true, typeof a.actionsCancelWorkflowRun === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.actionsCancelWorkflowRun(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsCancelWorkflowRun', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.actionsCancelWorkflowRun('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsCancelWorkflowRun', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing runId', (done) => {
        try {
          a.actionsCancelWorkflowRun('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'runId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsCancelWorkflowRun', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#actionsReviewCustomGatesForRun - errors', () => {
      it('should have a actionsReviewCustomGatesForRun function', (done) => {
        try {
          assert.equal(true, typeof a.actionsReviewCustomGatesForRun === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.actionsReviewCustomGatesForRun(null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsReviewCustomGatesForRun', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.actionsReviewCustomGatesForRun('fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsReviewCustomGatesForRun', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing runId', (done) => {
        try {
          a.actionsReviewCustomGatesForRun('fakeparam', 'fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'runId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsReviewCustomGatesForRun', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#actionsForceCancelWorkflowRun - errors', () => {
      it('should have a actionsForceCancelWorkflowRun function', (done) => {
        try {
          assert.equal(true, typeof a.actionsForceCancelWorkflowRun === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.actionsForceCancelWorkflowRun(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsForceCancelWorkflowRun', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.actionsForceCancelWorkflowRun('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsForceCancelWorkflowRun', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing runId', (done) => {
        try {
          a.actionsForceCancelWorkflowRun('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'runId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsForceCancelWorkflowRun', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#actionsListJobsForWorkflowRun - errors', () => {
      it('should have a actionsListJobsForWorkflowRun function', (done) => {
        try {
          assert.equal(true, typeof a.actionsListJobsForWorkflowRun === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.actionsListJobsForWorkflowRun(null, null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsListJobsForWorkflowRun', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.actionsListJobsForWorkflowRun('fakeparam', null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsListJobsForWorkflowRun', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing runId', (done) => {
        try {
          a.actionsListJobsForWorkflowRun('fakeparam', 'fakeparam', null, null, null, null, (data, error) => {
            try {
              const displayE = 'runId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsListJobsForWorkflowRun', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#actionsDownloadWorkflowRunLogs - errors', () => {
      it('should have a actionsDownloadWorkflowRunLogs function', (done) => {
        try {
          assert.equal(true, typeof a.actionsDownloadWorkflowRunLogs === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.actionsDownloadWorkflowRunLogs(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsDownloadWorkflowRunLogs', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.actionsDownloadWorkflowRunLogs('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsDownloadWorkflowRunLogs', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing runId', (done) => {
        try {
          a.actionsDownloadWorkflowRunLogs('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'runId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsDownloadWorkflowRunLogs', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#actionsDeleteWorkflowRunLogs - errors', () => {
      it('should have a actionsDeleteWorkflowRunLogs function', (done) => {
        try {
          assert.equal(true, typeof a.actionsDeleteWorkflowRunLogs === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.actionsDeleteWorkflowRunLogs(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsDeleteWorkflowRunLogs', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.actionsDeleteWorkflowRunLogs('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsDeleteWorkflowRunLogs', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing runId', (done) => {
        try {
          a.actionsDeleteWorkflowRunLogs('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'runId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsDeleteWorkflowRunLogs', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#actionsGetPendingDeploymentsForRun - errors', () => {
      it('should have a actionsGetPendingDeploymentsForRun function', (done) => {
        try {
          assert.equal(true, typeof a.actionsGetPendingDeploymentsForRun === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.actionsGetPendingDeploymentsForRun(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsGetPendingDeploymentsForRun', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.actionsGetPendingDeploymentsForRun('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsGetPendingDeploymentsForRun', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing runId', (done) => {
        try {
          a.actionsGetPendingDeploymentsForRun('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'runId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsGetPendingDeploymentsForRun', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#actionsReviewPendingDeploymentsForRun - errors', () => {
      it('should have a actionsReviewPendingDeploymentsForRun function', (done) => {
        try {
          assert.equal(true, typeof a.actionsReviewPendingDeploymentsForRun === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.actionsReviewPendingDeploymentsForRun(null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsReviewPendingDeploymentsForRun', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.actionsReviewPendingDeploymentsForRun('fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsReviewPendingDeploymentsForRun', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing runId', (done) => {
        try {
          a.actionsReviewPendingDeploymentsForRun('fakeparam', 'fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'runId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsReviewPendingDeploymentsForRun', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#actionsReRunWorkflow - errors', () => {
      it('should have a actionsReRunWorkflow function', (done) => {
        try {
          assert.equal(true, typeof a.actionsReRunWorkflow === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.actionsReRunWorkflow(null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsReRunWorkflow', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.actionsReRunWorkflow('fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsReRunWorkflow', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing runId', (done) => {
        try {
          a.actionsReRunWorkflow('fakeparam', 'fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'runId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsReRunWorkflow', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#actionsReRunWorkflowFailedJobs - errors', () => {
      it('should have a actionsReRunWorkflowFailedJobs function', (done) => {
        try {
          assert.equal(true, typeof a.actionsReRunWorkflowFailedJobs === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.actionsReRunWorkflowFailedJobs(null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsReRunWorkflowFailedJobs', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.actionsReRunWorkflowFailedJobs('fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsReRunWorkflowFailedJobs', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing runId', (done) => {
        try {
          a.actionsReRunWorkflowFailedJobs('fakeparam', 'fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'runId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsReRunWorkflowFailedJobs', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#actionsGetWorkflowRunUsage - errors', () => {
      it('should have a actionsGetWorkflowRunUsage function', (done) => {
        try {
          assert.equal(true, typeof a.actionsGetWorkflowRunUsage === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.actionsGetWorkflowRunUsage(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsGetWorkflowRunUsage', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.actionsGetWorkflowRunUsage('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsGetWorkflowRunUsage', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing runId', (done) => {
        try {
          a.actionsGetWorkflowRunUsage('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'runId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsGetWorkflowRunUsage', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#actionsListRepoSecrets - errors', () => {
      it('should have a actionsListRepoSecrets function', (done) => {
        try {
          assert.equal(true, typeof a.actionsListRepoSecrets === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.actionsListRepoSecrets(null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsListRepoSecrets', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.actionsListRepoSecrets('fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsListRepoSecrets', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#actionsGetRepoPublicKey - errors', () => {
      it('should have a actionsGetRepoPublicKey function', (done) => {
        try {
          assert.equal(true, typeof a.actionsGetRepoPublicKey === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.actionsGetRepoPublicKey(null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsGetRepoPublicKey', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.actionsGetRepoPublicKey('fakeparam', null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsGetRepoPublicKey', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#actionsGetRepoSecret - errors', () => {
      it('should have a actionsGetRepoSecret function', (done) => {
        try {
          assert.equal(true, typeof a.actionsGetRepoSecret === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.actionsGetRepoSecret(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsGetRepoSecret', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.actionsGetRepoSecret('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsGetRepoSecret', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing secretName', (done) => {
        try {
          a.actionsGetRepoSecret('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'secretName is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsGetRepoSecret', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#actionsCreateOrUpdateRepoSecret - errors', () => {
      it('should have a actionsCreateOrUpdateRepoSecret function', (done) => {
        try {
          assert.equal(true, typeof a.actionsCreateOrUpdateRepoSecret === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.actionsCreateOrUpdateRepoSecret(null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsCreateOrUpdateRepoSecret', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.actionsCreateOrUpdateRepoSecret('fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsCreateOrUpdateRepoSecret', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing secretName', (done) => {
        try {
          a.actionsCreateOrUpdateRepoSecret('fakeparam', 'fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'secretName is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsCreateOrUpdateRepoSecret', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#actionsDeleteRepoSecret - errors', () => {
      it('should have a actionsDeleteRepoSecret function', (done) => {
        try {
          assert.equal(true, typeof a.actionsDeleteRepoSecret === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.actionsDeleteRepoSecret(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsDeleteRepoSecret', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.actionsDeleteRepoSecret('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsDeleteRepoSecret', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing secretName', (done) => {
        try {
          a.actionsDeleteRepoSecret('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'secretName is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsDeleteRepoSecret', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#actionsListRepoVariables - errors', () => {
      it('should have a actionsListRepoVariables function', (done) => {
        try {
          assert.equal(true, typeof a.actionsListRepoVariables === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.actionsListRepoVariables(null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsListRepoVariables', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.actionsListRepoVariables('fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsListRepoVariables', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#actionsCreateRepoVariable - errors', () => {
      it('should have a actionsCreateRepoVariable function', (done) => {
        try {
          assert.equal(true, typeof a.actionsCreateRepoVariable === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.actionsCreateRepoVariable(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsCreateRepoVariable', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.actionsCreateRepoVariable('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsCreateRepoVariable', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#actionsGetRepoVariable - errors', () => {
      it('should have a actionsGetRepoVariable function', (done) => {
        try {
          assert.equal(true, typeof a.actionsGetRepoVariable === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.actionsGetRepoVariable(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsGetRepoVariable', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.actionsGetRepoVariable('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsGetRepoVariable', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing name', (done) => {
        try {
          a.actionsGetRepoVariable('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'name is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsGetRepoVariable', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#actionsUpdateRepoVariable - errors', () => {
      it('should have a actionsUpdateRepoVariable function', (done) => {
        try {
          assert.equal(true, typeof a.actionsUpdateRepoVariable === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.actionsUpdateRepoVariable(null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsUpdateRepoVariable', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.actionsUpdateRepoVariable('fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsUpdateRepoVariable', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing name', (done) => {
        try {
          a.actionsUpdateRepoVariable('fakeparam', 'fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'name is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsUpdateRepoVariable', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#actionsDeleteRepoVariable - errors', () => {
      it('should have a actionsDeleteRepoVariable function', (done) => {
        try {
          assert.equal(true, typeof a.actionsDeleteRepoVariable === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.actionsDeleteRepoVariable(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsDeleteRepoVariable', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.actionsDeleteRepoVariable('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsDeleteRepoVariable', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing name', (done) => {
        try {
          a.actionsDeleteRepoVariable('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'name is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsDeleteRepoVariable', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#actionsListRepoWorkflows - errors', () => {
      it('should have a actionsListRepoWorkflows function', (done) => {
        try {
          assert.equal(true, typeof a.actionsListRepoWorkflows === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.actionsListRepoWorkflows(null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsListRepoWorkflows', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.actionsListRepoWorkflows('fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsListRepoWorkflows', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#actionsGetWorkflow - errors', () => {
      it('should have a actionsGetWorkflow function', (done) => {
        try {
          assert.equal(true, typeof a.actionsGetWorkflow === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.actionsGetWorkflow(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsGetWorkflow', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.actionsGetWorkflow('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsGetWorkflow', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing workflowId', (done) => {
        try {
          a.actionsGetWorkflow('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'workflowId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsGetWorkflow', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#actionsDisableWorkflow - errors', () => {
      it('should have a actionsDisableWorkflow function', (done) => {
        try {
          assert.equal(true, typeof a.actionsDisableWorkflow === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.actionsDisableWorkflow(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsDisableWorkflow', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.actionsDisableWorkflow('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsDisableWorkflow', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing workflowId', (done) => {
        try {
          a.actionsDisableWorkflow('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'workflowId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsDisableWorkflow', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#actionsCreateWorkflowDispatch - errors', () => {
      it('should have a actionsCreateWorkflowDispatch function', (done) => {
        try {
          assert.equal(true, typeof a.actionsCreateWorkflowDispatch === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.actionsCreateWorkflowDispatch(null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsCreateWorkflowDispatch', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.actionsCreateWorkflowDispatch('fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsCreateWorkflowDispatch', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing workflowId', (done) => {
        try {
          a.actionsCreateWorkflowDispatch('fakeparam', 'fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'workflowId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsCreateWorkflowDispatch', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#actionsEnableWorkflow - errors', () => {
      it('should have a actionsEnableWorkflow function', (done) => {
        try {
          assert.equal(true, typeof a.actionsEnableWorkflow === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.actionsEnableWorkflow(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsEnableWorkflow', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.actionsEnableWorkflow('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsEnableWorkflow', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing workflowId', (done) => {
        try {
          a.actionsEnableWorkflow('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'workflowId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsEnableWorkflow', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#actionsListWorkflowRuns - errors', () => {
      it('should have a actionsListWorkflowRuns function', (done) => {
        try {
          assert.equal(true, typeof a.actionsListWorkflowRuns === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.actionsListWorkflowRuns(null, null, null, null, null, null, null, null, null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsListWorkflowRuns', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.actionsListWorkflowRuns('fakeparam', null, null, null, null, null, null, null, null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsListWorkflowRuns', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing workflowId', (done) => {
        try {
          a.actionsListWorkflowRuns('fakeparam', 'fakeparam', null, null, null, null, null, null, null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'workflowId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsListWorkflowRuns', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#actionsGetWorkflowUsage - errors', () => {
      it('should have a actionsGetWorkflowUsage function', (done) => {
        try {
          assert.equal(true, typeof a.actionsGetWorkflowUsage === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.actionsGetWorkflowUsage(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsGetWorkflowUsage', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.actionsGetWorkflowUsage('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsGetWorkflowUsage', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing workflowId', (done) => {
        try {
          a.actionsGetWorkflowUsage('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'workflowId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsGetWorkflowUsage', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#actionsListEnvironmentSecrets - errors', () => {
      it('should have a actionsListEnvironmentSecrets function', (done) => {
        try {
          assert.equal(true, typeof a.actionsListEnvironmentSecrets === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.actionsListEnvironmentSecrets(null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsListEnvironmentSecrets', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.actionsListEnvironmentSecrets('fakeparam', null, null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsListEnvironmentSecrets', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing environmentName', (done) => {
        try {
          a.actionsListEnvironmentSecrets('fakeparam', 'fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'environmentName is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsListEnvironmentSecrets', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#actionsGetEnvironmentPublicKey - errors', () => {
      it('should have a actionsGetEnvironmentPublicKey function', (done) => {
        try {
          assert.equal(true, typeof a.actionsGetEnvironmentPublicKey === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.actionsGetEnvironmentPublicKey(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsGetEnvironmentPublicKey', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.actionsGetEnvironmentPublicKey('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsGetEnvironmentPublicKey', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing environmentName', (done) => {
        try {
          a.actionsGetEnvironmentPublicKey('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'environmentName is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsGetEnvironmentPublicKey', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#actionsGetEnvironmentSecret - errors', () => {
      it('should have a actionsGetEnvironmentSecret function', (done) => {
        try {
          assert.equal(true, typeof a.actionsGetEnvironmentSecret === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.actionsGetEnvironmentSecret(null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsGetEnvironmentSecret', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.actionsGetEnvironmentSecret('fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsGetEnvironmentSecret', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing environmentName', (done) => {
        try {
          a.actionsGetEnvironmentSecret('fakeparam', 'fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'environmentName is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsGetEnvironmentSecret', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing secretName', (done) => {
        try {
          a.actionsGetEnvironmentSecret('fakeparam', 'fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'secretName is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsGetEnvironmentSecret', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#actionsCreateOrUpdateEnvironmentSecret - errors', () => {
      it('should have a actionsCreateOrUpdateEnvironmentSecret function', (done) => {
        try {
          assert.equal(true, typeof a.actionsCreateOrUpdateEnvironmentSecret === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.actionsCreateOrUpdateEnvironmentSecret(null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsCreateOrUpdateEnvironmentSecret', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.actionsCreateOrUpdateEnvironmentSecret('fakeparam', null, null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsCreateOrUpdateEnvironmentSecret', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing environmentName', (done) => {
        try {
          a.actionsCreateOrUpdateEnvironmentSecret('fakeparam', 'fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'environmentName is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsCreateOrUpdateEnvironmentSecret', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing secretName', (done) => {
        try {
          a.actionsCreateOrUpdateEnvironmentSecret('fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'secretName is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsCreateOrUpdateEnvironmentSecret', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#actionsDeleteEnvironmentSecret - errors', () => {
      it('should have a actionsDeleteEnvironmentSecret function', (done) => {
        try {
          assert.equal(true, typeof a.actionsDeleteEnvironmentSecret === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.actionsDeleteEnvironmentSecret(null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsDeleteEnvironmentSecret', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.actionsDeleteEnvironmentSecret('fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsDeleteEnvironmentSecret', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing environmentName', (done) => {
        try {
          a.actionsDeleteEnvironmentSecret('fakeparam', 'fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'environmentName is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsDeleteEnvironmentSecret', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing secretName', (done) => {
        try {
          a.actionsDeleteEnvironmentSecret('fakeparam', 'fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'secretName is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsDeleteEnvironmentSecret', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#actionsListEnvironmentVariables - errors', () => {
      it('should have a actionsListEnvironmentVariables function', (done) => {
        try {
          assert.equal(true, typeof a.actionsListEnvironmentVariables === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.actionsListEnvironmentVariables(null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsListEnvironmentVariables', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.actionsListEnvironmentVariables('fakeparam', null, null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsListEnvironmentVariables', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing environmentName', (done) => {
        try {
          a.actionsListEnvironmentVariables('fakeparam', 'fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'environmentName is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsListEnvironmentVariables', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#actionsCreateEnvironmentVariable - errors', () => {
      it('should have a actionsCreateEnvironmentVariable function', (done) => {
        try {
          assert.equal(true, typeof a.actionsCreateEnvironmentVariable === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.actionsCreateEnvironmentVariable(null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsCreateEnvironmentVariable', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.actionsCreateEnvironmentVariable('fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsCreateEnvironmentVariable', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing environmentName', (done) => {
        try {
          a.actionsCreateEnvironmentVariable('fakeparam', 'fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'environmentName is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsCreateEnvironmentVariable', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#actionsGetEnvironmentVariable - errors', () => {
      it('should have a actionsGetEnvironmentVariable function', (done) => {
        try {
          assert.equal(true, typeof a.actionsGetEnvironmentVariable === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.actionsGetEnvironmentVariable(null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsGetEnvironmentVariable', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.actionsGetEnvironmentVariable('fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsGetEnvironmentVariable', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing environmentName', (done) => {
        try {
          a.actionsGetEnvironmentVariable('fakeparam', 'fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'environmentName is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsGetEnvironmentVariable', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing name', (done) => {
        try {
          a.actionsGetEnvironmentVariable('fakeparam', 'fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'name is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsGetEnvironmentVariable', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#actionsUpdateEnvironmentVariable - errors', () => {
      it('should have a actionsUpdateEnvironmentVariable function', (done) => {
        try {
          assert.equal(true, typeof a.actionsUpdateEnvironmentVariable === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.actionsUpdateEnvironmentVariable(null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsUpdateEnvironmentVariable', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.actionsUpdateEnvironmentVariable('fakeparam', null, null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsUpdateEnvironmentVariable', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing name', (done) => {
        try {
          a.actionsUpdateEnvironmentVariable('fakeparam', 'fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'name is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsUpdateEnvironmentVariable', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing environmentName', (done) => {
        try {
          a.actionsUpdateEnvironmentVariable('fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'environmentName is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsUpdateEnvironmentVariable', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#actionsDeleteEnvironmentVariable - errors', () => {
      it('should have a actionsDeleteEnvironmentVariable function', (done) => {
        try {
          assert.equal(true, typeof a.actionsDeleteEnvironmentVariable === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.actionsDeleteEnvironmentVariable(null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsDeleteEnvironmentVariable', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.actionsDeleteEnvironmentVariable('fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsDeleteEnvironmentVariable', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing name', (done) => {
        try {
          a.actionsDeleteEnvironmentVariable('fakeparam', 'fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'name is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsDeleteEnvironmentVariable', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing environmentName', (done) => {
        try {
          a.actionsDeleteEnvironmentVariable('fakeparam', 'fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'environmentName is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-actionsDeleteEnvironmentVariable', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getEventsQuery - errors', () => {
      it('should have a getEventsQuery function', (done) => {
        try {
          assert.equal(true, typeof a.getEventsQuery === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getNetworksOwnerRepoEventsQuery - errors', () => {
      it('should have a getNetworksOwnerRepoEventsQuery function', (done) => {
        try {
          assert.equal(true, typeof a.getNetworksOwnerRepoEventsQuery === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.getNetworksOwnerRepoEventsQuery(null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getNetworksOwnerRepoEventsQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.getNetworksOwnerRepoEventsQuery('fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getNetworksOwnerRepoEventsQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getNotificationsQuery - errors', () => {
      it('should have a getNotificationsQuery function', (done) => {
        try {
          assert.equal(true, typeof a.getNotificationsQuery === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#activityGetThread - errors', () => {
      it('should have a activityGetThread function', (done) => {
        try {
          assert.equal(true, typeof a.activityGetThread === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        try {
          a.activityGetThread(null, (data, error) => {
            try {
              const displayE = 'id is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-activityGetThread', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#activityMarkThreadAsRead - errors', () => {
      it('should have a activityMarkThreadAsRead function', (done) => {
        try {
          assert.equal(true, typeof a.activityMarkThreadAsRead === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        try {
          a.activityMarkThreadAsRead(null, (data, error) => {
            try {
              const displayE = 'id is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-activityMarkThreadAsRead', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#activityMarkThreadAsDone - errors', () => {
      it('should have a activityMarkThreadAsDone function', (done) => {
        try {
          assert.equal(true, typeof a.activityMarkThreadAsDone === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        try {
          a.activityMarkThreadAsDone(null, (data, error) => {
            try {
              const displayE = 'id is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-activityMarkThreadAsDone', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#activityGetThreadSubscriptionForAuthenticatedUser - errors', () => {
      it('should have a activityGetThreadSubscriptionForAuthenticatedUser function', (done) => {
        try {
          assert.equal(true, typeof a.activityGetThreadSubscriptionForAuthenticatedUser === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        try {
          a.activityGetThreadSubscriptionForAuthenticatedUser(null, (data, error) => {
            try {
              const displayE = 'id is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-activityGetThreadSubscriptionForAuthenticatedUser', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#activitySetThreadSubscription - errors', () => {
      it('should have a activitySetThreadSubscription function', (done) => {
        try {
          assert.equal(true, typeof a.activitySetThreadSubscription === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        try {
          a.activitySetThreadSubscription(null, null, (data, error) => {
            try {
              const displayE = 'id is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-activitySetThreadSubscription', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#activityDeleteThreadSubscription - errors', () => {
      it('should have a activityDeleteThreadSubscription function', (done) => {
        try {
          assert.equal(true, typeof a.activityDeleteThreadSubscription === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        try {
          a.activityDeleteThreadSubscription(null, (data, error) => {
            try {
              const displayE = 'id is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-activityDeleteThreadSubscription', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#activityListPublicEventsForUser - errors', () => {
      it('should have a activityListPublicEventsForUser function', (done) => {
        try {
          assert.equal(true, typeof a.activityListPublicEventsForUser === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing username', (done) => {
        try {
          a.activityListPublicEventsForUser(null, null, null, (data, error) => {
            try {
              const displayE = 'username is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-activityListPublicEventsForUser', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getOrgsOrgEventsQuery - errors', () => {
      it('should have a getOrgsOrgEventsQuery function', (done) => {
        try {
          assert.equal(true, typeof a.getOrgsOrgEventsQuery === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.getOrgsOrgEventsQuery(null, null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getOrgsOrgEventsQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getOrgsOrgIssuesQuery - errors', () => {
      it('should have a getOrgsOrgIssuesQuery function', (done) => {
        try {
          assert.equal(true, typeof a.getOrgsOrgIssuesQuery === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.getOrgsOrgIssuesQuery(null, null, null, null, null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getOrgsOrgIssuesQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#orgsList - errors', () => {
      it('should have a orgsList function', (done) => {
        try {
          assert.equal(true, typeof a.orgsList === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#orgsDelete - errors', () => {
      it('should have a orgsDelete function', (done) => {
        try {
          assert.equal(true, typeof a.orgsDelete === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.orgsDelete(null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-orgsDelete', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#orgsListAttestations - errors', () => {
      it('should have a orgsListAttestations function', (done) => {
        try {
          assert.equal(true, typeof a.orgsListAttestations === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.orgsListAttestations('fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-orgsListAttestations', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing subjectDigest', (done) => {
        try {
          a.orgsListAttestations('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'subjectDigest is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-orgsListAttestations', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#orgsListBlockedUsers - errors', () => {
      it('should have a orgsListBlockedUsers function', (done) => {
        try {
          assert.equal(true, typeof a.orgsListBlockedUsers === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.orgsListBlockedUsers(null, null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-orgsListBlockedUsers', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#orgsCheckBlockedUser - errors', () => {
      it('should have a orgsCheckBlockedUser function', (done) => {
        try {
          assert.equal(true, typeof a.orgsCheckBlockedUser === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.orgsCheckBlockedUser(null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-orgsCheckBlockedUser', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing username', (done) => {
        try {
          a.orgsCheckBlockedUser('fakeparam', null, (data, error) => {
            try {
              const displayE = 'username is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-orgsCheckBlockedUser', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#orgsBlockUser - errors', () => {
      it('should have a orgsBlockUser function', (done) => {
        try {
          assert.equal(true, typeof a.orgsBlockUser === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.orgsBlockUser(null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-orgsBlockUser', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing username', (done) => {
        try {
          a.orgsBlockUser('fakeparam', null, (data, error) => {
            try {
              const displayE = 'username is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-orgsBlockUser', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#orgsUnblockUser - errors', () => {
      it('should have a orgsUnblockUser function', (done) => {
        try {
          assert.equal(true, typeof a.orgsUnblockUser === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.orgsUnblockUser(null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-orgsUnblockUser', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing username', (done) => {
        try {
          a.orgsUnblockUser('fakeparam', null, (data, error) => {
            try {
              const displayE = 'username is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-orgsUnblockUser', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#orgsListFailedInvitations - errors', () => {
      it('should have a orgsListFailedInvitations function', (done) => {
        try {
          assert.equal(true, typeof a.orgsListFailedInvitations === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.orgsListFailedInvitations(null, null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-orgsListFailedInvitations', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#orgsListWebhooks - errors', () => {
      it('should have a orgsListWebhooks function', (done) => {
        try {
          assert.equal(true, typeof a.orgsListWebhooks === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.orgsListWebhooks(null, null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-orgsListWebhooks', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#orgsCreateWebhook - errors', () => {
      it('should have a orgsCreateWebhook function', (done) => {
        try {
          assert.equal(true, typeof a.orgsCreateWebhook === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.orgsCreateWebhook(null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-orgsCreateWebhook', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#orgsGetWebhook - errors', () => {
      it('should have a orgsGetWebhook function', (done) => {
        try {
          assert.equal(true, typeof a.orgsGetWebhook === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.orgsGetWebhook(null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-orgsGetWebhook', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing hookId', (done) => {
        try {
          a.orgsGetWebhook('fakeparam', null, (data, error) => {
            try {
              const displayE = 'hookId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-orgsGetWebhook', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#orgsUpdateWebhook - errors', () => {
      it('should have a orgsUpdateWebhook function', (done) => {
        try {
          assert.equal(true, typeof a.orgsUpdateWebhook === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.orgsUpdateWebhook(null, null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-orgsUpdateWebhook', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing hookId', (done) => {
        try {
          a.orgsUpdateWebhook('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'hookId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-orgsUpdateWebhook', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#orgsDeleteWebhook - errors', () => {
      it('should have a orgsDeleteWebhook function', (done) => {
        try {
          assert.equal(true, typeof a.orgsDeleteWebhook === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.orgsDeleteWebhook(null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-orgsDeleteWebhook', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing hookId', (done) => {
        try {
          a.orgsDeleteWebhook('fakeparam', null, (data, error) => {
            try {
              const displayE = 'hookId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-orgsDeleteWebhook', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#orgsGetWebhookConfigForOrg - errors', () => {
      it('should have a orgsGetWebhookConfigForOrg function', (done) => {
        try {
          assert.equal(true, typeof a.orgsGetWebhookConfigForOrg === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.orgsGetWebhookConfigForOrg(null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-orgsGetWebhookConfigForOrg', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing hookId', (done) => {
        try {
          a.orgsGetWebhookConfigForOrg('fakeparam', null, (data, error) => {
            try {
              const displayE = 'hookId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-orgsGetWebhookConfigForOrg', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#orgsUpdateWebhookConfigForOrg - errors', () => {
      it('should have a orgsUpdateWebhookConfigForOrg function', (done) => {
        try {
          assert.equal(true, typeof a.orgsUpdateWebhookConfigForOrg === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.orgsUpdateWebhookConfigForOrg(null, null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-orgsUpdateWebhookConfigForOrg', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing hookId', (done) => {
        try {
          a.orgsUpdateWebhookConfigForOrg('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'hookId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-orgsUpdateWebhookConfigForOrg', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#orgsListWebhookDeliveries - errors', () => {
      it('should have a orgsListWebhookDeliveries function', (done) => {
        try {
          assert.equal(true, typeof a.orgsListWebhookDeliveries === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.orgsListWebhookDeliveries(null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-orgsListWebhookDeliveries', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing hookId', (done) => {
        try {
          a.orgsListWebhookDeliveries('fakeparam', null, null, null, null, (data, error) => {
            try {
              const displayE = 'hookId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-orgsListWebhookDeliveries', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#orgsGetWebhookDelivery - errors', () => {
      it('should have a orgsGetWebhookDelivery function', (done) => {
        try {
          assert.equal(true, typeof a.orgsGetWebhookDelivery === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.orgsGetWebhookDelivery(null, null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-orgsGetWebhookDelivery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing hookId', (done) => {
        try {
          a.orgsGetWebhookDelivery('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'hookId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-orgsGetWebhookDelivery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing deliveryId', (done) => {
        try {
          a.orgsGetWebhookDelivery('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'deliveryId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-orgsGetWebhookDelivery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#orgsRedeliverWebhookDelivery - errors', () => {
      it('should have a orgsRedeliverWebhookDelivery function', (done) => {
        try {
          assert.equal(true, typeof a.orgsRedeliverWebhookDelivery === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.orgsRedeliverWebhookDelivery(null, null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-orgsRedeliverWebhookDelivery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing hookId', (done) => {
        try {
          a.orgsRedeliverWebhookDelivery('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'hookId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-orgsRedeliverWebhookDelivery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing deliveryId', (done) => {
        try {
          a.orgsRedeliverWebhookDelivery('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'deliveryId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-orgsRedeliverWebhookDelivery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#orgsPingWebhook - errors', () => {
      it('should have a orgsPingWebhook function', (done) => {
        try {
          assert.equal(true, typeof a.orgsPingWebhook === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.orgsPingWebhook(null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-orgsPingWebhook', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing hookId', (done) => {
        try {
          a.orgsPingWebhook('fakeparam', null, (data, error) => {
            try {
              const displayE = 'hookId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-orgsPingWebhook', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#orgsListAppInstallations - errors', () => {
      it('should have a orgsListAppInstallations function', (done) => {
        try {
          assert.equal(true, typeof a.orgsListAppInstallations === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.orgsListAppInstallations(null, null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-orgsListAppInstallations', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#orgsListPendingInvitations - errors', () => {
      it('should have a orgsListPendingInvitations function', (done) => {
        try {
          assert.equal(true, typeof a.orgsListPendingInvitations === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.orgsListPendingInvitations(null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-orgsListPendingInvitations', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#orgsCreateInvitation - errors', () => {
      it('should have a orgsCreateInvitation function', (done) => {
        try {
          assert.equal(true, typeof a.orgsCreateInvitation === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.orgsCreateInvitation(null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-orgsCreateInvitation', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#orgsCancelInvitation - errors', () => {
      it('should have a orgsCancelInvitation function', (done) => {
        try {
          assert.equal(true, typeof a.orgsCancelInvitation === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.orgsCancelInvitation(null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-orgsCancelInvitation', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing invitationId', (done) => {
        try {
          a.orgsCancelInvitation('fakeparam', null, (data, error) => {
            try {
              const displayE = 'invitationId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-orgsCancelInvitation', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#orgsListInvitationTeams - errors', () => {
      it('should have a orgsListInvitationTeams function', (done) => {
        try {
          assert.equal(true, typeof a.orgsListInvitationTeams === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.orgsListInvitationTeams(null, null, null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-orgsListInvitationTeams', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing invitationId', (done) => {
        try {
          a.orgsListInvitationTeams('fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'invitationId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-orgsListInvitationTeams', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getOrgsOrgMembersQuery - errors', () => {
      it('should have a getOrgsOrgMembersQuery function', (done) => {
        try {
          assert.equal(true, typeof a.getOrgsOrgMembersQuery === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.getOrgsOrgMembersQuery(null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getOrgsOrgMembersQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#orgsGetMembershipForUser - errors', () => {
      it('should have a orgsGetMembershipForUser function', (done) => {
        try {
          assert.equal(true, typeof a.orgsGetMembershipForUser === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.orgsGetMembershipForUser(null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-orgsGetMembershipForUser', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing username', (done) => {
        try {
          a.orgsGetMembershipForUser('fakeparam', null, (data, error) => {
            try {
              const displayE = 'username is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-orgsGetMembershipForUser', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#orgsSetMembershipForUser - errors', () => {
      it('should have a orgsSetMembershipForUser function', (done) => {
        try {
          assert.equal(true, typeof a.orgsSetMembershipForUser === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.orgsSetMembershipForUser(null, null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-orgsSetMembershipForUser', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing username', (done) => {
        try {
          a.orgsSetMembershipForUser('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'username is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-orgsSetMembershipForUser', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#orgsRemoveMembershipForUser - errors', () => {
      it('should have a orgsRemoveMembershipForUser function', (done) => {
        try {
          assert.equal(true, typeof a.orgsRemoveMembershipForUser === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.orgsRemoveMembershipForUser(null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-orgsRemoveMembershipForUser', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing username', (done) => {
        try {
          a.orgsRemoveMembershipForUser('fakeparam', null, (data, error) => {
            try {
              const displayE = 'username is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-orgsRemoveMembershipForUser', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#orgsListOrgRoles - errors', () => {
      it('should have a orgsListOrgRoles function', (done) => {
        try {
          assert.equal(true, typeof a.orgsListOrgRoles === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.orgsListOrgRoles(null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-orgsListOrgRoles', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#orgsRevokeAllOrgRolesTeam - errors', () => {
      it('should have a orgsRevokeAllOrgRolesTeam function', (done) => {
        try {
          assert.equal(true, typeof a.orgsRevokeAllOrgRolesTeam === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.orgsRevokeAllOrgRolesTeam(null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-orgsRevokeAllOrgRolesTeam', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing teamSlug', (done) => {
        try {
          a.orgsRevokeAllOrgRolesTeam('fakeparam', null, (data, error) => {
            try {
              const displayE = 'teamSlug is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-orgsRevokeAllOrgRolesTeam', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#orgsAssignTeamToOrgRole - errors', () => {
      it('should have a orgsAssignTeamToOrgRole function', (done) => {
        try {
          assert.equal(true, typeof a.orgsAssignTeamToOrgRole === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.orgsAssignTeamToOrgRole(null, null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-orgsAssignTeamToOrgRole', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing teamSlug', (done) => {
        try {
          a.orgsAssignTeamToOrgRole('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'teamSlug is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-orgsAssignTeamToOrgRole', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing roleId', (done) => {
        try {
          a.orgsAssignTeamToOrgRole('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'roleId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-orgsAssignTeamToOrgRole', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#orgsRevokeOrgRoleTeam - errors', () => {
      it('should have a orgsRevokeOrgRoleTeam function', (done) => {
        try {
          assert.equal(true, typeof a.orgsRevokeOrgRoleTeam === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.orgsRevokeOrgRoleTeam(null, null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-orgsRevokeOrgRoleTeam', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing teamSlug', (done) => {
        try {
          a.orgsRevokeOrgRoleTeam('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'teamSlug is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-orgsRevokeOrgRoleTeam', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing roleId', (done) => {
        try {
          a.orgsRevokeOrgRoleTeam('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'roleId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-orgsRevokeOrgRoleTeam', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#orgsRevokeAllOrgRolesUser - errors', () => {
      it('should have a orgsRevokeAllOrgRolesUser function', (done) => {
        try {
          assert.equal(true, typeof a.orgsRevokeAllOrgRolesUser === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.orgsRevokeAllOrgRolesUser(null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-orgsRevokeAllOrgRolesUser', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing username', (done) => {
        try {
          a.orgsRevokeAllOrgRolesUser('fakeparam', null, (data, error) => {
            try {
              const displayE = 'username is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-orgsRevokeAllOrgRolesUser', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#orgsAssignUserToOrgRole - errors', () => {
      it('should have a orgsAssignUserToOrgRole function', (done) => {
        try {
          assert.equal(true, typeof a.orgsAssignUserToOrgRole === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.orgsAssignUserToOrgRole(null, null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-orgsAssignUserToOrgRole', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing username', (done) => {
        try {
          a.orgsAssignUserToOrgRole('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'username is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-orgsAssignUserToOrgRole', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing roleId', (done) => {
        try {
          a.orgsAssignUserToOrgRole('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'roleId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-orgsAssignUserToOrgRole', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#orgsRevokeOrgRoleUser - errors', () => {
      it('should have a orgsRevokeOrgRoleUser function', (done) => {
        try {
          assert.equal(true, typeof a.orgsRevokeOrgRoleUser === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.orgsRevokeOrgRoleUser(null, null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-orgsRevokeOrgRoleUser', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing username', (done) => {
        try {
          a.orgsRevokeOrgRoleUser('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'username is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-orgsRevokeOrgRoleUser', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing roleId', (done) => {
        try {
          a.orgsRevokeOrgRoleUser('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'roleId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-orgsRevokeOrgRoleUser', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#orgsGetOrgRole - errors', () => {
      it('should have a orgsGetOrgRole function', (done) => {
        try {
          assert.equal(true, typeof a.orgsGetOrgRole === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.orgsGetOrgRole(null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-orgsGetOrgRole', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing roleId', (done) => {
        try {
          a.orgsGetOrgRole('fakeparam', null, (data, error) => {
            try {
              const displayE = 'roleId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-orgsGetOrgRole', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#orgsListOrgRoleTeams - errors', () => {
      it('should have a orgsListOrgRoleTeams function', (done) => {
        try {
          assert.equal(true, typeof a.orgsListOrgRoleTeams === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.orgsListOrgRoleTeams(null, null, null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-orgsListOrgRoleTeams', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing roleId', (done) => {
        try {
          a.orgsListOrgRoleTeams('fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'roleId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-orgsListOrgRoleTeams', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#orgsListOrgRoleUsers - errors', () => {
      it('should have a orgsListOrgRoleUsers function', (done) => {
        try {
          assert.equal(true, typeof a.orgsListOrgRoleUsers === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.orgsListOrgRoleUsers(null, null, null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-orgsListOrgRoleUsers', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing roleId', (done) => {
        try {
          a.orgsListOrgRoleUsers('fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'roleId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-orgsListOrgRoleUsers', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#orgsListOutsideCollaborators - errors', () => {
      it('should have a orgsListOutsideCollaborators function', (done) => {
        try {
          assert.equal(true, typeof a.orgsListOutsideCollaborators === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.orgsListOutsideCollaborators(null, null, null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-orgsListOutsideCollaborators', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#orgsConvertMemberToOutsideCollaborator - errors', () => {
      it('should have a orgsConvertMemberToOutsideCollaborator function', (done) => {
        try {
          assert.equal(true, typeof a.orgsConvertMemberToOutsideCollaborator === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.orgsConvertMemberToOutsideCollaborator(null, null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-orgsConvertMemberToOutsideCollaborator', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing username', (done) => {
        try {
          a.orgsConvertMemberToOutsideCollaborator('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'username is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-orgsConvertMemberToOutsideCollaborator', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#orgsRemoveOutsideCollaborator - errors', () => {
      it('should have a orgsRemoveOutsideCollaborator function', (done) => {
        try {
          assert.equal(true, typeof a.orgsRemoveOutsideCollaborator === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.orgsRemoveOutsideCollaborator(null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-orgsRemoveOutsideCollaborator', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing username', (done) => {
        try {
          a.orgsRemoveOutsideCollaborator('fakeparam', null, (data, error) => {
            try {
              const displayE = 'username is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-orgsRemoveOutsideCollaborator', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#orgsListPatGrantRequests - errors', () => {
      it('should have a orgsListPatGrantRequests function', (done) => {
        try {
          assert.equal(true, typeof a.orgsListPatGrantRequests === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.orgsListPatGrantRequests(null, null, null, null, null, null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-orgsListPatGrantRequests', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#orgsReviewPatGrantRequestsInBulk - errors', () => {
      it('should have a orgsReviewPatGrantRequestsInBulk function', (done) => {
        try {
          assert.equal(true, typeof a.orgsReviewPatGrantRequestsInBulk === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.orgsReviewPatGrantRequestsInBulk(null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-orgsReviewPatGrantRequestsInBulk', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#orgsReviewPatGrantRequest - errors', () => {
      it('should have a orgsReviewPatGrantRequest function', (done) => {
        try {
          assert.equal(true, typeof a.orgsReviewPatGrantRequest === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.orgsReviewPatGrantRequest(null, null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-orgsReviewPatGrantRequest', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing patRequestId', (done) => {
        try {
          a.orgsReviewPatGrantRequest('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'patRequestId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-orgsReviewPatGrantRequest', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#orgsListPatGrantRequestRepositories - errors', () => {
      it('should have a orgsListPatGrantRequestRepositories function', (done) => {
        try {
          assert.equal(true, typeof a.orgsListPatGrantRequestRepositories === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.orgsListPatGrantRequestRepositories(null, null, null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-orgsListPatGrantRequestRepositories', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing patRequestId', (done) => {
        try {
          a.orgsListPatGrantRequestRepositories('fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'patRequestId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-orgsListPatGrantRequestRepositories', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#orgsListPatGrants - errors', () => {
      it('should have a orgsListPatGrants function', (done) => {
        try {
          assert.equal(true, typeof a.orgsListPatGrants === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.orgsListPatGrants(null, null, null, null, null, null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-orgsListPatGrants', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#orgsUpdatePatAccesses - errors', () => {
      it('should have a orgsUpdatePatAccesses function', (done) => {
        try {
          assert.equal(true, typeof a.orgsUpdatePatAccesses === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.orgsUpdatePatAccesses(null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-orgsUpdatePatAccesses', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#orgsUpdatePatAccess - errors', () => {
      it('should have a orgsUpdatePatAccess function', (done) => {
        try {
          assert.equal(true, typeof a.orgsUpdatePatAccess === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.orgsUpdatePatAccess(null, null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-orgsUpdatePatAccess', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing patId', (done) => {
        try {
          a.orgsUpdatePatAccess('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'patId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-orgsUpdatePatAccess', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#orgsListPatGrantRepositories - errors', () => {
      it('should have a orgsListPatGrantRepositories function', (done) => {
        try {
          assert.equal(true, typeof a.orgsListPatGrantRepositories === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.orgsListPatGrantRepositories(null, null, null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-orgsListPatGrantRepositories', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing patId', (done) => {
        try {
          a.orgsListPatGrantRepositories('fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'patId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-orgsListPatGrantRepositories', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#orgsGetAllCustomProperties - errors', () => {
      it('should have a orgsGetAllCustomProperties function', (done) => {
        try {
          assert.equal(true, typeof a.orgsGetAllCustomProperties === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.orgsGetAllCustomProperties(null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-orgsGetAllCustomProperties', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#orgsCreateOrUpdateCustomProperties - errors', () => {
      it('should have a orgsCreateOrUpdateCustomProperties function', (done) => {
        try {
          assert.equal(true, typeof a.orgsCreateOrUpdateCustomProperties === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.orgsCreateOrUpdateCustomProperties(null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-orgsCreateOrUpdateCustomProperties', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#orgsGetCustomProperty - errors', () => {
      it('should have a orgsGetCustomProperty function', (done) => {
        try {
          assert.equal(true, typeof a.orgsGetCustomProperty === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.orgsGetCustomProperty(null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-orgsGetCustomProperty', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing customPropertyName', (done) => {
        try {
          a.orgsGetCustomProperty('fakeparam', null, (data, error) => {
            try {
              const displayE = 'customPropertyName is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-orgsGetCustomProperty', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#orgsCreateOrUpdateCustomProperty - errors', () => {
      it('should have a orgsCreateOrUpdateCustomProperty function', (done) => {
        try {
          assert.equal(true, typeof a.orgsCreateOrUpdateCustomProperty === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.orgsCreateOrUpdateCustomProperty(null, null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-orgsCreateOrUpdateCustomProperty', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing customPropertyName', (done) => {
        try {
          a.orgsCreateOrUpdateCustomProperty('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'customPropertyName is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-orgsCreateOrUpdateCustomProperty', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#orgsRemoveCustomProperty - errors', () => {
      it('should have a orgsRemoveCustomProperty function', (done) => {
        try {
          assert.equal(true, typeof a.orgsRemoveCustomProperty === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.orgsRemoveCustomProperty(null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-orgsRemoveCustomProperty', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing customPropertyName', (done) => {
        try {
          a.orgsRemoveCustomProperty('fakeparam', null, (data, error) => {
            try {
              const displayE = 'customPropertyName is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-orgsRemoveCustomProperty', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#orgsListCustomPropertiesValuesForRepos - errors', () => {
      it('should have a orgsListCustomPropertiesValuesForRepos function', (done) => {
        try {
          assert.equal(true, typeof a.orgsListCustomPropertiesValuesForRepos === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.orgsListCustomPropertiesValuesForRepos(null, null, null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-orgsListCustomPropertiesValuesForRepos', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#orgsCreateOrUpdateCustomPropertiesValuesForRepos - errors', () => {
      it('should have a orgsCreateOrUpdateCustomPropertiesValuesForRepos function', (done) => {
        try {
          assert.equal(true, typeof a.orgsCreateOrUpdateCustomPropertiesValuesForRepos === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.orgsCreateOrUpdateCustomPropertiesValuesForRepos(null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-orgsCreateOrUpdateCustomPropertiesValuesForRepos', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getOrgsOrgPublicMembersQuery - errors', () => {
      it('should have a getOrgsOrgPublicMembersQuery function', (done) => {
        try {
          assert.equal(true, typeof a.getOrgsOrgPublicMembersQuery === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.getOrgsOrgPublicMembersQuery(null, null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getOrgsOrgPublicMembersQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#orgsListSecurityManagerTeams - errors', () => {
      it('should have a orgsListSecurityManagerTeams function', (done) => {
        try {
          assert.equal(true, typeof a.orgsListSecurityManagerTeams === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.orgsListSecurityManagerTeams(null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-orgsListSecurityManagerTeams', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#orgsAddSecurityManagerTeam - errors', () => {
      it('should have a orgsAddSecurityManagerTeam function', (done) => {
        try {
          assert.equal(true, typeof a.orgsAddSecurityManagerTeam === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.orgsAddSecurityManagerTeam(null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-orgsAddSecurityManagerTeam', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing teamSlug', (done) => {
        try {
          a.orgsAddSecurityManagerTeam('fakeparam', null, (data, error) => {
            try {
              const displayE = 'teamSlug is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-orgsAddSecurityManagerTeam', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#orgsRemoveSecurityManagerTeam - errors', () => {
      it('should have a orgsRemoveSecurityManagerTeam function', (done) => {
        try {
          assert.equal(true, typeof a.orgsRemoveSecurityManagerTeam === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.orgsRemoveSecurityManagerTeam(null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-orgsRemoveSecurityManagerTeam', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing teamSlug', (done) => {
        try {
          a.orgsRemoveSecurityManagerTeam('fakeparam', null, (data, error) => {
            try {
              const displayE = 'teamSlug is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-orgsRemoveSecurityManagerTeam', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#orgsListMembershipsForAuthenticatedUser - errors', () => {
      it('should have a orgsListMembershipsForAuthenticatedUser function', (done) => {
        try {
          assert.equal(true, typeof a.orgsListMembershipsForAuthenticatedUser === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#orgsGetMembershipForAuthenticatedUser - errors', () => {
      it('should have a orgsGetMembershipForAuthenticatedUser function', (done) => {
        try {
          assert.equal(true, typeof a.orgsGetMembershipForAuthenticatedUser === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.orgsGetMembershipForAuthenticatedUser(null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-orgsGetMembershipForAuthenticatedUser', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#orgsUpdateMembershipForAuthenticatedUser - errors', () => {
      it('should have a orgsUpdateMembershipForAuthenticatedUser function', (done) => {
        try {
          assert.equal(true, typeof a.orgsUpdateMembershipForAuthenticatedUser === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.orgsUpdateMembershipForAuthenticatedUser(null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-orgsUpdateMembershipForAuthenticatedUser', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getOrgsOrgReposQuery - errors', () => {
      it('should have a getOrgsOrgReposQuery function', (done) => {
        try {
          assert.equal(true, typeof a.getOrgsOrgReposQuery === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.getOrgsOrgReposQuery(null, null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getOrgsOrgReposQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getOrgsOrgTeamsQuery - errors', () => {
      it('should have a getOrgsOrgTeamsQuery function', (done) => {
        try {
          assert.equal(true, typeof a.getOrgsOrgTeamsQuery === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.getOrgsOrgTeamsQuery(null, null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getOrgsOrgTeamsQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoEventsQuery - errors', () => {
      it('should have a getReposOwnerRepoEventsQuery function', (done) => {
        try {
          assert.equal(true, typeof a.getReposOwnerRepoEventsQuery === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.getReposOwnerRepoEventsQuery(null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoEventsQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.getReposOwnerRepoEventsQuery('fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoEventsQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoNotificationsQuery - errors', () => {
      it('should have a getReposOwnerRepoNotificationsQuery function', (done) => {
        try {
          assert.equal(true, typeof a.getReposOwnerRepoNotificationsQuery === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.getReposOwnerRepoNotificationsQuery(null, null, null, null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoNotificationsQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.getReposOwnerRepoNotificationsQuery('fakeparam', null, null, null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoNotificationsQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoStargazersQuery - errors', () => {
      it('should have a getReposOwnerRepoStargazersQuery function', (done) => {
        try {
          assert.equal(true, typeof a.getReposOwnerRepoStargazersQuery === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.getReposOwnerRepoStargazersQuery(null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoStargazersQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.getReposOwnerRepoStargazersQuery('fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoStargazersQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoSubscribersQuery - errors', () => {
      it('should have a getReposOwnerRepoSubscribersQuery function', (done) => {
        try {
          assert.equal(true, typeof a.getReposOwnerRepoSubscribersQuery === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.getReposOwnerRepoSubscribersQuery(null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoSubscribersQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.getReposOwnerRepoSubscribersQuery('fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoSubscribersQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoAssigneesQuery - errors', () => {
      it('should have a getReposOwnerRepoAssigneesQuery function', (done) => {
        try {
          assert.equal(true, typeof a.getReposOwnerRepoAssigneesQuery === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.getReposOwnerRepoAssigneesQuery(null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoAssigneesQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.getReposOwnerRepoAssigneesQuery('fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoAssigneesQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoIssuesQuery - errors', () => {
      it('should have a getReposOwnerRepoIssuesQuery function', (done) => {
        try {
          assert.equal(true, typeof a.getReposOwnerRepoIssuesQuery === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.getReposOwnerRepoIssuesQuery(null, null, null, null, null, null, null, null, null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoIssuesQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.getReposOwnerRepoIssuesQuery('fakeparam', null, null, null, null, null, null, null, null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoIssuesQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoIssuesCommentsQuery - errors', () => {
      it('should have a getReposOwnerRepoIssuesCommentsQuery function', (done) => {
        try {
          assert.equal(true, typeof a.getReposOwnerRepoIssuesCommentsQuery === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.getReposOwnerRepoIssuesCommentsQuery(null, null, null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoIssuesCommentsQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.getReposOwnerRepoIssuesCommentsQuery('fakeparam', null, null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoIssuesCommentsQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoIssuesEventsQuery - errors', () => {
      it('should have a getReposOwnerRepoIssuesEventsQuery function', (done) => {
        try {
          assert.equal(true, typeof a.getReposOwnerRepoIssuesEventsQuery === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.getReposOwnerRepoIssuesEventsQuery(null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoIssuesEventsQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.getReposOwnerRepoIssuesEventsQuery('fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoIssuesEventsQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoIssuesNumberCommentsQuery - errors', () => {
      it('should have a getReposOwnerRepoIssuesNumberCommentsQuery function', (done) => {
        try {
          assert.equal(true, typeof a.getReposOwnerRepoIssuesNumberCommentsQuery === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.getReposOwnerRepoIssuesNumberCommentsQuery(null, null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoIssuesNumberCommentsQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.getReposOwnerRepoIssuesNumberCommentsQuery('fakeparam', null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoIssuesNumberCommentsQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing issueNumber', (done) => {
        try {
          a.getReposOwnerRepoIssuesNumberCommentsQuery('fakeparam', 'fakeparam', null, null, null, null, (data, error) => {
            try {
              const displayE = 'issueNumber is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoIssuesNumberCommentsQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoIssuesNumberEventsQuery - errors', () => {
      it('should have a getReposOwnerRepoIssuesNumberEventsQuery function', (done) => {
        try {
          assert.equal(true, typeof a.getReposOwnerRepoIssuesNumberEventsQuery === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.getReposOwnerRepoIssuesNumberEventsQuery(null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoIssuesNumberEventsQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.getReposOwnerRepoIssuesNumberEventsQuery('fakeparam', null, null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoIssuesNumberEventsQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing issueNumber', (done) => {
        try {
          a.getReposOwnerRepoIssuesNumberEventsQuery('fakeparam', 'fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'issueNumber is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoIssuesNumberEventsQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoIssuesNumberLabelsQuery - errors', () => {
      it('should have a getReposOwnerRepoIssuesNumberLabelsQuery function', (done) => {
        try {
          assert.equal(true, typeof a.getReposOwnerRepoIssuesNumberLabelsQuery === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.getReposOwnerRepoIssuesNumberLabelsQuery(null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoIssuesNumberLabelsQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.getReposOwnerRepoIssuesNumberLabelsQuery('fakeparam', null, null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoIssuesNumberLabelsQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing issueNumber', (done) => {
        try {
          a.getReposOwnerRepoIssuesNumberLabelsQuery('fakeparam', 'fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'issueNumber is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoIssuesNumberLabelsQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoLabelsQuery - errors', () => {
      it('should have a getReposOwnerRepoLabelsQuery function', (done) => {
        try {
          assert.equal(true, typeof a.getReposOwnerRepoLabelsQuery === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.getReposOwnerRepoLabelsQuery(null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoLabelsQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.getReposOwnerRepoLabelsQuery('fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoLabelsQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoMilestonesQuery - errors', () => {
      it('should have a getReposOwnerRepoMilestonesQuery function', (done) => {
        try {
          assert.equal(true, typeof a.getReposOwnerRepoMilestonesQuery === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.getReposOwnerRepoMilestonesQuery(null, null, null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoMilestonesQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.getReposOwnerRepoMilestonesQuery('fakeparam', null, null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoMilestonesQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoMilestonesNumberLabelsQuery - errors', () => {
      it('should have a getReposOwnerRepoMilestonesNumberLabelsQuery function', (done) => {
        try {
          assert.equal(true, typeof a.getReposOwnerRepoMilestonesNumberLabelsQuery === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.getReposOwnerRepoMilestonesNumberLabelsQuery(null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoMilestonesNumberLabelsQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.getReposOwnerRepoMilestonesNumberLabelsQuery('fakeparam', null, null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoMilestonesNumberLabelsQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing milestoneNumber', (done) => {
        try {
          a.getReposOwnerRepoMilestonesNumberLabelsQuery('fakeparam', 'fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'milestoneNumber is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoMilestonesNumberLabelsQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoPullsQuery - errors', () => {
      it('should have a getReposOwnerRepoPullsQuery function', (done) => {
        try {
          assert.equal(true, typeof a.getReposOwnerRepoPullsQuery === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.getReposOwnerRepoPullsQuery(null, null, null, null, null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoPullsQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.getReposOwnerRepoPullsQuery('fakeparam', null, null, null, null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoPullsQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoPullsCommentsQuery - errors', () => {
      it('should have a getReposOwnerRepoPullsCommentsQuery function', (done) => {
        try {
          assert.equal(true, typeof a.getReposOwnerRepoPullsCommentsQuery === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.getReposOwnerRepoPullsCommentsQuery(null, null, null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoPullsCommentsQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.getReposOwnerRepoPullsCommentsQuery('fakeparam', null, null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoPullsCommentsQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoPullsNumberCommentsQuery - errors', () => {
      it('should have a getReposOwnerRepoPullsNumberCommentsQuery function', (done) => {
        try {
          assert.equal(true, typeof a.getReposOwnerRepoPullsNumberCommentsQuery === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.getReposOwnerRepoPullsNumberCommentsQuery(null, null, null, null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoPullsNumberCommentsQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.getReposOwnerRepoPullsNumberCommentsQuery('fakeparam', null, null, null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoPullsNumberCommentsQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing pullNumber', (done) => {
        try {
          a.getReposOwnerRepoPullsNumberCommentsQuery('fakeparam', 'fakeparam', null, null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'pullNumber is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoPullsNumberCommentsQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoPullsNumberCommitsQuery - errors', () => {
      it('should have a getReposOwnerRepoPullsNumberCommitsQuery function', (done) => {
        try {
          assert.equal(true, typeof a.getReposOwnerRepoPullsNumberCommitsQuery === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.getReposOwnerRepoPullsNumberCommitsQuery(null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoPullsNumberCommitsQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.getReposOwnerRepoPullsNumberCommitsQuery('fakeparam', null, null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoPullsNumberCommitsQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing pullNumber', (done) => {
        try {
          a.getReposOwnerRepoPullsNumberCommitsQuery('fakeparam', 'fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'pullNumber is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoPullsNumberCommitsQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoPullsNumberFilesQuery - errors', () => {
      it('should have a getReposOwnerRepoPullsNumberFilesQuery function', (done) => {
        try {
          assert.equal(true, typeof a.getReposOwnerRepoPullsNumberFilesQuery === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.getReposOwnerRepoPullsNumberFilesQuery(null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoPullsNumberFilesQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.getReposOwnerRepoPullsNumberFilesQuery('fakeparam', null, null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoPullsNumberFilesQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing pullNumber', (done) => {
        try {
          a.getReposOwnerRepoPullsNumberFilesQuery('fakeparam', 'fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'pullNumber is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoPullsNumberFilesQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#reposGetOrgRulesets - errors', () => {
      it('should have a reposGetOrgRulesets function', (done) => {
        try {
          assert.equal(true, typeof a.reposGetOrgRulesets === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.reposGetOrgRulesets(null, null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposGetOrgRulesets', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#reposCreateOrgRuleset - errors', () => {
      it('should have a reposCreateOrgRuleset function', (done) => {
        try {
          assert.equal(true, typeof a.reposCreateOrgRuleset === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.reposCreateOrgRuleset(null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposCreateOrgRuleset', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#reposGetOrgRuleSuites - errors', () => {
      it('should have a reposGetOrgRuleSuites function', (done) => {
        try {
          assert.equal(true, typeof a.reposGetOrgRuleSuites === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.reposGetOrgRuleSuites(null, null, null, null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposGetOrgRuleSuites', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#reposGetOrgRuleSuite - errors', () => {
      it('should have a reposGetOrgRuleSuite function', (done) => {
        try {
          assert.equal(true, typeof a.reposGetOrgRuleSuite === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.reposGetOrgRuleSuite(null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposGetOrgRuleSuite', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing ruleSuiteId', (done) => {
        try {
          a.reposGetOrgRuleSuite('fakeparam', null, (data, error) => {
            try {
              const displayE = 'ruleSuiteId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposGetOrgRuleSuite', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#reposGetOrgRuleset - errors', () => {
      it('should have a reposGetOrgRuleset function', (done) => {
        try {
          assert.equal(true, typeof a.reposGetOrgRuleset === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.reposGetOrgRuleset(null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposGetOrgRuleset', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing rulesetId', (done) => {
        try {
          a.reposGetOrgRuleset('fakeparam', null, (data, error) => {
            try {
              const displayE = 'rulesetId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposGetOrgRuleset', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#reposUpdateOrgRuleset - errors', () => {
      it('should have a reposUpdateOrgRuleset function', (done) => {
        try {
          assert.equal(true, typeof a.reposUpdateOrgRuleset === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.reposUpdateOrgRuleset(null, null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposUpdateOrgRuleset', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing rulesetId', (done) => {
        try {
          a.reposUpdateOrgRuleset('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'rulesetId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposUpdateOrgRuleset', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#reposDeleteOrgRuleset - errors', () => {
      it('should have a reposDeleteOrgRuleset function', (done) => {
        try {
          assert.equal(true, typeof a.reposDeleteOrgRuleset === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.reposDeleteOrgRuleset(null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposDeleteOrgRuleset', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing rulesetId', (done) => {
        try {
          a.reposDeleteOrgRuleset('fakeparam', null, (data, error) => {
            try {
              const displayE = 'rulesetId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposDeleteOrgRuleset', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#reposListActivities - errors', () => {
      it('should have a reposListActivities function', (done) => {
        try {
          assert.equal(true, typeof a.reposListActivities === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.reposListActivities(null, null, null, null, null, null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposListActivities', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.reposListActivities('fakeparam', null, null, null, null, null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposListActivities', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#reposCreateAttestation - errors', () => {
      it('should have a reposCreateAttestation function', (done) => {
        try {
          assert.equal(true, typeof a.reposCreateAttestation === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.reposCreateAttestation(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposCreateAttestation', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.reposCreateAttestation('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposCreateAttestation', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#reposListAttestations - errors', () => {
      it('should have a reposListAttestations function', (done) => {
        try {
          assert.equal(true, typeof a.reposListAttestations === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.reposListAttestations(null, null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposListAttestations', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.reposListAttestations('fakeparam', null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposListAttestations', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing subjectDigest', (done) => {
        try {
          a.reposListAttestations('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'subjectDigest is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposListAttestations', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#reposListAutolinks - errors', () => {
      it('should have a reposListAutolinks function', (done) => {
        try {
          assert.equal(true, typeof a.reposListAutolinks === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.reposListAutolinks(null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposListAutolinks', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.reposListAutolinks('fakeparam', null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposListAutolinks', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#reposCreateAutolink - errors', () => {
      it('should have a reposCreateAutolink function', (done) => {
        try {
          assert.equal(true, typeof a.reposCreateAutolink === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.reposCreateAutolink(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposCreateAutolink', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.reposCreateAutolink('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposCreateAutolink', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#reposGetAutolink - errors', () => {
      it('should have a reposGetAutolink function', (done) => {
        try {
          assert.equal(true, typeof a.reposGetAutolink === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.reposGetAutolink(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposGetAutolink', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.reposGetAutolink('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposGetAutolink', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing autolinkId', (done) => {
        try {
          a.reposGetAutolink('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'autolinkId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposGetAutolink', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#reposDeleteAutolink - errors', () => {
      it('should have a reposDeleteAutolink function', (done) => {
        try {
          assert.equal(true, typeof a.reposDeleteAutolink === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.reposDeleteAutolink(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposDeleteAutolink', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.reposDeleteAutolink('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposDeleteAutolink', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing autolinkId', (done) => {
        try {
          a.reposDeleteAutolink('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'autolinkId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposDeleteAutolink', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#reposCheckAutomatedSecurityFixes - errors', () => {
      it('should have a reposCheckAutomatedSecurityFixes function', (done) => {
        try {
          assert.equal(true, typeof a.reposCheckAutomatedSecurityFixes === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.reposCheckAutomatedSecurityFixes(null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposCheckAutomatedSecurityFixes', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.reposCheckAutomatedSecurityFixes('fakeparam', null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposCheckAutomatedSecurityFixes', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#reposEnableAutomatedSecurityFixes - errors', () => {
      it('should have a reposEnableAutomatedSecurityFixes function', (done) => {
        try {
          assert.equal(true, typeof a.reposEnableAutomatedSecurityFixes === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.reposEnableAutomatedSecurityFixes(null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposEnableAutomatedSecurityFixes', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.reposEnableAutomatedSecurityFixes('fakeparam', null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposEnableAutomatedSecurityFixes', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#reposDisableAutomatedSecurityFixes - errors', () => {
      it('should have a reposDisableAutomatedSecurityFixes function', (done) => {
        try {
          assert.equal(true, typeof a.reposDisableAutomatedSecurityFixes === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.reposDisableAutomatedSecurityFixes(null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposDisableAutomatedSecurityFixes', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.reposDisableAutomatedSecurityFixes('fakeparam', null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposDisableAutomatedSecurityFixes', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoBranchesQuery - errors', () => {
      it('should have a getReposOwnerRepoBranchesQuery function', (done) => {
        try {
          assert.equal(true, typeof a.getReposOwnerRepoBranchesQuery === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.getReposOwnerRepoBranchesQuery(null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoBranchesQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.getReposOwnerRepoBranchesQuery('fakeparam', null, null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoBranchesQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#reposGetBranchProtection - errors', () => {
      it('should have a reposGetBranchProtection function', (done) => {
        try {
          assert.equal(true, typeof a.reposGetBranchProtection === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.reposGetBranchProtection(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposGetBranchProtection', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.reposGetBranchProtection('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposGetBranchProtection', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing branch', (done) => {
        try {
          a.reposGetBranchProtection('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'branch is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposGetBranchProtection', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#reposUpdateBranchProtection - errors', () => {
      it('should have a reposUpdateBranchProtection function', (done) => {
        try {
          assert.equal(true, typeof a.reposUpdateBranchProtection === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.reposUpdateBranchProtection(null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposUpdateBranchProtection', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.reposUpdateBranchProtection('fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposUpdateBranchProtection', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing branch', (done) => {
        try {
          a.reposUpdateBranchProtection('fakeparam', 'fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'branch is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposUpdateBranchProtection', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#reposDeleteBranchProtection - errors', () => {
      it('should have a reposDeleteBranchProtection function', (done) => {
        try {
          assert.equal(true, typeof a.reposDeleteBranchProtection === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.reposDeleteBranchProtection(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposDeleteBranchProtection', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.reposDeleteBranchProtection('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposDeleteBranchProtection', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing branch', (done) => {
        try {
          a.reposDeleteBranchProtection('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'branch is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposDeleteBranchProtection', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#reposGetAdminBranchProtection - errors', () => {
      it('should have a reposGetAdminBranchProtection function', (done) => {
        try {
          assert.equal(true, typeof a.reposGetAdminBranchProtection === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.reposGetAdminBranchProtection(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposGetAdminBranchProtection', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.reposGetAdminBranchProtection('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposGetAdminBranchProtection', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing branch', (done) => {
        try {
          a.reposGetAdminBranchProtection('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'branch is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposGetAdminBranchProtection', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#reposSetAdminBranchProtection - errors', () => {
      it('should have a reposSetAdminBranchProtection function', (done) => {
        try {
          assert.equal(true, typeof a.reposSetAdminBranchProtection === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.reposSetAdminBranchProtection(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposSetAdminBranchProtection', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.reposSetAdminBranchProtection('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposSetAdminBranchProtection', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing branch', (done) => {
        try {
          a.reposSetAdminBranchProtection('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'branch is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposSetAdminBranchProtection', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#reposDeleteAdminBranchProtection - errors', () => {
      it('should have a reposDeleteAdminBranchProtection function', (done) => {
        try {
          assert.equal(true, typeof a.reposDeleteAdminBranchProtection === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.reposDeleteAdminBranchProtection(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposDeleteAdminBranchProtection', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.reposDeleteAdminBranchProtection('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposDeleteAdminBranchProtection', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing branch', (done) => {
        try {
          a.reposDeleteAdminBranchProtection('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'branch is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposDeleteAdminBranchProtection', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#reposGetPullRequestReviewProtection - errors', () => {
      it('should have a reposGetPullRequestReviewProtection function', (done) => {
        try {
          assert.equal(true, typeof a.reposGetPullRequestReviewProtection === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.reposGetPullRequestReviewProtection(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposGetPullRequestReviewProtection', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.reposGetPullRequestReviewProtection('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposGetPullRequestReviewProtection', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing branch', (done) => {
        try {
          a.reposGetPullRequestReviewProtection('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'branch is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposGetPullRequestReviewProtection', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#reposUpdatePullRequestReviewProtection - errors', () => {
      it('should have a reposUpdatePullRequestReviewProtection function', (done) => {
        try {
          assert.equal(true, typeof a.reposUpdatePullRequestReviewProtection === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.reposUpdatePullRequestReviewProtection(null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposUpdatePullRequestReviewProtection', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.reposUpdatePullRequestReviewProtection('fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposUpdatePullRequestReviewProtection', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing branch', (done) => {
        try {
          a.reposUpdatePullRequestReviewProtection('fakeparam', 'fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'branch is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposUpdatePullRequestReviewProtection', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#reposDeletePullRequestReviewProtection - errors', () => {
      it('should have a reposDeletePullRequestReviewProtection function', (done) => {
        try {
          assert.equal(true, typeof a.reposDeletePullRequestReviewProtection === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.reposDeletePullRequestReviewProtection(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposDeletePullRequestReviewProtection', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.reposDeletePullRequestReviewProtection('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposDeletePullRequestReviewProtection', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing branch', (done) => {
        try {
          a.reposDeletePullRequestReviewProtection('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'branch is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposDeletePullRequestReviewProtection', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#reposGetCommitSignatureProtection - errors', () => {
      it('should have a reposGetCommitSignatureProtection function', (done) => {
        try {
          assert.equal(true, typeof a.reposGetCommitSignatureProtection === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.reposGetCommitSignatureProtection(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposGetCommitSignatureProtection', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.reposGetCommitSignatureProtection('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposGetCommitSignatureProtection', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing branch', (done) => {
        try {
          a.reposGetCommitSignatureProtection('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'branch is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposGetCommitSignatureProtection', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#reposCreateCommitSignatureProtection - errors', () => {
      it('should have a reposCreateCommitSignatureProtection function', (done) => {
        try {
          assert.equal(true, typeof a.reposCreateCommitSignatureProtection === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.reposCreateCommitSignatureProtection(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposCreateCommitSignatureProtection', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.reposCreateCommitSignatureProtection('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposCreateCommitSignatureProtection', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing branch', (done) => {
        try {
          a.reposCreateCommitSignatureProtection('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'branch is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposCreateCommitSignatureProtection', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#reposDeleteCommitSignatureProtection - errors', () => {
      it('should have a reposDeleteCommitSignatureProtection function', (done) => {
        try {
          assert.equal(true, typeof a.reposDeleteCommitSignatureProtection === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.reposDeleteCommitSignatureProtection(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposDeleteCommitSignatureProtection', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.reposDeleteCommitSignatureProtection('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposDeleteCommitSignatureProtection', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing branch', (done) => {
        try {
          a.reposDeleteCommitSignatureProtection('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'branch is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposDeleteCommitSignatureProtection', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#reposGetStatusChecksProtection - errors', () => {
      it('should have a reposGetStatusChecksProtection function', (done) => {
        try {
          assert.equal(true, typeof a.reposGetStatusChecksProtection === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.reposGetStatusChecksProtection(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposGetStatusChecksProtection', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.reposGetStatusChecksProtection('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposGetStatusChecksProtection', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing branch', (done) => {
        try {
          a.reposGetStatusChecksProtection('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'branch is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposGetStatusChecksProtection', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#reposUpdateStatusCheckProtection - errors', () => {
      it('should have a reposUpdateStatusCheckProtection function', (done) => {
        try {
          assert.equal(true, typeof a.reposUpdateStatusCheckProtection === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.reposUpdateStatusCheckProtection(null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposUpdateStatusCheckProtection', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.reposUpdateStatusCheckProtection('fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposUpdateStatusCheckProtection', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing branch', (done) => {
        try {
          a.reposUpdateStatusCheckProtection('fakeparam', 'fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'branch is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposUpdateStatusCheckProtection', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#reposRemoveStatusCheckProtection - errors', () => {
      it('should have a reposRemoveStatusCheckProtection function', (done) => {
        try {
          assert.equal(true, typeof a.reposRemoveStatusCheckProtection === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.reposRemoveStatusCheckProtection(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposRemoveStatusCheckProtection', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.reposRemoveStatusCheckProtection('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposRemoveStatusCheckProtection', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing branch', (done) => {
        try {
          a.reposRemoveStatusCheckProtection('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'branch is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposRemoveStatusCheckProtection', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#reposGetAllStatusCheckContexts - errors', () => {
      it('should have a reposGetAllStatusCheckContexts function', (done) => {
        try {
          assert.equal(true, typeof a.reposGetAllStatusCheckContexts === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.reposGetAllStatusCheckContexts(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposGetAllStatusCheckContexts', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.reposGetAllStatusCheckContexts('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposGetAllStatusCheckContexts', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing branch', (done) => {
        try {
          a.reposGetAllStatusCheckContexts('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'branch is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposGetAllStatusCheckContexts', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#reposAddStatusCheckContexts - errors', () => {
      it('should have a reposAddStatusCheckContexts function', (done) => {
        try {
          assert.equal(true, typeof a.reposAddStatusCheckContexts === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.reposAddStatusCheckContexts(null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposAddStatusCheckContexts', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.reposAddStatusCheckContexts('fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposAddStatusCheckContexts', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing branch', (done) => {
        try {
          a.reposAddStatusCheckContexts('fakeparam', 'fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'branch is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposAddStatusCheckContexts', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#reposSetStatusCheckContexts - errors', () => {
      it('should have a reposSetStatusCheckContexts function', (done) => {
        try {
          assert.equal(true, typeof a.reposSetStatusCheckContexts === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.reposSetStatusCheckContexts(null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposSetStatusCheckContexts', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.reposSetStatusCheckContexts('fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposSetStatusCheckContexts', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing branch', (done) => {
        try {
          a.reposSetStatusCheckContexts('fakeparam', 'fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'branch is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposSetStatusCheckContexts', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#reposRemoveStatusCheckContexts - errors', () => {
      it('should have a reposRemoveStatusCheckContexts function', (done) => {
        try {
          assert.equal(true, typeof a.reposRemoveStatusCheckContexts === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.reposRemoveStatusCheckContexts(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposRemoveStatusCheckContexts', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.reposRemoveStatusCheckContexts('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposRemoveStatusCheckContexts', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing branch', (done) => {
        try {
          a.reposRemoveStatusCheckContexts('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'branch is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposRemoveStatusCheckContexts', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#reposGetAccessRestrictions - errors', () => {
      it('should have a reposGetAccessRestrictions function', (done) => {
        try {
          assert.equal(true, typeof a.reposGetAccessRestrictions === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.reposGetAccessRestrictions(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposGetAccessRestrictions', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.reposGetAccessRestrictions('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposGetAccessRestrictions', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing branch', (done) => {
        try {
          a.reposGetAccessRestrictions('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'branch is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposGetAccessRestrictions', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#reposDeleteAccessRestrictions - errors', () => {
      it('should have a reposDeleteAccessRestrictions function', (done) => {
        try {
          assert.equal(true, typeof a.reposDeleteAccessRestrictions === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.reposDeleteAccessRestrictions(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposDeleteAccessRestrictions', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.reposDeleteAccessRestrictions('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposDeleteAccessRestrictions', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing branch', (done) => {
        try {
          a.reposDeleteAccessRestrictions('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'branch is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposDeleteAccessRestrictions', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#reposGetAppsWithAccessToProtectedBranch - errors', () => {
      it('should have a reposGetAppsWithAccessToProtectedBranch function', (done) => {
        try {
          assert.equal(true, typeof a.reposGetAppsWithAccessToProtectedBranch === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.reposGetAppsWithAccessToProtectedBranch(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposGetAppsWithAccessToProtectedBranch', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.reposGetAppsWithAccessToProtectedBranch('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposGetAppsWithAccessToProtectedBranch', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing branch', (done) => {
        try {
          a.reposGetAppsWithAccessToProtectedBranch('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'branch is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposGetAppsWithAccessToProtectedBranch', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#reposAddAppAccessRestrictions - errors', () => {
      it('should have a reposAddAppAccessRestrictions function', (done) => {
        try {
          assert.equal(true, typeof a.reposAddAppAccessRestrictions === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.reposAddAppAccessRestrictions(null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposAddAppAccessRestrictions', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.reposAddAppAccessRestrictions('fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposAddAppAccessRestrictions', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing branch', (done) => {
        try {
          a.reposAddAppAccessRestrictions('fakeparam', 'fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'branch is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposAddAppAccessRestrictions', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#reposSetAppAccessRestrictions - errors', () => {
      it('should have a reposSetAppAccessRestrictions function', (done) => {
        try {
          assert.equal(true, typeof a.reposSetAppAccessRestrictions === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.reposSetAppAccessRestrictions(null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposSetAppAccessRestrictions', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.reposSetAppAccessRestrictions('fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposSetAppAccessRestrictions', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing branch', (done) => {
        try {
          a.reposSetAppAccessRestrictions('fakeparam', 'fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'branch is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposSetAppAccessRestrictions', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#reposRemoveAppAccessRestrictions - errors', () => {
      it('should have a reposRemoveAppAccessRestrictions function', (done) => {
        try {
          assert.equal(true, typeof a.reposRemoveAppAccessRestrictions === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.reposRemoveAppAccessRestrictions(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposRemoveAppAccessRestrictions', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.reposRemoveAppAccessRestrictions('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposRemoveAppAccessRestrictions', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing branch', (done) => {
        try {
          a.reposRemoveAppAccessRestrictions('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'branch is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposRemoveAppAccessRestrictions', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#reposGetTeamsWithAccessToProtectedBranch - errors', () => {
      it('should have a reposGetTeamsWithAccessToProtectedBranch function', (done) => {
        try {
          assert.equal(true, typeof a.reposGetTeamsWithAccessToProtectedBranch === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.reposGetTeamsWithAccessToProtectedBranch(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposGetTeamsWithAccessToProtectedBranch', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.reposGetTeamsWithAccessToProtectedBranch('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposGetTeamsWithAccessToProtectedBranch', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing branch', (done) => {
        try {
          a.reposGetTeamsWithAccessToProtectedBranch('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'branch is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposGetTeamsWithAccessToProtectedBranch', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#reposAddTeamAccessRestrictions - errors', () => {
      it('should have a reposAddTeamAccessRestrictions function', (done) => {
        try {
          assert.equal(true, typeof a.reposAddTeamAccessRestrictions === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.reposAddTeamAccessRestrictions(null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposAddTeamAccessRestrictions', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.reposAddTeamAccessRestrictions('fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposAddTeamAccessRestrictions', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing branch', (done) => {
        try {
          a.reposAddTeamAccessRestrictions('fakeparam', 'fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'branch is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposAddTeamAccessRestrictions', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#reposSetTeamAccessRestrictions - errors', () => {
      it('should have a reposSetTeamAccessRestrictions function', (done) => {
        try {
          assert.equal(true, typeof a.reposSetTeamAccessRestrictions === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.reposSetTeamAccessRestrictions(null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposSetTeamAccessRestrictions', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.reposSetTeamAccessRestrictions('fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposSetTeamAccessRestrictions', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing branch', (done) => {
        try {
          a.reposSetTeamAccessRestrictions('fakeparam', 'fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'branch is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposSetTeamAccessRestrictions', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#reposRemoveTeamAccessRestrictions - errors', () => {
      it('should have a reposRemoveTeamAccessRestrictions function', (done) => {
        try {
          assert.equal(true, typeof a.reposRemoveTeamAccessRestrictions === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.reposRemoveTeamAccessRestrictions(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposRemoveTeamAccessRestrictions', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.reposRemoveTeamAccessRestrictions('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposRemoveTeamAccessRestrictions', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing branch', (done) => {
        try {
          a.reposRemoveTeamAccessRestrictions('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'branch is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposRemoveTeamAccessRestrictions', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#reposGetUsersWithAccessToProtectedBranch - errors', () => {
      it('should have a reposGetUsersWithAccessToProtectedBranch function', (done) => {
        try {
          assert.equal(true, typeof a.reposGetUsersWithAccessToProtectedBranch === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.reposGetUsersWithAccessToProtectedBranch(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposGetUsersWithAccessToProtectedBranch', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.reposGetUsersWithAccessToProtectedBranch('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposGetUsersWithAccessToProtectedBranch', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing branch', (done) => {
        try {
          a.reposGetUsersWithAccessToProtectedBranch('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'branch is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposGetUsersWithAccessToProtectedBranch', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#reposAddUserAccessRestrictions - errors', () => {
      it('should have a reposAddUserAccessRestrictions function', (done) => {
        try {
          assert.equal(true, typeof a.reposAddUserAccessRestrictions === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.reposAddUserAccessRestrictions(null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposAddUserAccessRestrictions', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.reposAddUserAccessRestrictions('fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposAddUserAccessRestrictions', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing branch', (done) => {
        try {
          a.reposAddUserAccessRestrictions('fakeparam', 'fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'branch is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposAddUserAccessRestrictions', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#reposSetUserAccessRestrictions - errors', () => {
      it('should have a reposSetUserAccessRestrictions function', (done) => {
        try {
          assert.equal(true, typeof a.reposSetUserAccessRestrictions === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.reposSetUserAccessRestrictions(null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposSetUserAccessRestrictions', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.reposSetUserAccessRestrictions('fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposSetUserAccessRestrictions', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing branch', (done) => {
        try {
          a.reposSetUserAccessRestrictions('fakeparam', 'fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'branch is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposSetUserAccessRestrictions', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#reposRemoveUserAccessRestrictions - errors', () => {
      it('should have a reposRemoveUserAccessRestrictions function', (done) => {
        try {
          assert.equal(true, typeof a.reposRemoveUserAccessRestrictions === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.reposRemoveUserAccessRestrictions(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposRemoveUserAccessRestrictions', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.reposRemoveUserAccessRestrictions('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposRemoveUserAccessRestrictions', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing branch', (done) => {
        try {
          a.reposRemoveUserAccessRestrictions('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'branch is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposRemoveUserAccessRestrictions', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#reposRenameBranch - errors', () => {
      it('should have a reposRenameBranch function', (done) => {
        try {
          assert.equal(true, typeof a.reposRenameBranch === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.reposRenameBranch(null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposRenameBranch', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.reposRenameBranch('fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposRenameBranch', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing branch', (done) => {
        try {
          a.reposRenameBranch('fakeparam', 'fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'branch is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposRenameBranch', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#reposCodeownersErrors - errors', () => {
      it('should have a reposCodeownersErrors function', (done) => {
        try {
          assert.equal(true, typeof a.reposCodeownersErrors === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.reposCodeownersErrors(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposCodeownersErrors', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.reposCodeownersErrors('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposCodeownersErrors', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoCollaboratorsQuery - errors', () => {
      it('should have a getReposOwnerRepoCollaboratorsQuery function', (done) => {
        try {
          assert.equal(true, typeof a.getReposOwnerRepoCollaboratorsQuery === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.getReposOwnerRepoCollaboratorsQuery(null, null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoCollaboratorsQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.getReposOwnerRepoCollaboratorsQuery('fakeparam', null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoCollaboratorsQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#reposCheckCollaborator - errors', () => {
      it('should have a reposCheckCollaborator function', (done) => {
        try {
          assert.equal(true, typeof a.reposCheckCollaborator === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.reposCheckCollaborator(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposCheckCollaborator', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.reposCheckCollaborator('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposCheckCollaborator', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing username', (done) => {
        try {
          a.reposCheckCollaborator('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'username is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposCheckCollaborator', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#reposAddCollaborator - errors', () => {
      it('should have a reposAddCollaborator function', (done) => {
        try {
          assert.equal(true, typeof a.reposAddCollaborator === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.reposAddCollaborator(null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposAddCollaborator', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.reposAddCollaborator('fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposAddCollaborator', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing username', (done) => {
        try {
          a.reposAddCollaborator('fakeparam', 'fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'username is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposAddCollaborator', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#reposRemoveCollaborator - errors', () => {
      it('should have a reposRemoveCollaborator function', (done) => {
        try {
          assert.equal(true, typeof a.reposRemoveCollaborator === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.reposRemoveCollaborator(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposRemoveCollaborator', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.reposRemoveCollaborator('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposRemoveCollaborator', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing username', (done) => {
        try {
          a.reposRemoveCollaborator('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'username is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposRemoveCollaborator', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#reposGetCollaboratorPermissionLevel - errors', () => {
      it('should have a reposGetCollaboratorPermissionLevel function', (done) => {
        try {
          assert.equal(true, typeof a.reposGetCollaboratorPermissionLevel === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.reposGetCollaboratorPermissionLevel(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposGetCollaboratorPermissionLevel', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.reposGetCollaboratorPermissionLevel('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposGetCollaboratorPermissionLevel', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing username', (done) => {
        try {
          a.reposGetCollaboratorPermissionLevel('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'username is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposGetCollaboratorPermissionLevel', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoCommentsQuery - errors', () => {
      it('should have a getReposOwnerRepoCommentsQuery function', (done) => {
        try {
          assert.equal(true, typeof a.getReposOwnerRepoCommentsQuery === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.getReposOwnerRepoCommentsQuery(null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoCommentsQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.getReposOwnerRepoCommentsQuery('fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoCommentsQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoCommitsQuery - errors', () => {
      it('should have a getReposOwnerRepoCommitsQuery function', (done) => {
        try {
          assert.equal(true, typeof a.getReposOwnerRepoCommitsQuery === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.getReposOwnerRepoCommitsQuery(null, null, null, null, null, null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoCommitsQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.getReposOwnerRepoCommitsQuery('fakeparam', null, null, null, null, null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoCommitsQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#reposListBranchesForHeadCommit - errors', () => {
      it('should have a reposListBranchesForHeadCommit function', (done) => {
        try {
          assert.equal(true, typeof a.reposListBranchesForHeadCommit === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.reposListBranchesForHeadCommit(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposListBranchesForHeadCommit', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.reposListBranchesForHeadCommit('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposListBranchesForHeadCommit', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing commitSha', (done) => {
        try {
          a.reposListBranchesForHeadCommit('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'commitSha is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposListBranchesForHeadCommit', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoCommitsShaCodeCommentsQuery - errors', () => {
      it('should have a getReposOwnerRepoCommitsShaCodeCommentsQuery function', (done) => {
        try {
          assert.equal(true, typeof a.getReposOwnerRepoCommitsShaCodeCommentsQuery === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.getReposOwnerRepoCommitsShaCodeCommentsQuery(null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoCommitsShaCodeCommentsQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.getReposOwnerRepoCommitsShaCodeCommentsQuery('fakeparam', null, null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoCommitsShaCodeCommentsQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing shaCode', (done) => {
        try {
          a.getReposOwnerRepoCommitsShaCodeCommentsQuery('fakeparam', 'fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'shaCode is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoCommitsShaCodeCommentsQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#reposListPullRequestsAssociatedWithCommit - errors', () => {
      it('should have a reposListPullRequestsAssociatedWithCommit function', (done) => {
        try {
          assert.equal(true, typeof a.reposListPullRequestsAssociatedWithCommit === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.reposListPullRequestsAssociatedWithCommit(null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposListPullRequestsAssociatedWithCommit', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.reposListPullRequestsAssociatedWithCommit('fakeparam', null, null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposListPullRequestsAssociatedWithCommit', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing shaCode', (done) => {
        try {
          a.reposListPullRequestsAssociatedWithCommit('fakeparam', 'fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'shaCode is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposListPullRequestsAssociatedWithCommit', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#reposGetCommit - errors', () => {
      it('should have a reposGetCommit function', (done) => {
        try {
          assert.equal(true, typeof a.reposGetCommit === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.reposGetCommit(null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposGetCommit', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.reposGetCommit('fakeparam', null, null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposGetCommit', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing ref', (done) => {
        try {
          a.reposGetCommit('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'ref is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposGetCommit', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoCommitsRefStatusQuery - errors', () => {
      it('should have a getReposOwnerRepoCommitsRefStatusQuery function', (done) => {
        try {
          assert.equal(true, typeof a.getReposOwnerRepoCommitsRefStatusQuery === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.getReposOwnerRepoCommitsRefStatusQuery(null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoCommitsRefStatusQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.getReposOwnerRepoCommitsRefStatusQuery('fakeparam', null, null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoCommitsRefStatusQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing ref', (done) => {
        try {
          a.getReposOwnerRepoCommitsRefStatusQuery('fakeparam', 'fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'ref is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoCommitsRefStatusQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#reposListCommitStatusesForRef - errors', () => {
      it('should have a reposListCommitStatusesForRef function', (done) => {
        try {
          assert.equal(true, typeof a.reposListCommitStatusesForRef === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.reposListCommitStatusesForRef(null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposListCommitStatusesForRef', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.reposListCommitStatusesForRef('fakeparam', null, null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposListCommitStatusesForRef', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing ref', (done) => {
        try {
          a.reposListCommitStatusesForRef('fakeparam', 'fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'ref is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposListCommitStatusesForRef', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#reposGetCommunityProfileMetrics - errors', () => {
      it('should have a reposGetCommunityProfileMetrics function', (done) => {
        try {
          assert.equal(true, typeof a.reposGetCommunityProfileMetrics === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.reposGetCommunityProfileMetrics(null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposGetCommunityProfileMetrics', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.reposGetCommunityProfileMetrics('fakeparam', null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposGetCommunityProfileMetrics', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoCompareBaseIdHeadIdQuery - errors', () => {
      it('should have a getReposOwnerRepoCompareBaseIdHeadIdQuery function', (done) => {
        try {
          assert.equal(true, typeof a.getReposOwnerRepoCompareBaseIdHeadIdQuery === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.getReposOwnerRepoCompareBaseIdHeadIdQuery(null, null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoCompareBaseIdHeadIdQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.getReposOwnerRepoCompareBaseIdHeadIdQuery('fakeparam', null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoCompareBaseIdHeadIdQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing basehead', (done) => {
        try {
          a.getReposOwnerRepoCompareBaseIdHeadIdQuery('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'baseId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoCompareBaseIdHeadIdQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#reposGetContent - errors', () => {
      it('should have a reposGetContent function', (done) => {
        try {
          assert.equal(true, typeof a.reposGetContent === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.reposGetContent(null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposGetContent', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.reposGetContent('fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposGetContent', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing pathParam', (done) => {
        try {
          a.reposGetContent('fakeparam', 'fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'pathParam is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposGetContent', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#reposCreateOrUpdateFileContents - errors', () => {
      it('should have a reposCreateOrUpdateFileContents function', (done) => {
        try {
          assert.equal(true, typeof a.reposCreateOrUpdateFileContents === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.reposCreateOrUpdateFileContents(null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposCreateOrUpdateFileContents', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.reposCreateOrUpdateFileContents('fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposCreateOrUpdateFileContents', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing pathParam', (done) => {
        try {
          a.reposCreateOrUpdateFileContents('fakeparam', 'fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'pathParam is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposCreateOrUpdateFileContents', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#reposDeleteFile - errors', () => {
      it('should have a reposDeleteFile function', (done) => {
        try {
          assert.equal(true, typeof a.reposDeleteFile === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.reposDeleteFile(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposDeleteFile', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.reposDeleteFile('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposDeleteFile', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing pathParam', (done) => {
        try {
          a.reposDeleteFile('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'pathParam is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposDeleteFile', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoContributorsQuery - errors', () => {
      it('should have a getReposOwnerRepoContributorsQuery function', (done) => {
        try {
          assert.equal(true, typeof a.getReposOwnerRepoContributorsQuery === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.getReposOwnerRepoContributorsQuery(null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoContributorsQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.getReposOwnerRepoContributorsQuery('fakeparam', null, null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoContributorsQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoDeploymentsQuery - errors', () => {
      it('should have a getReposOwnerRepoDeploymentsQuery function', (done) => {
        try {
          assert.equal(true, typeof a.getReposOwnerRepoDeploymentsQuery === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.getReposOwnerRepoDeploymentsQuery(null, null, null, null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoDeploymentsQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.getReposOwnerRepoDeploymentsQuery('fakeparam', null, null, null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoDeploymentsQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#reposGetDeployment - errors', () => {
      it('should have a reposGetDeployment function', (done) => {
        try {
          assert.equal(true, typeof a.reposGetDeployment === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.reposGetDeployment(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposGetDeployment', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.reposGetDeployment('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposGetDeployment', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing deploymentId', (done) => {
        try {
          a.reposGetDeployment('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'deploymentId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposGetDeployment', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#reposDeleteDeployment - errors', () => {
      it('should have a reposDeleteDeployment function', (done) => {
        try {
          assert.equal(true, typeof a.reposDeleteDeployment === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.reposDeleteDeployment(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposDeleteDeployment', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.reposDeleteDeployment('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposDeleteDeployment', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing deploymentId', (done) => {
        try {
          a.reposDeleteDeployment('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'deploymentId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposDeleteDeployment', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoDeploymentsIdStatusesQuery - errors', () => {
      it('should have a getReposOwnerRepoDeploymentsIdStatusesQuery function', (done) => {
        try {
          assert.equal(true, typeof a.getReposOwnerRepoDeploymentsIdStatusesQuery === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.getReposOwnerRepoDeploymentsIdStatusesQuery(null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoDeploymentsIdStatusesQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.getReposOwnerRepoDeploymentsIdStatusesQuery('fakeparam', null, null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoDeploymentsIdStatusesQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing deploymentId', (done) => {
        try {
          a.getReposOwnerRepoDeploymentsIdStatusesQuery('fakeparam', 'fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'deploymentId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoDeploymentsIdStatusesQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#reposGetDeploymentStatus - errors', () => {
      it('should have a reposGetDeploymentStatus function', (done) => {
        try {
          assert.equal(true, typeof a.reposGetDeploymentStatus === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.reposGetDeploymentStatus(null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposGetDeploymentStatus', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.reposGetDeploymentStatus('fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposGetDeploymentStatus', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing deploymentId', (done) => {
        try {
          a.reposGetDeploymentStatus('fakeparam', 'fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'deploymentId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposGetDeploymentStatus', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing statusId', (done) => {
        try {
          a.reposGetDeploymentStatus('fakeparam', 'fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'statusId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposGetDeploymentStatus', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#reposCreateDispatchEvent - errors', () => {
      it('should have a reposCreateDispatchEvent function', (done) => {
        try {
          assert.equal(true, typeof a.reposCreateDispatchEvent === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.reposCreateDispatchEvent(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposCreateDispatchEvent', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.reposCreateDispatchEvent('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposCreateDispatchEvent', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#reposGetAllEnvironments - errors', () => {
      it('should have a reposGetAllEnvironments function', (done) => {
        try {
          assert.equal(true, typeof a.reposGetAllEnvironments === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.reposGetAllEnvironments(null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposGetAllEnvironments', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.reposGetAllEnvironments('fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposGetAllEnvironments', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#reposGetEnvironment - errors', () => {
      it('should have a reposGetEnvironment function', (done) => {
        try {
          assert.equal(true, typeof a.reposGetEnvironment === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.reposGetEnvironment(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposGetEnvironment', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.reposGetEnvironment('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposGetEnvironment', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing environmentName', (done) => {
        try {
          a.reposGetEnvironment('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'environmentName is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposGetEnvironment', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#reposCreateOrUpdateEnvironment - errors', () => {
      it('should have a reposCreateOrUpdateEnvironment function', (done) => {
        try {
          assert.equal(true, typeof a.reposCreateOrUpdateEnvironment === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.reposCreateOrUpdateEnvironment(null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposCreateOrUpdateEnvironment', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.reposCreateOrUpdateEnvironment('fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposCreateOrUpdateEnvironment', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing environmentName', (done) => {
        try {
          a.reposCreateOrUpdateEnvironment('fakeparam', 'fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'environmentName is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposCreateOrUpdateEnvironment', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#reposDeleteAnEnvironment - errors', () => {
      it('should have a reposDeleteAnEnvironment function', (done) => {
        try {
          assert.equal(true, typeof a.reposDeleteAnEnvironment === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.reposDeleteAnEnvironment(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposDeleteAnEnvironment', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.reposDeleteAnEnvironment('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposDeleteAnEnvironment', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing environmentName', (done) => {
        try {
          a.reposDeleteAnEnvironment('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'environmentName is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposDeleteAnEnvironment', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#reposListDeploymentBranchPolicies - errors', () => {
      it('should have a reposListDeploymentBranchPolicies function', (done) => {
        try {
          assert.equal(true, typeof a.reposListDeploymentBranchPolicies === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.reposListDeploymentBranchPolicies(null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposListDeploymentBranchPolicies', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.reposListDeploymentBranchPolicies('fakeparam', null, null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposListDeploymentBranchPolicies', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing environmentName', (done) => {
        try {
          a.reposListDeploymentBranchPolicies('fakeparam', 'fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'environmentName is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposListDeploymentBranchPolicies', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#reposCreateDeploymentBranchPolicy - errors', () => {
      it('should have a reposCreateDeploymentBranchPolicy function', (done) => {
        try {
          assert.equal(true, typeof a.reposCreateDeploymentBranchPolicy === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.reposCreateDeploymentBranchPolicy(null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposCreateDeploymentBranchPolicy', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.reposCreateDeploymentBranchPolicy('fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposCreateDeploymentBranchPolicy', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing environmentName', (done) => {
        try {
          a.reposCreateDeploymentBranchPolicy('fakeparam', 'fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'environmentName is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposCreateDeploymentBranchPolicy', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#reposGetDeploymentBranchPolicy - errors', () => {
      it('should have a reposGetDeploymentBranchPolicy function', (done) => {
        try {
          assert.equal(true, typeof a.reposGetDeploymentBranchPolicy === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.reposGetDeploymentBranchPolicy(null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposGetDeploymentBranchPolicy', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.reposGetDeploymentBranchPolicy('fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposGetDeploymentBranchPolicy', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing environmentName', (done) => {
        try {
          a.reposGetDeploymentBranchPolicy('fakeparam', 'fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'environmentName is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposGetDeploymentBranchPolicy', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing branchPolicyId', (done) => {
        try {
          a.reposGetDeploymentBranchPolicy('fakeparam', 'fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'branchPolicyId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposGetDeploymentBranchPolicy', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#reposUpdateDeploymentBranchPolicy - errors', () => {
      it('should have a reposUpdateDeploymentBranchPolicy function', (done) => {
        try {
          assert.equal(true, typeof a.reposUpdateDeploymentBranchPolicy === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.reposUpdateDeploymentBranchPolicy(null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposUpdateDeploymentBranchPolicy', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.reposUpdateDeploymentBranchPolicy('fakeparam', null, null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposUpdateDeploymentBranchPolicy', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing environmentName', (done) => {
        try {
          a.reposUpdateDeploymentBranchPolicy('fakeparam', 'fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'environmentName is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposUpdateDeploymentBranchPolicy', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing branchPolicyId', (done) => {
        try {
          a.reposUpdateDeploymentBranchPolicy('fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'branchPolicyId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposUpdateDeploymentBranchPolicy', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#reposDeleteDeploymentBranchPolicy - errors', () => {
      it('should have a reposDeleteDeploymentBranchPolicy function', (done) => {
        try {
          assert.equal(true, typeof a.reposDeleteDeploymentBranchPolicy === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.reposDeleteDeploymentBranchPolicy(null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposDeleteDeploymentBranchPolicy', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.reposDeleteDeploymentBranchPolicy('fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposDeleteDeploymentBranchPolicy', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing environmentName', (done) => {
        try {
          a.reposDeleteDeploymentBranchPolicy('fakeparam', 'fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'environmentName is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposDeleteDeploymentBranchPolicy', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing branchPolicyId', (done) => {
        try {
          a.reposDeleteDeploymentBranchPolicy('fakeparam', 'fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'branchPolicyId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposDeleteDeploymentBranchPolicy', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#reposGetAllDeploymentProtectionRules - errors', () => {
      it('should have a reposGetAllDeploymentProtectionRules function', (done) => {
        try {
          assert.equal(true, typeof a.reposGetAllDeploymentProtectionRules === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing environmentName', (done) => {
        try {
          a.reposGetAllDeploymentProtectionRules(null, null, null, (data, error) => {
            try {
              const displayE = 'environmentName is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposGetAllDeploymentProtectionRules', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.reposGetAllDeploymentProtectionRules('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposGetAllDeploymentProtectionRules', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.reposGetAllDeploymentProtectionRules('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposGetAllDeploymentProtectionRules', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#reposCreateDeploymentProtectionRule - errors', () => {
      it('should have a reposCreateDeploymentProtectionRule function', (done) => {
        try {
          assert.equal(true, typeof a.reposCreateDeploymentProtectionRule === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing environmentName', (done) => {
        try {
          a.reposCreateDeploymentProtectionRule(null, null, null, null, (data, error) => {
            try {
              const displayE = 'environmentName is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposCreateDeploymentProtectionRule', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.reposCreateDeploymentProtectionRule('fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposCreateDeploymentProtectionRule', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.reposCreateDeploymentProtectionRule('fakeparam', 'fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposCreateDeploymentProtectionRule', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#reposListCustomDeploymentRuleIntegrations - errors', () => {
      it('should have a reposListCustomDeploymentRuleIntegrations function', (done) => {
        try {
          assert.equal(true, typeof a.reposListCustomDeploymentRuleIntegrations === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing environmentName', (done) => {
        try {
          a.reposListCustomDeploymentRuleIntegrations(null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'environmentName is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposListCustomDeploymentRuleIntegrations', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.reposListCustomDeploymentRuleIntegrations('fakeparam', null, null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposListCustomDeploymentRuleIntegrations', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.reposListCustomDeploymentRuleIntegrations('fakeparam', 'fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposListCustomDeploymentRuleIntegrations', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#reposGetCustomDeploymentProtectionRule - errors', () => {
      it('should have a reposGetCustomDeploymentProtectionRule function', (done) => {
        try {
          assert.equal(true, typeof a.reposGetCustomDeploymentProtectionRule === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.reposGetCustomDeploymentProtectionRule(null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposGetCustomDeploymentProtectionRule', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.reposGetCustomDeploymentProtectionRule('fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposGetCustomDeploymentProtectionRule', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing environmentName', (done) => {
        try {
          a.reposGetCustomDeploymentProtectionRule('fakeparam', 'fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'environmentName is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposGetCustomDeploymentProtectionRule', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing protectionRuleId', (done) => {
        try {
          a.reposGetCustomDeploymentProtectionRule('fakeparam', 'fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'protectionRuleId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposGetCustomDeploymentProtectionRule', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#reposDisableDeploymentProtectionRule - errors', () => {
      it('should have a reposDisableDeploymentProtectionRule function', (done) => {
        try {
          assert.equal(true, typeof a.reposDisableDeploymentProtectionRule === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing environmentName', (done) => {
        try {
          a.reposDisableDeploymentProtectionRule(null, null, null, null, (data, error) => {
            try {
              const displayE = 'environmentName is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposDisableDeploymentProtectionRule', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.reposDisableDeploymentProtectionRule('fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposDisableDeploymentProtectionRule', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.reposDisableDeploymentProtectionRule('fakeparam', 'fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposDisableDeploymentProtectionRule', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing protectionRuleId', (done) => {
        try {
          a.reposDisableDeploymentProtectionRule('fakeparam', 'fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'protectionRuleId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposDisableDeploymentProtectionRule', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoForksQuery - errors', () => {
      it('should have a getReposOwnerRepoForksQuery function', (done) => {
        try {
          assert.equal(true, typeof a.getReposOwnerRepoForksQuery === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.getReposOwnerRepoForksQuery(null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoForksQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.getReposOwnerRepoForksQuery('fakeparam', null, null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoForksQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoHooksQuery - errors', () => {
      it('should have a getReposOwnerRepoHooksQuery function', (done) => {
        try {
          assert.equal(true, typeof a.getReposOwnerRepoHooksQuery === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.getReposOwnerRepoHooksQuery(null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoHooksQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.getReposOwnerRepoHooksQuery('fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoHooksQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#reposGetWebhookConfigForRepo - errors', () => {
      it('should have a reposGetWebhookConfigForRepo function', (done) => {
        try {
          assert.equal(true, typeof a.reposGetWebhookConfigForRepo === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.reposGetWebhookConfigForRepo(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposGetWebhookConfigForRepo', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.reposGetWebhookConfigForRepo('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposGetWebhookConfigForRepo', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing hookId', (done) => {
        try {
          a.reposGetWebhookConfigForRepo('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'hookId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposGetWebhookConfigForRepo', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#reposUpdateWebhookConfigForRepo - errors', () => {
      it('should have a reposUpdateWebhookConfigForRepo function', (done) => {
        try {
          assert.equal(true, typeof a.reposUpdateWebhookConfigForRepo === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.reposUpdateWebhookConfigForRepo(null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposUpdateWebhookConfigForRepo', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.reposUpdateWebhookConfigForRepo('fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposUpdateWebhookConfigForRepo', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing hookId', (done) => {
        try {
          a.reposUpdateWebhookConfigForRepo('fakeparam', 'fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'hookId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposUpdateWebhookConfigForRepo', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#reposListWebhookDeliveries - errors', () => {
      it('should have a reposListWebhookDeliveries function', (done) => {
        try {
          assert.equal(true, typeof a.reposListWebhookDeliveries === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.reposListWebhookDeliveries(null, null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposListWebhookDeliveries', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.reposListWebhookDeliveries('fakeparam', null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposListWebhookDeliveries', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing hookId', (done) => {
        try {
          a.reposListWebhookDeliveries('fakeparam', 'fakeparam', null, null, null, null, (data, error) => {
            try {
              const displayE = 'hookId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposListWebhookDeliveries', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#reposGetWebhookDelivery - errors', () => {
      it('should have a reposGetWebhookDelivery function', (done) => {
        try {
          assert.equal(true, typeof a.reposGetWebhookDelivery === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.reposGetWebhookDelivery(null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposGetWebhookDelivery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.reposGetWebhookDelivery('fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposGetWebhookDelivery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing hookId', (done) => {
        try {
          a.reposGetWebhookDelivery('fakeparam', 'fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'hookId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposGetWebhookDelivery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing deliveryId', (done) => {
        try {
          a.reposGetWebhookDelivery('fakeparam', 'fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'deliveryId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposGetWebhookDelivery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#reposRedeliverWebhookDelivery - errors', () => {
      it('should have a reposRedeliverWebhookDelivery function', (done) => {
        try {
          assert.equal(true, typeof a.reposRedeliverWebhookDelivery === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.reposRedeliverWebhookDelivery(null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposRedeliverWebhookDelivery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.reposRedeliverWebhookDelivery('fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposRedeliverWebhookDelivery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing hookId', (done) => {
        try {
          a.reposRedeliverWebhookDelivery('fakeparam', 'fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'hookId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposRedeliverWebhookDelivery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing deliveryId', (done) => {
        try {
          a.reposRedeliverWebhookDelivery('fakeparam', 'fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'deliveryId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposRedeliverWebhookDelivery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#reposPingWebhook - errors', () => {
      it('should have a reposPingWebhook function', (done) => {
        try {
          assert.equal(true, typeof a.reposPingWebhook === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.reposPingWebhook(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposPingWebhook', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.reposPingWebhook('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposPingWebhook', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing hookId', (done) => {
        try {
          a.reposPingWebhook('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'hookId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposPingWebhook', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#reposListInvitations - errors', () => {
      it('should have a reposListInvitations function', (done) => {
        try {
          assert.equal(true, typeof a.reposListInvitations === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.reposListInvitations(null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposListInvitations', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.reposListInvitations('fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposListInvitations', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#reposUpdateInvitation - errors', () => {
      it('should have a reposUpdateInvitation function', (done) => {
        try {
          assert.equal(true, typeof a.reposUpdateInvitation === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.reposUpdateInvitation(null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposUpdateInvitation', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.reposUpdateInvitation('fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposUpdateInvitation', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing invitationId', (done) => {
        try {
          a.reposUpdateInvitation('fakeparam', 'fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'invitationId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposUpdateInvitation', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#reposDeleteInvitation - errors', () => {
      it('should have a reposDeleteInvitation function', (done) => {
        try {
          assert.equal(true, typeof a.reposDeleteInvitation === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.reposDeleteInvitation(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposDeleteInvitation', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.reposDeleteInvitation('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposDeleteInvitation', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing invitationId', (done) => {
        try {
          a.reposDeleteInvitation('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'invitationId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposDeleteInvitation', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoKeysQuery - errors', () => {
      it('should have a getReposOwnerRepoKeysQuery function', (done) => {
        try {
          assert.equal(true, typeof a.getReposOwnerRepoKeysQuery === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.getReposOwnerRepoKeysQuery(null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoKeysQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.getReposOwnerRepoKeysQuery('fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoKeysQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#reposMergeUpstream - errors', () => {
      it('should have a reposMergeUpstream function', (done) => {
        try {
          assert.equal(true, typeof a.reposMergeUpstream === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.reposMergeUpstream(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposMergeUpstream', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.reposMergeUpstream('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposMergeUpstream', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#reposGetPages - errors', () => {
      it('should have a reposGetPages function', (done) => {
        try {
          assert.equal(true, typeof a.reposGetPages === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.reposGetPages(null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposGetPages', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.reposGetPages('fakeparam', null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposGetPages', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#reposCreatePagesSite - errors', () => {
      it('should have a reposCreatePagesSite function', (done) => {
        try {
          assert.equal(true, typeof a.reposCreatePagesSite === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.reposCreatePagesSite(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposCreatePagesSite', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.reposCreatePagesSite('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposCreatePagesSite', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#reposUpdateInformationAboutPagesSite - errors', () => {
      it('should have a reposUpdateInformationAboutPagesSite function', (done) => {
        try {
          assert.equal(true, typeof a.reposUpdateInformationAboutPagesSite === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.reposUpdateInformationAboutPagesSite(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposUpdateInformationAboutPagesSite', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.reposUpdateInformationAboutPagesSite('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposUpdateInformationAboutPagesSite', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#reposDeletePagesSite - errors', () => {
      it('should have a reposDeletePagesSite function', (done) => {
        try {
          assert.equal(true, typeof a.reposDeletePagesSite === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.reposDeletePagesSite(null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposDeletePagesSite', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.reposDeletePagesSite('fakeparam', null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposDeletePagesSite', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#reposListPagesBuilds - errors', () => {
      it('should have a reposListPagesBuilds function', (done) => {
        try {
          assert.equal(true, typeof a.reposListPagesBuilds === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.reposListPagesBuilds(null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposListPagesBuilds', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.reposListPagesBuilds('fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposListPagesBuilds', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#reposRequestPagesBuild - errors', () => {
      it('should have a reposRequestPagesBuild function', (done) => {
        try {
          assert.equal(true, typeof a.reposRequestPagesBuild === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.reposRequestPagesBuild(null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposRequestPagesBuild', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.reposRequestPagesBuild('fakeparam', null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposRequestPagesBuild', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#reposGetLatestPagesBuild - errors', () => {
      it('should have a reposGetLatestPagesBuild function', (done) => {
        try {
          assert.equal(true, typeof a.reposGetLatestPagesBuild === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.reposGetLatestPagesBuild(null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposGetLatestPagesBuild', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.reposGetLatestPagesBuild('fakeparam', null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposGetLatestPagesBuild', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#reposGetPagesBuild - errors', () => {
      it('should have a reposGetPagesBuild function', (done) => {
        try {
          assert.equal(true, typeof a.reposGetPagesBuild === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.reposGetPagesBuild(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposGetPagesBuild', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.reposGetPagesBuild('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposGetPagesBuild', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing buildId', (done) => {
        try {
          a.reposGetPagesBuild('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'buildId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposGetPagesBuild', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#reposCreatePagesDeployment - errors', () => {
      it('should have a reposCreatePagesDeployment function', (done) => {
        try {
          assert.equal(true, typeof a.reposCreatePagesDeployment === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.reposCreatePagesDeployment(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposCreatePagesDeployment', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.reposCreatePagesDeployment('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposCreatePagesDeployment', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#reposGetPagesDeployment - errors', () => {
      it('should have a reposGetPagesDeployment function', (done) => {
        try {
          assert.equal(true, typeof a.reposGetPagesDeployment === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.reposGetPagesDeployment(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposGetPagesDeployment', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.reposGetPagesDeployment('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposGetPagesDeployment', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing pagesDeploymentId', (done) => {
        try {
          a.reposGetPagesDeployment('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'pagesDeploymentId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposGetPagesDeployment', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#reposCancelPagesDeployment - errors', () => {
      it('should have a reposCancelPagesDeployment function', (done) => {
        try {
          assert.equal(true, typeof a.reposCancelPagesDeployment === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.reposCancelPagesDeployment(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposCancelPagesDeployment', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.reposCancelPagesDeployment('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposCancelPagesDeployment', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing pagesDeploymentId', (done) => {
        try {
          a.reposCancelPagesDeployment('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'pagesDeploymentId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposCancelPagesDeployment', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#reposGetPagesHealthCheck - errors', () => {
      it('should have a reposGetPagesHealthCheck function', (done) => {
        try {
          assert.equal(true, typeof a.reposGetPagesHealthCheck === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.reposGetPagesHealthCheck(null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposGetPagesHealthCheck', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.reposGetPagesHealthCheck('fakeparam', null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposGetPagesHealthCheck', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#reposCheckPrivateVulnerabilityReporting - errors', () => {
      it('should have a reposCheckPrivateVulnerabilityReporting function', (done) => {
        try {
          assert.equal(true, typeof a.reposCheckPrivateVulnerabilityReporting === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.reposCheckPrivateVulnerabilityReporting(null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposCheckPrivateVulnerabilityReporting', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.reposCheckPrivateVulnerabilityReporting('fakeparam', null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposCheckPrivateVulnerabilityReporting', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#reposEnablePrivateVulnerabilityReporting - errors', () => {
      it('should have a reposEnablePrivateVulnerabilityReporting function', (done) => {
        try {
          assert.equal(true, typeof a.reposEnablePrivateVulnerabilityReporting === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.reposEnablePrivateVulnerabilityReporting(null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposEnablePrivateVulnerabilityReporting', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.reposEnablePrivateVulnerabilityReporting('fakeparam', null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposEnablePrivateVulnerabilityReporting', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#reposDisablePrivateVulnerabilityReporting - errors', () => {
      it('should have a reposDisablePrivateVulnerabilityReporting function', (done) => {
        try {
          assert.equal(true, typeof a.reposDisablePrivateVulnerabilityReporting === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.reposDisablePrivateVulnerabilityReporting(null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposDisablePrivateVulnerabilityReporting', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.reposDisablePrivateVulnerabilityReporting('fakeparam', null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposDisablePrivateVulnerabilityReporting', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#reposGetCustomPropertiesValues - errors', () => {
      it('should have a reposGetCustomPropertiesValues function', (done) => {
        try {
          assert.equal(true, typeof a.reposGetCustomPropertiesValues === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.reposGetCustomPropertiesValues(null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposGetCustomPropertiesValues', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.reposGetCustomPropertiesValues('fakeparam', null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposGetCustomPropertiesValues', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#reposCreateOrUpdateCustomPropertiesValues - errors', () => {
      it('should have a reposCreateOrUpdateCustomPropertiesValues function', (done) => {
        try {
          assert.equal(true, typeof a.reposCreateOrUpdateCustomPropertiesValues === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.reposCreateOrUpdateCustomPropertiesValues(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposCreateOrUpdateCustomPropertiesValues', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.reposCreateOrUpdateCustomPropertiesValues('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposCreateOrUpdateCustomPropertiesValues', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#reposGetReadmeInDirectory - errors', () => {
      it('should have a reposGetReadmeInDirectory function', (done) => {
        try {
          assert.equal(true, typeof a.reposGetReadmeInDirectory === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.reposGetReadmeInDirectory(null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposGetReadmeInDirectory', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.reposGetReadmeInDirectory('fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposGetReadmeInDirectory', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing dir', (done) => {
        try {
          a.reposGetReadmeInDirectory('fakeparam', 'fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'dir is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposGetReadmeInDirectory', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoReleasesQuery - errors', () => {
      it('should have a getReposOwnerRepoReleasesQuery function', (done) => {
        try {
          assert.equal(true, typeof a.getReposOwnerRepoReleasesQuery === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.getReposOwnerRepoReleasesQuery(null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoReleasesQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.getReposOwnerRepoReleasesQuery('fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoReleasesQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#reposGenerateReleaseNotes - errors', () => {
      it('should have a reposGenerateReleaseNotes function', (done) => {
        try {
          assert.equal(true, typeof a.reposGenerateReleaseNotes === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.reposGenerateReleaseNotes(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposGenerateReleaseNotes', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.reposGenerateReleaseNotes('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposGenerateReleaseNotes', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#reposGetLatestRelease - errors', () => {
      it('should have a reposGetLatestRelease function', (done) => {
        try {
          assert.equal(true, typeof a.reposGetLatestRelease === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.reposGetLatestRelease(null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposGetLatestRelease', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.reposGetLatestRelease('fakeparam', null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposGetLatestRelease', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#reposGetReleaseByTag - errors', () => {
      it('should have a reposGetReleaseByTag function', (done) => {
        try {
          assert.equal(true, typeof a.reposGetReleaseByTag === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.reposGetReleaseByTag(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposGetReleaseByTag', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.reposGetReleaseByTag('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposGetReleaseByTag', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing tag', (done) => {
        try {
          a.reposGetReleaseByTag('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'tag is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposGetReleaseByTag', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#reposListReleaseAssetsQuery - errors', () => {
      it('should have a reposListReleaseAssetsQuery function', (done) => {
        try {
          assert.equal(true, typeof a.reposListReleaseAssetsQuery === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.reposListReleaseAssetsQuery(null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposListReleaseAssetsQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.reposListReleaseAssetsQuery('fakeparam', null, null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposListReleaseAssetsQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing releaseId', (done) => {
        try {
          a.reposListReleaseAssetsQuery('fakeparam', 'fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'releaseId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposListReleaseAssetsQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#reposUploadReleaseAsset - errors', () => {
      it('should have a reposUploadReleaseAsset function', (done) => {
        try {
          assert.equal(true, typeof a.reposUploadReleaseAsset === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.reposUploadReleaseAsset(null, null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposUploadReleaseAsset', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.reposUploadReleaseAsset('fakeparam', null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposUploadReleaseAsset', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing releaseId', (done) => {
        try {
          a.reposUploadReleaseAsset('fakeparam', 'fakeparam', null, null, null, null, (data, error) => {
            try {
              const displayE = 'releaseId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposUploadReleaseAsset', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing name', (done) => {
        try {
          a.reposUploadReleaseAsset('fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'name is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposUploadReleaseAsset', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#reposGetBranchRules - errors', () => {
      it('should have a reposGetBranchRules function', (done) => {
        try {
          assert.equal(true, typeof a.reposGetBranchRules === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.reposGetBranchRules(null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposGetBranchRules', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.reposGetBranchRules('fakeparam', null, null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposGetBranchRules', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing branch', (done) => {
        try {
          a.reposGetBranchRules('fakeparam', 'fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'branch is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposGetBranchRules', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#reposGetRepoRulesets - errors', () => {
      it('should have a reposGetRepoRulesets function', (done) => {
        try {
          assert.equal(true, typeof a.reposGetRepoRulesets === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.reposGetRepoRulesets(null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposGetRepoRulesets', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.reposGetRepoRulesets('fakeparam', null, null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposGetRepoRulesets', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#reposCreateRepoRuleset - errors', () => {
      it('should have a reposCreateRepoRuleset function', (done) => {
        try {
          assert.equal(true, typeof a.reposCreateRepoRuleset === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.reposCreateRepoRuleset(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposCreateRepoRuleset', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.reposCreateRepoRuleset('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposCreateRepoRuleset', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#reposGetRepoRuleSuites - errors', () => {
      it('should have a reposGetRepoRuleSuites function', (done) => {
        try {
          assert.equal(true, typeof a.reposGetRepoRuleSuites === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.reposGetRepoRuleSuites(null, null, null, null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposGetRepoRuleSuites', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.reposGetRepoRuleSuites('fakeparam', null, null, null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposGetRepoRuleSuites', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#reposGetRepoRuleSuite - errors', () => {
      it('should have a reposGetRepoRuleSuite function', (done) => {
        try {
          assert.equal(true, typeof a.reposGetRepoRuleSuite === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.reposGetRepoRuleSuite(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposGetRepoRuleSuite', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.reposGetRepoRuleSuite('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposGetRepoRuleSuite', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing ruleSuiteId', (done) => {
        try {
          a.reposGetRepoRuleSuite('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'ruleSuiteId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposGetRepoRuleSuite', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#reposGetRepoRuleset - errors', () => {
      it('should have a reposGetRepoRuleset function', (done) => {
        try {
          assert.equal(true, typeof a.reposGetRepoRuleset === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.reposGetRepoRuleset(null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposGetRepoRuleset', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.reposGetRepoRuleset('fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposGetRepoRuleset', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing rulesetId', (done) => {
        try {
          a.reposGetRepoRuleset('fakeparam', 'fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'rulesetId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposGetRepoRuleset', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#reposUpdateRepoRuleset - errors', () => {
      it('should have a reposUpdateRepoRuleset function', (done) => {
        try {
          assert.equal(true, typeof a.reposUpdateRepoRuleset === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.reposUpdateRepoRuleset(null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposUpdateRepoRuleset', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.reposUpdateRepoRuleset('fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposUpdateRepoRuleset', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing rulesetId', (done) => {
        try {
          a.reposUpdateRepoRuleset('fakeparam', 'fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'rulesetId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposUpdateRepoRuleset', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#reposDeleteRepoRuleset - errors', () => {
      it('should have a reposDeleteRepoRuleset function', (done) => {
        try {
          assert.equal(true, typeof a.reposDeleteRepoRuleset === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.reposDeleteRepoRuleset(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposDeleteRepoRuleset', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.reposDeleteRepoRuleset('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposDeleteRepoRuleset', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing rulesetId', (done) => {
        try {
          a.reposDeleteRepoRuleset('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'rulesetId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposDeleteRepoRuleset', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#reposCreateCommitStatus - errors', () => {
      it('should have a reposCreateCommitStatus function', (done) => {
        try {
          assert.equal(true, typeof a.reposCreateCommitStatus === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.reposCreateCommitStatus(null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposCreateCommitStatus', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.reposCreateCommitStatus('fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposCreateCommitStatus', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing sha', (done) => {
        try {
          a.reposCreateCommitStatus('fakeparam', 'fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'sha is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposCreateCommitStatus', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoTagsQuery - errors', () => {
      it('should have a getReposOwnerRepoTagsQuery function', (done) => {
        try {
          assert.equal(true, typeof a.getReposOwnerRepoTagsQuery === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.getReposOwnerRepoTagsQuery(null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoTagsQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.getReposOwnerRepoTagsQuery('fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoTagsQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#reposListTagProtection - errors', () => {
      it('should have a reposListTagProtection function', (done) => {
        try {
          assert.equal(true, typeof a.reposListTagProtection === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.reposListTagProtection(null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposListTagProtection', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.reposListTagProtection('fakeparam', null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposListTagProtection', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#reposCreateTagProtection - errors', () => {
      it('should have a reposCreateTagProtection function', (done) => {
        try {
          assert.equal(true, typeof a.reposCreateTagProtection === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.reposCreateTagProtection(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposCreateTagProtection', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.reposCreateTagProtection('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposCreateTagProtection', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#reposDeleteTagProtection - errors', () => {
      it('should have a reposDeleteTagProtection function', (done) => {
        try {
          assert.equal(true, typeof a.reposDeleteTagProtection === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.reposDeleteTagProtection(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposDeleteTagProtection', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.reposDeleteTagProtection('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposDeleteTagProtection', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing tagProtectionId', (done) => {
        try {
          a.reposDeleteTagProtection('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'tagProtectionId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposDeleteTagProtection', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#reposDownloadTarballArchive - errors', () => {
      it('should have a reposDownloadTarballArchive function', (done) => {
        try {
          assert.equal(true, typeof a.reposDownloadTarballArchive === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.reposDownloadTarballArchive(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposDownloadTarballArchive', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.reposDownloadTarballArchive('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposDownloadTarballArchive', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing ref', (done) => {
        try {
          a.reposDownloadTarballArchive('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'ref is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposDownloadTarballArchive', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoTeamsQuery - errors', () => {
      it('should have a getReposOwnerRepoTeamsQuery function', (done) => {
        try {
          assert.equal(true, typeof a.getReposOwnerRepoTeamsQuery === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.getReposOwnerRepoTeamsQuery(null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoTeamsQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.getReposOwnerRepoTeamsQuery('fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoTeamsQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#reposGetAllTopics - errors', () => {
      it('should have a reposGetAllTopics function', (done) => {
        try {
          assert.equal(true, typeof a.reposGetAllTopics === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.reposGetAllTopics(null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposGetAllTopics', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.reposGetAllTopics('fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposGetAllTopics', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#reposReplaceAllTopics - errors', () => {
      it('should have a reposReplaceAllTopics function', (done) => {
        try {
          assert.equal(true, typeof a.reposReplaceAllTopics === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.reposReplaceAllTopics(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposReplaceAllTopics', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.reposReplaceAllTopics('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposReplaceAllTopics', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#reposGetClones - errors', () => {
      it('should have a reposGetClones function', (done) => {
        try {
          assert.equal(true, typeof a.reposGetClones === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.reposGetClones(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposGetClones', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.reposGetClones('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposGetClones', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#reposGetTopPaths - errors', () => {
      it('should have a reposGetTopPaths function', (done) => {
        try {
          assert.equal(true, typeof a.reposGetTopPaths === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.reposGetTopPaths(null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposGetTopPaths', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.reposGetTopPaths('fakeparam', null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposGetTopPaths', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#reposGetTopReferrers - errors', () => {
      it('should have a reposGetTopReferrers function', (done) => {
        try {
          assert.equal(true, typeof a.reposGetTopReferrers === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.reposGetTopReferrers(null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposGetTopReferrers', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.reposGetTopReferrers('fakeparam', null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposGetTopReferrers', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#reposGetViews - errors', () => {
      it('should have a reposGetViews function', (done) => {
        try {
          assert.equal(true, typeof a.reposGetViews === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.reposGetViews(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposGetViews', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.reposGetViews('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposGetViews', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#reposTransfer - errors', () => {
      it('should have a reposTransfer function', (done) => {
        try {
          assert.equal(true, typeof a.reposTransfer === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.reposTransfer(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposTransfer', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.reposTransfer('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposTransfer', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#reposCheckVulnerabilityAlerts - errors', () => {
      it('should have a reposCheckVulnerabilityAlerts function', (done) => {
        try {
          assert.equal(true, typeof a.reposCheckVulnerabilityAlerts === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.reposCheckVulnerabilityAlerts(null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposCheckVulnerabilityAlerts', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.reposCheckVulnerabilityAlerts('fakeparam', null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposCheckVulnerabilityAlerts', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#reposEnableVulnerabilityAlerts - errors', () => {
      it('should have a reposEnableVulnerabilityAlerts function', (done) => {
        try {
          assert.equal(true, typeof a.reposEnableVulnerabilityAlerts === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.reposEnableVulnerabilityAlerts(null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposEnableVulnerabilityAlerts', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.reposEnableVulnerabilityAlerts('fakeparam', null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposEnableVulnerabilityAlerts', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#reposDisableVulnerabilityAlerts - errors', () => {
      it('should have a reposDisableVulnerabilityAlerts function', (done) => {
        try {
          assert.equal(true, typeof a.reposDisableVulnerabilityAlerts === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.reposDisableVulnerabilityAlerts(null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposDisableVulnerabilityAlerts', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.reposDisableVulnerabilityAlerts('fakeparam', null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposDisableVulnerabilityAlerts', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#reposDownloadZipballArchive - errors', () => {
      it('should have a reposDownloadZipballArchive function', (done) => {
        try {
          assert.equal(true, typeof a.reposDownloadZipballArchive === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.reposDownloadZipballArchive(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposDownloadZipballArchive', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.reposDownloadZipballArchive('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposDownloadZipballArchive', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing ref', (done) => {
        try {
          a.reposDownloadZipballArchive('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'ref is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposDownloadZipballArchive', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#reposCreateUsingTemplate - errors', () => {
      it('should have a reposCreateUsingTemplate function', (done) => {
        try {
          assert.equal(true, typeof a.reposCreateUsingTemplate === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing templateOwner', (done) => {
        try {
          a.reposCreateUsingTemplate(null, null, null, (data, error) => {
            try {
              const displayE = 'templateOwner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposCreateUsingTemplate', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing templateRepo', (done) => {
        try {
          a.reposCreateUsingTemplate('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'templateRepo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposCreateUsingTemplate', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#reposListInvitationsForAuthenticatedUser - errors', () => {
      it('should have a reposListInvitationsForAuthenticatedUser function', (done) => {
        try {
          assert.equal(true, typeof a.reposListInvitationsForAuthenticatedUser === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#reposAcceptInvitationForAuthenticatedUser - errors', () => {
      it('should have a reposAcceptInvitationForAuthenticatedUser function', (done) => {
        try {
          assert.equal(true, typeof a.reposAcceptInvitationForAuthenticatedUser === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing invitationId', (done) => {
        try {
          a.reposAcceptInvitationForAuthenticatedUser(null, (data, error) => {
            try {
              const displayE = 'invitationId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposAcceptInvitationForAuthenticatedUser', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#reposDeclineInvitationForAuthenticatedUser - errors', () => {
      it('should have a reposDeclineInvitationForAuthenticatedUser function', (done) => {
        try {
          assert.equal(true, typeof a.reposDeclineInvitationForAuthenticatedUser === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing invitationId', (done) => {
        try {
          a.reposDeclineInvitationForAuthenticatedUser(null, (data, error) => {
            try {
              const displayE = 'invitationId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reposDeclineInvitationForAuthenticatedUser', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getUserStarredQuery - errors', () => {
      it('should have a getUserStarredQuery function', (done) => {
        try {
          assert.equal(true, typeof a.getUserStarredQuery === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getUserSubscriptionsQuery - errors', () => {
      it('should have a getUserSubscriptionsQuery function', (done) => {
        try {
          assert.equal(true, typeof a.getUserSubscriptionsQuery === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getUserIssuesQuery - errors', () => {
      it('should have a getUserIssuesQuery function', (done) => {
        try {
          assert.equal(true, typeof a.getUserIssuesQuery === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getUserOrgsQuery - errors', () => {
      it('should have a getUserOrgsQuery function', (done) => {
        try {
          assert.equal(true, typeof a.getUserOrgsQuery === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getUserReposQuery - errors', () => {
      it('should have a getUserReposQuery function', (done) => {
        try {
          assert.equal(true, typeof a.getUserReposQuery === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getUserTeamsQuery - errors', () => {
      it('should have a getUserTeamsQuery function', (done) => {
        try {
          assert.equal(true, typeof a.getUserTeamsQuery === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getUserEmailsQuery - errors', () => {
      it('should have a getUserEmailsQuery function', (done) => {
        try {
          assert.equal(true, typeof a.getUserEmailsQuery === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getUserFollowersQuery - errors', () => {
      it('should have a getUserFollowersQuery function', (done) => {
        try {
          assert.equal(true, typeof a.getUserFollowersQuery === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getUserFollowingQuery - errors', () => {
      it('should have a getUserFollowingQuery function', (done) => {
        try {
          assert.equal(true, typeof a.getUserFollowingQuery === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getUserKeysQuery - errors', () => {
      it('should have a getUserKeysQuery function', (done) => {
        try {
          assert.equal(true, typeof a.getUserKeysQuery === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getUsersUsernameEventsQuery - errors', () => {
      it('should have a getUsersUsernameEventsQuery function', (done) => {
        try {
          assert.equal(true, typeof a.getUsersUsernameEventsQuery === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing username', (done) => {
        try {
          a.getUsersUsernameEventsQuery(null, null, null, (data, error) => {
            try {
              const displayE = 'username is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getUsersUsernameEventsQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getUsersUsernameEventsOrgsOrgQuery - errors', () => {
      it('should have a getUsersUsernameEventsOrgsOrgQuery function', (done) => {
        try {
          assert.equal(true, typeof a.getUsersUsernameEventsOrgsOrgQuery === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing username', (done) => {
        try {
          a.getUsersUsernameEventsOrgsOrgQuery(null, null, null, null, (data, error) => {
            try {
              const displayE = 'username is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getUsersUsernameEventsOrgsOrgQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.getUsersUsernameEventsOrgsOrgQuery('fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getUsersUsernameEventsOrgsOrgQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getUsersUsernameReceivedEventsQuery - errors', () => {
      it('should have a getUsersUsernameReceivedEventsQuery function', (done) => {
        try {
          assert.equal(true, typeof a.getUsersUsernameReceivedEventsQuery === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing username', (done) => {
        try {
          a.getUsersUsernameReceivedEventsQuery(null, null, null, (data, error) => {
            try {
              const displayE = 'username is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getUsersUsernameReceivedEventsQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getUsersUsernameReceivedEventsPublicQuery - errors', () => {
      it('should have a getUsersUsernameReceivedEventsPublicQuery function', (done) => {
        try {
          assert.equal(true, typeof a.getUsersUsernameReceivedEventsPublicQuery === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing username', (done) => {
        try {
          a.getUsersUsernameReceivedEventsPublicQuery(null, null, null, (data, error) => {
            try {
              const displayE = 'username is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getUsersUsernameReceivedEventsPublicQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getUsersUsernameStarredQuery - errors', () => {
      it('should have a getUsersUsernameStarredQuery function', (done) => {
        try {
          assert.equal(true, typeof a.getUsersUsernameStarredQuery === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing username', (done) => {
        try {
          a.getUsersUsernameStarredQuery(null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'username is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getUsersUsernameStarredQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getUsersUsernameSubscriptionsQuery - errors', () => {
      it('should have a getUsersUsernameSubscriptionsQuery function', (done) => {
        try {
          assert.equal(true, typeof a.getUsersUsernameSubscriptionsQuery === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing username', (done) => {
        try {
          a.getUsersUsernameSubscriptionsQuery(null, null, null, (data, error) => {
            try {
              const displayE = 'username is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getUsersUsernameSubscriptionsQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getUsersUsernameGistsQuery - errors', () => {
      it('should have a getUsersUsernameGistsQuery function', (done) => {
        try {
          assert.equal(true, typeof a.getUsersUsernameGistsQuery === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing username', (done) => {
        try {
          a.getUsersUsernameGistsQuery(null, null, null, null, (data, error) => {
            try {
              const displayE = 'username is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getUsersUsernameGistsQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getUsersUsernameOrgsQuery - errors', () => {
      it('should have a getUsersUsernameOrgsQuery function', (done) => {
        try {
          assert.equal(true, typeof a.getUsersUsernameOrgsQuery === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing username', (done) => {
        try {
          a.getUsersUsernameOrgsQuery(null, null, null, (data, error) => {
            try {
              const displayE = 'username is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getUsersUsernameOrgsQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getUsersUsernameReposQuery - errors', () => {
      it('should have a getUsersUsernameReposQuery function', (done) => {
        try {
          assert.equal(true, typeof a.getUsersUsernameReposQuery === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing username', (done) => {
        try {
          a.getUsersUsernameReposQuery(null, null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'username is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getUsersUsernameReposQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#usersListBlockedByAuthenticatedUser - errors', () => {
      it('should have a usersListBlockedByAuthenticatedUser function', (done) => {
        try {
          assert.equal(true, typeof a.usersListBlockedByAuthenticatedUser === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#usersCheckBlocked - errors', () => {
      it('should have a usersCheckBlocked function', (done) => {
        try {
          assert.equal(true, typeof a.usersCheckBlocked === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing username', (done) => {
        try {
          a.usersCheckBlocked(null, (data, error) => {
            try {
              const displayE = 'username is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-usersCheckBlocked', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#usersBlock - errors', () => {
      it('should have a usersBlock function', (done) => {
        try {
          assert.equal(true, typeof a.usersBlock === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing username', (done) => {
        try {
          a.usersBlock(null, (data, error) => {
            try {
              const displayE = 'username is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-usersBlock', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#usersUnblock - errors', () => {
      it('should have a usersUnblock function', (done) => {
        try {
          assert.equal(true, typeof a.usersUnblock === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing username', (done) => {
        try {
          a.usersUnblock(null, (data, error) => {
            try {
              const displayE = 'username is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-usersUnblock', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#usersSetPrimaryEmailVisibilityForAuthenticatedUser - errors', () => {
      it('should have a usersSetPrimaryEmailVisibilityForAuthenticatedUser function', (done) => {
        try {
          assert.equal(true, typeof a.usersSetPrimaryEmailVisibilityForAuthenticatedUser === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#usersListGpgKeysForAuthenticatedUser - errors', () => {
      it('should have a usersListGpgKeysForAuthenticatedUser function', (done) => {
        try {
          assert.equal(true, typeof a.usersListGpgKeysForAuthenticatedUser === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#usersCreateGpgKeyForAuthenticatedUser - errors', () => {
      it('should have a usersCreateGpgKeyForAuthenticatedUser function', (done) => {
        try {
          assert.equal(true, typeof a.usersCreateGpgKeyForAuthenticatedUser === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#usersGetGpgKeyForAuthenticatedUser - errors', () => {
      it('should have a usersGetGpgKeyForAuthenticatedUser function', (done) => {
        try {
          assert.equal(true, typeof a.usersGetGpgKeyForAuthenticatedUser === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing gpgKeyId', (done) => {
        try {
          a.usersGetGpgKeyForAuthenticatedUser(null, (data, error) => {
            try {
              const displayE = 'gpgKeyId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-usersGetGpgKeyForAuthenticatedUser', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#usersDeleteGpgKeyForAuthenticatedUser - errors', () => {
      it('should have a usersDeleteGpgKeyForAuthenticatedUser function', (done) => {
        try {
          assert.equal(true, typeof a.usersDeleteGpgKeyForAuthenticatedUser === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing gpgKeyId', (done) => {
        try {
          a.usersDeleteGpgKeyForAuthenticatedUser(null, (data, error) => {
            try {
              const displayE = 'gpgKeyId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-usersDeleteGpgKeyForAuthenticatedUser', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#usersListPublicEmailsForAuthenticatedUser - errors', () => {
      it('should have a usersListPublicEmailsForAuthenticatedUser function', (done) => {
        try {
          assert.equal(true, typeof a.usersListPublicEmailsForAuthenticatedUser === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#usersListSocialAccountsForAuthenticatedUser - errors', () => {
      it('should have a usersListSocialAccountsForAuthenticatedUser function', (done) => {
        try {
          assert.equal(true, typeof a.usersListSocialAccountsForAuthenticatedUser === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#usersAddSocialAccountForAuthenticatedUser - errors', () => {
      it('should have a usersAddSocialAccountForAuthenticatedUser function', (done) => {
        try {
          assert.equal(true, typeof a.usersAddSocialAccountForAuthenticatedUser === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#usersDeleteSocialAccountForAuthenticatedUser - errors', () => {
      it('should have a usersDeleteSocialAccountForAuthenticatedUser function', (done) => {
        try {
          assert.equal(true, typeof a.usersDeleteSocialAccountForAuthenticatedUser === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#usersListSshSigningKeysForAuthenticatedUser - errors', () => {
      it('should have a usersListSshSigningKeysForAuthenticatedUser function', (done) => {
        try {
          assert.equal(true, typeof a.usersListSshSigningKeysForAuthenticatedUser === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#usersCreateSshSigningKeyForAuthenticatedUser - errors', () => {
      it('should have a usersCreateSshSigningKeyForAuthenticatedUser function', (done) => {
        try {
          assert.equal(true, typeof a.usersCreateSshSigningKeyForAuthenticatedUser === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#usersGetSshSigningKeyForAuthenticatedUser - errors', () => {
      it('should have a usersGetSshSigningKeyForAuthenticatedUser function', (done) => {
        try {
          assert.equal(true, typeof a.usersGetSshSigningKeyForAuthenticatedUser === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing sshSigningKeyId', (done) => {
        try {
          a.usersGetSshSigningKeyForAuthenticatedUser(null, (data, error) => {
            try {
              const displayE = 'sshSigningKeyId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-usersGetSshSigningKeyForAuthenticatedUser', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#usersDeleteSshSigningKeyForAuthenticatedUser - errors', () => {
      it('should have a usersDeleteSshSigningKeyForAuthenticatedUser function', (done) => {
        try {
          assert.equal(true, typeof a.usersDeleteSshSigningKeyForAuthenticatedUser === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing sshSigningKeyId', (done) => {
        try {
          a.usersDeleteSshSigningKeyForAuthenticatedUser(null, (data, error) => {
            try {
              const displayE = 'sshSigningKeyId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-usersDeleteSshSigningKeyForAuthenticatedUser', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#usersGetById - errors', () => {
      it('should have a usersGetById function', (done) => {
        try {
          assert.equal(true, typeof a.usersGetById === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing accountId', (done) => {
        try {
          a.usersGetById(null, (data, error) => {
            try {
              const displayE = 'accountId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-usersGetById', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getUsersQuery - errors', () => {
      it('should have a getUsersQuery function', (done) => {
        try {
          assert.equal(true, typeof a.getUsersQuery === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#usersListAttestations - errors', () => {
      it('should have a usersListAttestations function', (done) => {
        try {
          assert.equal(true, typeof a.usersListAttestations === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing username', (done) => {
        try {
          a.usersListAttestations('fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'username is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-usersListAttestations', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing subjectDigest', (done) => {
        try {
          a.usersListAttestations('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'subjectDigest is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-usersListAttestations', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getUsersUsernameFollowersQuery - errors', () => {
      it('should have a getUsersUsernameFollowersQuery function', (done) => {
        try {
          assert.equal(true, typeof a.getUsersUsernameFollowersQuery === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing username', (done) => {
        try {
          a.getUsersUsernameFollowersQuery(null, null, null, (data, error) => {
            try {
              const displayE = 'username is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getUsersUsernameFollowersQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#usersListFollowingForUser - errors', () => {
      it('should have a usersListFollowingForUser function', (done) => {
        try {
          assert.equal(true, typeof a.usersListFollowingForUser === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing username', (done) => {
        try {
          a.usersListFollowingForUser(null, null, null, (data, error) => {
            try {
              const displayE = 'username is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-usersListFollowingForUser', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#usersCheckFollowingForUser - errors', () => {
      it('should have a usersCheckFollowingForUser function', (done) => {
        try {
          assert.equal(true, typeof a.usersCheckFollowingForUser === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing username', (done) => {
        try {
          a.usersCheckFollowingForUser(null, null, (data, error) => {
            try {
              const displayE = 'username is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-usersCheckFollowingForUser', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing targetUser', (done) => {
        try {
          a.usersCheckFollowingForUser('fakeparam', null, (data, error) => {
            try {
              const displayE = 'targetUser is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-usersCheckFollowingForUser', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#usersListGpgKeysForUser - errors', () => {
      it('should have a usersListGpgKeysForUser function', (done) => {
        try {
          assert.equal(true, typeof a.usersListGpgKeysForUser === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing username', (done) => {
        try {
          a.usersListGpgKeysForUser(null, null, null, (data, error) => {
            try {
              const displayE = 'username is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-usersListGpgKeysForUser', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#usersGetContextForUser - errors', () => {
      it('should have a usersGetContextForUser function', (done) => {
        try {
          assert.equal(true, typeof a.usersGetContextForUser === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing username', (done) => {
        try {
          a.usersGetContextForUser(null, null, null, (data, error) => {
            try {
              const displayE = 'username is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-usersGetContextForUser', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getUsersUsernameKeysQuery - errors', () => {
      it('should have a getUsersUsernameKeysQuery function', (done) => {
        try {
          assert.equal(true, typeof a.getUsersUsernameKeysQuery === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing username', (done) => {
        try {
          a.getUsersUsernameKeysQuery(null, null, null, (data, error) => {
            try {
              const displayE = 'username is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getUsersUsernameKeysQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#usersListSocialAccountsForUser - errors', () => {
      it('should have a usersListSocialAccountsForUser function', (done) => {
        try {
          assert.equal(true, typeof a.usersListSocialAccountsForUser === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing username', (done) => {
        try {
          a.usersListSocialAccountsForUser(null, null, null, (data, error) => {
            try {
              const displayE = 'username is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-usersListSocialAccountsForUser', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#usersListSshSigningKeysForUser - errors', () => {
      it('should have a usersListSshSigningKeysForUser function', (done) => {
        try {
          assert.equal(true, typeof a.usersListSshSigningKeysForUser === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing username', (done) => {
        try {
          a.usersListSshSigningKeysForUser(null, null, null, (data, error) => {
            try {
              const displayE = 'username is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-usersListSshSigningKeysForUser', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#appsGetAuthenticated - errors', () => {
      it('should have a appsGetAuthenticated function', (done) => {
        try {
          assert.equal(true, typeof a.appsGetAuthenticated === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#appsCreateFromManifest - errors', () => {
      it('should have a appsCreateFromManifest function', (done) => {
        try {
          assert.equal(true, typeof a.appsCreateFromManifest === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing code', (done) => {
        try {
          a.appsCreateFromManifest(null, (data, error) => {
            try {
              const displayE = 'code is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-appsCreateFromManifest', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#appsGetWebhookConfigForApp - errors', () => {
      it('should have a appsGetWebhookConfigForApp function', (done) => {
        try {
          assert.equal(true, typeof a.appsGetWebhookConfigForApp === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#appsUpdateWebhookConfigForApp - errors', () => {
      it('should have a appsUpdateWebhookConfigForApp function', (done) => {
        try {
          assert.equal(true, typeof a.appsUpdateWebhookConfigForApp === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#appsListWebhookDeliveries - errors', () => {
      it('should have a appsListWebhookDeliveries function', (done) => {
        try {
          assert.equal(true, typeof a.appsListWebhookDeliveries === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#appsGetWebhookDelivery - errors', () => {
      it('should have a appsGetWebhookDelivery function', (done) => {
        try {
          assert.equal(true, typeof a.appsGetWebhookDelivery === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing deliveryId', (done) => {
        try {
          a.appsGetWebhookDelivery(null, (data, error) => {
            try {
              const displayE = 'deliveryId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-appsGetWebhookDelivery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#appsRedeliverWebhookDelivery - errors', () => {
      it('should have a appsRedeliverWebhookDelivery function', (done) => {
        try {
          assert.equal(true, typeof a.appsRedeliverWebhookDelivery === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing deliveryId', (done) => {
        try {
          a.appsRedeliverWebhookDelivery(null, (data, error) => {
            try {
              const displayE = 'deliveryId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-appsRedeliverWebhookDelivery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#appsListInstallationRequestsForAuthenticatedApp - errors', () => {
      it('should have a appsListInstallationRequestsForAuthenticatedApp function', (done) => {
        try {
          assert.equal(true, typeof a.appsListInstallationRequestsForAuthenticatedApp === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#appsListInstallations - errors', () => {
      it('should have a appsListInstallations function', (done) => {
        try {
          assert.equal(true, typeof a.appsListInstallations === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#appsGetInstallation - errors', () => {
      it('should have a appsGetInstallation function', (done) => {
        try {
          assert.equal(true, typeof a.appsGetInstallation === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing installationId', (done) => {
        try {
          a.appsGetInstallation(null, (data, error) => {
            try {
              const displayE = 'installationId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-appsGetInstallation', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#appsDeleteInstallation - errors', () => {
      it('should have a appsDeleteInstallation function', (done) => {
        try {
          assert.equal(true, typeof a.appsDeleteInstallation === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing installationId', (done) => {
        try {
          a.appsDeleteInstallation(null, (data, error) => {
            try {
              const displayE = 'installationId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-appsDeleteInstallation', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#appsCreateInstallationAccessToken - errors', () => {
      it('should have a appsCreateInstallationAccessToken function', (done) => {
        try {
          assert.equal(true, typeof a.appsCreateInstallationAccessToken === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing installationId', (done) => {
        try {
          a.appsCreateInstallationAccessToken(null, null, (data, error) => {
            try {
              const displayE = 'installationId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-appsCreateInstallationAccessToken', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#appsSuspendInstallation - errors', () => {
      it('should have a appsSuspendInstallation function', (done) => {
        try {
          assert.equal(true, typeof a.appsSuspendInstallation === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing installationId', (done) => {
        try {
          a.appsSuspendInstallation(null, (data, error) => {
            try {
              const displayE = 'installationId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-appsSuspendInstallation', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#appsUnsuspendInstallation - errors', () => {
      it('should have a appsUnsuspendInstallation function', (done) => {
        try {
          assert.equal(true, typeof a.appsUnsuspendInstallation === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing installationId', (done) => {
        try {
          a.appsUnsuspendInstallation(null, (data, error) => {
            try {
              const displayE = 'installationId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-appsUnsuspendInstallation', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#appsDeleteAuthorization - errors', () => {
      it('should have a appsDeleteAuthorization function', (done) => {
        try {
          assert.equal(true, typeof a.appsDeleteAuthorization === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing clientId', (done) => {
        try {
          a.appsDeleteAuthorization(null, (data, error) => {
            try {
              const displayE = 'clientId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-appsDeleteAuthorization', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#appsCheckToken - errors', () => {
      it('should have a appsCheckToken function', (done) => {
        try {
          assert.equal(true, typeof a.appsCheckToken === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing clientId', (done) => {
        try {
          a.appsCheckToken(null, null, (data, error) => {
            try {
              const displayE = 'clientId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-appsCheckToken', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#appsResetToken - errors', () => {
      it('should have a appsResetToken function', (done) => {
        try {
          assert.equal(true, typeof a.appsResetToken === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing clientId', (done) => {
        try {
          a.appsResetToken(null, null, (data, error) => {
            try {
              const displayE = 'clientId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-appsResetToken', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#appsDeleteToken - errors', () => {
      it('should have a appsDeleteToken function', (done) => {
        try {
          assert.equal(true, typeof a.appsDeleteToken === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing clientId', (done) => {
        try {
          a.appsDeleteToken(null, (data, error) => {
            try {
              const displayE = 'clientId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-appsDeleteToken', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#appsScopeToken - errors', () => {
      it('should have a appsScopeToken function', (done) => {
        try {
          assert.equal(true, typeof a.appsScopeToken === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing clientId', (done) => {
        try {
          a.appsScopeToken(null, null, (data, error) => {
            try {
              const displayE = 'clientId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-appsScopeToken', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#appsGetBySlug - errors', () => {
      it('should have a appsGetBySlug function', (done) => {
        try {
          assert.equal(true, typeof a.appsGetBySlug === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing appSlug', (done) => {
        try {
          a.appsGetBySlug(null, (data, error) => {
            try {
              const displayE = 'appSlug is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-appsGetBySlug', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#appsListReposAccessibleToInstallation - errors', () => {
      it('should have a appsListReposAccessibleToInstallation function', (done) => {
        try {
          assert.equal(true, typeof a.appsListReposAccessibleToInstallation === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#appsRevokeInstallationAccessToken - errors', () => {
      it('should have a appsRevokeInstallationAccessToken function', (done) => {
        try {
          assert.equal(true, typeof a.appsRevokeInstallationAccessToken === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#appsGetSubscriptionPlanForAccount - errors', () => {
      it('should have a appsGetSubscriptionPlanForAccount function', (done) => {
        try {
          assert.equal(true, typeof a.appsGetSubscriptionPlanForAccount === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing accountId', (done) => {
        try {
          a.appsGetSubscriptionPlanForAccount(null, (data, error) => {
            try {
              const displayE = 'accountId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-appsGetSubscriptionPlanForAccount', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#appsListPlans - errors', () => {
      it('should have a appsListPlans function', (done) => {
        try {
          assert.equal(true, typeof a.appsListPlans === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#appsListAccountsForPlan - errors', () => {
      it('should have a appsListAccountsForPlan function', (done) => {
        try {
          assert.equal(true, typeof a.appsListAccountsForPlan === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing planId', (done) => {
        try {
          a.appsListAccountsForPlan(null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'planId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-appsListAccountsForPlan', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#appsGetSubscriptionPlanForAccountStubbed - errors', () => {
      it('should have a appsGetSubscriptionPlanForAccountStubbed function', (done) => {
        try {
          assert.equal(true, typeof a.appsGetSubscriptionPlanForAccountStubbed === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing accountId', (done) => {
        try {
          a.appsGetSubscriptionPlanForAccountStubbed(null, (data, error) => {
            try {
              const displayE = 'accountId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-appsGetSubscriptionPlanForAccountStubbed', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#appsListPlansStubbed - errors', () => {
      it('should have a appsListPlansStubbed function', (done) => {
        try {
          assert.equal(true, typeof a.appsListPlansStubbed === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#appsListAccountsForPlanStubbed - errors', () => {
      it('should have a appsListAccountsForPlanStubbed function', (done) => {
        try {
          assert.equal(true, typeof a.appsListAccountsForPlanStubbed === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing planId', (done) => {
        try {
          a.appsListAccountsForPlanStubbed(null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'planId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-appsListAccountsForPlanStubbed', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#appsGetOrgInstallation - errors', () => {
      it('should have a appsGetOrgInstallation function', (done) => {
        try {
          assert.equal(true, typeof a.appsGetOrgInstallation === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.appsGetOrgInstallation(null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-appsGetOrgInstallation', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#appsGetRepoInstallation - errors', () => {
      it('should have a appsGetRepoInstallation function', (done) => {
        try {
          assert.equal(true, typeof a.appsGetRepoInstallation === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.appsGetRepoInstallation(null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-appsGetRepoInstallation', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.appsGetRepoInstallation('fakeparam', null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-appsGetRepoInstallation', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#appsListInstallationsForAuthenticatedUser - errors', () => {
      it('should have a appsListInstallationsForAuthenticatedUser function', (done) => {
        try {
          assert.equal(true, typeof a.appsListInstallationsForAuthenticatedUser === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#appsListInstallationReposForAuthenticatedUser - errors', () => {
      it('should have a appsListInstallationReposForAuthenticatedUser function', (done) => {
        try {
          assert.equal(true, typeof a.appsListInstallationReposForAuthenticatedUser === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing installationId', (done) => {
        try {
          a.appsListInstallationReposForAuthenticatedUser(null, null, null, (data, error) => {
            try {
              const displayE = 'installationId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-appsListInstallationReposForAuthenticatedUser', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#appsAddRepoToInstallationForAuthenticatedUser - errors', () => {
      it('should have a appsAddRepoToInstallationForAuthenticatedUser function', (done) => {
        try {
          assert.equal(true, typeof a.appsAddRepoToInstallationForAuthenticatedUser === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing installationId', (done) => {
        try {
          a.appsAddRepoToInstallationForAuthenticatedUser(null, null, (data, error) => {
            try {
              const displayE = 'installationId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-appsAddRepoToInstallationForAuthenticatedUser', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repositoryId', (done) => {
        try {
          a.appsAddRepoToInstallationForAuthenticatedUser('fakeparam', null, (data, error) => {
            try {
              const displayE = 'repositoryId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-appsAddRepoToInstallationForAuthenticatedUser', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#appsRemoveRepoFromInstallationForAuthenticatedUser - errors', () => {
      it('should have a appsRemoveRepoFromInstallationForAuthenticatedUser function', (done) => {
        try {
          assert.equal(true, typeof a.appsRemoveRepoFromInstallationForAuthenticatedUser === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing installationId', (done) => {
        try {
          a.appsRemoveRepoFromInstallationForAuthenticatedUser(null, null, (data, error) => {
            try {
              const displayE = 'installationId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-appsRemoveRepoFromInstallationForAuthenticatedUser', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repositoryId', (done) => {
        try {
          a.appsRemoveRepoFromInstallationForAuthenticatedUser('fakeparam', null, (data, error) => {
            try {
              const displayE = 'repositoryId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-appsRemoveRepoFromInstallationForAuthenticatedUser', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#appsListSubscriptionsForAuthenticatedUser - errors', () => {
      it('should have a appsListSubscriptionsForAuthenticatedUser function', (done) => {
        try {
          assert.equal(true, typeof a.appsListSubscriptionsForAuthenticatedUser === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#appsListSubscriptionsForAuthenticatedUserStubbed - errors', () => {
      it('should have a appsListSubscriptionsForAuthenticatedUserStubbed function', (done) => {
        try {
          assert.equal(true, typeof a.appsListSubscriptionsForAuthenticatedUserStubbed === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#appsGetUserInstallation - errors', () => {
      it('should have a appsGetUserInstallation function', (done) => {
        try {
          assert.equal(true, typeof a.appsGetUserInstallation === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing username', (done) => {
        try {
          a.appsGetUserInstallation(null, (data, error) => {
            try {
              const displayE = 'username is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-appsGetUserInstallation', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#billingGetGithubActionsBillingOrg - errors', () => {
      it('should have a billingGetGithubActionsBillingOrg function', (done) => {
        try {
          assert.equal(true, typeof a.billingGetGithubActionsBillingOrg === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.billingGetGithubActionsBillingOrg(null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-billingGetGithubActionsBillingOrg', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#billingGetGithubPackagesBillingOrg - errors', () => {
      it('should have a billingGetGithubPackagesBillingOrg function', (done) => {
        try {
          assert.equal(true, typeof a.billingGetGithubPackagesBillingOrg === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.billingGetGithubPackagesBillingOrg(null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-billingGetGithubPackagesBillingOrg', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#billingGetSharedStorageBillingOrg - errors', () => {
      it('should have a billingGetSharedStorageBillingOrg function', (done) => {
        try {
          assert.equal(true, typeof a.billingGetSharedStorageBillingOrg === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.billingGetSharedStorageBillingOrg(null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-billingGetSharedStorageBillingOrg', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#billingGetGithubActionsBillingUser - errors', () => {
      it('should have a billingGetGithubActionsBillingUser function', (done) => {
        try {
          assert.equal(true, typeof a.billingGetGithubActionsBillingUser === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing username', (done) => {
        try {
          a.billingGetGithubActionsBillingUser(null, (data, error) => {
            try {
              const displayE = 'username is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-billingGetGithubActionsBillingUser', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#billingGetGithubPackagesBillingUser - errors', () => {
      it('should have a billingGetGithubPackagesBillingUser function', (done) => {
        try {
          assert.equal(true, typeof a.billingGetGithubPackagesBillingUser === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing username', (done) => {
        try {
          a.billingGetGithubPackagesBillingUser(null, (data, error) => {
            try {
              const displayE = 'username is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-billingGetGithubPackagesBillingUser', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#billingGetSharedStorageBillingUser - errors', () => {
      it('should have a billingGetSharedStorageBillingUser function', (done) => {
        try {
          assert.equal(true, typeof a.billingGetSharedStorageBillingUser === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing username', (done) => {
        try {
          a.billingGetSharedStorageBillingUser(null, (data, error) => {
            try {
              const displayE = 'username is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-billingGetSharedStorageBillingUser', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#checksCreate - errors', () => {
      it('should have a checksCreate function', (done) => {
        try {
          assert.equal(true, typeof a.checksCreate === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.checksCreate(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-checksCreate', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.checksCreate('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-checksCreate', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#checksGet - errors', () => {
      it('should have a checksGet function', (done) => {
        try {
          assert.equal(true, typeof a.checksGet === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.checksGet(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-checksGet', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.checksGet('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-checksGet', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing checkRunId', (done) => {
        try {
          a.checksGet('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'checkRunId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-checksGet', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#checksUpdate - errors', () => {
      it('should have a checksUpdate function', (done) => {
        try {
          assert.equal(true, typeof a.checksUpdate === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.checksUpdate(null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-checksUpdate', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.checksUpdate('fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-checksUpdate', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing checkRunId', (done) => {
        try {
          a.checksUpdate('fakeparam', 'fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'checkRunId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-checksUpdate', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#checksListAnnotations - errors', () => {
      it('should have a checksListAnnotations function', (done) => {
        try {
          assert.equal(true, typeof a.checksListAnnotations === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.checksListAnnotations(null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-checksListAnnotations', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.checksListAnnotations('fakeparam', null, null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-checksListAnnotations', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing checkRunId', (done) => {
        try {
          a.checksListAnnotations('fakeparam', 'fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'checkRunId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-checksListAnnotations', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#checksRerequestRun - errors', () => {
      it('should have a checksRerequestRun function', (done) => {
        try {
          assert.equal(true, typeof a.checksRerequestRun === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.checksRerequestRun(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-checksRerequestRun', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.checksRerequestRun('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-checksRerequestRun', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing checkRunId', (done) => {
        try {
          a.checksRerequestRun('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'checkRunId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-checksRerequestRun', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#checksCreateSuite - errors', () => {
      it('should have a checksCreateSuite function', (done) => {
        try {
          assert.equal(true, typeof a.checksCreateSuite === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.checksCreateSuite(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-checksCreateSuite', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.checksCreateSuite('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-checksCreateSuite', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#checksSetSuitesPreferences - errors', () => {
      it('should have a checksSetSuitesPreferences function', (done) => {
        try {
          assert.equal(true, typeof a.checksSetSuitesPreferences === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.checksSetSuitesPreferences(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-checksSetSuitesPreferences', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.checksSetSuitesPreferences('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-checksSetSuitesPreferences', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#checksGetSuite - errors', () => {
      it('should have a checksGetSuite function', (done) => {
        try {
          assert.equal(true, typeof a.checksGetSuite === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.checksGetSuite(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-checksGetSuite', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.checksGetSuite('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-checksGetSuite', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing checkSuiteId', (done) => {
        try {
          a.checksGetSuite('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'checkSuiteId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-checksGetSuite', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#checksListForSuite - errors', () => {
      it('should have a checksListForSuite function', (done) => {
        try {
          assert.equal(true, typeof a.checksListForSuite === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.checksListForSuite(null, null, null, null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-checksListForSuite', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.checksListForSuite('fakeparam', null, null, null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-checksListForSuite', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing checkSuiteId', (done) => {
        try {
          a.checksListForSuite('fakeparam', 'fakeparam', null, null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'checkSuiteId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-checksListForSuite', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#checksRerequestSuite - errors', () => {
      it('should have a checksRerequestSuite function', (done) => {
        try {
          assert.equal(true, typeof a.checksRerequestSuite === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.checksRerequestSuite(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-checksRerequestSuite', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.checksRerequestSuite('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-checksRerequestSuite', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing checkSuiteId', (done) => {
        try {
          a.checksRerequestSuite('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'checkSuiteId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-checksRerequestSuite', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#checksListForRef - errors', () => {
      it('should have a checksListForRef function', (done) => {
        try {
          assert.equal(true, typeof a.checksListForRef === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.checksListForRef(null, null, null, null, null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-checksListForRef', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.checksListForRef('fakeparam', null, null, null, null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-checksListForRef', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing ref', (done) => {
        try {
          a.checksListForRef('fakeparam', 'fakeparam', null, null, null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'ref is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-checksListForRef', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#checksListSuitesForRef - errors', () => {
      it('should have a checksListSuitesForRef function', (done) => {
        try {
          assert.equal(true, typeof a.checksListSuitesForRef === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.checksListSuitesForRef(null, null, null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-checksListSuitesForRef', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.checksListSuitesForRef('fakeparam', null, null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-checksListSuitesForRef', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing ref', (done) => {
        try {
          a.checksListSuitesForRef('fakeparam', 'fakeparam', null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'ref is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-checksListSuitesForRef', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#codeScanningListAlertsForOrg - errors', () => {
      it('should have a codeScanningListAlertsForOrg function', (done) => {
        try {
          assert.equal(true, typeof a.codeScanningListAlertsForOrg === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.codeScanningListAlertsForOrg(null, null, null, null, null, null, null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-codeScanningListAlertsForOrg', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#codeScanningListAlertsForRepo - errors', () => {
      it('should have a codeScanningListAlertsForRepo function', (done) => {
        try {
          assert.equal(true, typeof a.codeScanningListAlertsForRepo === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.codeScanningListAlertsForRepo(null, null, null, null, null, null, null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-codeScanningListAlertsForRepo', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.codeScanningListAlertsForRepo('fakeparam', null, null, null, null, null, null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-codeScanningListAlertsForRepo', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#codeScanningGetAlert - errors', () => {
      it('should have a codeScanningGetAlert function', (done) => {
        try {
          assert.equal(true, typeof a.codeScanningGetAlert === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.codeScanningGetAlert(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-codeScanningGetAlert', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.codeScanningGetAlert('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-codeScanningGetAlert', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing alertNumber', (done) => {
        try {
          a.codeScanningGetAlert('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'alertNumber is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-codeScanningGetAlert', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#codeScanningUpdateAlert - errors', () => {
      it('should have a codeScanningUpdateAlert function', (done) => {
        try {
          assert.equal(true, typeof a.codeScanningUpdateAlert === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.codeScanningUpdateAlert(null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-codeScanningUpdateAlert', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.codeScanningUpdateAlert('fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-codeScanningUpdateAlert', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing alertNumber', (done) => {
        try {
          a.codeScanningUpdateAlert('fakeparam', 'fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'alertNumber is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-codeScanningUpdateAlert', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#codeScanningListAlertInstances - errors', () => {
      it('should have a codeScanningListAlertInstances function', (done) => {
        try {
          assert.equal(true, typeof a.codeScanningListAlertInstances === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.codeScanningListAlertInstances(null, null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-codeScanningListAlertInstances', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.codeScanningListAlertInstances('fakeparam', null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-codeScanningListAlertInstances', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing alertNumber', (done) => {
        try {
          a.codeScanningListAlertInstances('fakeparam', 'fakeparam', null, null, null, null, (data, error) => {
            try {
              const displayE = 'alertNumber is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-codeScanningListAlertInstances', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#codeScanningListRecentAnalyses - errors', () => {
      it('should have a codeScanningListRecentAnalyses function', (done) => {
        try {
          assert.equal(true, typeof a.codeScanningListRecentAnalyses === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.codeScanningListRecentAnalyses(null, null, null, null, null, null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-codeScanningListRecentAnalyses', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.codeScanningListRecentAnalyses('fakeparam', null, null, null, null, null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-codeScanningListRecentAnalyses', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#codeScanningGetAnalysis - errors', () => {
      it('should have a codeScanningGetAnalysis function', (done) => {
        try {
          assert.equal(true, typeof a.codeScanningGetAnalysis === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.codeScanningGetAnalysis(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-codeScanningGetAnalysis', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.codeScanningGetAnalysis('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-codeScanningGetAnalysis', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing analysisId', (done) => {
        try {
          a.codeScanningGetAnalysis('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'analysisId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-codeScanningGetAnalysis', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#codeScanningDeleteAnalysis - errors', () => {
      it('should have a codeScanningDeleteAnalysis function', (done) => {
        try {
          assert.equal(true, typeof a.codeScanningDeleteAnalysis === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.codeScanningDeleteAnalysis(null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-codeScanningDeleteAnalysis', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.codeScanningDeleteAnalysis('fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-codeScanningDeleteAnalysis', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing analysisId', (done) => {
        try {
          a.codeScanningDeleteAnalysis('fakeparam', 'fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'analysisId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-codeScanningDeleteAnalysis', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#codeScanningListCodeqlDatabases - errors', () => {
      it('should have a codeScanningListCodeqlDatabases function', (done) => {
        try {
          assert.equal(true, typeof a.codeScanningListCodeqlDatabases === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.codeScanningListCodeqlDatabases(null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-codeScanningListCodeqlDatabases', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.codeScanningListCodeqlDatabases('fakeparam', null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-codeScanningListCodeqlDatabases', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#codeScanningGetCodeqlDatabase - errors', () => {
      it('should have a codeScanningGetCodeqlDatabase function', (done) => {
        try {
          assert.equal(true, typeof a.codeScanningGetCodeqlDatabase === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.codeScanningGetCodeqlDatabase(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-codeScanningGetCodeqlDatabase', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.codeScanningGetCodeqlDatabase('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-codeScanningGetCodeqlDatabase', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing language', (done) => {
        try {
          a.codeScanningGetCodeqlDatabase('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'language is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-codeScanningGetCodeqlDatabase', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#codeScanningCreateVariantAnalysis - errors', () => {
      it('should have a codeScanningCreateVariantAnalysis function', (done) => {
        try {
          assert.equal(true, typeof a.codeScanningCreateVariantAnalysis === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.codeScanningCreateVariantAnalysis(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-codeScanningCreateVariantAnalysis', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.codeScanningCreateVariantAnalysis('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-codeScanningCreateVariantAnalysis', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#codeScanningGetVariantAnalysis - errors', () => {
      it('should have a codeScanningGetVariantAnalysis function', (done) => {
        try {
          assert.equal(true, typeof a.codeScanningGetVariantAnalysis === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.codeScanningGetVariantAnalysis(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-codeScanningGetVariantAnalysis', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.codeScanningGetVariantAnalysis('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-codeScanningGetVariantAnalysis', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing codeqlVariantAnalysisId', (done) => {
        try {
          a.codeScanningGetVariantAnalysis('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'codeqlVariantAnalysisId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-codeScanningGetVariantAnalysis', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#codeScanningGetVariantAnalysisRepoTask - errors', () => {
      it('should have a codeScanningGetVariantAnalysisRepoTask function', (done) => {
        try {
          assert.equal(true, typeof a.codeScanningGetVariantAnalysisRepoTask === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.codeScanningGetVariantAnalysisRepoTask(null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-codeScanningGetVariantAnalysisRepoTask', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.codeScanningGetVariantAnalysisRepoTask('fakeparam', null, null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-codeScanningGetVariantAnalysisRepoTask', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing codeqlVariantAnalysisId', (done) => {
        try {
          a.codeScanningGetVariantAnalysisRepoTask('fakeparam', 'fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'codeqlVariantAnalysisId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-codeScanningGetVariantAnalysisRepoTask', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repoOwner', (done) => {
        try {
          a.codeScanningGetVariantAnalysisRepoTask('fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repoOwner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-codeScanningGetVariantAnalysisRepoTask', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repoName', (done) => {
        try {
          a.codeScanningGetVariantAnalysisRepoTask('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'repoName is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-codeScanningGetVariantAnalysisRepoTask', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#codeScanningGetDefaultSetup - errors', () => {
      it('should have a codeScanningGetDefaultSetup function', (done) => {
        try {
          assert.equal(true, typeof a.codeScanningGetDefaultSetup === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.codeScanningGetDefaultSetup(null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-codeScanningGetDefaultSetup', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.codeScanningGetDefaultSetup('fakeparam', null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-codeScanningGetDefaultSetup', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#codeScanningUpdateDefaultSetup - errors', () => {
      it('should have a codeScanningUpdateDefaultSetup function', (done) => {
        try {
          assert.equal(true, typeof a.codeScanningUpdateDefaultSetup === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.codeScanningUpdateDefaultSetup(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-codeScanningUpdateDefaultSetup', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.codeScanningUpdateDefaultSetup('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-codeScanningUpdateDefaultSetup', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#codeScanningUploadSarif - errors', () => {
      it('should have a codeScanningUploadSarif function', (done) => {
        try {
          assert.equal(true, typeof a.codeScanningUploadSarif === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.codeScanningUploadSarif(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-codeScanningUploadSarif', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.codeScanningUploadSarif('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-codeScanningUploadSarif', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#codeScanningGetSarif - errors', () => {
      it('should have a codeScanningGetSarif function', (done) => {
        try {
          assert.equal(true, typeof a.codeScanningGetSarif === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.codeScanningGetSarif(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-codeScanningGetSarif', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.codeScanningGetSarif('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-codeScanningGetSarif', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing sarifId', (done) => {
        try {
          a.codeScanningGetSarif('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'sarifId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-codeScanningGetSarif', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#codesOfConductGetAllCodesOfConduct - errors', () => {
      it('should have a codesOfConductGetAllCodesOfConduct function', (done) => {
        try {
          assert.equal(true, typeof a.codesOfConductGetAllCodesOfConduct === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#codesOfConductGetConductCode - errors', () => {
      it('should have a codesOfConductGetConductCode function', (done) => {
        try {
          assert.equal(true, typeof a.codesOfConductGetConductCode === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing key', (done) => {
        try {
          a.codesOfConductGetConductCode(null, (data, error) => {
            try {
              const displayE = 'key is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-codesOfConductGetConductCode', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#dependabotListAlertsForEnterprise - errors', () => {
      it('should have a dependabotListAlertsForEnterprise function', (done) => {
        try {
          assert.equal(true, typeof a.dependabotListAlertsForEnterprise === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing enterprise', (done) => {
        try {
          a.dependabotListAlertsForEnterprise(null, null, null, null, null, null, null, null, null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'enterprise is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-dependabotListAlertsForEnterprise', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#dependabotListAlertsForOrg - errors', () => {
      it('should have a dependabotListAlertsForOrg function', (done) => {
        try {
          assert.equal(true, typeof a.dependabotListAlertsForOrg === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.dependabotListAlertsForOrg(null, null, null, null, null, null, null, null, null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-dependabotListAlertsForOrg', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#dependabotListOrgSecrets - errors', () => {
      it('should have a dependabotListOrgSecrets function', (done) => {
        try {
          assert.equal(true, typeof a.dependabotListOrgSecrets === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.dependabotListOrgSecrets(null, null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-dependabotListOrgSecrets', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#dependabotGetOrgPublicKey - errors', () => {
      it('should have a dependabotGetOrgPublicKey function', (done) => {
        try {
          assert.equal(true, typeof a.dependabotGetOrgPublicKey === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.dependabotGetOrgPublicKey(null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-dependabotGetOrgPublicKey', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#dependabotGetOrgSecret - errors', () => {
      it('should have a dependabotGetOrgSecret function', (done) => {
        try {
          assert.equal(true, typeof a.dependabotGetOrgSecret === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.dependabotGetOrgSecret(null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-dependabotGetOrgSecret', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing secretName', (done) => {
        try {
          a.dependabotGetOrgSecret('fakeparam', null, (data, error) => {
            try {
              const displayE = 'secretName is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-dependabotGetOrgSecret', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#dependabotCreateOrUpdateOrgSecret - errors', () => {
      it('should have a dependabotCreateOrUpdateOrgSecret function', (done) => {
        try {
          assert.equal(true, typeof a.dependabotCreateOrUpdateOrgSecret === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.dependabotCreateOrUpdateOrgSecret(null, null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-dependabotCreateOrUpdateOrgSecret', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing secretName', (done) => {
        try {
          a.dependabotCreateOrUpdateOrgSecret('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'secretName is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-dependabotCreateOrUpdateOrgSecret', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#dependabotDeleteOrgSecret - errors', () => {
      it('should have a dependabotDeleteOrgSecret function', (done) => {
        try {
          assert.equal(true, typeof a.dependabotDeleteOrgSecret === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.dependabotDeleteOrgSecret(null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-dependabotDeleteOrgSecret', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing secretName', (done) => {
        try {
          a.dependabotDeleteOrgSecret('fakeparam', null, (data, error) => {
            try {
              const displayE = 'secretName is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-dependabotDeleteOrgSecret', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#dependabotListSelectedReposForOrgSecret - errors', () => {
      it('should have a dependabotListSelectedReposForOrgSecret function', (done) => {
        try {
          assert.equal(true, typeof a.dependabotListSelectedReposForOrgSecret === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.dependabotListSelectedReposForOrgSecret(null, null, null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-dependabotListSelectedReposForOrgSecret', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing secretName', (done) => {
        try {
          a.dependabotListSelectedReposForOrgSecret('fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'secretName is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-dependabotListSelectedReposForOrgSecret', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#dependabotSetSelectedReposForOrgSecret - errors', () => {
      it('should have a dependabotSetSelectedReposForOrgSecret function', (done) => {
        try {
          assert.equal(true, typeof a.dependabotSetSelectedReposForOrgSecret === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.dependabotSetSelectedReposForOrgSecret(null, null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-dependabotSetSelectedReposForOrgSecret', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing secretName', (done) => {
        try {
          a.dependabotSetSelectedReposForOrgSecret('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'secretName is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-dependabotSetSelectedReposForOrgSecret', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#dependabotAddSelectedRepoToOrgSecret - errors', () => {
      it('should have a dependabotAddSelectedRepoToOrgSecret function', (done) => {
        try {
          assert.equal(true, typeof a.dependabotAddSelectedRepoToOrgSecret === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.dependabotAddSelectedRepoToOrgSecret(null, null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-dependabotAddSelectedRepoToOrgSecret', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing secretName', (done) => {
        try {
          a.dependabotAddSelectedRepoToOrgSecret('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'secretName is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-dependabotAddSelectedRepoToOrgSecret', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repositoryId', (done) => {
        try {
          a.dependabotAddSelectedRepoToOrgSecret('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'repositoryId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-dependabotAddSelectedRepoToOrgSecret', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#dependabotRemoveSelectedRepoFromOrgSecret - errors', () => {
      it('should have a dependabotRemoveSelectedRepoFromOrgSecret function', (done) => {
        try {
          assert.equal(true, typeof a.dependabotRemoveSelectedRepoFromOrgSecret === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.dependabotRemoveSelectedRepoFromOrgSecret(null, null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-dependabotRemoveSelectedRepoFromOrgSecret', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing secretName', (done) => {
        try {
          a.dependabotRemoveSelectedRepoFromOrgSecret('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'secretName is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-dependabotRemoveSelectedRepoFromOrgSecret', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repositoryId', (done) => {
        try {
          a.dependabotRemoveSelectedRepoFromOrgSecret('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'repositoryId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-dependabotRemoveSelectedRepoFromOrgSecret', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#dependabotListAlertsForRepo - errors', () => {
      it('should have a dependabotListAlertsForRepo function', (done) => {
        try {
          assert.equal(true, typeof a.dependabotListAlertsForRepo === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.dependabotListAlertsForRepo(null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-dependabotListAlertsForRepo', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.dependabotListAlertsForRepo('fakeparam', null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-dependabotListAlertsForRepo', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#dependabotGetAlert - errors', () => {
      it('should have a dependabotGetAlert function', (done) => {
        try {
          assert.equal(true, typeof a.dependabotGetAlert === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.dependabotGetAlert(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-dependabotGetAlert', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.dependabotGetAlert('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-dependabotGetAlert', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing alertNumber', (done) => {
        try {
          a.dependabotGetAlert('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'alertNumber is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-dependabotGetAlert', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#dependabotUpdateAlert - errors', () => {
      it('should have a dependabotUpdateAlert function', (done) => {
        try {
          assert.equal(true, typeof a.dependabotUpdateAlert === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.dependabotUpdateAlert(null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-dependabotUpdateAlert', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.dependabotUpdateAlert('fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-dependabotUpdateAlert', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing alertNumber', (done) => {
        try {
          a.dependabotUpdateAlert('fakeparam', 'fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'alertNumber is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-dependabotUpdateAlert', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#dependabotListRepoSecrets - errors', () => {
      it('should have a dependabotListRepoSecrets function', (done) => {
        try {
          assert.equal(true, typeof a.dependabotListRepoSecrets === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.dependabotListRepoSecrets(null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-dependabotListRepoSecrets', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.dependabotListRepoSecrets('fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-dependabotListRepoSecrets', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#dependabotGetRepoPublicKey - errors', () => {
      it('should have a dependabotGetRepoPublicKey function', (done) => {
        try {
          assert.equal(true, typeof a.dependabotGetRepoPublicKey === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.dependabotGetRepoPublicKey(null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-dependabotGetRepoPublicKey', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.dependabotGetRepoPublicKey('fakeparam', null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-dependabotGetRepoPublicKey', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#dependabotGetRepoSecret - errors', () => {
      it('should have a dependabotGetRepoSecret function', (done) => {
        try {
          assert.equal(true, typeof a.dependabotGetRepoSecret === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.dependabotGetRepoSecret(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-dependabotGetRepoSecret', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.dependabotGetRepoSecret('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-dependabotGetRepoSecret', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing secretName', (done) => {
        try {
          a.dependabotGetRepoSecret('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'secretName is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-dependabotGetRepoSecret', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#dependabotCreateOrUpdateRepoSecret - errors', () => {
      it('should have a dependabotCreateOrUpdateRepoSecret function', (done) => {
        try {
          assert.equal(true, typeof a.dependabotCreateOrUpdateRepoSecret === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.dependabotCreateOrUpdateRepoSecret(null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-dependabotCreateOrUpdateRepoSecret', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.dependabotCreateOrUpdateRepoSecret('fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-dependabotCreateOrUpdateRepoSecret', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing secretName', (done) => {
        try {
          a.dependabotCreateOrUpdateRepoSecret('fakeparam', 'fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'secretName is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-dependabotCreateOrUpdateRepoSecret', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#dependabotDeleteRepoSecret - errors', () => {
      it('should have a dependabotDeleteRepoSecret function', (done) => {
        try {
          assert.equal(true, typeof a.dependabotDeleteRepoSecret === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.dependabotDeleteRepoSecret(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-dependabotDeleteRepoSecret', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.dependabotDeleteRepoSecret('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-dependabotDeleteRepoSecret', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing secretName', (done) => {
        try {
          a.dependabotDeleteRepoSecret('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'secretName is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-dependabotDeleteRepoSecret', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#dependencyGraphDiffRange - errors', () => {
      it('should have a dependencyGraphDiffRange function', (done) => {
        try {
          assert.equal(true, typeof a.dependencyGraphDiffRange === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.dependencyGraphDiffRange(null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-dependencyGraphDiffRange', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.dependencyGraphDiffRange('fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-dependencyGraphDiffRange', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing basehead', (done) => {
        try {
          a.dependencyGraphDiffRange('fakeparam', 'fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'basehead is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-dependencyGraphDiffRange', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#dependencyGraphExportSbom - errors', () => {
      it('should have a dependencyGraphExportSbom function', (done) => {
        try {
          assert.equal(true, typeof a.dependencyGraphExportSbom === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.dependencyGraphExportSbom(null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-dependencyGraphExportSbom', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.dependencyGraphExportSbom('fakeparam', null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-dependencyGraphExportSbom', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#dependencyGraphCreateRepositorySnapshot - errors', () => {
      it('should have a dependencyGraphCreateRepositorySnapshot function', (done) => {
        try {
          assert.equal(true, typeof a.dependencyGraphCreateRepositorySnapshot === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.dependencyGraphCreateRepositorySnapshot(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-dependencyGraphCreateRepositorySnapshot', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.dependencyGraphCreateRepositorySnapshot('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-dependencyGraphCreateRepositorySnapshot', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getGistsQuery - errors', () => {
      it('should have a getGistsQuery function', (done) => {
        try {
          assert.equal(true, typeof a.getGistsQuery === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getGistsPublicQuery - errors', () => {
      it('should have a getGistsPublicQuery function', (done) => {
        try {
          assert.equal(true, typeof a.getGistsPublicQuery === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getGistsStarredQuery - errors', () => {
      it('should have a getGistsStarredQuery function', (done) => {
        try {
          assert.equal(true, typeof a.getGistsStarredQuery === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getGistsIdCommentsQuery - errors', () => {
      it('should have a getGistsIdCommentsQuery function', (done) => {
        try {
          assert.equal(true, typeof a.getGistsIdCommentsQuery === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing gistId', (done) => {
        try {
          a.getGistsIdCommentsQuery(null, null, null, (data, error) => {
            try {
              const displayE = 'gistId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getGistsIdCommentsQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#gistsListCommits - errors', () => {
      it('should have a gistsListCommits function', (done) => {
        try {
          assert.equal(true, typeof a.gistsListCommits === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing gistId', (done) => {
        try {
          a.gistsListCommits(null, null, null, (data, error) => {
            try {
              const displayE = 'gistId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-gistsListCommits', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#gistsListForks - errors', () => {
      it('should have a gistsListForks function', (done) => {
        try {
          assert.equal(true, typeof a.gistsListForks === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing gistId', (done) => {
        try {
          a.gistsListForks(null, null, null, (data, error) => {
            try {
              const displayE = 'gistId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-gistsListForks', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#gistsGetRevision - errors', () => {
      it('should have a gistsGetRevision function', (done) => {
        try {
          assert.equal(true, typeof a.gistsGetRevision === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing gistId', (done) => {
        try {
          a.gistsGetRevision(null, null, (data, error) => {
            try {
              const displayE = 'gistId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-gistsGetRevision', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing sha', (done) => {
        try {
          a.gistsGetRevision('fakeparam', null, (data, error) => {
            try {
              const displayE = 'sha is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-gistsGetRevision', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#gitGetRef - errors', () => {
      it('should have a gitGetRef function', (done) => {
        try {
          assert.equal(true, typeof a.gitGetRef === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.gitGetRef(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-gitGetRef', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.gitGetRef('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-gitGetRef', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing ref', (done) => {
        try {
          a.gitGetRef('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'ref is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-gitGetRef', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#gitignoreGetTemplate - errors', () => {
      it('should have a gitignoreGetTemplate function', (done) => {
        try {
          assert.equal(true, typeof a.gitignoreGetTemplate === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing name', (done) => {
        try {
          a.gitignoreGetTemplate(null, (data, error) => {
            try {
              const displayE = 'name is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-gitignoreGetTemplate', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getIssuesQuery - errors', () => {
      it('should have a getIssuesQuery function', (done) => {
        try {
          assert.equal(true, typeof a.getIssuesQuery === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#issuesAddAssignees - errors', () => {
      it('should have a issuesAddAssignees function', (done) => {
        try {
          assert.equal(true, typeof a.issuesAddAssignees === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.issuesAddAssignees(null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-issuesAddAssignees', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.issuesAddAssignees('fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-issuesAddAssignees', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing issueNumber', (done) => {
        try {
          a.issuesAddAssignees('fakeparam', 'fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'issueNumber is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-issuesAddAssignees', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#issuesRemoveAssignees - errors', () => {
      it('should have a issuesRemoveAssignees function', (done) => {
        try {
          assert.equal(true, typeof a.issuesRemoveAssignees === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.issuesRemoveAssignees(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-issuesRemoveAssignees', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.issuesRemoveAssignees('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-issuesRemoveAssignees', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing issueNumber', (done) => {
        try {
          a.issuesRemoveAssignees('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'issueNumber is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-issuesRemoveAssignees', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#issuesCheckUserCanBeAssignedToIssue - errors', () => {
      it('should have a issuesCheckUserCanBeAssignedToIssue function', (done) => {
        try {
          assert.equal(true, typeof a.issuesCheckUserCanBeAssignedToIssue === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.issuesCheckUserCanBeAssignedToIssue(null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-issuesCheckUserCanBeAssignedToIssue', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.issuesCheckUserCanBeAssignedToIssue('fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-issuesCheckUserCanBeAssignedToIssue', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing issueNumber', (done) => {
        try {
          a.issuesCheckUserCanBeAssignedToIssue('fakeparam', 'fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'issueNumber is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-issuesCheckUserCanBeAssignedToIssue', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing assignee', (done) => {
        try {
          a.issuesCheckUserCanBeAssignedToIssue('fakeparam', 'fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'assignee is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-issuesCheckUserCanBeAssignedToIssue', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#issuesLock - errors', () => {
      it('should have a issuesLock function', (done) => {
        try {
          assert.equal(true, typeof a.issuesLock === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.issuesLock(null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-issuesLock', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.issuesLock('fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-issuesLock', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing issueNumber', (done) => {
        try {
          a.issuesLock('fakeparam', 'fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'issueNumber is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-issuesLock', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#issuesUnlock - errors', () => {
      it('should have a issuesUnlock function', (done) => {
        try {
          assert.equal(true, typeof a.issuesUnlock === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.issuesUnlock(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-issuesUnlock', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.issuesUnlock('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-issuesUnlock', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing issueNumber', (done) => {
        try {
          a.issuesUnlock('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'issueNumber is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-issuesUnlock', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#issuesListEventsForTimeline - errors', () => {
      it('should have a issuesListEventsForTimeline function', (done) => {
        try {
          assert.equal(true, typeof a.issuesListEventsForTimeline === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.issuesListEventsForTimeline(null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-issuesListEventsForTimeline', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.issuesListEventsForTimeline('fakeparam', null, null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-issuesListEventsForTimeline', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing issueNumber', (done) => {
        try {
          a.issuesListEventsForTimeline('fakeparam', 'fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'issueNumber is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-issuesListEventsForTimeline', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#licensesGetAllCommonlyUsed - errors', () => {
      it('should have a licensesGetAllCommonlyUsed function', (done) => {
        try {
          assert.equal(true, typeof a.licensesGetAllCommonlyUsed === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#licensesGet - errors', () => {
      it('should have a licensesGet function', (done) => {
        try {
          assert.equal(true, typeof a.licensesGet === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing license', (done) => {
        try {
          a.licensesGet(null, (data, error) => {
            try {
              const displayE = 'license is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-licensesGet', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#licensesGetForRepo - errors', () => {
      it('should have a licensesGetForRepo function', (done) => {
        try {
          assert.equal(true, typeof a.licensesGetForRepo === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.licensesGetForRepo(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-licensesGetForRepo', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.licensesGetForRepo('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-licensesGetForRepo', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#metaRoot - errors', () => {
      it('should have a metaRoot function', (done) => {
        try {
          assert.equal(true, typeof a.metaRoot === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#metaGetOctocat - errors', () => {
      it('should have a metaGetOctocat function', (done) => {
        try {
          assert.equal(true, typeof a.metaGetOctocat === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#metaGetAllVersions - errors', () => {
      it('should have a metaGetAllVersions function', (done) => {
        try {
          assert.equal(true, typeof a.metaGetAllVersions === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#metaGetZen - errors', () => {
      it('should have a metaGetZen function', (done) => {
        try {
          assert.equal(true, typeof a.metaGetZen === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#migrationsListForOrg - errors', () => {
      it('should have a migrationsListForOrg function', (done) => {
        try {
          assert.equal(true, typeof a.migrationsListForOrg === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.migrationsListForOrg(null, null, null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-migrationsListForOrg', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#migrationsStartForOrg - errors', () => {
      it('should have a migrationsStartForOrg function', (done) => {
        try {
          assert.equal(true, typeof a.migrationsStartForOrg === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.migrationsStartForOrg(null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-migrationsStartForOrg', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#migrationsGetStatusForOrg - errors', () => {
      it('should have a migrationsGetStatusForOrg function', (done) => {
        try {
          assert.equal(true, typeof a.migrationsGetStatusForOrg === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.migrationsGetStatusForOrg(null, null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-migrationsGetStatusForOrg', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing migrationId', (done) => {
        try {
          a.migrationsGetStatusForOrg('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'migrationId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-migrationsGetStatusForOrg', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#migrationsDownloadArchiveForOrg - errors', () => {
      it('should have a migrationsDownloadArchiveForOrg function', (done) => {
        try {
          assert.equal(true, typeof a.migrationsDownloadArchiveForOrg === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.migrationsDownloadArchiveForOrg(null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-migrationsDownloadArchiveForOrg', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing migrationId', (done) => {
        try {
          a.migrationsDownloadArchiveForOrg('fakeparam', null, (data, error) => {
            try {
              const displayE = 'migrationId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-migrationsDownloadArchiveForOrg', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#migrationsDeleteArchiveForOrg - errors', () => {
      it('should have a migrationsDeleteArchiveForOrg function', (done) => {
        try {
          assert.equal(true, typeof a.migrationsDeleteArchiveForOrg === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.migrationsDeleteArchiveForOrg(null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-migrationsDeleteArchiveForOrg', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing migrationId', (done) => {
        try {
          a.migrationsDeleteArchiveForOrg('fakeparam', null, (data, error) => {
            try {
              const displayE = 'migrationId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-migrationsDeleteArchiveForOrg', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#migrationsUnlockRepoForOrg - errors', () => {
      it('should have a migrationsUnlockRepoForOrg function', (done) => {
        try {
          assert.equal(true, typeof a.migrationsUnlockRepoForOrg === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.migrationsUnlockRepoForOrg(null, null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-migrationsUnlockRepoForOrg', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing migrationId', (done) => {
        try {
          a.migrationsUnlockRepoForOrg('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'migrationId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-migrationsUnlockRepoForOrg', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repoName', (done) => {
        try {
          a.migrationsUnlockRepoForOrg('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'repoName is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-migrationsUnlockRepoForOrg', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#migrationsListReposForOrg - errors', () => {
      it('should have a migrationsListReposForOrg function', (done) => {
        try {
          assert.equal(true, typeof a.migrationsListReposForOrg === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.migrationsListReposForOrg(null, null, null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-migrationsListReposForOrg', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing migrationId', (done) => {
        try {
          a.migrationsListReposForOrg('fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'migrationId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-migrationsListReposForOrg', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#migrationsGetImportStatus - errors', () => {
      it('should have a migrationsGetImportStatus function', (done) => {
        try {
          assert.equal(true, typeof a.migrationsGetImportStatus === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.migrationsGetImportStatus(null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-migrationsGetImportStatus', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.migrationsGetImportStatus('fakeparam', null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-migrationsGetImportStatus', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#migrationsStartImport - errors', () => {
      it('should have a migrationsStartImport function', (done) => {
        try {
          assert.equal(true, typeof a.migrationsStartImport === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.migrationsStartImport(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-migrationsStartImport', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.migrationsStartImport('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-migrationsStartImport', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#migrationsUpdateImport - errors', () => {
      it('should have a migrationsUpdateImport function', (done) => {
        try {
          assert.equal(true, typeof a.migrationsUpdateImport === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.migrationsUpdateImport(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-migrationsUpdateImport', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.migrationsUpdateImport('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-migrationsUpdateImport', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#migrationsCancelImport - errors', () => {
      it('should have a migrationsCancelImport function', (done) => {
        try {
          assert.equal(true, typeof a.migrationsCancelImport === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.migrationsCancelImport(null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-migrationsCancelImport', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.migrationsCancelImport('fakeparam', null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-migrationsCancelImport', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#migrationsGetCommitAuthors - errors', () => {
      it('should have a migrationsGetCommitAuthors function', (done) => {
        try {
          assert.equal(true, typeof a.migrationsGetCommitAuthors === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.migrationsGetCommitAuthors(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-migrationsGetCommitAuthors', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.migrationsGetCommitAuthors('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-migrationsGetCommitAuthors', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#migrationsMapCommitAuthor - errors', () => {
      it('should have a migrationsMapCommitAuthor function', (done) => {
        try {
          assert.equal(true, typeof a.migrationsMapCommitAuthor === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.migrationsMapCommitAuthor(null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-migrationsMapCommitAuthor', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.migrationsMapCommitAuthor('fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-migrationsMapCommitAuthor', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing authorId', (done) => {
        try {
          a.migrationsMapCommitAuthor('fakeparam', 'fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'authorId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-migrationsMapCommitAuthor', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#migrationsGetLargeFiles - errors', () => {
      it('should have a migrationsGetLargeFiles function', (done) => {
        try {
          assert.equal(true, typeof a.migrationsGetLargeFiles === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.migrationsGetLargeFiles(null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-migrationsGetLargeFiles', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.migrationsGetLargeFiles('fakeparam', null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-migrationsGetLargeFiles', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#migrationsSetLfsPreference - errors', () => {
      it('should have a migrationsSetLfsPreference function', (done) => {
        try {
          assert.equal(true, typeof a.migrationsSetLfsPreference === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.migrationsSetLfsPreference(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-migrationsSetLfsPreference', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.migrationsSetLfsPreference('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-migrationsSetLfsPreference', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#migrationsListForAuthenticatedUser - errors', () => {
      it('should have a migrationsListForAuthenticatedUser function', (done) => {
        try {
          assert.equal(true, typeof a.migrationsListForAuthenticatedUser === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#migrationsStartForAuthenticatedUser - errors', () => {
      it('should have a migrationsStartForAuthenticatedUser function', (done) => {
        try {
          assert.equal(true, typeof a.migrationsStartForAuthenticatedUser === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#migrationsGetStatusForAuthenticatedUser - errors', () => {
      it('should have a migrationsGetStatusForAuthenticatedUser function', (done) => {
        try {
          assert.equal(true, typeof a.migrationsGetStatusForAuthenticatedUser === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing migrationId', (done) => {
        try {
          a.migrationsGetStatusForAuthenticatedUser(null, null, (data, error) => {
            try {
              const displayE = 'migrationId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-migrationsGetStatusForAuthenticatedUser', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#migrationsGetArchiveForAuthenticatedUser - errors', () => {
      it('should have a migrationsGetArchiveForAuthenticatedUser function', (done) => {
        try {
          assert.equal(true, typeof a.migrationsGetArchiveForAuthenticatedUser === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing migrationId', (done) => {
        try {
          a.migrationsGetArchiveForAuthenticatedUser(null, (data, error) => {
            try {
              const displayE = 'migrationId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-migrationsGetArchiveForAuthenticatedUser', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#migrationsDeleteArchiveForAuthenticatedUser - errors', () => {
      it('should have a migrationsDeleteArchiveForAuthenticatedUser function', (done) => {
        try {
          assert.equal(true, typeof a.migrationsDeleteArchiveForAuthenticatedUser === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing migrationId', (done) => {
        try {
          a.migrationsDeleteArchiveForAuthenticatedUser(null, (data, error) => {
            try {
              const displayE = 'migrationId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-migrationsDeleteArchiveForAuthenticatedUser', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#migrationsUnlockRepoForAuthenticatedUser - errors', () => {
      it('should have a migrationsUnlockRepoForAuthenticatedUser function', (done) => {
        try {
          assert.equal(true, typeof a.migrationsUnlockRepoForAuthenticatedUser === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing migrationId', (done) => {
        try {
          a.migrationsUnlockRepoForAuthenticatedUser(null, null, (data, error) => {
            try {
              const displayE = 'migrationId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-migrationsUnlockRepoForAuthenticatedUser', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repoName', (done) => {
        try {
          a.migrationsUnlockRepoForAuthenticatedUser('fakeparam', null, (data, error) => {
            try {
              const displayE = 'repoName is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-migrationsUnlockRepoForAuthenticatedUser', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#migrationsListReposForAuthenticatedUser - errors', () => {
      it('should have a migrationsListReposForAuthenticatedUser function', (done) => {
        try {
          assert.equal(true, typeof a.migrationsListReposForAuthenticatedUser === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing migrationId', (done) => {
        try {
          a.migrationsListReposForAuthenticatedUser(null, null, null, (data, error) => {
            try {
              const displayE = 'migrationId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-migrationsListReposForAuthenticatedUser', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#oidcGetOidcCustomSubTemplateForOrg - errors', () => {
      it('should have a oidcGetOidcCustomSubTemplateForOrg function', (done) => {
        try {
          assert.equal(true, typeof a.oidcGetOidcCustomSubTemplateForOrg === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.oidcGetOidcCustomSubTemplateForOrg(null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-oidcGetOidcCustomSubTemplateForOrg', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#oidcUpdateOidcCustomSubTemplateForOrg - errors', () => {
      it('should have a oidcUpdateOidcCustomSubTemplateForOrg function', (done) => {
        try {
          assert.equal(true, typeof a.oidcUpdateOidcCustomSubTemplateForOrg === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.oidcUpdateOidcCustomSubTemplateForOrg(null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-oidcUpdateOidcCustomSubTemplateForOrg', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#packagesListDockerMigrationConflictingPackagesForOrganization - errors', () => {
      it('should have a packagesListDockerMigrationConflictingPackagesForOrganization function', (done) => {
        try {
          assert.equal(true, typeof a.packagesListDockerMigrationConflictingPackagesForOrganization === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.packagesListDockerMigrationConflictingPackagesForOrganization(null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-packagesListDockerMigrationConflictingPackagesForOrganization', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#packagesListPackagesForOrganization - errors', () => {
      it('should have a packagesListPackagesForOrganization function', (done) => {
        try {
          assert.equal(true, typeof a.packagesListPackagesForOrganization === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing packageType', (done) => {
        try {
          a.packagesListPackagesForOrganization(null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'packageType is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-packagesListPackagesForOrganization', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.packagesListPackagesForOrganization('fakeparam', null, null, null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-packagesListPackagesForOrganization', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#packagesGetPackageForOrganization - errors', () => {
      it('should have a packagesGetPackageForOrganization function', (done) => {
        try {
          assert.equal(true, typeof a.packagesGetPackageForOrganization === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing packageType', (done) => {
        try {
          a.packagesGetPackageForOrganization(null, null, null, (data, error) => {
            try {
              const displayE = 'packageType is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-packagesGetPackageForOrganization', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing packageName', (done) => {
        try {
          a.packagesGetPackageForOrganization('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'packageName is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-packagesGetPackageForOrganization', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.packagesGetPackageForOrganization('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-packagesGetPackageForOrganization', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#packagesDeletePackageForOrg - errors', () => {
      it('should have a packagesDeletePackageForOrg function', (done) => {
        try {
          assert.equal(true, typeof a.packagesDeletePackageForOrg === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing packageType', (done) => {
        try {
          a.packagesDeletePackageForOrg(null, null, null, (data, error) => {
            try {
              const displayE = 'packageType is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-packagesDeletePackageForOrg', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing packageName', (done) => {
        try {
          a.packagesDeletePackageForOrg('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'packageName is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-packagesDeletePackageForOrg', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.packagesDeletePackageForOrg('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-packagesDeletePackageForOrg', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#packagesRestorePackageForOrg - errors', () => {
      it('should have a packagesRestorePackageForOrg function', (done) => {
        try {
          assert.equal(true, typeof a.packagesRestorePackageForOrg === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing packageType', (done) => {
        try {
          a.packagesRestorePackageForOrg(null, null, null, null, (data, error) => {
            try {
              const displayE = 'packageType is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-packagesRestorePackageForOrg', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing packageName', (done) => {
        try {
          a.packagesRestorePackageForOrg('fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'packageName is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-packagesRestorePackageForOrg', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.packagesRestorePackageForOrg('fakeparam', 'fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-packagesRestorePackageForOrg', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#packagesGetAllPackageVersionsForPackageOwnedByOrg - errors', () => {
      it('should have a packagesGetAllPackageVersionsForPackageOwnedByOrg function', (done) => {
        try {
          assert.equal(true, typeof a.packagesGetAllPackageVersionsForPackageOwnedByOrg === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing packageType', (done) => {
        try {
          a.packagesGetAllPackageVersionsForPackageOwnedByOrg(null, null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'packageType is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-packagesGetAllPackageVersionsForPackageOwnedByOrg', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing packageName', (done) => {
        try {
          a.packagesGetAllPackageVersionsForPackageOwnedByOrg('fakeparam', null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'packageName is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-packagesGetAllPackageVersionsForPackageOwnedByOrg', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.packagesGetAllPackageVersionsForPackageOwnedByOrg('fakeparam', 'fakeparam', null, null, null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-packagesGetAllPackageVersionsForPackageOwnedByOrg', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#packagesGetPackageVersionForOrganization - errors', () => {
      it('should have a packagesGetPackageVersionForOrganization function', (done) => {
        try {
          assert.equal(true, typeof a.packagesGetPackageVersionForOrganization === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing packageType', (done) => {
        try {
          a.packagesGetPackageVersionForOrganization(null, null, null, null, (data, error) => {
            try {
              const displayE = 'packageType is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-packagesGetPackageVersionForOrganization', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing packageName', (done) => {
        try {
          a.packagesGetPackageVersionForOrganization('fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'packageName is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-packagesGetPackageVersionForOrganization', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.packagesGetPackageVersionForOrganization('fakeparam', 'fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-packagesGetPackageVersionForOrganization', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing packageVersionId', (done) => {
        try {
          a.packagesGetPackageVersionForOrganization('fakeparam', 'fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'packageVersionId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-packagesGetPackageVersionForOrganization', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#packagesDeletePackageVersionForOrg - errors', () => {
      it('should have a packagesDeletePackageVersionForOrg function', (done) => {
        try {
          assert.equal(true, typeof a.packagesDeletePackageVersionForOrg === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing packageType', (done) => {
        try {
          a.packagesDeletePackageVersionForOrg(null, null, null, null, (data, error) => {
            try {
              const displayE = 'packageType is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-packagesDeletePackageVersionForOrg', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing packageName', (done) => {
        try {
          a.packagesDeletePackageVersionForOrg('fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'packageName is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-packagesDeletePackageVersionForOrg', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.packagesDeletePackageVersionForOrg('fakeparam', 'fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-packagesDeletePackageVersionForOrg', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing packageVersionId', (done) => {
        try {
          a.packagesDeletePackageVersionForOrg('fakeparam', 'fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'packageVersionId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-packagesDeletePackageVersionForOrg', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#packagesRestorePackageVersionForOrg - errors', () => {
      it('should have a packagesRestorePackageVersionForOrg function', (done) => {
        try {
          assert.equal(true, typeof a.packagesRestorePackageVersionForOrg === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing packageType', (done) => {
        try {
          a.packagesRestorePackageVersionForOrg(null, null, null, null, (data, error) => {
            try {
              const displayE = 'packageType is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-packagesRestorePackageVersionForOrg', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing packageName', (done) => {
        try {
          a.packagesRestorePackageVersionForOrg('fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'packageName is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-packagesRestorePackageVersionForOrg', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.packagesRestorePackageVersionForOrg('fakeparam', 'fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-packagesRestorePackageVersionForOrg', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing packageVersionId', (done) => {
        try {
          a.packagesRestorePackageVersionForOrg('fakeparam', 'fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'packageVersionId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-packagesRestorePackageVersionForOrg', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#packagesListDockerMigrationConflictingPackagesForAuthenticatedUser - errors', () => {
      it('should have a packagesListDockerMigrationConflictingPackagesForAuthenticatedUser function', (done) => {
        try {
          assert.equal(true, typeof a.packagesListDockerMigrationConflictingPackagesForAuthenticatedUser === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#packagesListPackagesForAuthenticatedUser - errors', () => {
      it('should have a packagesListPackagesForAuthenticatedUser function', (done) => {
        try {
          assert.equal(true, typeof a.packagesListPackagesForAuthenticatedUser === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing packageType', (done) => {
        try {
          a.packagesListPackagesForAuthenticatedUser(null, null, null, null, (data, error) => {
            try {
              const displayE = 'packageType is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-packagesListPackagesForAuthenticatedUser', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#packagesGetPackageForAuthenticatedUser - errors', () => {
      it('should have a packagesGetPackageForAuthenticatedUser function', (done) => {
        try {
          assert.equal(true, typeof a.packagesGetPackageForAuthenticatedUser === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing packageType', (done) => {
        try {
          a.packagesGetPackageForAuthenticatedUser(null, null, (data, error) => {
            try {
              const displayE = 'packageType is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-packagesGetPackageForAuthenticatedUser', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing packageName', (done) => {
        try {
          a.packagesGetPackageForAuthenticatedUser('fakeparam', null, (data, error) => {
            try {
              const displayE = 'packageName is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-packagesGetPackageForAuthenticatedUser', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#packagesDeletePackageForAuthenticatedUser - errors', () => {
      it('should have a packagesDeletePackageForAuthenticatedUser function', (done) => {
        try {
          assert.equal(true, typeof a.packagesDeletePackageForAuthenticatedUser === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing packageType', (done) => {
        try {
          a.packagesDeletePackageForAuthenticatedUser(null, null, (data, error) => {
            try {
              const displayE = 'packageType is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-packagesDeletePackageForAuthenticatedUser', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing packageName', (done) => {
        try {
          a.packagesDeletePackageForAuthenticatedUser('fakeparam', null, (data, error) => {
            try {
              const displayE = 'packageName is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-packagesDeletePackageForAuthenticatedUser', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#packagesRestorePackageForAuthenticatedUser - errors', () => {
      it('should have a packagesRestorePackageForAuthenticatedUser function', (done) => {
        try {
          assert.equal(true, typeof a.packagesRestorePackageForAuthenticatedUser === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing packageType', (done) => {
        try {
          a.packagesRestorePackageForAuthenticatedUser(null, null, null, (data, error) => {
            try {
              const displayE = 'packageType is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-packagesRestorePackageForAuthenticatedUser', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing packageName', (done) => {
        try {
          a.packagesRestorePackageForAuthenticatedUser('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'packageName is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-packagesRestorePackageForAuthenticatedUser', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#packagesGetAllPackageVersionsForPackageOwnedByAuthenticatedUser - errors', () => {
      it('should have a packagesGetAllPackageVersionsForPackageOwnedByAuthenticatedUser function', (done) => {
        try {
          assert.equal(true, typeof a.packagesGetAllPackageVersionsForPackageOwnedByAuthenticatedUser === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing packageType', (done) => {
        try {
          a.packagesGetAllPackageVersionsForPackageOwnedByAuthenticatedUser(null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'packageType is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-packagesGetAllPackageVersionsForPackageOwnedByAuthenticatedUser', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing packageName', (done) => {
        try {
          a.packagesGetAllPackageVersionsForPackageOwnedByAuthenticatedUser('fakeparam', null, null, null, null, (data, error) => {
            try {
              const displayE = 'packageName is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-packagesGetAllPackageVersionsForPackageOwnedByAuthenticatedUser', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#packagesGetPackageVersionForAuthenticatedUser - errors', () => {
      it('should have a packagesGetPackageVersionForAuthenticatedUser function', (done) => {
        try {
          assert.equal(true, typeof a.packagesGetPackageVersionForAuthenticatedUser === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing packageType', (done) => {
        try {
          a.packagesGetPackageVersionForAuthenticatedUser(null, null, null, (data, error) => {
            try {
              const displayE = 'packageType is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-packagesGetPackageVersionForAuthenticatedUser', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing packageName', (done) => {
        try {
          a.packagesGetPackageVersionForAuthenticatedUser('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'packageName is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-packagesGetPackageVersionForAuthenticatedUser', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing packageVersionId', (done) => {
        try {
          a.packagesGetPackageVersionForAuthenticatedUser('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'packageVersionId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-packagesGetPackageVersionForAuthenticatedUser', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#packagesDeletePackageVersionForAuthenticatedUser - errors', () => {
      it('should have a packagesDeletePackageVersionForAuthenticatedUser function', (done) => {
        try {
          assert.equal(true, typeof a.packagesDeletePackageVersionForAuthenticatedUser === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing packageType', (done) => {
        try {
          a.packagesDeletePackageVersionForAuthenticatedUser(null, null, null, (data, error) => {
            try {
              const displayE = 'packageType is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-packagesDeletePackageVersionForAuthenticatedUser', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing packageName', (done) => {
        try {
          a.packagesDeletePackageVersionForAuthenticatedUser('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'packageName is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-packagesDeletePackageVersionForAuthenticatedUser', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing packageVersionId', (done) => {
        try {
          a.packagesDeletePackageVersionForAuthenticatedUser('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'packageVersionId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-packagesDeletePackageVersionForAuthenticatedUser', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#packagesRestorePackageVersionForAuthenticatedUser - errors', () => {
      it('should have a packagesRestorePackageVersionForAuthenticatedUser function', (done) => {
        try {
          assert.equal(true, typeof a.packagesRestorePackageVersionForAuthenticatedUser === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing packageType', (done) => {
        try {
          a.packagesRestorePackageVersionForAuthenticatedUser(null, null, null, (data, error) => {
            try {
              const displayE = 'packageType is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-packagesRestorePackageVersionForAuthenticatedUser', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing packageName', (done) => {
        try {
          a.packagesRestorePackageVersionForAuthenticatedUser('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'packageName is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-packagesRestorePackageVersionForAuthenticatedUser', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing packageVersionId', (done) => {
        try {
          a.packagesRestorePackageVersionForAuthenticatedUser('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'packageVersionId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-packagesRestorePackageVersionForAuthenticatedUser', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#packagesListDockerMigrationConflictingPackagesForUser - errors', () => {
      it('should have a packagesListDockerMigrationConflictingPackagesForUser function', (done) => {
        try {
          assert.equal(true, typeof a.packagesListDockerMigrationConflictingPackagesForUser === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing username', (done) => {
        try {
          a.packagesListDockerMigrationConflictingPackagesForUser(null, (data, error) => {
            try {
              const displayE = 'username is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-packagesListDockerMigrationConflictingPackagesForUser', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#packagesListPackagesForUser - errors', () => {
      it('should have a packagesListPackagesForUser function', (done) => {
        try {
          assert.equal(true, typeof a.packagesListPackagesForUser === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing packageType', (done) => {
        try {
          a.packagesListPackagesForUser(null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'packageType is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-packagesListPackagesForUser', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing username', (done) => {
        try {
          a.packagesListPackagesForUser('fakeparam', 'fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'username is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-packagesListPackagesForUser', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#packagesGetPackageForUser - errors', () => {
      it('should have a packagesGetPackageForUser function', (done) => {
        try {
          assert.equal(true, typeof a.packagesGetPackageForUser === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing packageType', (done) => {
        try {
          a.packagesGetPackageForUser(null, null, null, (data, error) => {
            try {
              const displayE = 'packageType is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-packagesGetPackageForUser', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing packageName', (done) => {
        try {
          a.packagesGetPackageForUser('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'packageName is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-packagesGetPackageForUser', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing username', (done) => {
        try {
          a.packagesGetPackageForUser('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'username is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-packagesGetPackageForUser', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#packagesDeletePackageForUser - errors', () => {
      it('should have a packagesDeletePackageForUser function', (done) => {
        try {
          assert.equal(true, typeof a.packagesDeletePackageForUser === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing packageType', (done) => {
        try {
          a.packagesDeletePackageForUser(null, null, null, (data, error) => {
            try {
              const displayE = 'packageType is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-packagesDeletePackageForUser', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing packageName', (done) => {
        try {
          a.packagesDeletePackageForUser('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'packageName is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-packagesDeletePackageForUser', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing username', (done) => {
        try {
          a.packagesDeletePackageForUser('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'username is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-packagesDeletePackageForUser', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#packagesRestorePackageForUser - errors', () => {
      it('should have a packagesRestorePackageForUser function', (done) => {
        try {
          assert.equal(true, typeof a.packagesRestorePackageForUser === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing packageType', (done) => {
        try {
          a.packagesRestorePackageForUser(null, null, null, null, (data, error) => {
            try {
              const displayE = 'packageType is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-packagesRestorePackageForUser', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing packageName', (done) => {
        try {
          a.packagesRestorePackageForUser('fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'packageName is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-packagesRestorePackageForUser', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing username', (done) => {
        try {
          a.packagesRestorePackageForUser('fakeparam', 'fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'username is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-packagesRestorePackageForUser', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#packagesGetAllPackageVersionsForPackageOwnedByUser - errors', () => {
      it('should have a packagesGetAllPackageVersionsForPackageOwnedByUser function', (done) => {
        try {
          assert.equal(true, typeof a.packagesGetAllPackageVersionsForPackageOwnedByUser === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing packageType', (done) => {
        try {
          a.packagesGetAllPackageVersionsForPackageOwnedByUser(null, null, null, (data, error) => {
            try {
              const displayE = 'packageType is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-packagesGetAllPackageVersionsForPackageOwnedByUser', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing packageName', (done) => {
        try {
          a.packagesGetAllPackageVersionsForPackageOwnedByUser('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'packageName is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-packagesGetAllPackageVersionsForPackageOwnedByUser', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing username', (done) => {
        try {
          a.packagesGetAllPackageVersionsForPackageOwnedByUser('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'username is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-packagesGetAllPackageVersionsForPackageOwnedByUser', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#packagesGetPackageVersionForUser - errors', () => {
      it('should have a packagesGetPackageVersionForUser function', (done) => {
        try {
          assert.equal(true, typeof a.packagesGetPackageVersionForUser === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing packageType', (done) => {
        try {
          a.packagesGetPackageVersionForUser(null, null, null, null, (data, error) => {
            try {
              const displayE = 'packageType is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-packagesGetPackageVersionForUser', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing packageName', (done) => {
        try {
          a.packagesGetPackageVersionForUser('fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'packageName is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-packagesGetPackageVersionForUser', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing packageVersionId', (done) => {
        try {
          a.packagesGetPackageVersionForUser('fakeparam', 'fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'packageVersionId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-packagesGetPackageVersionForUser', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing username', (done) => {
        try {
          a.packagesGetPackageVersionForUser('fakeparam', 'fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'username is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-packagesGetPackageVersionForUser', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#packagesDeletePackageVersionForUser - errors', () => {
      it('should have a packagesDeletePackageVersionForUser function', (done) => {
        try {
          assert.equal(true, typeof a.packagesDeletePackageVersionForUser === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing packageType', (done) => {
        try {
          a.packagesDeletePackageVersionForUser(null, null, null, null, (data, error) => {
            try {
              const displayE = 'packageType is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-packagesDeletePackageVersionForUser', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing packageName', (done) => {
        try {
          a.packagesDeletePackageVersionForUser('fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'packageName is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-packagesDeletePackageVersionForUser', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing username', (done) => {
        try {
          a.packagesDeletePackageVersionForUser('fakeparam', 'fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'username is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-packagesDeletePackageVersionForUser', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing packageVersionId', (done) => {
        try {
          a.packagesDeletePackageVersionForUser('fakeparam', 'fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'packageVersionId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-packagesDeletePackageVersionForUser', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#packagesRestorePackageVersionForUser - errors', () => {
      it('should have a packagesRestorePackageVersionForUser function', (done) => {
        try {
          assert.equal(true, typeof a.packagesRestorePackageVersionForUser === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing packageType', (done) => {
        try {
          a.packagesRestorePackageVersionForUser(null, null, null, null, (data, error) => {
            try {
              const displayE = 'packageType is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-packagesRestorePackageVersionForUser', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing packageName', (done) => {
        try {
          a.packagesRestorePackageVersionForUser('fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'packageName is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-packagesRestorePackageVersionForUser', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing username', (done) => {
        try {
          a.packagesRestorePackageVersionForUser('fakeparam', 'fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'username is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-packagesRestorePackageVersionForUser', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing packageVersionId', (done) => {
        try {
          a.packagesRestorePackageVersionForUser('fakeparam', 'fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'packageVersionId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-packagesRestorePackageVersionForUser', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#projectsListForOrg - errors', () => {
      it('should have a projectsListForOrg function', (done) => {
        try {
          assert.equal(true, typeof a.projectsListForOrg === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.projectsListForOrg(null, null, null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-projectsListForOrg', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#projectsCreateForOrg - errors', () => {
      it('should have a projectsCreateForOrg function', (done) => {
        try {
          assert.equal(true, typeof a.projectsCreateForOrg === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.projectsCreateForOrg(null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-projectsCreateForOrg', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#projectsGetCard - errors', () => {
      it('should have a projectsGetCard function', (done) => {
        try {
          assert.equal(true, typeof a.projectsGetCard === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing cardId', (done) => {
        try {
          a.projectsGetCard(null, (data, error) => {
            try {
              const displayE = 'cardId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-projectsGetCard', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#projectsUpdateCard - errors', () => {
      it('should have a projectsUpdateCard function', (done) => {
        try {
          assert.equal(true, typeof a.projectsUpdateCard === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing cardId', (done) => {
        try {
          a.projectsUpdateCard(null, null, (data, error) => {
            try {
              const displayE = 'cardId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-projectsUpdateCard', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#projectsDeleteCard - errors', () => {
      it('should have a projectsDeleteCard function', (done) => {
        try {
          assert.equal(true, typeof a.projectsDeleteCard === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing cardId', (done) => {
        try {
          a.projectsDeleteCard(null, (data, error) => {
            try {
              const displayE = 'cardId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-projectsDeleteCard', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#projectsMoveCard - errors', () => {
      it('should have a projectsMoveCard function', (done) => {
        try {
          assert.equal(true, typeof a.projectsMoveCard === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing cardId', (done) => {
        try {
          a.projectsMoveCard(null, null, (data, error) => {
            try {
              const displayE = 'cardId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-projectsMoveCard', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#projectsGetColumn - errors', () => {
      it('should have a projectsGetColumn function', (done) => {
        try {
          assert.equal(true, typeof a.projectsGetColumn === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing columnId', (done) => {
        try {
          a.projectsGetColumn(null, (data, error) => {
            try {
              const displayE = 'columnId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-projectsGetColumn', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#projectsUpdateColumn - errors', () => {
      it('should have a projectsUpdateColumn function', (done) => {
        try {
          assert.equal(true, typeof a.projectsUpdateColumn === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing columnId', (done) => {
        try {
          a.projectsUpdateColumn(null, null, (data, error) => {
            try {
              const displayE = 'columnId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-projectsUpdateColumn', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#projectsDeleteColumn - errors', () => {
      it('should have a projectsDeleteColumn function', (done) => {
        try {
          assert.equal(true, typeof a.projectsDeleteColumn === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing columnId', (done) => {
        try {
          a.projectsDeleteColumn(null, (data, error) => {
            try {
              const displayE = 'columnId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-projectsDeleteColumn', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#projectsListCards - errors', () => {
      it('should have a projectsListCards function', (done) => {
        try {
          assert.equal(true, typeof a.projectsListCards === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing columnId', (done) => {
        try {
          a.projectsListCards(null, null, null, null, (data, error) => {
            try {
              const displayE = 'columnId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-projectsListCards', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#projectsCreateCard - errors', () => {
      it('should have a projectsCreateCard function', (done) => {
        try {
          assert.equal(true, typeof a.projectsCreateCard === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing columnId', (done) => {
        try {
          a.projectsCreateCard(null, null, (data, error) => {
            try {
              const displayE = 'columnId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-projectsCreateCard', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#projectsMoveColumn - errors', () => {
      it('should have a projectsMoveColumn function', (done) => {
        try {
          assert.equal(true, typeof a.projectsMoveColumn === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing columnId', (done) => {
        try {
          a.projectsMoveColumn(null, null, (data, error) => {
            try {
              const displayE = 'columnId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-projectsMoveColumn', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#projectsGet - errors', () => {
      it('should have a projectsGet function', (done) => {
        try {
          assert.equal(true, typeof a.projectsGet === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing projectId', (done) => {
        try {
          a.projectsGet(null, (data, error) => {
            try {
              const displayE = 'projectId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-projectsGet', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#projectsUpdate - errors', () => {
      it('should have a projectsUpdate function', (done) => {
        try {
          assert.equal(true, typeof a.projectsUpdate === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing projectId', (done) => {
        try {
          a.projectsUpdate(null, null, (data, error) => {
            try {
              const displayE = 'projectId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-projectsUpdate', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#projectsDelete - errors', () => {
      it('should have a projectsDelete function', (done) => {
        try {
          assert.equal(true, typeof a.projectsDelete === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing projectId', (done) => {
        try {
          a.projectsDelete(null, (data, error) => {
            try {
              const displayE = 'projectId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-projectsDelete', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#projectsListCollaborators - errors', () => {
      it('should have a projectsListCollaborators function', (done) => {
        try {
          assert.equal(true, typeof a.projectsListCollaborators === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing projectId', (done) => {
        try {
          a.projectsListCollaborators(null, null, null, null, (data, error) => {
            try {
              const displayE = 'projectId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-projectsListCollaborators', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#projectsAddCollaborator - errors', () => {
      it('should have a projectsAddCollaborator function', (done) => {
        try {
          assert.equal(true, typeof a.projectsAddCollaborator === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing projectId', (done) => {
        try {
          a.projectsAddCollaborator(null, null, null, (data, error) => {
            try {
              const displayE = 'projectId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-projectsAddCollaborator', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing username', (done) => {
        try {
          a.projectsAddCollaborator('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'username is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-projectsAddCollaborator', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#projectsRemoveCollaborator - errors', () => {
      it('should have a projectsRemoveCollaborator function', (done) => {
        try {
          assert.equal(true, typeof a.projectsRemoveCollaborator === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing projectId', (done) => {
        try {
          a.projectsRemoveCollaborator(null, null, (data, error) => {
            try {
              const displayE = 'projectId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-projectsRemoveCollaborator', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing username', (done) => {
        try {
          a.projectsRemoveCollaborator('fakeparam', null, (data, error) => {
            try {
              const displayE = 'username is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-projectsRemoveCollaborator', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#projectsGetPermissionForUser - errors', () => {
      it('should have a projectsGetPermissionForUser function', (done) => {
        try {
          assert.equal(true, typeof a.projectsGetPermissionForUser === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing projectId', (done) => {
        try {
          a.projectsGetPermissionForUser(null, null, (data, error) => {
            try {
              const displayE = 'projectId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-projectsGetPermissionForUser', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing username', (done) => {
        try {
          a.projectsGetPermissionForUser('fakeparam', null, (data, error) => {
            try {
              const displayE = 'username is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-projectsGetPermissionForUser', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#projectsListColumns - errors', () => {
      it('should have a projectsListColumns function', (done) => {
        try {
          assert.equal(true, typeof a.projectsListColumns === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing projectId', (done) => {
        try {
          a.projectsListColumns(null, null, null, (data, error) => {
            try {
              const displayE = 'projectId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-projectsListColumns', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#projectsCreateColumn - errors', () => {
      it('should have a projectsCreateColumn function', (done) => {
        try {
          assert.equal(true, typeof a.projectsCreateColumn === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing projectId', (done) => {
        try {
          a.projectsCreateColumn(null, null, (data, error) => {
            try {
              const displayE = 'projectId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-projectsCreateColumn', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#projectsListForRepo - errors', () => {
      it('should have a projectsListForRepo function', (done) => {
        try {
          assert.equal(true, typeof a.projectsListForRepo === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.projectsListForRepo(null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-projectsListForRepo', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.projectsListForRepo('fakeparam', null, null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-projectsListForRepo', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#projectsCreateForRepo - errors', () => {
      it('should have a projectsCreateForRepo function', (done) => {
        try {
          assert.equal(true, typeof a.projectsCreateForRepo === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.projectsCreateForRepo(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-projectsCreateForRepo', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.projectsCreateForRepo('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-projectsCreateForRepo', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#projectsCreateForAuthenticatedUser - errors', () => {
      it('should have a projectsCreateForAuthenticatedUser function', (done) => {
        try {
          assert.equal(true, typeof a.projectsCreateForAuthenticatedUser === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#projectsListForUser - errors', () => {
      it('should have a projectsListForUser function', (done) => {
        try {
          assert.equal(true, typeof a.projectsListForUser === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing username', (done) => {
        try {
          a.projectsListForUser(null, null, null, null, (data, error) => {
            try {
              const displayE = 'username is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-projectsListForUser', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#pullsCreateReplyForReviewComment - errors', () => {
      it('should have a pullsCreateReplyForReviewComment function', (done) => {
        try {
          assert.equal(true, typeof a.pullsCreateReplyForReviewComment === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.pullsCreateReplyForReviewComment(null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-pullsCreateReplyForReviewComment', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.pullsCreateReplyForReviewComment('fakeparam', null, null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-pullsCreateReplyForReviewComment', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing pullNumber', (done) => {
        try {
          a.pullsCreateReplyForReviewComment('fakeparam', 'fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'pullNumber is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-pullsCreateReplyForReviewComment', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing commentId', (done) => {
        try {
          a.pullsCreateReplyForReviewComment('fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'commentId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-pullsCreateReplyForReviewComment', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#pullsListRequestedReviewers - errors', () => {
      it('should have a pullsListRequestedReviewers function', (done) => {
        try {
          assert.equal(true, typeof a.pullsListRequestedReviewers === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.pullsListRequestedReviewers(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-pullsListRequestedReviewers', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.pullsListRequestedReviewers('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-pullsListRequestedReviewers', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing pullNumber', (done) => {
        try {
          a.pullsListRequestedReviewers('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'pullNumber is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-pullsListRequestedReviewers', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#pullsRequestReviewers - errors', () => {
      it('should have a pullsRequestReviewers function', (done) => {
        try {
          assert.equal(true, typeof a.pullsRequestReviewers === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.pullsRequestReviewers(null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-pullsRequestReviewers', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.pullsRequestReviewers('fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-pullsRequestReviewers', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing pullNumber', (done) => {
        try {
          a.pullsRequestReviewers('fakeparam', 'fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'pullNumber is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-pullsRequestReviewers', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#pullsRemoveRequestedReviewers - errors', () => {
      it('should have a pullsRemoveRequestedReviewers function', (done) => {
        try {
          assert.equal(true, typeof a.pullsRemoveRequestedReviewers === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.pullsRemoveRequestedReviewers(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-pullsRemoveRequestedReviewers', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.pullsRemoveRequestedReviewers('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-pullsRemoveRequestedReviewers', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing pullNumber', (done) => {
        try {
          a.pullsRemoveRequestedReviewers('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'pullNumber is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-pullsRemoveRequestedReviewers', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#pullsListReviews - errors', () => {
      it('should have a pullsListReviews function', (done) => {
        try {
          assert.equal(true, typeof a.pullsListReviews === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.pullsListReviews(null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-pullsListReviews', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.pullsListReviews('fakeparam', null, null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-pullsListReviews', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing pullNumber', (done) => {
        try {
          a.pullsListReviews('fakeparam', 'fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'pullNumber is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-pullsListReviews', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#pullsCreateReview - errors', () => {
      it('should have a pullsCreateReview function', (done) => {
        try {
          assert.equal(true, typeof a.pullsCreateReview === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.pullsCreateReview(null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-pullsCreateReview', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.pullsCreateReview('fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-pullsCreateReview', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing pullNumber', (done) => {
        try {
          a.pullsCreateReview('fakeparam', 'fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'pullNumber is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-pullsCreateReview', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#pullsGetReview - errors', () => {
      it('should have a pullsGetReview function', (done) => {
        try {
          assert.equal(true, typeof a.pullsGetReview === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.pullsGetReview(null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-pullsGetReview', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.pullsGetReview('fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-pullsGetReview', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing pullNumber', (done) => {
        try {
          a.pullsGetReview('fakeparam', 'fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'pullNumber is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-pullsGetReview', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing reviewId', (done) => {
        try {
          a.pullsGetReview('fakeparam', 'fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'reviewId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-pullsGetReview', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#pullsUpdateReview - errors', () => {
      it('should have a pullsUpdateReview function', (done) => {
        try {
          assert.equal(true, typeof a.pullsUpdateReview === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.pullsUpdateReview(null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-pullsUpdateReview', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.pullsUpdateReview('fakeparam', null, null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-pullsUpdateReview', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing pullNumber', (done) => {
        try {
          a.pullsUpdateReview('fakeparam', 'fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'pullNumber is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-pullsUpdateReview', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing reviewId', (done) => {
        try {
          a.pullsUpdateReview('fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'reviewId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-pullsUpdateReview', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#pullsDeletePendingReview - errors', () => {
      it('should have a pullsDeletePendingReview function', (done) => {
        try {
          assert.equal(true, typeof a.pullsDeletePendingReview === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.pullsDeletePendingReview(null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-pullsDeletePendingReview', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.pullsDeletePendingReview('fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-pullsDeletePendingReview', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing pullNumber', (done) => {
        try {
          a.pullsDeletePendingReview('fakeparam', 'fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'pullNumber is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-pullsDeletePendingReview', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing reviewId', (done) => {
        try {
          a.pullsDeletePendingReview('fakeparam', 'fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'reviewId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-pullsDeletePendingReview', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#pullsListCommentsForReview - errors', () => {
      it('should have a pullsListCommentsForReview function', (done) => {
        try {
          assert.equal(true, typeof a.pullsListCommentsForReview === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.pullsListCommentsForReview(null, null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-pullsListCommentsForReview', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.pullsListCommentsForReview('fakeparam', null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-pullsListCommentsForReview', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing pullNumber', (done) => {
        try {
          a.pullsListCommentsForReview('fakeparam', 'fakeparam', null, null, null, null, (data, error) => {
            try {
              const displayE = 'pullNumber is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-pullsListCommentsForReview', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing reviewId', (done) => {
        try {
          a.pullsListCommentsForReview('fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'reviewId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-pullsListCommentsForReview', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#pullsDismissReview - errors', () => {
      it('should have a pullsDismissReview function', (done) => {
        try {
          assert.equal(true, typeof a.pullsDismissReview === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.pullsDismissReview(null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-pullsDismissReview', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.pullsDismissReview('fakeparam', null, null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-pullsDismissReview', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing pullNumber', (done) => {
        try {
          a.pullsDismissReview('fakeparam', 'fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'pullNumber is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-pullsDismissReview', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing reviewId', (done) => {
        try {
          a.pullsDismissReview('fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'reviewId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-pullsDismissReview', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#pullsSubmitReview - errors', () => {
      it('should have a pullsSubmitReview function', (done) => {
        try {
          assert.equal(true, typeof a.pullsSubmitReview === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.pullsSubmitReview(null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-pullsSubmitReview', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.pullsSubmitReview('fakeparam', null, null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-pullsSubmitReview', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing pullNumber', (done) => {
        try {
          a.pullsSubmitReview('fakeparam', 'fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'pullNumber is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-pullsSubmitReview', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing reviewId', (done) => {
        try {
          a.pullsSubmitReview('fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'reviewId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-pullsSubmitReview', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#pullsUpdateBranch - errors', () => {
      it('should have a pullsUpdateBranch function', (done) => {
        try {
          assert.equal(true, typeof a.pullsUpdateBranch === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.pullsUpdateBranch(null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-pullsUpdateBranch', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.pullsUpdateBranch('fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-pullsUpdateBranch', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing pullNumber', (done) => {
        try {
          a.pullsUpdateBranch('fakeparam', 'fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'pullNumber is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-pullsUpdateBranch', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#reactionsListForTeamDiscussionCommentInOrg - errors', () => {
      it('should have a reactionsListForTeamDiscussionCommentInOrg function', (done) => {
        try {
          assert.equal(true, typeof a.reactionsListForTeamDiscussionCommentInOrg === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.reactionsListForTeamDiscussionCommentInOrg(null, null, null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reactionsListForTeamDiscussionCommentInOrg', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing teamSlug', (done) => {
        try {
          a.reactionsListForTeamDiscussionCommentInOrg('fakeparam', null, null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'teamSlug is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reactionsListForTeamDiscussionCommentInOrg', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing discussionNumber', (done) => {
        try {
          a.reactionsListForTeamDiscussionCommentInOrg('fakeparam', 'fakeparam', null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'discussionNumber is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reactionsListForTeamDiscussionCommentInOrg', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing commentNumber', (done) => {
        try {
          a.reactionsListForTeamDiscussionCommentInOrg('fakeparam', 'fakeparam', 'fakeparam', null, null, null, null, (data, error) => {
            try {
              const displayE = 'commentNumber is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reactionsListForTeamDiscussionCommentInOrg', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#reactionsCreateForTeamDiscussionCommentInOrg - errors', () => {
      it('should have a reactionsCreateForTeamDiscussionCommentInOrg function', (done) => {
        try {
          assert.equal(true, typeof a.reactionsCreateForTeamDiscussionCommentInOrg === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.reactionsCreateForTeamDiscussionCommentInOrg(null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reactionsCreateForTeamDiscussionCommentInOrg', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing teamSlug', (done) => {
        try {
          a.reactionsCreateForTeamDiscussionCommentInOrg('fakeparam', null, null, null, null, (data, error) => {
            try {
              const displayE = 'teamSlug is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reactionsCreateForTeamDiscussionCommentInOrg', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing discussionNumber', (done) => {
        try {
          a.reactionsCreateForTeamDiscussionCommentInOrg('fakeparam', 'fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'discussionNumber is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reactionsCreateForTeamDiscussionCommentInOrg', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing commentNumber', (done) => {
        try {
          a.reactionsCreateForTeamDiscussionCommentInOrg('fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'commentNumber is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reactionsCreateForTeamDiscussionCommentInOrg', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#reactionsDeleteForTeamDiscussionComment - errors', () => {
      it('should have a reactionsDeleteForTeamDiscussionComment function', (done) => {
        try {
          assert.equal(true, typeof a.reactionsDeleteForTeamDiscussionComment === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.reactionsDeleteForTeamDiscussionComment(null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reactionsDeleteForTeamDiscussionComment', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing teamSlug', (done) => {
        try {
          a.reactionsDeleteForTeamDiscussionComment('fakeparam', null, null, null, null, (data, error) => {
            try {
              const displayE = 'teamSlug is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reactionsDeleteForTeamDiscussionComment', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing discussionNumber', (done) => {
        try {
          a.reactionsDeleteForTeamDiscussionComment('fakeparam', 'fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'discussionNumber is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reactionsDeleteForTeamDiscussionComment', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing commentNumber', (done) => {
        try {
          a.reactionsDeleteForTeamDiscussionComment('fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'commentNumber is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reactionsDeleteForTeamDiscussionComment', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing reactionId', (done) => {
        try {
          a.reactionsDeleteForTeamDiscussionComment('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'reactionId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reactionsDeleteForTeamDiscussionComment', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#reactionsListForTeamDiscussionInOrg - errors', () => {
      it('should have a reactionsListForTeamDiscussionInOrg function', (done) => {
        try {
          assert.equal(true, typeof a.reactionsListForTeamDiscussionInOrg === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.reactionsListForTeamDiscussionInOrg(null, null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reactionsListForTeamDiscussionInOrg', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing teamSlug', (done) => {
        try {
          a.reactionsListForTeamDiscussionInOrg('fakeparam', null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'teamSlug is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reactionsListForTeamDiscussionInOrg', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing discussionNumber', (done) => {
        try {
          a.reactionsListForTeamDiscussionInOrg('fakeparam', 'fakeparam', null, null, null, null, (data, error) => {
            try {
              const displayE = 'discussionNumber is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reactionsListForTeamDiscussionInOrg', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#reactionsCreateForTeamDiscussionInOrg - errors', () => {
      it('should have a reactionsCreateForTeamDiscussionInOrg function', (done) => {
        try {
          assert.equal(true, typeof a.reactionsCreateForTeamDiscussionInOrg === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.reactionsCreateForTeamDiscussionInOrg(null, null, null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reactionsCreateForTeamDiscussionInOrg', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing teamSlug', (done) => {
        try {
          a.reactionsCreateForTeamDiscussionInOrg('fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'teamSlug is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reactionsCreateForTeamDiscussionInOrg', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing discussionNumber', (done) => {
        try {
          a.reactionsCreateForTeamDiscussionInOrg('fakeparam', 'fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'discussionNumber is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reactionsCreateForTeamDiscussionInOrg', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#reactionsDeleteForTeamDiscussion - errors', () => {
      it('should have a reactionsDeleteForTeamDiscussion function', (done) => {
        try {
          assert.equal(true, typeof a.reactionsDeleteForTeamDiscussion === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.reactionsDeleteForTeamDiscussion(null, null, null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reactionsDeleteForTeamDiscussion', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing teamSlug', (done) => {
        try {
          a.reactionsDeleteForTeamDiscussion('fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'teamSlug is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reactionsDeleteForTeamDiscussion', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing discussionNumber', (done) => {
        try {
          a.reactionsDeleteForTeamDiscussion('fakeparam', 'fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'discussionNumber is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reactionsDeleteForTeamDiscussion', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing reactionId', (done) => {
        try {
          a.reactionsDeleteForTeamDiscussion('fakeparam', 'fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'reactionId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reactionsDeleteForTeamDiscussion', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#reactionsListForCommitComment - errors', () => {
      it('should have a reactionsListForCommitComment function', (done) => {
        try {
          assert.equal(true, typeof a.reactionsListForCommitComment === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.reactionsListForCommitComment(null, null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reactionsListForCommitComment', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.reactionsListForCommitComment('fakeparam', null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reactionsListForCommitComment', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing commentId', (done) => {
        try {
          a.reactionsListForCommitComment('fakeparam', 'fakeparam', null, null, null, null, (data, error) => {
            try {
              const displayE = 'commentId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reactionsListForCommitComment', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#reactionsCreateForCommitComment - errors', () => {
      it('should have a reactionsCreateForCommitComment function', (done) => {
        try {
          assert.equal(true, typeof a.reactionsCreateForCommitComment === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.reactionsCreateForCommitComment(null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reactionsCreateForCommitComment', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.reactionsCreateForCommitComment('fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reactionsCreateForCommitComment', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing commentId', (done) => {
        try {
          a.reactionsCreateForCommitComment('fakeparam', 'fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'commentId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reactionsCreateForCommitComment', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#reactionsDeleteForCommitComment - errors', () => {
      it('should have a reactionsDeleteForCommitComment function', (done) => {
        try {
          assert.equal(true, typeof a.reactionsDeleteForCommitComment === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.reactionsDeleteForCommitComment(null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reactionsDeleteForCommitComment', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.reactionsDeleteForCommitComment('fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reactionsDeleteForCommitComment', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing commentId', (done) => {
        try {
          a.reactionsDeleteForCommitComment('fakeparam', 'fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'commentId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reactionsDeleteForCommitComment', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing reactionId', (done) => {
        try {
          a.reactionsDeleteForCommitComment('fakeparam', 'fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'reactionId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reactionsDeleteForCommitComment', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#reactionsListForIssueComment - errors', () => {
      it('should have a reactionsListForIssueComment function', (done) => {
        try {
          assert.equal(true, typeof a.reactionsListForIssueComment === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.reactionsListForIssueComment(null, null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reactionsListForIssueComment', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.reactionsListForIssueComment('fakeparam', null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reactionsListForIssueComment', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing commentId', (done) => {
        try {
          a.reactionsListForIssueComment('fakeparam', 'fakeparam', null, null, null, null, (data, error) => {
            try {
              const displayE = 'commentId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reactionsListForIssueComment', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#reactionsCreateForIssueComment - errors', () => {
      it('should have a reactionsCreateForIssueComment function', (done) => {
        try {
          assert.equal(true, typeof a.reactionsCreateForIssueComment === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.reactionsCreateForIssueComment(null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reactionsCreateForIssueComment', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.reactionsCreateForIssueComment('fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reactionsCreateForIssueComment', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing commentId', (done) => {
        try {
          a.reactionsCreateForIssueComment('fakeparam', 'fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'commentId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reactionsCreateForIssueComment', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#reactionsDeleteForIssueComment - errors', () => {
      it('should have a reactionsDeleteForIssueComment function', (done) => {
        try {
          assert.equal(true, typeof a.reactionsDeleteForIssueComment === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.reactionsDeleteForIssueComment(null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reactionsDeleteForIssueComment', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.reactionsDeleteForIssueComment('fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reactionsDeleteForIssueComment', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing commentId', (done) => {
        try {
          a.reactionsDeleteForIssueComment('fakeparam', 'fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'commentId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reactionsDeleteForIssueComment', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing reactionId', (done) => {
        try {
          a.reactionsDeleteForIssueComment('fakeparam', 'fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'reactionId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reactionsDeleteForIssueComment', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#reactionsListForIssue - errors', () => {
      it('should have a reactionsListForIssue function', (done) => {
        try {
          assert.equal(true, typeof a.reactionsListForIssue === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.reactionsListForIssue(null, null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reactionsListForIssue', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.reactionsListForIssue('fakeparam', null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reactionsListForIssue', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing issueNumber', (done) => {
        try {
          a.reactionsListForIssue('fakeparam', 'fakeparam', null, null, null, null, (data, error) => {
            try {
              const displayE = 'issueNumber is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reactionsListForIssue', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#reactionsCreateForIssue - errors', () => {
      it('should have a reactionsCreateForIssue function', (done) => {
        try {
          assert.equal(true, typeof a.reactionsCreateForIssue === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.reactionsCreateForIssue(null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reactionsCreateForIssue', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.reactionsCreateForIssue('fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reactionsCreateForIssue', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing issueNumber', (done) => {
        try {
          a.reactionsCreateForIssue('fakeparam', 'fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'issueNumber is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reactionsCreateForIssue', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#reactionsDeleteForIssue - errors', () => {
      it('should have a reactionsDeleteForIssue function', (done) => {
        try {
          assert.equal(true, typeof a.reactionsDeleteForIssue === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.reactionsDeleteForIssue(null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reactionsDeleteForIssue', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.reactionsDeleteForIssue('fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reactionsDeleteForIssue', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing issueNumber', (done) => {
        try {
          a.reactionsDeleteForIssue('fakeparam', 'fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'issueNumber is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reactionsDeleteForIssue', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing reactionId', (done) => {
        try {
          a.reactionsDeleteForIssue('fakeparam', 'fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'reactionId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reactionsDeleteForIssue', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#reactionsListForPullRequestReviewComment - errors', () => {
      it('should have a reactionsListForPullRequestReviewComment function', (done) => {
        try {
          assert.equal(true, typeof a.reactionsListForPullRequestReviewComment === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.reactionsListForPullRequestReviewComment(null, null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reactionsListForPullRequestReviewComment', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.reactionsListForPullRequestReviewComment('fakeparam', null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reactionsListForPullRequestReviewComment', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing commentId', (done) => {
        try {
          a.reactionsListForPullRequestReviewComment('fakeparam', 'fakeparam', null, null, null, null, (data, error) => {
            try {
              const displayE = 'commentId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reactionsListForPullRequestReviewComment', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#reactionsCreateForPullRequestReviewComment - errors', () => {
      it('should have a reactionsCreateForPullRequestReviewComment function', (done) => {
        try {
          assert.equal(true, typeof a.reactionsCreateForPullRequestReviewComment === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.reactionsCreateForPullRequestReviewComment(null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reactionsCreateForPullRequestReviewComment', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.reactionsCreateForPullRequestReviewComment('fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reactionsCreateForPullRequestReviewComment', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing commentId', (done) => {
        try {
          a.reactionsCreateForPullRequestReviewComment('fakeparam', 'fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'commentId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reactionsCreateForPullRequestReviewComment', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#reactionsDeleteForPullRequestComment - errors', () => {
      it('should have a reactionsDeleteForPullRequestComment function', (done) => {
        try {
          assert.equal(true, typeof a.reactionsDeleteForPullRequestComment === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.reactionsDeleteForPullRequestComment(null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reactionsDeleteForPullRequestComment', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.reactionsDeleteForPullRequestComment('fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reactionsDeleteForPullRequestComment', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing commentId', (done) => {
        try {
          a.reactionsDeleteForPullRequestComment('fakeparam', 'fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'commentId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reactionsDeleteForPullRequestComment', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing reactionId', (done) => {
        try {
          a.reactionsDeleteForPullRequestComment('fakeparam', 'fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'reactionId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reactionsDeleteForPullRequestComment', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#reactionsListForRelease - errors', () => {
      it('should have a reactionsListForRelease function', (done) => {
        try {
          assert.equal(true, typeof a.reactionsListForRelease === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.reactionsListForRelease(null, null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reactionsListForRelease', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.reactionsListForRelease('fakeparam', null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reactionsListForRelease', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing releaseId', (done) => {
        try {
          a.reactionsListForRelease('fakeparam', 'fakeparam', null, null, null, null, (data, error) => {
            try {
              const displayE = 'releaseId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reactionsListForRelease', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#reactionsCreateForRelease - errors', () => {
      it('should have a reactionsCreateForRelease function', (done) => {
        try {
          assert.equal(true, typeof a.reactionsCreateForRelease === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.reactionsCreateForRelease(null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reactionsCreateForRelease', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.reactionsCreateForRelease('fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reactionsCreateForRelease', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing releaseId', (done) => {
        try {
          a.reactionsCreateForRelease('fakeparam', 'fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'releaseId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reactionsCreateForRelease', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#reactionsDeleteForRelease - errors', () => {
      it('should have a reactionsDeleteForRelease function', (done) => {
        try {
          assert.equal(true, typeof a.reactionsDeleteForRelease === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.reactionsDeleteForRelease(null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reactionsDeleteForRelease', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.reactionsDeleteForRelease('fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reactionsDeleteForRelease', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing releaseId', (done) => {
        try {
          a.reactionsDeleteForRelease('fakeparam', 'fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'releaseId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reactionsDeleteForRelease', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing reactionId', (done) => {
        try {
          a.reactionsDeleteForRelease('fakeparam', 'fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'reactionId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reactionsDeleteForRelease', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#reactionsListForTeamDiscussionCommentLegacy - errors', () => {
      it('should have a reactionsListForTeamDiscussionCommentLegacy function', (done) => {
        try {
          assert.equal(true, typeof a.reactionsListForTeamDiscussionCommentLegacy === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing teamId', (done) => {
        try {
          a.reactionsListForTeamDiscussionCommentLegacy(null, null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'teamId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reactionsListForTeamDiscussionCommentLegacy', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing discussionNumber', (done) => {
        try {
          a.reactionsListForTeamDiscussionCommentLegacy('fakeparam', null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'discussionNumber is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reactionsListForTeamDiscussionCommentLegacy', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing commentNumber', (done) => {
        try {
          a.reactionsListForTeamDiscussionCommentLegacy('fakeparam', 'fakeparam', null, null, null, null, (data, error) => {
            try {
              const displayE = 'commentNumber is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reactionsListForTeamDiscussionCommentLegacy', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#reactionsCreateForTeamDiscussionCommentLegacy - errors', () => {
      it('should have a reactionsCreateForTeamDiscussionCommentLegacy function', (done) => {
        try {
          assert.equal(true, typeof a.reactionsCreateForTeamDiscussionCommentLegacy === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing teamId', (done) => {
        try {
          a.reactionsCreateForTeamDiscussionCommentLegacy(null, null, null, null, (data, error) => {
            try {
              const displayE = 'teamId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reactionsCreateForTeamDiscussionCommentLegacy', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing discussionNumber', (done) => {
        try {
          a.reactionsCreateForTeamDiscussionCommentLegacy('fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'discussionNumber is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reactionsCreateForTeamDiscussionCommentLegacy', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing commentNumber', (done) => {
        try {
          a.reactionsCreateForTeamDiscussionCommentLegacy('fakeparam', 'fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'commentNumber is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reactionsCreateForTeamDiscussionCommentLegacy', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#reactionsListForTeamDiscussionLegacy - errors', () => {
      it('should have a reactionsListForTeamDiscussionLegacy function', (done) => {
        try {
          assert.equal(true, typeof a.reactionsListForTeamDiscussionLegacy === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing teamId', (done) => {
        try {
          a.reactionsListForTeamDiscussionLegacy(null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'teamId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reactionsListForTeamDiscussionLegacy', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing discussionNumber', (done) => {
        try {
          a.reactionsListForTeamDiscussionLegacy('fakeparam', null, null, null, null, (data, error) => {
            try {
              const displayE = 'discussionNumber is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reactionsListForTeamDiscussionLegacy', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#reactionsCreateForTeamDiscussionLegacy - errors', () => {
      it('should have a reactionsCreateForTeamDiscussionLegacy function', (done) => {
        try {
          assert.equal(true, typeof a.reactionsCreateForTeamDiscussionLegacy === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing teamId', (done) => {
        try {
          a.reactionsCreateForTeamDiscussionLegacy(null, null, null, (data, error) => {
            try {
              const displayE = 'teamId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reactionsCreateForTeamDiscussionLegacy', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing discussionNumber', (done) => {
        try {
          a.reactionsCreateForTeamDiscussionLegacy('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'discussionNumber is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-reactionsCreateForTeamDiscussionLegacy', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#searchCommits - errors', () => {
      it('should have a searchCommits function', (done) => {
        try {
          assert.equal(true, typeof a.searchCommits === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing q', (done) => {
        try {
          a.searchCommits(null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'q is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-searchCommits', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#searchLabels - errors', () => {
      it('should have a searchLabels function', (done) => {
        try {
          assert.equal(true, typeof a.searchLabels === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repositoryId', (done) => {
        try {
          a.searchLabels(null, null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'repositoryId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-searchLabels', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing q', (done) => {
        try {
          a.searchLabels('fakeparam', null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'q is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-searchLabels', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getSearchRepositoriesQuery - errors', () => {
      it('should have a getSearchRepositoriesQuery function', (done) => {
        try {
          assert.equal(true, typeof a.getSearchRepositoriesQuery === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing q', (done) => {
        try {
          a.getSearchRepositoriesQuery(null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'q is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getSearchRepositoriesQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#searchTopics - errors', () => {
      it('should have a searchTopics function', (done) => {
        try {
          assert.equal(true, typeof a.searchTopics === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing q', (done) => {
        try {
          a.searchTopics(null, null, null, (data, error) => {
            try {
              const displayE = 'q is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-searchTopics', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getSearchUsersQuery - errors', () => {
      it('should have a getSearchUsersQuery function', (done) => {
        try {
          assert.equal(true, typeof a.getSearchUsersQuery === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing q', (done) => {
        try {
          a.getSearchUsersQuery(null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'q is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getSearchUsersQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#secretScanningListAlertsForEnterprise - errors', () => {
      it('should have a secretScanningListAlertsForEnterprise function', (done) => {
        try {
          assert.equal(true, typeof a.secretScanningListAlertsForEnterprise === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing enterprise', (done) => {
        try {
          a.secretScanningListAlertsForEnterprise(null, null, null, null, null, null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'enterprise is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-secretScanningListAlertsForEnterprise', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#secretScanningListAlertsForOrg - errors', () => {
      it('should have a secretScanningListAlertsForOrg function', (done) => {
        try {
          assert.equal(true, typeof a.secretScanningListAlertsForOrg === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.secretScanningListAlertsForOrg(null, null, null, null, null, null, null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-secretScanningListAlertsForOrg', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#secretScanningListAlertsForRepo - errors', () => {
      it('should have a secretScanningListAlertsForRepo function', (done) => {
        try {
          assert.equal(true, typeof a.secretScanningListAlertsForRepo === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.secretScanningListAlertsForRepo(null, null, null, null, null, null, null, null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-secretScanningListAlertsForRepo', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.secretScanningListAlertsForRepo('fakeparam', null, null, null, null, null, null, null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-secretScanningListAlertsForRepo', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#secretScanningGetAlert - errors', () => {
      it('should have a secretScanningGetAlert function', (done) => {
        try {
          assert.equal(true, typeof a.secretScanningGetAlert === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.secretScanningGetAlert(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-secretScanningGetAlert', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.secretScanningGetAlert('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-secretScanningGetAlert', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing alertNumber', (done) => {
        try {
          a.secretScanningGetAlert('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'alertNumber is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-secretScanningGetAlert', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#secretScanningUpdateAlert - errors', () => {
      it('should have a secretScanningUpdateAlert function', (done) => {
        try {
          assert.equal(true, typeof a.secretScanningUpdateAlert === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.secretScanningUpdateAlert(null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-secretScanningUpdateAlert', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.secretScanningUpdateAlert('fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-secretScanningUpdateAlert', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing alertNumber', (done) => {
        try {
          a.secretScanningUpdateAlert('fakeparam', 'fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'alertNumber is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-secretScanningUpdateAlert', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#secretScanningListLocationsForAlert - errors', () => {
      it('should have a secretScanningListLocationsForAlert function', (done) => {
        try {
          assert.equal(true, typeof a.secretScanningListLocationsForAlert === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.secretScanningListLocationsForAlert(null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-secretScanningListLocationsForAlert', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.secretScanningListLocationsForAlert('fakeparam', null, null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-secretScanningListLocationsForAlert', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing alertNumber', (done) => {
        try {
          a.secretScanningListLocationsForAlert('fakeparam', 'fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'alertNumber is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-secretScanningListLocationsForAlert', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#secretScanningCreatePushProtectionBypass - errors', () => {
      it('should have a secretScanningCreatePushProtectionBypass function', (done) => {
        try {
          assert.equal(true, typeof a.secretScanningCreatePushProtectionBypass === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.secretScanningCreatePushProtectionBypass(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-secretScanningCreatePushProtectionBypass', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.secretScanningCreatePushProtectionBypass('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-secretScanningCreatePushProtectionBypass', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#teamsGetByName - errors', () => {
      it('should have a teamsGetByName function', (done) => {
        try {
          assert.equal(true, typeof a.teamsGetByName === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.teamsGetByName(null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-teamsGetByName', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing teamSlug', (done) => {
        try {
          a.teamsGetByName('fakeparam', null, (data, error) => {
            try {
              const displayE = 'teamSlug is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-teamsGetByName', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#teamsUpdateInOrg - errors', () => {
      it('should have a teamsUpdateInOrg function', (done) => {
        try {
          assert.equal(true, typeof a.teamsUpdateInOrg === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.teamsUpdateInOrg(null, null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-teamsUpdateInOrg', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing teamSlug', (done) => {
        try {
          a.teamsUpdateInOrg('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'teamSlug is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-teamsUpdateInOrg', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#teamsDeleteInOrg - errors', () => {
      it('should have a teamsDeleteInOrg function', (done) => {
        try {
          assert.equal(true, typeof a.teamsDeleteInOrg === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.teamsDeleteInOrg(null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-teamsDeleteInOrg', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing teamSlug', (done) => {
        try {
          a.teamsDeleteInOrg('fakeparam', null, (data, error) => {
            try {
              const displayE = 'teamSlug is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-teamsDeleteInOrg', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#teamsListDiscussionsInOrg - errors', () => {
      it('should have a teamsListDiscussionsInOrg function', (done) => {
        try {
          assert.equal(true, typeof a.teamsListDiscussionsInOrg === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.teamsListDiscussionsInOrg(null, null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-teamsListDiscussionsInOrg', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing teamSlug', (done) => {
        try {
          a.teamsListDiscussionsInOrg('fakeparam', null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'teamSlug is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-teamsListDiscussionsInOrg', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#teamsCreateDiscussionInOrg - errors', () => {
      it('should have a teamsCreateDiscussionInOrg function', (done) => {
        try {
          assert.equal(true, typeof a.teamsCreateDiscussionInOrg === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.teamsCreateDiscussionInOrg(null, null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-teamsCreateDiscussionInOrg', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing teamSlug', (done) => {
        try {
          a.teamsCreateDiscussionInOrg('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'teamSlug is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-teamsCreateDiscussionInOrg', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#teamsGetDiscussionInOrg - errors', () => {
      it('should have a teamsGetDiscussionInOrg function', (done) => {
        try {
          assert.equal(true, typeof a.teamsGetDiscussionInOrg === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.teamsGetDiscussionInOrg(null, null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-teamsGetDiscussionInOrg', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing teamSlug', (done) => {
        try {
          a.teamsGetDiscussionInOrg('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'teamSlug is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-teamsGetDiscussionInOrg', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing discussionNumber', (done) => {
        try {
          a.teamsGetDiscussionInOrg('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'discussionNumber is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-teamsGetDiscussionInOrg', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#teamsUpdateDiscussionInOrg - errors', () => {
      it('should have a teamsUpdateDiscussionInOrg function', (done) => {
        try {
          assert.equal(true, typeof a.teamsUpdateDiscussionInOrg === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.teamsUpdateDiscussionInOrg(null, null, null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-teamsUpdateDiscussionInOrg', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing teamSlug', (done) => {
        try {
          a.teamsUpdateDiscussionInOrg('fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'teamSlug is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-teamsUpdateDiscussionInOrg', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing discussionNumber', (done) => {
        try {
          a.teamsUpdateDiscussionInOrg('fakeparam', 'fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'discussionNumber is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-teamsUpdateDiscussionInOrg', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#teamsDeleteDiscussionInOrg - errors', () => {
      it('should have a teamsDeleteDiscussionInOrg function', (done) => {
        try {
          assert.equal(true, typeof a.teamsDeleteDiscussionInOrg === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.teamsDeleteDiscussionInOrg(null, null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-teamsDeleteDiscussionInOrg', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing teamSlug', (done) => {
        try {
          a.teamsDeleteDiscussionInOrg('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'teamSlug is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-teamsDeleteDiscussionInOrg', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing discussionNumber', (done) => {
        try {
          a.teamsDeleteDiscussionInOrg('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'discussionNumber is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-teamsDeleteDiscussionInOrg', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#teamsListDiscussionCommentsInOrg - errors', () => {
      it('should have a teamsListDiscussionCommentsInOrg function', (done) => {
        try {
          assert.equal(true, typeof a.teamsListDiscussionCommentsInOrg === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.teamsListDiscussionCommentsInOrg(null, null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-teamsListDiscussionCommentsInOrg', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing teamSlug', (done) => {
        try {
          a.teamsListDiscussionCommentsInOrg('fakeparam', null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'teamSlug is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-teamsListDiscussionCommentsInOrg', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing discussionNumber', (done) => {
        try {
          a.teamsListDiscussionCommentsInOrg('fakeparam', 'fakeparam', null, null, null, null, (data, error) => {
            try {
              const displayE = 'discussionNumber is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-teamsListDiscussionCommentsInOrg', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#teamsCreateDiscussionCommentInOrg - errors', () => {
      it('should have a teamsCreateDiscussionCommentInOrg function', (done) => {
        try {
          assert.equal(true, typeof a.teamsCreateDiscussionCommentInOrg === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.teamsCreateDiscussionCommentInOrg(null, null, null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-teamsCreateDiscussionCommentInOrg', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing teamSlug', (done) => {
        try {
          a.teamsCreateDiscussionCommentInOrg('fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'teamSlug is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-teamsCreateDiscussionCommentInOrg', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing discussionNumber', (done) => {
        try {
          a.teamsCreateDiscussionCommentInOrg('fakeparam', 'fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'discussionNumber is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-teamsCreateDiscussionCommentInOrg', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#teamsGetDiscussionCommentInOrg - errors', () => {
      it('should have a teamsGetDiscussionCommentInOrg function', (done) => {
        try {
          assert.equal(true, typeof a.teamsGetDiscussionCommentInOrg === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.teamsGetDiscussionCommentInOrg(null, null, null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-teamsGetDiscussionCommentInOrg', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing teamSlug', (done) => {
        try {
          a.teamsGetDiscussionCommentInOrg('fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'teamSlug is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-teamsGetDiscussionCommentInOrg', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing discussionNumber', (done) => {
        try {
          a.teamsGetDiscussionCommentInOrg('fakeparam', 'fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'discussionNumber is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-teamsGetDiscussionCommentInOrg', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing commentNumber', (done) => {
        try {
          a.teamsGetDiscussionCommentInOrg('fakeparam', 'fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'commentNumber is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-teamsGetDiscussionCommentInOrg', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#teamsUpdateDiscussionCommentInOrg - errors', () => {
      it('should have a teamsUpdateDiscussionCommentInOrg function', (done) => {
        try {
          assert.equal(true, typeof a.teamsUpdateDiscussionCommentInOrg === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.teamsUpdateDiscussionCommentInOrg(null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-teamsUpdateDiscussionCommentInOrg', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing teamSlug', (done) => {
        try {
          a.teamsUpdateDiscussionCommentInOrg('fakeparam', null, null, null, null, (data, error) => {
            try {
              const displayE = 'teamSlug is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-teamsUpdateDiscussionCommentInOrg', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing discussionNumber', (done) => {
        try {
          a.teamsUpdateDiscussionCommentInOrg('fakeparam', 'fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'discussionNumber is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-teamsUpdateDiscussionCommentInOrg', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing commentNumber', (done) => {
        try {
          a.teamsUpdateDiscussionCommentInOrg('fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'commentNumber is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-teamsUpdateDiscussionCommentInOrg', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#teamsDeleteDiscussionCommentInOrg - errors', () => {
      it('should have a teamsDeleteDiscussionCommentInOrg function', (done) => {
        try {
          assert.equal(true, typeof a.teamsDeleteDiscussionCommentInOrg === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.teamsDeleteDiscussionCommentInOrg(null, null, null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-teamsDeleteDiscussionCommentInOrg', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing teamSlug', (done) => {
        try {
          a.teamsDeleteDiscussionCommentInOrg('fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'teamSlug is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-teamsDeleteDiscussionCommentInOrg', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing discussionNumber', (done) => {
        try {
          a.teamsDeleteDiscussionCommentInOrg('fakeparam', 'fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'discussionNumber is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-teamsDeleteDiscussionCommentInOrg', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing commentNumber', (done) => {
        try {
          a.teamsDeleteDiscussionCommentInOrg('fakeparam', 'fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'commentNumber is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-teamsDeleteDiscussionCommentInOrg', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#teamsListPendingInvitationsInOrg - errors', () => {
      it('should have a teamsListPendingInvitationsInOrg function', (done) => {
        try {
          assert.equal(true, typeof a.teamsListPendingInvitationsInOrg === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.teamsListPendingInvitationsInOrg(null, null, null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-teamsListPendingInvitationsInOrg', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing teamSlug', (done) => {
        try {
          a.teamsListPendingInvitationsInOrg('fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'teamSlug is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-teamsListPendingInvitationsInOrg', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#teamsListMembersInOrg - errors', () => {
      it('should have a teamsListMembersInOrg function', (done) => {
        try {
          assert.equal(true, typeof a.teamsListMembersInOrg === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.teamsListMembersInOrg(null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-teamsListMembersInOrg', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing teamSlug', (done) => {
        try {
          a.teamsListMembersInOrg('fakeparam', null, null, null, null, (data, error) => {
            try {
              const displayE = 'teamSlug is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-teamsListMembersInOrg', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#teamsGetMembershipForUserInOrg - errors', () => {
      it('should have a teamsGetMembershipForUserInOrg function', (done) => {
        try {
          assert.equal(true, typeof a.teamsGetMembershipForUserInOrg === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.teamsGetMembershipForUserInOrg(null, null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-teamsGetMembershipForUserInOrg', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing teamSlug', (done) => {
        try {
          a.teamsGetMembershipForUserInOrg('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'teamSlug is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-teamsGetMembershipForUserInOrg', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing username', (done) => {
        try {
          a.teamsGetMembershipForUserInOrg('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'username is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-teamsGetMembershipForUserInOrg', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#teamsAddOrUpdateMembershipForUserInOrg - errors', () => {
      it('should have a teamsAddOrUpdateMembershipForUserInOrg function', (done) => {
        try {
          assert.equal(true, typeof a.teamsAddOrUpdateMembershipForUserInOrg === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.teamsAddOrUpdateMembershipForUserInOrg(null, null, null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-teamsAddOrUpdateMembershipForUserInOrg', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing teamSlug', (done) => {
        try {
          a.teamsAddOrUpdateMembershipForUserInOrg('fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'teamSlug is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-teamsAddOrUpdateMembershipForUserInOrg', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing username', (done) => {
        try {
          a.teamsAddOrUpdateMembershipForUserInOrg('fakeparam', 'fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'username is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-teamsAddOrUpdateMembershipForUserInOrg', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#teamsRemoveMembershipForUserInOrg - errors', () => {
      it('should have a teamsRemoveMembershipForUserInOrg function', (done) => {
        try {
          assert.equal(true, typeof a.teamsRemoveMembershipForUserInOrg === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.teamsRemoveMembershipForUserInOrg(null, null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-teamsRemoveMembershipForUserInOrg', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing teamSlug', (done) => {
        try {
          a.teamsRemoveMembershipForUserInOrg('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'teamSlug is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-teamsRemoveMembershipForUserInOrg', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing username', (done) => {
        try {
          a.teamsRemoveMembershipForUserInOrg('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'username is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-teamsRemoveMembershipForUserInOrg', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#teamsListProjectsInOrg - errors', () => {
      it('should have a teamsListProjectsInOrg function', (done) => {
        try {
          assert.equal(true, typeof a.teamsListProjectsInOrg === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.teamsListProjectsInOrg(null, null, null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-teamsListProjectsInOrg', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing teamSlug', (done) => {
        try {
          a.teamsListProjectsInOrg('fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'teamSlug is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-teamsListProjectsInOrg', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#teamsCheckPermissionsForProjectInOrg - errors', () => {
      it('should have a teamsCheckPermissionsForProjectInOrg function', (done) => {
        try {
          assert.equal(true, typeof a.teamsCheckPermissionsForProjectInOrg === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.teamsCheckPermissionsForProjectInOrg(null, null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-teamsCheckPermissionsForProjectInOrg', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing teamSlug', (done) => {
        try {
          a.teamsCheckPermissionsForProjectInOrg('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'teamSlug is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-teamsCheckPermissionsForProjectInOrg', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing projectId', (done) => {
        try {
          a.teamsCheckPermissionsForProjectInOrg('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'projectId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-teamsCheckPermissionsForProjectInOrg', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#teamsAddOrUpdateProjectPermissionsInOrg - errors', () => {
      it('should have a teamsAddOrUpdateProjectPermissionsInOrg function', (done) => {
        try {
          assert.equal(true, typeof a.teamsAddOrUpdateProjectPermissionsInOrg === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.teamsAddOrUpdateProjectPermissionsInOrg(null, null, null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-teamsAddOrUpdateProjectPermissionsInOrg', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing teamSlug', (done) => {
        try {
          a.teamsAddOrUpdateProjectPermissionsInOrg('fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'teamSlug is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-teamsAddOrUpdateProjectPermissionsInOrg', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing projectId', (done) => {
        try {
          a.teamsAddOrUpdateProjectPermissionsInOrg('fakeparam', 'fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'projectId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-teamsAddOrUpdateProjectPermissionsInOrg', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#teamsRemoveProjectInOrg - errors', () => {
      it('should have a teamsRemoveProjectInOrg function', (done) => {
        try {
          assert.equal(true, typeof a.teamsRemoveProjectInOrg === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.teamsRemoveProjectInOrg(null, null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-teamsRemoveProjectInOrg', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing teamSlug', (done) => {
        try {
          a.teamsRemoveProjectInOrg('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'teamSlug is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-teamsRemoveProjectInOrg', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing projectId', (done) => {
        try {
          a.teamsRemoveProjectInOrg('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'projectId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-teamsRemoveProjectInOrg', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#teamsListReposInOrg - errors', () => {
      it('should have a teamsListReposInOrg function', (done) => {
        try {
          assert.equal(true, typeof a.teamsListReposInOrg === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.teamsListReposInOrg(null, null, null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-teamsListReposInOrg', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing teamSlug', (done) => {
        try {
          a.teamsListReposInOrg('fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'teamSlug is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-teamsListReposInOrg', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#teamsCheckPermissionsForRepoInOrg - errors', () => {
      it('should have a teamsCheckPermissionsForRepoInOrg function', (done) => {
        try {
          assert.equal(true, typeof a.teamsCheckPermissionsForRepoInOrg === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.teamsCheckPermissionsForRepoInOrg(null, null, null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-teamsCheckPermissionsForRepoInOrg', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing teamSlug', (done) => {
        try {
          a.teamsCheckPermissionsForRepoInOrg('fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'teamSlug is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-teamsCheckPermissionsForRepoInOrg', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.teamsCheckPermissionsForRepoInOrg('fakeparam', 'fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-teamsCheckPermissionsForRepoInOrg', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.teamsCheckPermissionsForRepoInOrg('fakeparam', 'fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-teamsCheckPermissionsForRepoInOrg', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#teamsAddOrUpdateRepoPermissionsInOrg - errors', () => {
      it('should have a teamsAddOrUpdateRepoPermissionsInOrg function', (done) => {
        try {
          assert.equal(true, typeof a.teamsAddOrUpdateRepoPermissionsInOrg === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.teamsAddOrUpdateRepoPermissionsInOrg(null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-teamsAddOrUpdateRepoPermissionsInOrg', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing teamSlug', (done) => {
        try {
          a.teamsAddOrUpdateRepoPermissionsInOrg('fakeparam', null, null, null, null, (data, error) => {
            try {
              const displayE = 'teamSlug is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-teamsAddOrUpdateRepoPermissionsInOrg', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.teamsAddOrUpdateRepoPermissionsInOrg('fakeparam', 'fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-teamsAddOrUpdateRepoPermissionsInOrg', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.teamsAddOrUpdateRepoPermissionsInOrg('fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-teamsAddOrUpdateRepoPermissionsInOrg', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#teamsRemoveRepoInOrg - errors', () => {
      it('should have a teamsRemoveRepoInOrg function', (done) => {
        try {
          assert.equal(true, typeof a.teamsRemoveRepoInOrg === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.teamsRemoveRepoInOrg(null, null, null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-teamsRemoveRepoInOrg', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing teamSlug', (done) => {
        try {
          a.teamsRemoveRepoInOrg('fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'teamSlug is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-teamsRemoveRepoInOrg', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.teamsRemoveRepoInOrg('fakeparam', 'fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-teamsRemoveRepoInOrg', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.teamsRemoveRepoInOrg('fakeparam', 'fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-teamsRemoveRepoInOrg', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#teamsListChildInOrg - errors', () => {
      it('should have a teamsListChildInOrg function', (done) => {
        try {
          assert.equal(true, typeof a.teamsListChildInOrg === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.teamsListChildInOrg(null, null, null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-teamsListChildInOrg', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing teamSlug', (done) => {
        try {
          a.teamsListChildInOrg('fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'teamSlug is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-teamsListChildInOrg', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#teamsListDiscussionsLegacy - errors', () => {
      it('should have a teamsListDiscussionsLegacy function', (done) => {
        try {
          assert.equal(true, typeof a.teamsListDiscussionsLegacy === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing teamId', (done) => {
        try {
          a.teamsListDiscussionsLegacy(null, null, null, null, (data, error) => {
            try {
              const displayE = 'teamId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-teamsListDiscussionsLegacy', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#teamsCreateDiscussionLegacy - errors', () => {
      it('should have a teamsCreateDiscussionLegacy function', (done) => {
        try {
          assert.equal(true, typeof a.teamsCreateDiscussionLegacy === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing teamId', (done) => {
        try {
          a.teamsCreateDiscussionLegacy(null, null, (data, error) => {
            try {
              const displayE = 'teamId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-teamsCreateDiscussionLegacy', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#teamsGetDiscussionLegacy - errors', () => {
      it('should have a teamsGetDiscussionLegacy function', (done) => {
        try {
          assert.equal(true, typeof a.teamsGetDiscussionLegacy === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing teamId', (done) => {
        try {
          a.teamsGetDiscussionLegacy(null, null, (data, error) => {
            try {
              const displayE = 'teamId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-teamsGetDiscussionLegacy', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing discussionNumber', (done) => {
        try {
          a.teamsGetDiscussionLegacy('fakeparam', null, (data, error) => {
            try {
              const displayE = 'discussionNumber is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-teamsGetDiscussionLegacy', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#teamsUpdateDiscussionLegacy - errors', () => {
      it('should have a teamsUpdateDiscussionLegacy function', (done) => {
        try {
          assert.equal(true, typeof a.teamsUpdateDiscussionLegacy === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing teamId', (done) => {
        try {
          a.teamsUpdateDiscussionLegacy(null, null, null, (data, error) => {
            try {
              const displayE = 'teamId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-teamsUpdateDiscussionLegacy', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing discussionNumber', (done) => {
        try {
          a.teamsUpdateDiscussionLegacy('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'discussionNumber is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-teamsUpdateDiscussionLegacy', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#teamsDeleteDiscussionLegacy - errors', () => {
      it('should have a teamsDeleteDiscussionLegacy function', (done) => {
        try {
          assert.equal(true, typeof a.teamsDeleteDiscussionLegacy === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing teamId', (done) => {
        try {
          a.teamsDeleteDiscussionLegacy(null, null, (data, error) => {
            try {
              const displayE = 'teamId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-teamsDeleteDiscussionLegacy', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing discussionNumber', (done) => {
        try {
          a.teamsDeleteDiscussionLegacy('fakeparam', null, (data, error) => {
            try {
              const displayE = 'discussionNumber is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-teamsDeleteDiscussionLegacy', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#teamsListDiscussionCommentsLegacy - errors', () => {
      it('should have a teamsListDiscussionCommentsLegacy function', (done) => {
        try {
          assert.equal(true, typeof a.teamsListDiscussionCommentsLegacy === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing teamId', (done) => {
        try {
          a.teamsListDiscussionCommentsLegacy(null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'teamId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-teamsListDiscussionCommentsLegacy', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing discussionNumber', (done) => {
        try {
          a.teamsListDiscussionCommentsLegacy('fakeparam', null, null, null, null, (data, error) => {
            try {
              const displayE = 'discussionNumber is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-teamsListDiscussionCommentsLegacy', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#teamsCreateDiscussionCommentLegacy - errors', () => {
      it('should have a teamsCreateDiscussionCommentLegacy function', (done) => {
        try {
          assert.equal(true, typeof a.teamsCreateDiscussionCommentLegacy === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing teamId', (done) => {
        try {
          a.teamsCreateDiscussionCommentLegacy(null, null, null, (data, error) => {
            try {
              const displayE = 'teamId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-teamsCreateDiscussionCommentLegacy', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing discussionNumber', (done) => {
        try {
          a.teamsCreateDiscussionCommentLegacy('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'discussionNumber is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-teamsCreateDiscussionCommentLegacy', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#teamsGetDiscussionCommentLegacy - errors', () => {
      it('should have a teamsGetDiscussionCommentLegacy function', (done) => {
        try {
          assert.equal(true, typeof a.teamsGetDiscussionCommentLegacy === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing teamId', (done) => {
        try {
          a.teamsGetDiscussionCommentLegacy(null, null, null, (data, error) => {
            try {
              const displayE = 'teamId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-teamsGetDiscussionCommentLegacy', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing discussionNumber', (done) => {
        try {
          a.teamsGetDiscussionCommentLegacy('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'discussionNumber is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-teamsGetDiscussionCommentLegacy', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing commentNumber', (done) => {
        try {
          a.teamsGetDiscussionCommentLegacy('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'commentNumber is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-teamsGetDiscussionCommentLegacy', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#teamsUpdateDiscussionCommentLegacy - errors', () => {
      it('should have a teamsUpdateDiscussionCommentLegacy function', (done) => {
        try {
          assert.equal(true, typeof a.teamsUpdateDiscussionCommentLegacy === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing teamId', (done) => {
        try {
          a.teamsUpdateDiscussionCommentLegacy(null, null, null, null, (data, error) => {
            try {
              const displayE = 'teamId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-teamsUpdateDiscussionCommentLegacy', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing discussionNumber', (done) => {
        try {
          a.teamsUpdateDiscussionCommentLegacy('fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'discussionNumber is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-teamsUpdateDiscussionCommentLegacy', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing commentNumber', (done) => {
        try {
          a.teamsUpdateDiscussionCommentLegacy('fakeparam', 'fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'commentNumber is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-teamsUpdateDiscussionCommentLegacy', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#teamsDeleteDiscussionCommentLegacy - errors', () => {
      it('should have a teamsDeleteDiscussionCommentLegacy function', (done) => {
        try {
          assert.equal(true, typeof a.teamsDeleteDiscussionCommentLegacy === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing teamId', (done) => {
        try {
          a.teamsDeleteDiscussionCommentLegacy(null, null, null, (data, error) => {
            try {
              const displayE = 'teamId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-teamsDeleteDiscussionCommentLegacy', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing discussionNumber', (done) => {
        try {
          a.teamsDeleteDiscussionCommentLegacy('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'discussionNumber is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-teamsDeleteDiscussionCommentLegacy', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing commentNumber', (done) => {
        try {
          a.teamsDeleteDiscussionCommentLegacy('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'commentNumber is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-teamsDeleteDiscussionCommentLegacy', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#teamsListPendingInvitationsLegacy - errors', () => {
      it('should have a teamsListPendingInvitationsLegacy function', (done) => {
        try {
          assert.equal(true, typeof a.teamsListPendingInvitationsLegacy === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing teamId', (done) => {
        try {
          a.teamsListPendingInvitationsLegacy(null, null, null, (data, error) => {
            try {
              const displayE = 'teamId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-teamsListPendingInvitationsLegacy', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getTeamsTeamIdMembersQuery - errors', () => {
      it('should have a getTeamsTeamIdMembersQuery function', (done) => {
        try {
          assert.equal(true, typeof a.getTeamsTeamIdMembersQuery === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing teamId', (done) => {
        try {
          a.getTeamsTeamIdMembersQuery(null, null, null, null, (data, error) => {
            try {
              const displayE = 'teamId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getTeamsTeamIdMembersQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#teamsListProjectsLegacy - errors', () => {
      it('should have a teamsListProjectsLegacy function', (done) => {
        try {
          assert.equal(true, typeof a.teamsListProjectsLegacy === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing teamId', (done) => {
        try {
          a.teamsListProjectsLegacy(null, null, null, (data, error) => {
            try {
              const displayE = 'teamId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-teamsListProjectsLegacy', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#teamsCheckPermissionsForProjectLegacy - errors', () => {
      it('should have a teamsCheckPermissionsForProjectLegacy function', (done) => {
        try {
          assert.equal(true, typeof a.teamsCheckPermissionsForProjectLegacy === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing teamId', (done) => {
        try {
          a.teamsCheckPermissionsForProjectLegacy(null, null, (data, error) => {
            try {
              const displayE = 'teamId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-teamsCheckPermissionsForProjectLegacy', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing projectId', (done) => {
        try {
          a.teamsCheckPermissionsForProjectLegacy('fakeparam', null, (data, error) => {
            try {
              const displayE = 'projectId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-teamsCheckPermissionsForProjectLegacy', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#teamsAddOrUpdateProjectPermissionsLegacy - errors', () => {
      it('should have a teamsAddOrUpdateProjectPermissionsLegacy function', (done) => {
        try {
          assert.equal(true, typeof a.teamsAddOrUpdateProjectPermissionsLegacy === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing teamId', (done) => {
        try {
          a.teamsAddOrUpdateProjectPermissionsLegacy(null, null, null, (data, error) => {
            try {
              const displayE = 'teamId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-teamsAddOrUpdateProjectPermissionsLegacy', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing projectId', (done) => {
        try {
          a.teamsAddOrUpdateProjectPermissionsLegacy('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'projectId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-teamsAddOrUpdateProjectPermissionsLegacy', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#teamsRemoveProjectLegacy - errors', () => {
      it('should have a teamsRemoveProjectLegacy function', (done) => {
        try {
          assert.equal(true, typeof a.teamsRemoveProjectLegacy === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing teamId', (done) => {
        try {
          a.teamsRemoveProjectLegacy(null, null, (data, error) => {
            try {
              const displayE = 'teamId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-teamsRemoveProjectLegacy', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing projectId', (done) => {
        try {
          a.teamsRemoveProjectLegacy('fakeparam', null, (data, error) => {
            try {
              const displayE = 'projectId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-teamsRemoveProjectLegacy', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getTeamsTeamIdReposQuery - errors', () => {
      it('should have a getTeamsTeamIdReposQuery function', (done) => {
        try {
          assert.equal(true, typeof a.getTeamsTeamIdReposQuery === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing teamId', (done) => {
        try {
          a.getTeamsTeamIdReposQuery(null, null, null, (data, error) => {
            try {
              const displayE = 'teamId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getTeamsTeamIdReposQuery', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#teamsListChildLegacy - errors', () => {
      it('should have a teamsListChildLegacy function', (done) => {
        try {
          assert.equal(true, typeof a.teamsListChildLegacy === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing teamId', (done) => {
        try {
          a.teamsListChildLegacy(null, null, null, (data, error) => {
            try {
              const displayE = 'teamId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-teamsListChildLegacy', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#codespacesListInOrganization - errors', () => {
      it('should have a codespacesListInOrganization function', (done) => {
        try {
          assert.equal(true, typeof a.codespacesListInOrganization === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.codespacesListInOrganization('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-codespacesListInOrganization', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#codespacesSetCodespacesAccess - errors', () => {
      it('should have a codespacesSetCodespacesAccess function', (done) => {
        try {
          assert.equal(true, typeof a.codespacesSetCodespacesAccess === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.codespacesSetCodespacesAccess(null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-codespacesSetCodespacesAccess', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#codespacesSetCodespacesAccessUsers - errors', () => {
      it('should have a codespacesSetCodespacesAccessUsers function', (done) => {
        try {
          assert.equal(true, typeof a.codespacesSetCodespacesAccessUsers === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.codespacesSetCodespacesAccessUsers(null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-codespacesSetCodespacesAccessUsers', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#codespacesDeleteCodespacesAccessUsers - errors', () => {
      it('should have a codespacesDeleteCodespacesAccessUsers function', (done) => {
        try {
          assert.equal(true, typeof a.codespacesDeleteCodespacesAccessUsers === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.codespacesDeleteCodespacesAccessUsers(null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-codespacesDeleteCodespacesAccessUsers', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#codespacesListOrgSecrets - errors', () => {
      it('should have a codespacesListOrgSecrets function', (done) => {
        try {
          assert.equal(true, typeof a.codespacesListOrgSecrets === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.codespacesListOrgSecrets(null, null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-codespacesListOrgSecrets', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#codespacesGetOrgPublicKey - errors', () => {
      it('should have a codespacesGetOrgPublicKey function', (done) => {
        try {
          assert.equal(true, typeof a.codespacesGetOrgPublicKey === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.codespacesGetOrgPublicKey(null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-codespacesGetOrgPublicKey', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#codespacesGetOrgSecret - errors', () => {
      it('should have a codespacesGetOrgSecret function', (done) => {
        try {
          assert.equal(true, typeof a.codespacesGetOrgSecret === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.codespacesGetOrgSecret(null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-codespacesGetOrgSecret', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing secretName', (done) => {
        try {
          a.codespacesGetOrgSecret('fakeparam', null, (data, error) => {
            try {
              const displayE = 'secretName is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-codespacesGetOrgSecret', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#codespacesCreateOrUpdateOrgSecret - errors', () => {
      it('should have a codespacesCreateOrUpdateOrgSecret function', (done) => {
        try {
          assert.equal(true, typeof a.codespacesCreateOrUpdateOrgSecret === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.codespacesCreateOrUpdateOrgSecret(null, null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-codespacesCreateOrUpdateOrgSecret', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing secretName', (done) => {
        try {
          a.codespacesCreateOrUpdateOrgSecret('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'secretName is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-codespacesCreateOrUpdateOrgSecret', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#codespacesDeleteOrgSecret - errors', () => {
      it('should have a codespacesDeleteOrgSecret function', (done) => {
        try {
          assert.equal(true, typeof a.codespacesDeleteOrgSecret === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.codespacesDeleteOrgSecret(null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-codespacesDeleteOrgSecret', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing secretName', (done) => {
        try {
          a.codespacesDeleteOrgSecret('fakeparam', null, (data, error) => {
            try {
              const displayE = 'secretName is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-codespacesDeleteOrgSecret', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#codespacesListSelectedReposForOrgSecret - errors', () => {
      it('should have a codespacesListSelectedReposForOrgSecret function', (done) => {
        try {
          assert.equal(true, typeof a.codespacesListSelectedReposForOrgSecret === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.codespacesListSelectedReposForOrgSecret(null, null, null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-codespacesListSelectedReposForOrgSecret', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing secretName', (done) => {
        try {
          a.codespacesListSelectedReposForOrgSecret('fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'secretName is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-codespacesListSelectedReposForOrgSecret', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#codespacesSetSelectedReposForOrgSecret - errors', () => {
      it('should have a codespacesSetSelectedReposForOrgSecret function', (done) => {
        try {
          assert.equal(true, typeof a.codespacesSetSelectedReposForOrgSecret === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.codespacesSetSelectedReposForOrgSecret(null, null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-codespacesSetSelectedReposForOrgSecret', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing secretName', (done) => {
        try {
          a.codespacesSetSelectedReposForOrgSecret('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'secretName is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-codespacesSetSelectedReposForOrgSecret', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#codespacesAddSelectedRepoToOrgSecret - errors', () => {
      it('should have a codespacesAddSelectedRepoToOrgSecret function', (done) => {
        try {
          assert.equal(true, typeof a.codespacesAddSelectedRepoToOrgSecret === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.codespacesAddSelectedRepoToOrgSecret(null, null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-codespacesAddSelectedRepoToOrgSecret', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing secretName', (done) => {
        try {
          a.codespacesAddSelectedRepoToOrgSecret('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'secretName is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-codespacesAddSelectedRepoToOrgSecret', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repositoryId', (done) => {
        try {
          a.codespacesAddSelectedRepoToOrgSecret('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'repositoryId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-codespacesAddSelectedRepoToOrgSecret', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#codespacesRemoveSelectedRepoFromOrgSecret - errors', () => {
      it('should have a codespacesRemoveSelectedRepoFromOrgSecret function', (done) => {
        try {
          assert.equal(true, typeof a.codespacesRemoveSelectedRepoFromOrgSecret === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.codespacesRemoveSelectedRepoFromOrgSecret(null, null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-codespacesRemoveSelectedRepoFromOrgSecret', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing secretName', (done) => {
        try {
          a.codespacesRemoveSelectedRepoFromOrgSecret('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'secretName is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-codespacesRemoveSelectedRepoFromOrgSecret', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repositoryId', (done) => {
        try {
          a.codespacesRemoveSelectedRepoFromOrgSecret('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'repositoryId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-codespacesRemoveSelectedRepoFromOrgSecret', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#codespacesGetCodespacesForUserInOrg - errors', () => {
      it('should have a codespacesGetCodespacesForUserInOrg function', (done) => {
        try {
          assert.equal(true, typeof a.codespacesGetCodespacesForUserInOrg === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.codespacesGetCodespacesForUserInOrg('fakeparam', 'fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-codespacesGetCodespacesForUserInOrg', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing username', (done) => {
        try {
          a.codespacesGetCodespacesForUserInOrg('fakeparam', 'fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'username is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-codespacesGetCodespacesForUserInOrg', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#codespacesDeleteFromOrganization - errors', () => {
      it('should have a codespacesDeleteFromOrganization function', (done) => {
        try {
          assert.equal(true, typeof a.codespacesDeleteFromOrganization === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.codespacesDeleteFromOrganization(null, null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-codespacesDeleteFromOrganization', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing username', (done) => {
        try {
          a.codespacesDeleteFromOrganization('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'username is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-codespacesDeleteFromOrganization', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing codespaceName', (done) => {
        try {
          a.codespacesDeleteFromOrganization('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'codespaceName is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-codespacesDeleteFromOrganization', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#codespacesStopInOrganization - errors', () => {
      it('should have a codespacesStopInOrganization function', (done) => {
        try {
          assert.equal(true, typeof a.codespacesStopInOrganization === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.codespacesStopInOrganization(null, null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-codespacesStopInOrganization', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing username', (done) => {
        try {
          a.codespacesStopInOrganization('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'username is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-codespacesStopInOrganization', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing codespaceName', (done) => {
        try {
          a.codespacesStopInOrganization('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'codespaceName is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-codespacesStopInOrganization', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#codespacesListInRepositoryForAuthenticatedUser - errors', () => {
      it('should have a codespacesListInRepositoryForAuthenticatedUser function', (done) => {
        try {
          assert.equal(true, typeof a.codespacesListInRepositoryForAuthenticatedUser === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.codespacesListInRepositoryForAuthenticatedUser('fakeparam', 'fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-codespacesListInRepositoryForAuthenticatedUser', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.codespacesListInRepositoryForAuthenticatedUser('fakeparam', 'fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-codespacesListInRepositoryForAuthenticatedUser', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#codespacesCreateWithRepoForAuthenticatedUser - errors', () => {
      it('should have a codespacesCreateWithRepoForAuthenticatedUser function', (done) => {
        try {
          assert.equal(true, typeof a.codespacesCreateWithRepoForAuthenticatedUser === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.codespacesCreateWithRepoForAuthenticatedUser(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-codespacesCreateWithRepoForAuthenticatedUser', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.codespacesCreateWithRepoForAuthenticatedUser('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-codespacesCreateWithRepoForAuthenticatedUser', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#codespacesListDevcontainersInRepositoryForAuthenticatedUser - errors', () => {
      it('should have a codespacesListDevcontainersInRepositoryForAuthenticatedUser function', (done) => {
        try {
          assert.equal(true, typeof a.codespacesListDevcontainersInRepositoryForAuthenticatedUser === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.codespacesListDevcontainersInRepositoryForAuthenticatedUser('fakeparam', 'fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-codespacesListDevcontainersInRepositoryForAuthenticatedUser', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.codespacesListDevcontainersInRepositoryForAuthenticatedUser('fakeparam', 'fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-codespacesListDevcontainersInRepositoryForAuthenticatedUser', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#codespacesRepoMachinesForAuthenticatedUser - errors', () => {
      it('should have a codespacesRepoMachinesForAuthenticatedUser function', (done) => {
        try {
          assert.equal(true, typeof a.codespacesRepoMachinesForAuthenticatedUser === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.codespacesRepoMachinesForAuthenticatedUser(null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-codespacesRepoMachinesForAuthenticatedUser', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.codespacesRepoMachinesForAuthenticatedUser('fakeparam', null, null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-codespacesRepoMachinesForAuthenticatedUser', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#codespacesPreFlightWithRepoForAuthenticatedUser - errors', () => {
      it('should have a codespacesPreFlightWithRepoForAuthenticatedUser function', (done) => {
        try {
          assert.equal(true, typeof a.codespacesPreFlightWithRepoForAuthenticatedUser === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.codespacesPreFlightWithRepoForAuthenticatedUser(null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-codespacesPreFlightWithRepoForAuthenticatedUser', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.codespacesPreFlightWithRepoForAuthenticatedUser('fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-codespacesPreFlightWithRepoForAuthenticatedUser', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#codespacesCheckPermissionsForDevcontainer - errors', () => {
      it('should have a codespacesCheckPermissionsForDevcontainer function', (done) => {
        try {
          assert.equal(true, typeof a.codespacesCheckPermissionsForDevcontainer === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.codespacesCheckPermissionsForDevcontainer(null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-codespacesCheckPermissionsForDevcontainer', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.codespacesCheckPermissionsForDevcontainer('fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-codespacesCheckPermissionsForDevcontainer', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing ref', (done) => {
        try {
          a.codespacesCheckPermissionsForDevcontainer('fakeparam', 'fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'ref is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-codespacesCheckPermissionsForDevcontainer', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing devcontainerPath', (done) => {
        try {
          a.codespacesCheckPermissionsForDevcontainer('fakeparam', 'fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'devcontainerPath is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-codespacesCheckPermissionsForDevcontainer', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#codespacesListRepoSecrets - errors', () => {
      it('should have a codespacesListRepoSecrets function', (done) => {
        try {
          assert.equal(true, typeof a.codespacesListRepoSecrets === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.codespacesListRepoSecrets(null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-codespacesListRepoSecrets', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.codespacesListRepoSecrets('fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-codespacesListRepoSecrets', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#codespacesGetRepoPublicKey - errors', () => {
      it('should have a codespacesGetRepoPublicKey function', (done) => {
        try {
          assert.equal(true, typeof a.codespacesGetRepoPublicKey === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.codespacesGetRepoPublicKey(null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-codespacesGetRepoPublicKey', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.codespacesGetRepoPublicKey('fakeparam', null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-codespacesGetRepoPublicKey', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#codespacesGetRepoSecret - errors', () => {
      it('should have a codespacesGetRepoSecret function', (done) => {
        try {
          assert.equal(true, typeof a.codespacesGetRepoSecret === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.codespacesGetRepoSecret(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-codespacesGetRepoSecret', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.codespacesGetRepoSecret('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-codespacesGetRepoSecret', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing secretName', (done) => {
        try {
          a.codespacesGetRepoSecret('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'secretName is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-codespacesGetRepoSecret', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#codespacesCreateOrUpdateRepoSecret - errors', () => {
      it('should have a codespacesCreateOrUpdateRepoSecret function', (done) => {
        try {
          assert.equal(true, typeof a.codespacesCreateOrUpdateRepoSecret === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.codespacesCreateOrUpdateRepoSecret(null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-codespacesCreateOrUpdateRepoSecret', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.codespacesCreateOrUpdateRepoSecret('fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-codespacesCreateOrUpdateRepoSecret', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing secretName', (done) => {
        try {
          a.codespacesCreateOrUpdateRepoSecret('fakeparam', 'fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'secretName is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-codespacesCreateOrUpdateRepoSecret', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#codespacesDeleteRepoSecret - errors', () => {
      it('should have a codespacesDeleteRepoSecret function', (done) => {
        try {
          assert.equal(true, typeof a.codespacesDeleteRepoSecret === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.codespacesDeleteRepoSecret(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-codespacesDeleteRepoSecret', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.codespacesDeleteRepoSecret('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-codespacesDeleteRepoSecret', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing secretName', (done) => {
        try {
          a.codespacesDeleteRepoSecret('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'secretName is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-codespacesDeleteRepoSecret', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#codespacesCreateWithPrForAuthenticatedUser - errors', () => {
      it('should have a codespacesCreateWithPrForAuthenticatedUser function', (done) => {
        try {
          assert.equal(true, typeof a.codespacesCreateWithPrForAuthenticatedUser === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.codespacesCreateWithPrForAuthenticatedUser(null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-codespacesCreateWithPrForAuthenticatedUser', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.codespacesCreateWithPrForAuthenticatedUser('fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-codespacesCreateWithPrForAuthenticatedUser', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing pullNumber', (done) => {
        try {
          a.codespacesCreateWithPrForAuthenticatedUser('fakeparam', 'fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'pullNumber is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-codespacesCreateWithPrForAuthenticatedUser', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#codespacesListForAuthenticatedUser - errors', () => {
      it('should have a codespacesListForAuthenticatedUser function', (done) => {
        try {
          assert.equal(true, typeof a.codespacesListForAuthenticatedUser === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#codespacesCreateForAuthenticatedUser - errors', () => {
      it('should have a codespacesCreateForAuthenticatedUser function', (done) => {
        try {
          assert.equal(true, typeof a.codespacesCreateForAuthenticatedUser === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#codespacesListSecretsForAuthenticatedUser - errors', () => {
      it('should have a codespacesListSecretsForAuthenticatedUser function', (done) => {
        try {
          assert.equal(true, typeof a.codespacesListSecretsForAuthenticatedUser === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#codespacesGetPublicKeyForAuthenticatedUser - errors', () => {
      it('should have a codespacesGetPublicKeyForAuthenticatedUser function', (done) => {
        try {
          assert.equal(true, typeof a.codespacesGetPublicKeyForAuthenticatedUser === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#codespacesGetSecretForAuthenticatedUser - errors', () => {
      it('should have a codespacesGetSecretForAuthenticatedUser function', (done) => {
        try {
          assert.equal(true, typeof a.codespacesGetSecretForAuthenticatedUser === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing secretName', (done) => {
        try {
          a.codespacesGetSecretForAuthenticatedUser(null, (data, error) => {
            try {
              const displayE = 'secretName is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-codespacesGetSecretForAuthenticatedUser', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#codespacesCreateOrUpdateSecretForAuthenticatedUser - errors', () => {
      it('should have a codespacesCreateOrUpdateSecretForAuthenticatedUser function', (done) => {
        try {
          assert.equal(true, typeof a.codespacesCreateOrUpdateSecretForAuthenticatedUser === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing secretName', (done) => {
        try {
          a.codespacesCreateOrUpdateSecretForAuthenticatedUser(null, null, (data, error) => {
            try {
              const displayE = 'secretName is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-codespacesCreateOrUpdateSecretForAuthenticatedUser', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#codespacesDeleteSecretForAuthenticatedUser - errors', () => {
      it('should have a codespacesDeleteSecretForAuthenticatedUser function', (done) => {
        try {
          assert.equal(true, typeof a.codespacesDeleteSecretForAuthenticatedUser === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing secretName', (done) => {
        try {
          a.codespacesDeleteSecretForAuthenticatedUser(null, (data, error) => {
            try {
              const displayE = 'secretName is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-codespacesDeleteSecretForAuthenticatedUser', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#codespacesListRepositoriesForSecretForAuthenticatedUser - errors', () => {
      it('should have a codespacesListRepositoriesForSecretForAuthenticatedUser function', (done) => {
        try {
          assert.equal(true, typeof a.codespacesListRepositoriesForSecretForAuthenticatedUser === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing secretName', (done) => {
        try {
          a.codespacesListRepositoriesForSecretForAuthenticatedUser(null, (data, error) => {
            try {
              const displayE = 'secretName is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-codespacesListRepositoriesForSecretForAuthenticatedUser', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#codespacesSetRepositoriesForSecretForAuthenticatedUser - errors', () => {
      it('should have a codespacesSetRepositoriesForSecretForAuthenticatedUser function', (done) => {
        try {
          assert.equal(true, typeof a.codespacesSetRepositoriesForSecretForAuthenticatedUser === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing secretName', (done) => {
        try {
          a.codespacesSetRepositoriesForSecretForAuthenticatedUser(null, null, (data, error) => {
            try {
              const displayE = 'secretName is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-codespacesSetRepositoriesForSecretForAuthenticatedUser', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#codespacesAddRepositoryForSecretForAuthenticatedUser - errors', () => {
      it('should have a codespacesAddRepositoryForSecretForAuthenticatedUser function', (done) => {
        try {
          assert.equal(true, typeof a.codespacesAddRepositoryForSecretForAuthenticatedUser === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing secretName', (done) => {
        try {
          a.codespacesAddRepositoryForSecretForAuthenticatedUser(null, null, (data, error) => {
            try {
              const displayE = 'secretName is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-codespacesAddRepositoryForSecretForAuthenticatedUser', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repositoryId', (done) => {
        try {
          a.codespacesAddRepositoryForSecretForAuthenticatedUser('fakeparam', null, (data, error) => {
            try {
              const displayE = 'repositoryId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-codespacesAddRepositoryForSecretForAuthenticatedUser', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#codespacesRemoveRepositoryForSecretForAuthenticatedUser - errors', () => {
      it('should have a codespacesRemoveRepositoryForSecretForAuthenticatedUser function', (done) => {
        try {
          assert.equal(true, typeof a.codespacesRemoveRepositoryForSecretForAuthenticatedUser === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing secretName', (done) => {
        try {
          a.codespacesRemoveRepositoryForSecretForAuthenticatedUser(null, null, (data, error) => {
            try {
              const displayE = 'secretName is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-codespacesRemoveRepositoryForSecretForAuthenticatedUser', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repositoryId', (done) => {
        try {
          a.codespacesRemoveRepositoryForSecretForAuthenticatedUser('fakeparam', null, (data, error) => {
            try {
              const displayE = 'repositoryId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-codespacesRemoveRepositoryForSecretForAuthenticatedUser', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#codespacesGetForAuthenticatedUser - errors', () => {
      it('should have a codespacesGetForAuthenticatedUser function', (done) => {
        try {
          assert.equal(true, typeof a.codespacesGetForAuthenticatedUser === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing codespaceName', (done) => {
        try {
          a.codespacesGetForAuthenticatedUser(null, (data, error) => {
            try {
              const displayE = 'codespaceName is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-codespacesGetForAuthenticatedUser', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#codespacesUpdateForAuthenticatedUser - errors', () => {
      it('should have a codespacesUpdateForAuthenticatedUser function', (done) => {
        try {
          assert.equal(true, typeof a.codespacesUpdateForAuthenticatedUser === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing codespaceName', (done) => {
        try {
          a.codespacesUpdateForAuthenticatedUser(null, null, (data, error) => {
            try {
              const displayE = 'codespaceName is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-codespacesUpdateForAuthenticatedUser', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#codespacesDeleteForAuthenticatedUser - errors', () => {
      it('should have a codespacesDeleteForAuthenticatedUser function', (done) => {
        try {
          assert.equal(true, typeof a.codespacesDeleteForAuthenticatedUser === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing codespaceName', (done) => {
        try {
          a.codespacesDeleteForAuthenticatedUser(null, (data, error) => {
            try {
              const displayE = 'codespaceName is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-codespacesDeleteForAuthenticatedUser', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#codespacesExportForAuthenticatedUser - errors', () => {
      it('should have a codespacesExportForAuthenticatedUser function', (done) => {
        try {
          assert.equal(true, typeof a.codespacesExportForAuthenticatedUser === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing codespaceName', (done) => {
        try {
          a.codespacesExportForAuthenticatedUser(null, (data, error) => {
            try {
              const displayE = 'codespaceName is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-codespacesExportForAuthenticatedUser', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#codespacesGetExportDetailsForAuthenticatedUser - errors', () => {
      it('should have a codespacesGetExportDetailsForAuthenticatedUser function', (done) => {
        try {
          assert.equal(true, typeof a.codespacesGetExportDetailsForAuthenticatedUser === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing codespaceName', (done) => {
        try {
          a.codespacesGetExportDetailsForAuthenticatedUser(null, null, (data, error) => {
            try {
              const displayE = 'codespaceName is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-codespacesGetExportDetailsForAuthenticatedUser', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing exportId', (done) => {
        try {
          a.codespacesGetExportDetailsForAuthenticatedUser('fakeparam', null, (data, error) => {
            try {
              const displayE = 'exportId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-codespacesGetExportDetailsForAuthenticatedUser', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#codespacesCodespaceMachinesForAuthenticatedUser - errors', () => {
      it('should have a codespacesCodespaceMachinesForAuthenticatedUser function', (done) => {
        try {
          assert.equal(true, typeof a.codespacesCodespaceMachinesForAuthenticatedUser === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing codespaceName', (done) => {
        try {
          a.codespacesCodespaceMachinesForAuthenticatedUser(null, (data, error) => {
            try {
              const displayE = 'codespaceName is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-codespacesCodespaceMachinesForAuthenticatedUser', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#codespacesPublishForAuthenticatedUser - errors', () => {
      it('should have a codespacesPublishForAuthenticatedUser function', (done) => {
        try {
          assert.equal(true, typeof a.codespacesPublishForAuthenticatedUser === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing codespaceName', (done) => {
        try {
          a.codespacesPublishForAuthenticatedUser(null, null, (data, error) => {
            try {
              const displayE = 'codespaceName is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-codespacesPublishForAuthenticatedUser', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#codespacesStartForAuthenticatedUser - errors', () => {
      it('should have a codespacesStartForAuthenticatedUser function', (done) => {
        try {
          assert.equal(true, typeof a.codespacesStartForAuthenticatedUser === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing codespaceName', (done) => {
        try {
          a.codespacesStartForAuthenticatedUser(null, (data, error) => {
            try {
              const displayE = 'codespaceName is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-codespacesStartForAuthenticatedUser', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#codespacesStopForAuthenticatedUser - errors', () => {
      it('should have a codespacesStopForAuthenticatedUser function', (done) => {
        try {
          assert.equal(true, typeof a.codespacesStopForAuthenticatedUser === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing codespaceName', (done) => {
        try {
          a.codespacesStopForAuthenticatedUser(null, (data, error) => {
            try {
              const displayE = 'codespaceName is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-codespacesStopForAuthenticatedUser', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#copilotListCopilotSeatsForEnterprise - errors', () => {
      it('should have a copilotListCopilotSeatsForEnterprise function', (done) => {
        try {
          assert.equal(true, typeof a.copilotListCopilotSeatsForEnterprise === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing enterprise', (done) => {
        try {
          a.copilotListCopilotSeatsForEnterprise(null, null, null, (data, error) => {
            try {
              const displayE = 'enterprise is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-copilotListCopilotSeatsForEnterprise', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#copilotUsageMetricsForEnterprise - errors', () => {
      it('should have a copilotUsageMetricsForEnterprise function', (done) => {
        try {
          assert.equal(true, typeof a.copilotUsageMetricsForEnterprise === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing enterprise', (done) => {
        try {
          a.copilotUsageMetricsForEnterprise(null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'enterprise is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-copilotUsageMetricsForEnterprise', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#copilotUsageMetricsForEnterpriseTeam - errors', () => {
      it('should have a copilotUsageMetricsForEnterpriseTeam function', (done) => {
        try {
          assert.equal(true, typeof a.copilotUsageMetricsForEnterpriseTeam === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing enterprise', (done) => {
        try {
          a.copilotUsageMetricsForEnterpriseTeam(null, null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'enterprise is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-copilotUsageMetricsForEnterpriseTeam', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing teamSlug', (done) => {
        try {
          a.copilotUsageMetricsForEnterpriseTeam('fakeparam', null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'teamSlug is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-copilotUsageMetricsForEnterpriseTeam', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#copilotGetCopilotOrganizationDetails - errors', () => {
      it('should have a copilotGetCopilotOrganizationDetails function', (done) => {
        try {
          assert.equal(true, typeof a.copilotGetCopilotOrganizationDetails === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.copilotGetCopilotOrganizationDetails(null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-copilotGetCopilotOrganizationDetails', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#copilotListCopilotSeats - errors', () => {
      it('should have a copilotListCopilotSeats function', (done) => {
        try {
          assert.equal(true, typeof a.copilotListCopilotSeats === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.copilotListCopilotSeats(null, null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-copilotListCopilotSeats', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#copilotAddCopilotSeatsForTeams - errors', () => {
      it('should have a copilotAddCopilotSeatsForTeams function', (done) => {
        try {
          assert.equal(true, typeof a.copilotAddCopilotSeatsForTeams === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.copilotAddCopilotSeatsForTeams(null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-copilotAddCopilotSeatsForTeams', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#copilotCancelCopilotSeatAssignmentForTeams - errors', () => {
      it('should have a copilotCancelCopilotSeatAssignmentForTeams function', (done) => {
        try {
          assert.equal(true, typeof a.copilotCancelCopilotSeatAssignmentForTeams === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.copilotCancelCopilotSeatAssignmentForTeams(null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-copilotCancelCopilotSeatAssignmentForTeams', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#copilotAddCopilotSeatsForUsers - errors', () => {
      it('should have a copilotAddCopilotSeatsForUsers function', (done) => {
        try {
          assert.equal(true, typeof a.copilotAddCopilotSeatsForUsers === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.copilotAddCopilotSeatsForUsers(null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-copilotAddCopilotSeatsForUsers', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#copilotCancelCopilotSeatAssignmentForUsers - errors', () => {
      it('should have a copilotCancelCopilotSeatAssignmentForUsers function', (done) => {
        try {
          assert.equal(true, typeof a.copilotCancelCopilotSeatAssignmentForUsers === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.copilotCancelCopilotSeatAssignmentForUsers(null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-copilotCancelCopilotSeatAssignmentForUsers', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#copilotUsageMetricsForOrg - errors', () => {
      it('should have a copilotUsageMetricsForOrg function', (done) => {
        try {
          assert.equal(true, typeof a.copilotUsageMetricsForOrg === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.copilotUsageMetricsForOrg(null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-copilotUsageMetricsForOrg', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#copilotGetCopilotSeatDetailsForUser - errors', () => {
      it('should have a copilotGetCopilotSeatDetailsForUser function', (done) => {
        try {
          assert.equal(true, typeof a.copilotGetCopilotSeatDetailsForUser === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.copilotGetCopilotSeatDetailsForUser(null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-copilotGetCopilotSeatDetailsForUser', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing username', (done) => {
        try {
          a.copilotGetCopilotSeatDetailsForUser('fakeparam', null, (data, error) => {
            try {
              const displayE = 'username is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-copilotGetCopilotSeatDetailsForUser', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#copilotUsageMetricsForTeam - errors', () => {
      it('should have a copilotUsageMetricsForTeam function', (done) => {
        try {
          assert.equal(true, typeof a.copilotUsageMetricsForTeam === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.copilotUsageMetricsForTeam(null, null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-copilotUsageMetricsForTeam', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing teamSlug', (done) => {
        try {
          a.copilotUsageMetricsForTeam('fakeparam', null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'teamSlug is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-copilotUsageMetricsForTeam', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#securityAdvisoriesListGlobalAdvisories - errors', () => {
      it('should have a securityAdvisoriesListGlobalAdvisories function', (done) => {
        try {
          assert.equal(true, typeof a.securityAdvisoriesListGlobalAdvisories === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#securityAdvisoriesGetGlobalAdvisory - errors', () => {
      it('should have a securityAdvisoriesGetGlobalAdvisory function', (done) => {
        try {
          assert.equal(true, typeof a.securityAdvisoriesGetGlobalAdvisory === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing ghsaId', (done) => {
        try {
          a.securityAdvisoriesGetGlobalAdvisory(null, (data, error) => {
            try {
              const displayE = 'ghsaId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-securityAdvisoriesGetGlobalAdvisory', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#securityAdvisoriesListOrgRepositoryAdvisories - errors', () => {
      it('should have a securityAdvisoriesListOrgRepositoryAdvisories function', (done) => {
        try {
          assert.equal(true, typeof a.securityAdvisoriesListOrgRepositoryAdvisories === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.securityAdvisoriesListOrgRepositoryAdvisories(null, null, null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-securityAdvisoriesListOrgRepositoryAdvisories', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#securityAdvisoriesListRepositoryAdvisories - errors', () => {
      it('should have a securityAdvisoriesListRepositoryAdvisories function', (done) => {
        try {
          assert.equal(true, typeof a.securityAdvisoriesListRepositoryAdvisories === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.securityAdvisoriesListRepositoryAdvisories(null, null, null, null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-securityAdvisoriesListRepositoryAdvisories', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.securityAdvisoriesListRepositoryAdvisories('fakeparam', null, null, null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-securityAdvisoriesListRepositoryAdvisories', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#securityAdvisoriesCreateRepositoryAdvisory - errors', () => {
      it('should have a securityAdvisoriesCreateRepositoryAdvisory function', (done) => {
        try {
          assert.equal(true, typeof a.securityAdvisoriesCreateRepositoryAdvisory === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.securityAdvisoriesCreateRepositoryAdvisory(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-securityAdvisoriesCreateRepositoryAdvisory', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.securityAdvisoriesCreateRepositoryAdvisory('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-securityAdvisoriesCreateRepositoryAdvisory', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#securityAdvisoriesCreatePrivateVulnerabilityReport - errors', () => {
      it('should have a securityAdvisoriesCreatePrivateVulnerabilityReport function', (done) => {
        try {
          assert.equal(true, typeof a.securityAdvisoriesCreatePrivateVulnerabilityReport === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.securityAdvisoriesCreatePrivateVulnerabilityReport(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-securityAdvisoriesCreatePrivateVulnerabilityReport', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.securityAdvisoriesCreatePrivateVulnerabilityReport('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-securityAdvisoriesCreatePrivateVulnerabilityReport', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#securityAdvisoriesGetRepositoryAdvisory - errors', () => {
      it('should have a securityAdvisoriesGetRepositoryAdvisory function', (done) => {
        try {
          assert.equal(true, typeof a.securityAdvisoriesGetRepositoryAdvisory === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.securityAdvisoriesGetRepositoryAdvisory(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-securityAdvisoriesGetRepositoryAdvisory', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.securityAdvisoriesGetRepositoryAdvisory('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-securityAdvisoriesGetRepositoryAdvisory', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing ghsaId', (done) => {
        try {
          a.securityAdvisoriesGetRepositoryAdvisory('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'ghsaId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-securityAdvisoriesGetRepositoryAdvisory', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#securityAdvisoriesUpdateRepositoryAdvisory - errors', () => {
      it('should have a securityAdvisoriesUpdateRepositoryAdvisory function', (done) => {
        try {
          assert.equal(true, typeof a.securityAdvisoriesUpdateRepositoryAdvisory === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.securityAdvisoriesUpdateRepositoryAdvisory(null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-securityAdvisoriesUpdateRepositoryAdvisory', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.securityAdvisoriesUpdateRepositoryAdvisory('fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-securityAdvisoriesUpdateRepositoryAdvisory', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing ghsaId', (done) => {
        try {
          a.securityAdvisoriesUpdateRepositoryAdvisory('fakeparam', 'fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'ghsaId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-securityAdvisoriesUpdateRepositoryAdvisory', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#securityAdvisoriesCreateRepositoryAdvisoryCveRequest - errors', () => {
      it('should have a securityAdvisoriesCreateRepositoryAdvisoryCveRequest function', (done) => {
        try {
          assert.equal(true, typeof a.securityAdvisoriesCreateRepositoryAdvisoryCveRequest === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.securityAdvisoriesCreateRepositoryAdvisoryCveRequest(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-securityAdvisoriesCreateRepositoryAdvisoryCveRequest', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.securityAdvisoriesCreateRepositoryAdvisoryCveRequest('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-securityAdvisoriesCreateRepositoryAdvisoryCveRequest', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing ghsaId', (done) => {
        try {
          a.securityAdvisoriesCreateRepositoryAdvisoryCveRequest('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'ghsaId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-securityAdvisoriesCreateRepositoryAdvisoryCveRequest', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#securityAdvisoriesCreateFork - errors', () => {
      it('should have a securityAdvisoriesCreateFork function', (done) => {
        try {
          assert.equal(true, typeof a.securityAdvisoriesCreateFork === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.securityAdvisoriesCreateFork(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-securityAdvisoriesCreateFork', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.securityAdvisoriesCreateFork('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-securityAdvisoriesCreateFork', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing ghsaId', (done) => {
        try {
          a.securityAdvisoriesCreateFork('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'ghsaId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-securityAdvisoriesCreateFork', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#interactionsGetRestrictionsForOrg - errors', () => {
      it('should have a interactionsGetRestrictionsForOrg function', (done) => {
        try {
          assert.equal(true, typeof a.interactionsGetRestrictionsForOrg === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.interactionsGetRestrictionsForOrg(null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-interactionsGetRestrictionsForOrg', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#interactionsSetRestrictionsForOrg - errors', () => {
      it('should have a interactionsSetRestrictionsForOrg function', (done) => {
        try {
          assert.equal(true, typeof a.interactionsSetRestrictionsForOrg === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.interactionsSetRestrictionsForOrg(null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-interactionsSetRestrictionsForOrg', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#interactionsRemoveRestrictionsForOrg - errors', () => {
      it('should have a interactionsRemoveRestrictionsForOrg function', (done) => {
        try {
          assert.equal(true, typeof a.interactionsRemoveRestrictionsForOrg === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.interactionsRemoveRestrictionsForOrg(null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-interactionsRemoveRestrictionsForOrg', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#interactionsGetRestrictionsForRepo - errors', () => {
      it('should have a interactionsGetRestrictionsForRepo function', (done) => {
        try {
          assert.equal(true, typeof a.interactionsGetRestrictionsForRepo === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.interactionsGetRestrictionsForRepo(null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-interactionsGetRestrictionsForRepo', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.interactionsGetRestrictionsForRepo('fakeparam', null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-interactionsGetRestrictionsForRepo', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#interactionsSetRestrictionsForRepo - errors', () => {
      it('should have a interactionsSetRestrictionsForRepo function', (done) => {
        try {
          assert.equal(true, typeof a.interactionsSetRestrictionsForRepo === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.interactionsSetRestrictionsForRepo(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-interactionsSetRestrictionsForRepo', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.interactionsSetRestrictionsForRepo('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-interactionsSetRestrictionsForRepo', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#interactionsRemoveRestrictionsForRepo - errors', () => {
      it('should have a interactionsRemoveRestrictionsForRepo function', (done) => {
        try {
          assert.equal(true, typeof a.interactionsRemoveRestrictionsForRepo === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.interactionsRemoveRestrictionsForRepo(null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-interactionsRemoveRestrictionsForRepo', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.interactionsRemoveRestrictionsForRepo('fakeparam', null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-interactionsRemoveRestrictionsForRepo', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#interactionsGetRestrictionsForAuthenticatedUser - errors', () => {
      it('should have a interactionsGetRestrictionsForAuthenticatedUser function', (done) => {
        try {
          assert.equal(true, typeof a.interactionsGetRestrictionsForAuthenticatedUser === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#interactionsSetRestrictionsForAuthenticatedUser - errors', () => {
      it('should have a interactionsSetRestrictionsForAuthenticatedUser function', (done) => {
        try {
          assert.equal(true, typeof a.interactionsSetRestrictionsForAuthenticatedUser === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#interactionsRemoveRestrictionsForAuthenticatedUser - errors', () => {
      it('should have a interactionsRemoveRestrictionsForAuthenticatedUser function', (done) => {
        try {
          assert.equal(true, typeof a.interactionsRemoveRestrictionsForAuthenticatedUser === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#classroomGetAnAssignment - errors', () => {
      it('should have a classroomGetAnAssignment function', (done) => {
        try {
          assert.equal(true, typeof a.classroomGetAnAssignment === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing assignmentId', (done) => {
        try {
          a.classroomGetAnAssignment(null, (data, error) => {
            try {
              const displayE = 'assignmentId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-classroomGetAnAssignment', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#classroomListAcceptedAssigmentsForAnAssignment - errors', () => {
      it('should have a classroomListAcceptedAssigmentsForAnAssignment function', (done) => {
        try {
          assert.equal(true, typeof a.classroomListAcceptedAssigmentsForAnAssignment === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing assignmentId', (done) => {
        try {
          a.classroomListAcceptedAssigmentsForAnAssignment(null, null, null, (data, error) => {
            try {
              const displayE = 'assignmentId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-classroomListAcceptedAssigmentsForAnAssignment', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#classroomGetAssignmentGrades - errors', () => {
      it('should have a classroomGetAssignmentGrades function', (done) => {
        try {
          assert.equal(true, typeof a.classroomGetAssignmentGrades === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing assignmentId', (done) => {
        try {
          a.classroomGetAssignmentGrades(null, (data, error) => {
            try {
              const displayE = 'assignmentId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-classroomGetAssignmentGrades', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#classroomListClassrooms - errors', () => {
      it('should have a classroomListClassrooms function', (done) => {
        try {
          assert.equal(true, typeof a.classroomListClassrooms === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#classroomGetAClassroom - errors', () => {
      it('should have a classroomGetAClassroom function', (done) => {
        try {
          assert.equal(true, typeof a.classroomGetAClassroom === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing classroomId', (done) => {
        try {
          a.classroomGetAClassroom(null, (data, error) => {
            try {
              const displayE = 'classroomId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-classroomGetAClassroom', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#classroomListAssignmentsForAClassroom - errors', () => {
      it('should have a classroomListAssignmentsForAClassroom function', (done) => {
        try {
          assert.equal(true, typeof a.classroomListAssignmentsForAClassroom === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing classroomId', (done) => {
        try {
          a.classroomListAssignmentsForAClassroom(null, null, null, (data, error) => {
            try {
              const displayE = 'classroomId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-classroomListAssignmentsForAClassroom', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#codeSecurityGetConfigurationsForOrg - errors', () => {
      it('should have a codeSecurityGetConfigurationsForOrg function', (done) => {
        try {
          assert.equal(true, typeof a.codeSecurityGetConfigurationsForOrg === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.codeSecurityGetConfigurationsForOrg(null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-codeSecurityGetConfigurationsForOrg', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#codeSecurityCreateConfiguration - errors', () => {
      it('should have a codeSecurityCreateConfiguration function', (done) => {
        try {
          assert.equal(true, typeof a.codeSecurityCreateConfiguration === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.codeSecurityCreateConfiguration(null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-codeSecurityCreateConfiguration', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#codeSecurityGetDefaultConfigurations - errors', () => {
      it('should have a codeSecurityGetDefaultConfigurations function', (done) => {
        try {
          assert.equal(true, typeof a.codeSecurityGetDefaultConfigurations === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.codeSecurityGetDefaultConfigurations(null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-codeSecurityGetDefaultConfigurations', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#codeSecurityDetachConfiguration - errors', () => {
      it('should have a codeSecurityDetachConfiguration function', (done) => {
        try {
          assert.equal(true, typeof a.codeSecurityDetachConfiguration === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.codeSecurityDetachConfiguration(null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-codeSecurityDetachConfiguration', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#codeSecurityGetConfiguration - errors', () => {
      it('should have a codeSecurityGetConfiguration function', (done) => {
        try {
          assert.equal(true, typeof a.codeSecurityGetConfiguration === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.codeSecurityGetConfiguration(null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-codeSecurityGetConfiguration', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing configurationId', (done) => {
        try {
          a.codeSecurityGetConfiguration('fakeparam', null, (data, error) => {
            try {
              const displayE = 'configurationId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-codeSecurityGetConfiguration', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#codeSecurityUpdateConfiguration - errors', () => {
      it('should have a codeSecurityUpdateConfiguration function', (done) => {
        try {
          assert.equal(true, typeof a.codeSecurityUpdateConfiguration === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.codeSecurityUpdateConfiguration(null, null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-codeSecurityUpdateConfiguration', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing configurationId', (done) => {
        try {
          a.codeSecurityUpdateConfiguration('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'configurationId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-codeSecurityUpdateConfiguration', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#codeSecurityDeleteConfiguration - errors', () => {
      it('should have a codeSecurityDeleteConfiguration function', (done) => {
        try {
          assert.equal(true, typeof a.codeSecurityDeleteConfiguration === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.codeSecurityDeleteConfiguration(null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-codeSecurityDeleteConfiguration', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing configurationId', (done) => {
        try {
          a.codeSecurityDeleteConfiguration('fakeparam', null, (data, error) => {
            try {
              const displayE = 'configurationId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-codeSecurityDeleteConfiguration', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#codeSecurityAttachConfiguration - errors', () => {
      it('should have a codeSecurityAttachConfiguration function', (done) => {
        try {
          assert.equal(true, typeof a.codeSecurityAttachConfiguration === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.codeSecurityAttachConfiguration(null, null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-codeSecurityAttachConfiguration', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing configurationId', (done) => {
        try {
          a.codeSecurityAttachConfiguration('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'configurationId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-codeSecurityAttachConfiguration', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#codeSecuritySetConfigurationAsDefault - errors', () => {
      it('should have a codeSecuritySetConfigurationAsDefault function', (done) => {
        try {
          assert.equal(true, typeof a.codeSecuritySetConfigurationAsDefault === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.codeSecuritySetConfigurationAsDefault(null, null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-codeSecuritySetConfigurationAsDefault', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing configurationId', (done) => {
        try {
          a.codeSecuritySetConfigurationAsDefault('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'configurationId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-codeSecuritySetConfigurationAsDefault', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#codeSecurityGetRepositoriesForConfiguration - errors', () => {
      it('should have a codeSecurityGetRepositoriesForConfiguration function', (done) => {
        try {
          assert.equal(true, typeof a.codeSecurityGetRepositoriesForConfiguration === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.codeSecurityGetRepositoriesForConfiguration(null, null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-codeSecurityGetRepositoriesForConfiguration', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing configurationId', (done) => {
        try {
          a.codeSecurityGetRepositoriesForConfiguration('fakeparam', null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'configurationId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-codeSecurityGetRepositoriesForConfiguration', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#codeSecurityGetConfigurationForRepository - errors', () => {
      it('should have a codeSecurityGetConfigurationForRepository function', (done) => {
        try {
          assert.equal(true, typeof a.codeSecurityGetConfigurationForRepository === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.codeSecurityGetConfigurationForRepository(null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-codeSecurityGetConfigurationForRepository', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.codeSecurityGetConfigurationForRepository('fakeparam', null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-codeSecurityGetConfigurationForRepository', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });
  });
});
